(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   3509263,     132183]
NotebookOptionsPosition[   2529712,     101899]
NotebookOutlinePosition[   3001210,     114946]
CellTagsIndexPosition[   2984845,     114468]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["FeynCalc 8.0", "Title",
 CellChangeTimes->{3.50097011067782*^9},
 TextAlignment->Center],

Cell["Tools for quantum field theory calculations", "Subtitle",
 TextAlignment->Center],

Cell[TextData[StyleBox["Reference Guide",
 FontWeight->"Bold"]], "Subtitle",
 PageBreakBelow->True,
 TextAlignment->Center],

Cell["Rolf Mertig and Frederik Orellana", "Subsubtitle",
 TextAlignment->Center],

Cell[TextData[{
 "HTML version: ",
 ButtonBox["http://www.feyncalc.org/",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.feyncalc.org/"], None},
  ButtonNote->"http://www.feyncalc.org/"]
}], "Subsubtitle",
 TextAlignment->Center],

Cell[BoxData[
 ButtonBox[
  RowBox[{
  "Click", " ", "to", " ", "save", " ", "this", " ", "notebook", " ", 
   "without", " ", "cache", " ", "and", " ", "FrontEndVersion", " ", "info"}],
  
  ButtonFunction:>Module[{fn}, SetDirectory[
      DirectoryName[fn = ToFileName[
         ReplaceAll["FileName", 
          NotebookInformation[
           InputNotebook[]]]]]]; 
    newfn = StringReplace[fn, ".nb" -> "NoCache.nb"]; 
    If[FileNames[newfn] =!= {}, 
      DeleteFile[newfn]]; Put[
      ReplaceAll[
       NotebookGet[
        InputNotebook[]], Condition[FrontEndVersion -> Pattern[v, 
           Blank[]], Head[v] == String] :> Sequence[]], "fcr.nb"]; 
    CopyFile["fcr.nb", newfn]; DeleteFile["fcr.nb"]],
  Evaluator->Automatic]], NotebookDefault,
 Deployed->True,
 CellTags->"ClickSave"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"$Version", ",", 
   RowBox[{"Date", "[", "]"}], ",", "$UserName"}], "}"}]], "Input",
 CellLabel->"In[1]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"\<\"8.0 for Microsoft Windows (64-bit) (February 23, 2011)\"\>", 
    ",", 
    RowBox[{"{", 
     RowBox[{
     "2011", ",", "8", ",", "20", ",", "0", ",", "48", ",", 
      "19.7536`9.048221192623904"}], "}"}], ",", "\<\"rolfm\"\>"}], "}"}], 
  TraditionalForm]], "Output",
 CellLabel->"Out[1]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions", "Section",
 CellTags->"Functions"],

Cell["Evaluation time and memory usage", "Commentary"],

Cell["\<\
This is only for timing purposes and can be omitted in general.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"absolutestarttime", "=", 
  RowBox[{"AbsoluteTime", "[", "]"}]}]], "Input",
 CellLabel->"In[2]:="],

Cell[BoxData[
 FormBox["3.5227901000296`17.29946175635067*^9", TraditionalForm]], "Output",
 CellLabel->"Out[2]="]
}, Open  ]],

Cell["<<HighEnergyPhysics`FeynCalc`", "Input",
 CellLabel->"In[3]:="],

Cell["Loading FeynCalc from C:\\Users\\rolfm\\HighEnergyPhysics", "Text",
 CellMargins->{{Inherited, Inherited}, {1, 0}},
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[TextData[{
 StyleBox["FeynCalc",
  FontWeight->"Bold"],
 " ",
 "8.0.2",
 " For help, type ?FeynCalc, open ",
 ButtonBox["FeynCalcRef8.nb",
  BaseStyle->"AddOnsLink",
  ButtonFunction:>NotebookOpen[
   "C:\\Users\\rolfm\\HighEnergyPhysics\\Documentation\\English\\FeynCalcRef8.\
nb"],
  ButtonData:>{"Short Overview", "intro"},
  ButtonNote->"Open FeynCalcRef8.nb"],
 " or visit ",
 ButtonBox["www.feyncalc.org",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.feyncalc.org/"], None},
  ButtonNote->"http://www.feyncalc.org/"]
}], "Text",
 CellMargins->{{Inherited, Inherited}, {1, 0}},
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[TextData[{
 "Loading FeynArts, see ",
 ButtonBox["www.feynarts.de",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.feynarts.de/"], None},
  ButtonNote->"http://www.feynarts.de/"],
 " for documentation"
}], "Text",
 CellMargins->{{Inherited, Inherited}, {1, 0}},
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell["FeynArts 3.4 patched for use with FeynCalc", "Text",
 CellMargins->{{Inherited, Inherited}, {1, 0}},
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell["Abbreviation", "ObjectName",
 PageBreakAbove->True,
 CellTags->"Abbreviation"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Abbreviation"],

Cell["\<\
Abbreviation is a function used by OneLoop and PaVeReduce for generating \
smaller files when saving results to the hard disk. The convention is that a \
definition like GP = GluonPropagator should be accompanied by the definition \
Abbreviation[GluonPropagator] = HoldForm[GP].\
\>", "Text",
 CellTags->"Abbreviation"],

Cell[TextData[{
 "See also:  ",
 ButtonBox["$Abbreviations",
  BaseStyle->"AddOnsLink",
  ButtonData:>"$Abbreviations",
  ButtonNote->"$Abbreviations"],
 ", ",
 ButtonBox["OneLoop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoop",
  ButtonNote->"OneLoop"],
 ", ",
 ButtonBox["PaVeReduce",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVeReduce",
  ButtonNote->"PaVeReduce"],
 ", ",
 ButtonBox["WriteOut",
  BaseStyle->"AddOnsLink",
  ButtonData:>"WriteOut",
  ButtonNote->"WriteOut"],
 ", ",
 ButtonBox["WriteOutPaVe",
  BaseStyle->"AddOnsLink",
  ButtonData:>"WriteOutPaVe",
  ButtonNote->"WriteOutPaVe"],
 ", ",
 ButtonBox["GluonPropagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonPropagator",
  ButtonNote->"GluonPropagator"],
 ", ",
 ButtonBox["GluonVertex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonVertex",
  ButtonNote->"GluonVertex"],
 ", ",
 ButtonBox["QuarkPropagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"QuarkPropagator",
  ButtonNote->"QuarkPropagator"],
 "."
}], "Text",
 CellTags->"Abbreviation"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Abbreviation"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GP", "[", 
  RowBox[{"p", ",", " ", 
   RowBox[{"{", 
    RowBox[{"\[Mu]", ",", " ", "a"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"\[Nu]", ",", " ", "b"}], "}"}]}], "]"}]], "Input",
 CellTags->"Abbreviation",
 CellLabel->"In[4]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubsuperscriptBox["\[CapitalPi]", 
    RowBox[{"a", "b"}], 
    RowBox[{"\[Mu]", "\[Nu]"}]], "(", "p", ")"}], TraditionalForm]], "Output",\

 CellTags->"Abbreviation",
 CellLabel->"Out[4]="]
}, Open  ]]
}, Open  ]],

Cell["Amplitude", "ObjectName",
 CellTags->"Amplitude"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Amplitude"],

Cell["\<\
Amplitude is a database of Feynman amplitudes. Amplitude[\"name\"] returns \
the amplitude corresponding to the string \"name\". A list of all defined \
names is obtained with Amplitude[]. New amplitudes can be added to the file \
\"Amplitude.m\". It is strongly recommended to use names that reflect the \
process. The option Gauge \[Rule] 1 means `t Hooft Feynman gauge; \
Polarization \[Rule] 0 gives unpolarized OPE-type amplitudes, Polarization \
\[Rule] 1 the polarized ones.\
\>", "Text",
 CellTags->"Amplitude"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Amplitude", "]"}]], "Input",
 CellTags->"Amplitude",
 CellLabel->"In[5]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Gauge", "\[Rule]", "1"}], ",", 
    RowBox[{"QuarkMass", "\[Rule]", "0"}], ",", 
    RowBox[{"Polarization", "\[Rule]", "1"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Amplitude",
 CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynAmp",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynAmp",
  ButtonNote->"FeynAmp"],
 "."
}], "Text",
 CellTags->"Amplitude"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Amplitude"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Amplitude", "[", "]"}], "//", "Length"}]], "Input",
 CellTags->"Amplitude",
 CellLabel->"In[6]:="],

Cell[BoxData[
 FormBox["98", TraditionalForm]], "Output",
 CellTags->"Amplitude",
 CellLabel->"Out[6]="]
}, Open  ]],

Cell["This is the amplitude of a gluon self-energy diagram.", "Text",
 CellTags->"Amplitude"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Amplitude", "[", "\"\<se1g1\>\"", "]"}]], "Input",
 CellTags->"Amplitude",
 CellLabel->"In[7]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{
    SubsuperscriptBox["\[CapitalPi]", 
     RowBox[{"e", "f"}], 
     RowBox[{"\[Beta]", "\[Sigma]"}]], "(", "q", ")"}], " ", 
   RowBox[{
    SuperscriptBox["V", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Alpha]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Beta]",
        TraditionalForm],
       TraditionalForm]}]], "(", 
    RowBox[{
     FormBox["p",
      TraditionalForm], 
     RowBox[{",", " "}], 
     FormBox[
      RowBox[{"q", "-", "p"}],
      TraditionalForm], 
     RowBox[{",", " "}], 
     FormBox[
      RowBox[{"-", "q"}],
      TraditionalForm]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["V", 
     RowBox[{
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]}]], "(", 
    RowBox[{
     FormBox[
      RowBox[{"-", "p"}],
      TraditionalForm], 
     RowBox[{",", " "}], 
     FormBox[
      RowBox[{"p", "-", "q"}],
      TraditionalForm], 
     RowBox[{",", " "}], 
     FormBox["q",
      TraditionalForm]}], ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["\[CapitalPi]", 
     RowBox[{"c", "d"}], 
     RowBox[{"\[Alpha]", "\[Rho]"}]], "(", 
    FormBox[
     RowBox[{"p", "-", "q"}],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Amplitude",
 CellLabel->"Out[7]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Explicit", "[", "%", "]"}]], "Input",
 CellTags->"Amplitude",
 CellLabel->"In[8]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      SuperscriptBox["q", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"p", "-", "q"}], ")"}], "2"]}]], 
    RowBox[{
     SubsuperscriptBox["g", "s", "2"], " ", 
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"\[Alpha]", "\[Rho]"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"\[Beta]", "\[Sigma]"}]], " ", 
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"\[Beta]", "\[Mu]"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox[
            FormBox["p",
             TraditionalForm], 
            FormBox[
             FormBox["\[Alpha]",
              TraditionalForm],
             TraditionalForm]]}], "-", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["\[Alpha]",
             TraditionalForm],
            TraditionalForm]]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"\[Alpha]", "\[Mu]"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox[
            FormBox["p",
             TraditionalForm], 
            FormBox[
             FormBox["\[Beta]",
              TraditionalForm],
             TraditionalForm]]}], "-", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["\[Beta]",
             TraditionalForm],
            TraditionalForm]]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"\[Alpha]", "\[Beta]"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox[
            FormBox["q",
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]",
              TraditionalForm],
             TraditionalForm]]}], "-", 
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], 
           FormBox[
            FormBox["\[Mu]",
             TraditionalForm],
            TraditionalForm]]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"\[Rho]", "\[Sigma]"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], 
           FormBox[
            FormBox["\[Nu]",
             TraditionalForm],
            TraditionalForm]], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            FormBox["q",
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]",
              TraditionalForm],
             TraditionalForm]]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"\[Nu]", "\[Sigma]"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], 
           FormBox[
            FormBox["\[Rho]",
             TraditionalForm],
            TraditionalForm]], "+", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["\[Rho]",
             TraditionalForm],
            TraditionalForm]]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["\[Sigma]",
             TraditionalForm],
            TraditionalForm]], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            FormBox["p",
             TraditionalForm], 
            FormBox[
             FormBox["\[Sigma]",
              TraditionalForm],
             TraditionalForm]]}]}], ")"}]}]}], ")"}]}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"Amplitude",
 CellLabel->"Out[8]="]
}, Open  ]],

Cell[TextData[{
 "This is the amplitude for graph 6.2 from the paper Z.Phys C ",
 StyleBox["70:",
  FontWeight->"Bold"],
 "637-654, 1996",
 StyleBox[".",
  FontWeight->"Bold"]
}], "Text",
 CellTags->"Amplitude"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FeynAmp", "[", 
  RowBox[{"q1", ",", "q2", ",", 
   RowBox[{"EpsEvaluate", "[", 
    RowBox[{"Trick", "[", 
     RowBox[{"Explicit", "[", 
      RowBox[{"Amplitude", "[", "\"\<gg2\>\"", "]"}], "]"}], "]"}], "]"}]}], 
  "]"}]], "Input",
 CellTags->"Amplitude",
 CellLabel->"In[9]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[Integral]", 
   RowBox[{
    StyleBox[
     RowBox[{
      SuperscriptBox["\[DifferentialD]", "D"], "q1"}],
     ZeroWidthTimes->True], "\[Integral]", 
    RowBox[{
     SuperscriptBox["\[DifferentialD]", "D"], "q2"}]}], "(", 
   FormBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FormBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "1"}], ")"}], "m"],
          TraditionalForm]}], ")"}], " ", 
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox[
           SubscriptBox["\<\"c\"\>", "5"],
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox[
           SubscriptBox["\<\"c\"\>", "7"],
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox[
           SubscriptBox["\<\"c\"\>", "12"],
           TraditionalForm],
          TraditionalForm]}]], " ", 
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox[
           SubscriptBox["\<\"c\"\>", "10"],
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox[
           SubscriptBox["\<\"c\"\>", "11"],
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox[
           SubscriptBox["\<\"c\"\>", "12"],
           TraditionalForm],
          TraditionalForm]}]], " ", 
       SubsuperscriptBox["g", "s", "4"], " ", 
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox[
           SubscriptBox["\<\"c\"\>", "5"],
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox[
           SubscriptBox["\<\"c\"\>", "11"],
           TraditionalForm],
          TraditionalForm]}]], " ", 
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox[
           SubscriptBox["\<\"c\"\>", "7"],
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox[
           SubscriptBox["\<\"c\"\>", "10"],
           TraditionalForm],
          TraditionalForm]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["g", 
           RowBox[{
            SubscriptBox["\[Lambda]", "7"], 
            SubscriptBox["\[Lambda]", "12"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             FormBox["q2",
              TraditionalForm], 
             FormBox[
              FormBox[
               SubscriptBox["\[Lambda]", "5"],
               TraditionalForm],
              TraditionalForm]], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              FormBox["q1",
               TraditionalForm], 
              FormBox[
               FormBox[
                SubscriptBox["\[Lambda]", "5"],
                TraditionalForm],
               TraditionalForm]]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["g", 
           RowBox[{
            SubscriptBox["\[Lambda]", "5"], 
            SubscriptBox["\[Lambda]", "12"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             FormBox["q1",
              TraditionalForm], 
             FormBox[
              FormBox[
               SubscriptBox["\[Lambda]", "7"],
               TraditionalForm],
              TraditionalForm]], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              FormBox["q2",
               TraditionalForm], 
              FormBox[
               FormBox[
                SubscriptBox["\[Lambda]", "7"],
                TraditionalForm],
               TraditionalForm]]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["g", 
           RowBox[{
            SubscriptBox["\[Lambda]", "5"], 
            SubscriptBox["\[Lambda]", "7"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             FormBox["q1",
              TraditionalForm], 
             FormBox[
              FormBox[
               SubscriptBox["\[Lambda]", "12"],
               TraditionalForm],
              TraditionalForm]], "+", 
            SuperscriptBox[
             FormBox["q2",
              TraditionalForm], 
             FormBox[
              FormBox[
               SubscriptBox["\[Lambda]", "12"],
               TraditionalForm],
              TraditionalForm]]}], ")"}]}]}], ")"}], " ", 
       FormBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q2",
            TraditionalForm]}], ")"}], 
         RowBox[{"m", "-", "1"}]],
        TraditionalForm], " ", 
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox[
           SubscriptBox["\[Lambda]", "1"],
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox[
           SubscriptBox["\[Lambda]", "5"],
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["q2",
          TraditionalForm]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["g", 
           RowBox[{
            SubscriptBox["\[Lambda]", "7"], 
            SubscriptBox["\[Lambda]", "10"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox[
              FormBox["q1",
               TraditionalForm], 
              FormBox[
               FormBox["\[Nu]",
                TraditionalForm],
               TraditionalForm]]}], "-", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]",
               TraditionalForm],
              TraditionalForm]]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["g", 
           RowBox[{"\[Nu]", 
            SubscriptBox["\[Lambda]", "10"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox[
              FormBox["p",
               TraditionalForm], 
              FormBox[
               FormBox[
                SubscriptBox["\[Lambda]", "7"],
                TraditionalForm],
               TraditionalForm]]}], "-", 
            SuperscriptBox[
             FormBox["q1",
              TraditionalForm], 
             FormBox[
              FormBox[
               SubscriptBox["\[Lambda]", "7"],
               TraditionalForm],
              TraditionalForm]]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["g", 
           RowBox[{"\[Nu]", 
            SubscriptBox["\[Lambda]", "7"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              FormBox["p",
               TraditionalForm], 
              FormBox[
               FormBox[
                SubscriptBox["\[Lambda]", "10"],
                TraditionalForm],
               TraditionalForm]]}], "-", 
            SuperscriptBox[
             FormBox["q1",
              TraditionalForm], 
             FormBox[
              FormBox[
               SubscriptBox["\[Lambda]", "10"],
               TraditionalForm],
              TraditionalForm]]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["g", 
           RowBox[{
            SubscriptBox["\[Lambda]", "11"], 
            SubscriptBox["\[Lambda]", "12"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              FormBox["p",
               TraditionalForm], 
              FormBox[
               FormBox[
                SubscriptBox["\[Lambda]", "10"],
                TraditionalForm],
               TraditionalForm]]}], "-", 
            SuperscriptBox[
             FormBox["q1",
              TraditionalForm], 
             FormBox[
              FormBox[
               SubscriptBox["\[Lambda]", "10"],
               TraditionalForm],
              TraditionalForm]], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              FormBox["q2",
               TraditionalForm], 
              FormBox[
               FormBox[
                SubscriptBox["\[Lambda]", "10"],
                TraditionalForm],
               TraditionalForm]]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["g", 
           RowBox[{
            SubscriptBox["\[Lambda]", "10"], 
            SubscriptBox["\[Lambda]", "12"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              FormBox["p",
               TraditionalForm], 
              FormBox[
               FormBox[
                SubscriptBox["\[Lambda]", "11"],
                TraditionalForm],
               TraditionalForm]]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              FormBox["q1",
               TraditionalForm], 
              FormBox[
               FormBox[
                SubscriptBox["\[Lambda]", "11"],
                TraditionalForm],
               TraditionalForm]]}], "-", 
            SuperscriptBox[
             FormBox["q2",
              TraditionalForm], 
             FormBox[
              FormBox[
               SubscriptBox["\[Lambda]", "11"],
               TraditionalForm],
              TraditionalForm]]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["g", 
           RowBox[{
            SubscriptBox["\[Lambda]", "10"], 
            SubscriptBox["\[Lambda]", "11"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox[
              FormBox["p",
               TraditionalForm], 
              FormBox[
               FormBox[
                SubscriptBox["\[Lambda]", "12"],
                TraditionalForm],
               TraditionalForm]]}], "-", 
            SuperscriptBox[
             FormBox["q1",
              TraditionalForm], 
             FormBox[
              FormBox[
               SubscriptBox["\[Lambda]", "12"],
               TraditionalForm],
              TraditionalForm]], "-", 
            SuperscriptBox[
             FormBox["q2",
              TraditionalForm], 
             FormBox[
              FormBox[
               SubscriptBox["\[Lambda]", "12"],
               TraditionalForm],
              TraditionalForm]]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["g", 
           RowBox[{
            SubscriptBox["\[Lambda]", "1"], 
            SubscriptBox["\[Lambda]", "11"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]",
               TraditionalForm],
              TraditionalForm]], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              FormBox["q2",
               TraditionalForm], 
              FormBox[
               FormBox["\[Mu]",
                TraditionalForm],
               TraditionalForm]]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["g", 
           RowBox[{"\[Mu]", 
            SubscriptBox["\[Lambda]", "11"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             FormBox["q2",
              TraditionalForm], 
             FormBox[
              FormBox[
               SubscriptBox["\[Lambda]", "1"],
               TraditionalForm],
              TraditionalForm]], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              FormBox["p",
               TraditionalForm], 
              FormBox[
               FormBox[
                SubscriptBox["\[Lambda]", "1"],
                TraditionalForm],
               TraditionalForm]]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["g", 
           RowBox[{"\[Mu]", 
            SubscriptBox["\[Lambda]", "1"]}]], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox[
               SubscriptBox["\[Lambda]", "11"],
               TraditionalForm],
              TraditionalForm]], "+", 
            SuperscriptBox[
             FormBox["q2",
              TraditionalForm], 
             FormBox[
              FormBox[
               SubscriptBox["\[Lambda]", "11"],
               TraditionalForm],
              TraditionalForm]]}], ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{
      SuperscriptBox["q1", "2"], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"q1", "-", "p"}], ")"}], "2"], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"q1", "-", "q2"}], ")"}], "2"], ".", 
      SuperscriptBox["q2", "2"], ".", 
      SuperscriptBox["q2", "2"], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"q2", "-", "p"}], ")"}], "2"]}]}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"Amplitude",
 CellLabel->"Out[9]="]
}, Open  ]]
}, Open  ]],

Cell["Amputate", "ObjectName",
 CellTags->"Amputate"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Amputate"],

Cell["\<\
Amputate[exp,q1,q2,...] amputates Eps and DiracGamma. Amputate[exp,q1,q2,Pair\
\[Rule]{p}] amputates also p.q1 and p.q2; Pair\[Rule]All amputates all except \
OPEDelta.\
\>", "Text",
 CellTags->"Amputate"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Amputate", "]"}]], "Input",
 CellTags->"Amputate",
 CellLabel->"In[10]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Pair", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"Unique", "\[Rule]", "True"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Amputate",
 CellLabel->"Out[10]="]
}, Open  ]],

Cell[TextData[{
 "See also:  ",
 ButtonBox["DiracGamma",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGamma",
  ButtonNote->"DiracGamma"],
 ", ",
 ButtonBox["DiracMatrix",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracMatrix",
  ButtonNote->"DiracMatrix"],
 ", ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 ", ",
 ButtonBox["DiracSlash",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSlash",
  ButtonNote->"DiracSlash"],
 ", ",
 ButtonBox["DiracTrick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrick",
  ButtonNote->"DiracTrick"],
 "."
}], "Text",
 CellTags->"Amputate"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Amputate"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracSlash", "[", "p", "]"}], ".", 
  RowBox[{"DiracSlash", "[", "q", "]"}]}]], "Input",
 CellTags->"Amputate",
 CellLabel->"In[11]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["p",
      TraditionalForm]}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Amputate",
 CellLabel->"Out[11]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Amputate", "[", 
  RowBox[{"%", ",", "q"}], "]"}]], "Input",
 CellTags->"Amputate",
 CellLabel->"In[12]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["q",
     TraditionalForm], 
    FormBox[
     FormBox[
      RowBox[{"$AL$714", "\[InvisibleApplication]", 
       RowBox[{"(", "1", ")"}]}],
      TraditionalForm],
     TraditionalForm]], " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["p",
       TraditionalForm]}], ")"}], ".", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox[
       RowBox[{"$AL$714", "\[InvisibleApplication]", 
        RowBox[{"(", "1", ")"}]}],
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"Amputate",
 CellLabel->"Out[12]="]
}, Open  ]]
}, Open  ]],

Cell["AnomalousDimension", "ObjectName",
 CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"AnomalousDimension"],

Cell["\<\
AnomalousDimension[name] is a database of anomalous dimensions of twist 2 \
operators.\
\>", "Text",
 CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "AnomalousDimension", "]"}]], "Input",
 CellTags->"AnomalousDimension",
 CellLabel->"In[13]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
    RowBox[{"Simplify", "\[Rule]", "FullSimplify"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"AnomalousDimension",
 CellLabel->"Out[13]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 ButtonBox["SplittingFunction",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SplittingFunction",
  ButtonNote->"SplittingFunction"],
 ", ",
 ButtonBox["SumS",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SumS",
  ButtonNote->"SumS"],
 ", ",
 ButtonBox["SumT",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SumT",
  ButtonNote->"SumT"],
 "."
}], "Text",
 CellTags->"AnomalousDimension"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"AnomalousDimension"],

Cell["Polarized case", "Text",
 CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetOptions", "[", " ", 
  RowBox[{"AnomalousDimension", ",", 
   RowBox[{"Polarization", "\[Rule]", "1"}]}], "]"}]], "Input",
 CellTags->"AnomalousDimension",
 CellLabel->"In[14]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
    RowBox[{"Simplify", "\[Rule]", "FullSimplify"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"AnomalousDimension",
 CellLabel->"Out[14]="]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Gamma]", 
    RowBox[{"NS", ",", "qq", " "}], 
    RowBox[{
     RowBox[{"(", "0", ")"}], " "}]], TraditionalForm]]],
 "polarized"
}], "Text",
 CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AnomalousDimension", "[", "gnsqq0", "]"}]], "Input",
 CellTags->"AnomalousDimension",
 CellLabel->"In[15]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "F"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"8", " ", 
      RowBox[{
       SubscriptBox["S", "1"], "(", 
       FormBox[
        RowBox[{"m", "-", "1"}],
        TraditionalForm], ")"}]}], "+", 
     FractionBox["4", "m"], "+", 
     FractionBox["4", 
      RowBox[{"m", "+", "1"}]], "-", "6"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"AnomalousDimension",
 CellLabel->"Out[15]="]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Gamma]", 
    RowBox[{"S", ",", "qg", " "}], 
    RowBox[{
     RowBox[{"(", "0", ")"}], " "}]], TraditionalForm]]],
 "polarized"
}], "Text",
 CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AnomalousDimension", "[", "gsqg0", "]"}]], "Input",
 CellTags->"AnomalousDimension",
 CellLabel->"In[16]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox["8", "m"], "-", 
     FractionBox["16", 
      RowBox[{"m", "+", "1"}]]}], ")"}], " ", 
   SubscriptBox["T", "f"]}], TraditionalForm]], "Output",
 CellTags->"AnomalousDimension",
 CellLabel->"Out[16]="]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Gamma]", 
    RowBox[{"S", ",", "gq", " "}], 
    RowBox[{
     RowBox[{"(", "0", ")"}], " "}]], TraditionalForm]]],
 "polarized"
}], "Text",
 CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AnomalousDimension", "[", "gsgq0", "]"}]], "Input",
 CellTags->"AnomalousDimension",
 CellLabel->"In[17]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox["4", 
      RowBox[{"m", "+", "1"}]], "-", 
     FractionBox["8", "m"]}], ")"}], " ", 
   SubscriptBox["C", "F"]}], TraditionalForm]], "Output",
 CellTags->"AnomalousDimension",
 CellLabel->"Out[17]="]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Gamma]", 
    RowBox[{"S", ",", "gg", " "}], 
    RowBox[{
     RowBox[{"(", "0", ")"}], " "}]], TraditionalForm]]],
 "polarized"
}], "Text",
 CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AnomalousDimension", "[", "gsgg0", "]"}]], "Input",
 CellTags->"AnomalousDimension",
 CellLabel->"In[18]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "A"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"8", " ", 
       RowBox[{
        SubscriptBox["S", "1"], "(", 
        FormBox[
         RowBox[{"m", "-", "1"}],
         TraditionalForm], ")"}]}], "-", 
      FractionBox["8", "m"], "+", 
      FractionBox["16", 
       RowBox[{"m", "+", "1"}]], "-", 
      FractionBox["22", "3"]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{"8", " ", 
     SubscriptBox["T", "f"]}], "3"]}], TraditionalForm]], "Output",
 CellTags->"AnomalousDimension",
 CellLabel->"Out[18]="]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Gamma]", 
    RowBox[{"PS", ",", "qq", " "}], 
    RowBox[{
     RowBox[{"(", "0", ")"}], " "}]], TraditionalForm]]],
 "polarized"
}], "Text",
 CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AnomalousDimension", "[", "gpsqq1", "]"}]], "Input",
 CellTags->"AnomalousDimension",
 CellLabel->"In[19]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"16", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["2", 
      SuperscriptBox["m", "3"]], "-", 
     FractionBox["1", 
      SuperscriptBox["m", "2"]], "+", 
     FractionBox["1", 
      RowBox[{"m", "+", "1"}]], "+", 
     FractionBox["3", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m", "+", "1"}], ")"}], "2"]], "+", 
     FractionBox["2", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"m", "+", "1"}], ")"}], "3"]], "-", 
     FractionBox["1", "m"]}], ")"}], " ", 
   SubscriptBox["C", "F"], " ", 
   SubscriptBox["T", "f"]}], TraditionalForm]], "Output",
 CellTags->"AnomalousDimension",
 CellLabel->"Out[19]="]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Gamma]", 
    RowBox[{"NS", ",", "qq", " "}], 
    RowBox[{
     RowBox[{"(", "1", ")"}], " "}]], TraditionalForm]]],
 "polarized"
}], "Text",
 CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AnomalousDimension", "[", "gnsqq1", "]"}]], "Input",
 CellTags->"AnomalousDimension",
 CellLabel->"In[20]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SubscriptBox["C", "A"], " ", 
     SubscriptBox["C", "F"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"16", " ", 
          RowBox[{
           SubscriptBox[
            OverscriptBox["S", "~"], "2"], "(", 
           FormBox[
            RowBox[{"m", "-", "1"}],
            TraditionalForm], ")"}]}], "m"]}], "-", 
       FractionBox[
        RowBox[{"16", " ", 
         RowBox[{
          SubscriptBox[
           OverscriptBox["S", "~"], "2"], "(", 
          FormBox[
           RowBox[{"m", "-", "1"}],
           TraditionalForm], ")"}]}], 
        RowBox[{"m", "+", "1"}]], "+", 
       RowBox[{"16", " ", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["S", "~"], "3"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], "-", 
       RowBox[{"32", " ", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["S", "~"], "12"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], "+", 
       FractionBox["44", 
        RowBox[{"3", " ", 
         SuperscriptBox["m", "2"]}]], "-", 
       RowBox[{
        FractionBox["536", "9"], " ", 
        RowBox[{
         SubscriptBox["S", "1"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], "+", 
       RowBox[{
        FractionBox["88", "3"], " ", 
        RowBox[{
         SubscriptBox["S", "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], "-", 
       RowBox[{"16", " ", 
        RowBox[{
         SubscriptBox["S", "3"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], "+", 
       FractionBox["212", 
        RowBox[{"9", " ", "m"}]], "-", 
       FractionBox["748", 
        RowBox[{"9", " ", 
         RowBox[{"(", 
          RowBox[{"m", "+", "1"}], ")"}]}]], "-", 
       FractionBox["4", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m", "+", "1"}], ")"}], "2"]}]], "-", 
       FractionBox["16", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"m", "+", "1"}], ")"}], "3"]], "+", 
       FractionBox["17", "3"]}], ")"}]}]}], "+", 
   RowBox[{
    SubsuperscriptBox["C", "F", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"32", " ", 
          RowBox[{
           SubscriptBox[
            OverscriptBox["S", "~"], "2"], "(", 
           FormBox[
            RowBox[{"m", "-", "1"}],
            TraditionalForm], ")"}]}], "m"], "+", 
        FractionBox[
         RowBox[{"32", " ", 
          RowBox[{
           SubscriptBox[
            OverscriptBox["S", "~"], "2"], "(", 
           FormBox[
            RowBox[{"m", "-", "1"}],
            TraditionalForm], ")"}]}], 
         RowBox[{"m", "+", "1"}]], "-", 
        RowBox[{"32", " ", 
         RowBox[{
          SubscriptBox[
           OverscriptBox["S", "~"], "3"], "(", 
          FormBox[
           RowBox[{"m", "-", "1"}],
           TraditionalForm], ")"}]}], "+", 
        RowBox[{"64", " ", 
         RowBox[{
          SubscriptBox[
           OverscriptBox["S", "~"], "12"], "(", 
          FormBox[
           RowBox[{"m", "-", "1"}],
           TraditionalForm], ")"}]}], "+", 
        FractionBox["8", 
         SuperscriptBox["m", "3"]], "+", 
        FractionBox[
         RowBox[{"16", " ", 
          RowBox[{
           SubscriptBox["S", "1"], "(", 
           FormBox[
            RowBox[{"m", "-", "1"}],
            TraditionalForm], ")"}]}], 
         SuperscriptBox["m", "2"]], "+", 
        FractionBox[
         RowBox[{"16", " ", 
          RowBox[{
           SubscriptBox["S", "1"], "(", 
           FormBox[
            RowBox[{"m", "-", "1"}],
            TraditionalForm], ")"}]}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m", "+", "1"}], ")"}], "2"]], "+", 
        FractionBox[
         RowBox[{"16", " ", 
          RowBox[{
           SubscriptBox["S", "2"], "(", 
           FormBox[
            RowBox[{"m", "-", "1"}],
            TraditionalForm], ")"}]}], "m"], "+", 
        FractionBox[
         RowBox[{"16", " ", 
          RowBox[{
           SubscriptBox["S", "2"], "(", 
           FormBox[
            RowBox[{"m", "-", "1"}],
            TraditionalForm], ")"}]}], 
         RowBox[{"m", "+", "1"}]], "-", 
        RowBox[{"24", " ", 
         RowBox[{
          SubscriptBox["S", "2"], "(", 
          FormBox[
           RowBox[{"m", "-", "1"}],
           TraditionalForm], ")"}]}], "+", 
        RowBox[{"32", " ", 
         RowBox[{
          SubscriptBox["S", "12"], "(", 
          FormBox[
           RowBox[{"m", "-", "1"}],
           TraditionalForm], ")"}]}], "+", 
        RowBox[{"32", " ", 
         RowBox[{
          SubscriptBox["S", "21"], "(", 
          FormBox[
           RowBox[{"m", "-", "1"}],
           TraditionalForm], ")"}]}], "-", 
        FractionBox["40", "m"], "+", 
        FractionBox["40", 
         RowBox[{"m", "+", "1"}]], "+", 
        FractionBox["16", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m", "+", "1"}], ")"}], "2"]], "+", 
        FractionBox["40", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"m", "+", "1"}], ")"}], "3"]], "+", "3"}], ")"}]}], 
     ")"}]}], "-", 
   RowBox[{
    SubscriptBox["C", "F"], " ", 
    SubscriptBox["N", "f"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["8", 
        RowBox[{"3", " ", 
         SuperscriptBox["m", "2"]}]]}], "+", 
      RowBox[{
       FractionBox["80", "9"], " ", 
       RowBox[{
        SubscriptBox["S", "1"], "(", 
        FormBox[
         RowBox[{"m", "-", "1"}],
         TraditionalForm], ")"}]}], "-", 
      RowBox[{
       FractionBox["16", "3"], " ", 
       RowBox[{
        SubscriptBox["S", "2"], "(", 
        FormBox[
         RowBox[{"m", "-", "1"}],
         TraditionalForm], ")"}]}], "-", 
      FractionBox["8", 
       RowBox[{"9", " ", "m"}]], "+", 
      FractionBox["88", 
       RowBox[{"9", " ", 
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}]}]], "-", 
      FractionBox["8", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"m", "+", "1"}], ")"}], "2"]}]], "-", 
      FractionBox["2", "3"]}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"AnomalousDimension",
 CellLabel->"Out[20]="]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Gamma]", 
    RowBox[{"S", ",", "qg", " "}], 
    RowBox[{
     RowBox[{"(", "1", ")"}], " "}]], TraditionalForm]]],
 "polarized"
}], "Text",
 CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AnomalousDimension", "[", "gsqg1", "]"}]], "Input",
 CellTags->"AnomalousDimension",
 CellLabel->"In[21]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"16", " ", 
    SubscriptBox["C", "A"], " ", 
    SubscriptBox["T", "f"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SubscriptBox[
           OverscriptBox["S", "~"], "2"], "(", 
          FormBox[
           RowBox[{"m", "-", "1"}],
           TraditionalForm], ")"}]}], "m"]}], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["S", "~"], "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       RowBox[{"m", "+", "1"}]], "+", 
      FractionBox["2", 
       SuperscriptBox["m", "3"]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SubscriptBox["S", "1"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       SuperscriptBox["m", "2"]], "-", 
      FractionBox["3", 
       SuperscriptBox["m", "2"]], "-", 
      FractionBox[
       RowBox[{
        SubsuperscriptBox["S", "1", "2"], "(", 
        FormBox[
         RowBox[{"m", "-", "1"}],
         TraditionalForm], ")"}], "m"], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SubsuperscriptBox["S", "1", "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       RowBox[{"m", "+", "1"}]], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{
         SubscriptBox["S", "1"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}], "2"]], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["S", "2"], "(", 
        FormBox[
         RowBox[{"m", "-", "1"}],
         TraditionalForm], ")"}], "m"], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SubscriptBox["S", "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       RowBox[{"m", "+", "1"}]], "-", 
      FractionBox["4", "m"], "+", 
      FractionBox["3", 
       RowBox[{"m", "+", "1"}]], "+", 
      FractionBox["8", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}], "2"]], "+", 
      FractionBox["12", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}], "3"]]}], ")"}]}], "+", 
   RowBox[{"8", " ", 
    SubscriptBox["C", "F"], " ", 
    SubscriptBox["T", "f"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", 
        SuperscriptBox["m", "3"]]}], "-", 
      FractionBox["1", 
       SuperscriptBox["m", "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SubsuperscriptBox["S", "1", "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], "m"], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{
         SubsuperscriptBox["S", "1", "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       RowBox[{"m", "+", "1"}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SubscriptBox["S", "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], "m"], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{
         SubscriptBox["S", "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       RowBox[{"m", "+", "1"}]], "+", 
      FractionBox["14", "m"], "-", 
      FractionBox["19", 
       RowBox[{"m", "+", "1"}]], "-", 
      FractionBox["8", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}], "2"]], "+", 
      FractionBox["4", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}], "3"]]}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"AnomalousDimension",
 CellLabel->"Out[21]="]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Gamma]", 
    RowBox[{"S", ",", "gq", " "}], 
    RowBox[{
     RowBox[{"(", "1", ")"}], " "}]], TraditionalForm]]],
 "polarized"
}], "Text",
 CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AnomalousDimension", "[", "gsgq1", "]"}]], "Input",
 CellTags->"AnomalousDimension",
 CellLabel->"In[22]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"8", " ", 
    SubscriptBox["C", "A"], " ", 
    SubscriptBox["C", "F"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["S", "~"], "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], "m"], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["S", "~"], "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       RowBox[{"m", "+", "1"}]], "-", 
      FractionBox["4", 
       SuperscriptBox["m", "3"]], "+", 
      FractionBox["28", 
       RowBox[{"3", " ", 
        SuperscriptBox["m", "2"]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SubsuperscriptBox["S", "1", "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], "m"], "+", 
      FractionBox[
       RowBox[{
        SubsuperscriptBox["S", "1", "2"], "(", 
        FormBox[
         RowBox[{"m", "-", "1"}],
         TraditionalForm], ")"}], 
       RowBox[{"m", "+", "1"}]], "+", 
      FractionBox[
       RowBox[{"16", " ", 
        RowBox[{
         SubscriptBox["S", "1"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       RowBox[{"3", " ", "m"}]], "-", 
      FractionBox[
       RowBox[{"5", " ", 
        RowBox[{
         SubscriptBox["S", "1"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SubscriptBox["S", "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], "m"], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["S", "2"], "(", 
        FormBox[
         RowBox[{"m", "-", "1"}],
         TraditionalForm], ")"}], 
       RowBox[{"m", "+", "1"}]], "-", 
      FractionBox["56", 
       RowBox[{"9", " ", "m"}]], "-", 
      FractionBox["20", 
       RowBox[{"9", " ", 
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}]}]], "-", 
      FractionBox["38", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"m", "+", "1"}], ")"}], "2"]}]], "-", 
      FractionBox["6", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}], "3"]]}], ")"}]}], "+", 
   RowBox[{"32", " ", 
    SubscriptBox["C", "F"], " ", 
    SubscriptBox["T", "f"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", 
        RowBox[{"3", " ", 
         SuperscriptBox["m", "2"]}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SubscriptBox["S", "1"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       RowBox[{"3", " ", "m"}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["S", "1"], "(", 
        FormBox[
         RowBox[{"m", "-", "1"}],
         TraditionalForm], ")"}], 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}]}]], "+", 
      FractionBox["7", 
       RowBox[{"9", " ", "m"}]], "-", 
      FractionBox["2", 
       RowBox[{"9", " ", 
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}]}]], "+", 
      FractionBox["1", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"m", "+", "1"}], ")"}], "2"]}]]}], ")"}]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["C", "F", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["4", 
       SuperscriptBox["m", "3"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{
         SubscriptBox["S", "1"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       SuperscriptBox["m", "2"]], "-", 
      FractionBox["12", 
       SuperscriptBox["m", "2"]], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{
         SubsuperscriptBox["S", "1", "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], "m"], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SubsuperscriptBox["S", "1", "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       RowBox[{"m", "+", "1"}]], "-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{
         SubscriptBox["S", "1"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], "m"], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SubscriptBox["S", "1"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       RowBox[{"m", "+", "1"}]], "-", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{
         SubscriptBox["S", "1"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}], "2"]], "+", 
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{
         SubscriptBox["S", "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], "m"], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{
         SubscriptBox["S", "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       RowBox[{"m", "+", "1"}]], "+", 
      FractionBox["15", "m"], "-", 
      FractionBox["6", 
       RowBox[{"m", "+", "1"}]], "+", 
      FractionBox["3", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}], "2"]], "-", 
      FractionBox["2", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}], "3"]]}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"AnomalousDimension",
 CellLabel->"Out[22]="]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Gamma]", 
    RowBox[{"S", ",", "gg", " "}], 
    RowBox[{
     RowBox[{"(", "1", ")"}], " "}]], TraditionalForm]]],
 "polarized"
}], "Text",
 CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AnomalousDimension", "[", "gsgg1", "]"}]], "Input",
 CellTags->"AnomalousDimension",
 CellLabel->"In[23]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"4", " ", 
    SubsuperscriptBox["C", "A", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["S", "~"], "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], "m"], "-", 
      FractionBox[
       RowBox[{"16", " ", 
        RowBox[{
         SubscriptBox[
          OverscriptBox["S", "~"], "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       RowBox[{"m", "+", "1"}]], "+", 
      RowBox[{"4", " ", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["S", "~"], "3"], "(", 
        FormBox[
         RowBox[{"m", "-", "1"}],
         TraditionalForm], ")"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{
        SubscriptBox[
         OverscriptBox["S", "~"], "12"], "(", 
        FormBox[
         RowBox[{"m", "-", "1"}],
         TraditionalForm], ")"}]}], "-", 
      FractionBox["8", 
       SuperscriptBox["m", "3"]], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{
         SubscriptBox["S", "1"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       SuperscriptBox["m", "2"]], "+", 
      FractionBox["58", 
       RowBox[{"3", " ", 
        SuperscriptBox["m", "2"]}]], "-", 
      FractionBox[
       RowBox[{"16", " ", 
        RowBox[{
         SubscriptBox["S", "1"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}], "2"]], "+", 
      RowBox[{
       FractionBox["134", "9"], " ", 
       RowBox[{
        SubscriptBox["S", "1"], "(", 
        FormBox[
         RowBox[{"m", "-", "1"}],
         TraditionalForm], ")"}]}], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{
         SubscriptBox["S", "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], "m"], "-", 
      FractionBox[
       RowBox[{"16", " ", 
        RowBox[{
         SubscriptBox["S", "2"], "(", 
         FormBox[
          RowBox[{"m", "-", "1"}],
          TraditionalForm], ")"}]}], 
       RowBox[{"m", "+", "1"}]], "+", 
      RowBox[{"4", " ", 
       RowBox[{
        SubscriptBox["S", "3"], "(", 
        FormBox[
         RowBox[{"m", "-", "1"}],
         TraditionalForm], ")"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{
        SubscriptBox["S", "12"], "(", 
        FormBox[
         RowBox[{"m", "-", "1"}],
         TraditionalForm], ")"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{
        SubscriptBox["S", "21"], "(", 
        FormBox[
         RowBox[{"m", "-", "1"}],
         TraditionalForm], ")"}]}], "-", 
      FractionBox["107", 
       RowBox[{"9", " ", "m"}]], "+", 
      FractionBox["241", 
       RowBox[{"9", " ", 
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}]}]], "-", 
      FractionBox["86", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"m", "+", "1"}], ")"}], "2"]}]], "-", 
      FractionBox["48", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}], "3"]], "-", 
      FractionBox["16", "3"]}], ")"}]}], "+", 
   RowBox[{"32", " ", 
    SubscriptBox["C", "A"], " ", 
    SubscriptBox["T", "f"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", 
        RowBox[{"3", " ", 
         SuperscriptBox["m", "2"]}]]}], "-", 
      RowBox[{
       FractionBox["5", "9"], " ", 
       RowBox[{
        SubscriptBox["S", "1"], "(", 
        FormBox[
         RowBox[{"m", "-", "1"}],
         TraditionalForm], ")"}]}], "+", 
      FractionBox["14", 
       RowBox[{"9", " ", "m"}]], "-", 
      FractionBox["19", 
       RowBox[{"9", " ", 
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}]}]], "-", 
      FractionBox["1", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"m", "+", "1"}], ")"}], "2"]}]], "+", 
      FractionBox["1", "3"]}], ")"}]}], "+", 
   RowBox[{"8", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["4", 
       SuperscriptBox["m", "3"]], "-", 
      FractionBox["10", 
       SuperscriptBox["m", "2"]], "-", 
      FractionBox["10", 
       RowBox[{"m", "+", "1"}]], "+", 
      FractionBox["2", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}], "2"]], "+", 
      FractionBox["4", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}], "3"]], "+", 
      FractionBox["10", "m"], "+", "1"}], ")"}], " ", 
    SubscriptBox["C", "F"], " ", 
    SubscriptBox["T", "f"]}]}], TraditionalForm]], "Output",
 CellTags->"AnomalousDimension",
 CellLabel->"Out[23]="]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["\[Gamma]", 
    RowBox[{"S", ",", "gg", " "}], 
    RowBox[{
     RowBox[{"(", "1", ")"}], " "}]], TraditionalForm]]],
 "polarized (different representation)"
}], "Text",
 CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AnomalousDimension", "[", "GSGG1", "]"}]], "Input",
 CellTags->"AnomalousDimension",
 CellLabel->"In[24]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"4", " ", 
    SubsuperscriptBox["C", "A", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"8", " ", 
       RowBox[{
        OverscriptBox["S", "~"], "(", 
        FormBox["m",
         TraditionalForm], ")"}]}], "+", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{
         SubsuperscriptBox["S", "2", "'"], "\[NoBreak]", "(", "\[NoBreak]", 
         FormBox[
          FractionBox["m", "2"],
          TraditionalForm], "\[NoBreak]", ")"}]}], 
       RowBox[{"m", " ", 
        RowBox[{"(", 
         RowBox[{"m", "+", "1"}], ")"}]}]], "-", 
      RowBox[{
       SubsuperscriptBox["S", "3", "'"], "\[NoBreak]", "(", "\[NoBreak]", 
       FormBox[
        FractionBox["m", "2"],
        TraditionalForm], "\[NoBreak]", ")"}], "-", 
      RowBox[{"4", " ", 
       RowBox[{
        SubscriptBox["S", "1"], "(", 
        FormBox["m",
         TraditionalForm], ")"}], " ", 
       RowBox[{
        SubsuperscriptBox["S", "2", "'"], "\[NoBreak]", "(", "\[NoBreak]", 
        FormBox[
         FractionBox["m", "2"],
         TraditionalForm], "\[NoBreak]", ")"}]}], "-", 
      FractionBox[
       RowBox[{
        RowBox[{"m", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"m", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"m", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"m", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"48", " ", "m", " ", 
                    RowBox[{"(", 
                    RowBox[{"m", "+", "3"}], ")"}]}], "+", "469"}], ")"}]}], 
                 "+", "698"}], ")"}]}], "+", "7"}], ")"}]}], "+", "258"}], 
          ")"}]}], "+", "144"}], 
       RowBox[{"9", " ", 
        SuperscriptBox["m", "3"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"m", "+", "1"}], ")"}], "3"]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"m", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"67", " ", "m", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"m", "+", "1"}], ")"}], "2"]}], "+", "144"}], ")"}]}],
           "+", "72"}], ")"}], " ", 
        RowBox[{
         SubscriptBox["S", "1"], "(", 
         FormBox["m",
          TraditionalForm], ")"}]}], 
       RowBox[{"9", " ", 
        SuperscriptBox["m", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"m", "+", "1"}], ")"}], "2"]}]]}], ")"}]}], "+", 
   RowBox[{"32", " ", 
    SubscriptBox["C", "A"], " ", 
    SubscriptBox["T", "f"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"m", " ", 
         RowBox[{"(", 
          RowBox[{"m", "+", "1"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "m", " ", 
            RowBox[{"(", 
             RowBox[{"m", "+", "1"}], ")"}]}], "+", "13"}], ")"}]}], "-", 
        "3"}], 
       RowBox[{"9", " ", 
        SuperscriptBox["m", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"m", "+", "1"}], ")"}], "2"]}]], "-", 
      FractionBox[
       RowBox[{"5", " ", 
        RowBox[{
         SubscriptBox["S", "1"], "(", 
         FormBox["m",
          TraditionalForm], ")"}]}], "9"]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{"8", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"m", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"m", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"m", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"m", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"m", " ", 
                    RowBox[{"(", 
                    RowBox[{"m", "+", "3"}], ")"}]}], "+", "5"}], ")"}]}], 
                "+", "1"}], ")"}]}], "-", "8"}], ")"}]}], "+", "2"}], ")"}]}],
        "+", "4"}], ")"}], " ", 
     SubscriptBox["C", "F"], " ", 
     SubscriptBox["T", "f"]}], 
    RowBox[{
     SuperscriptBox["m", "3"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"m", "+", "1"}], ")"}], "3"]}]]}], TraditionalForm]], "Output",\

 CellTags->"AnomalousDimension",
 CellLabel->"Out[24]="]
}, Open  ]],

Cell[TextData[{
 "Check that all odd moments give the same for the two representations of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[Gamma]", 
     RowBox[{"S", ",", "gg", " "}], 
     RowBox[{
      RowBox[{"(", "1", ")"}], " "}]], "."}], TraditionalForm]]]
}], "Text",
 CellTags->"AnomalousDimension"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"%", "-", "%%"}], "/.", 
    RowBox[{"OPEm", "\[Rule]", "ij"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"ij", ",", "1", ",", "17", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellTags->"AnomalousDimension",
 CellLabel->"In[25]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
    ",", "0"}], "}"}], TraditionalForm]], "Output",
 CellTags->"AnomalousDimension",
 CellLabel->"Out[25]="]
}, Open  ]]
}, Open  ]],

Cell["AntiCommutator", "ObjectName",
 CellTags->"AntiCommutator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"AntiCommutator"],

Cell["\<\
AntiCommutator[x, y] = c defines the anti-commutator of the non commuting \
objects x and y.\
\>", "Text",
 CellTags->"AntiCommutator"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Commutator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Commutator",
  ButtonNote->"Commutator"],
 ", ",
 ButtonBox["CommutatorExplicit",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CommutatorExplicit",
  ButtonNote->"CommutatorExplicit"],
 ", ",
 ButtonBox["DeclareNonCommutative",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DeclareNonCommutative",
  ButtonNote->"DeclareNonCommutative"],
 ", ",
 ButtonBox["DotSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DotSimplify",
  ButtonNote->"DotSimplify"],
 "."
}], "Text",
 CellTags->"AntiCommutator"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"AntiCommutator"],

Cell[TextData[{
 "This declares ",
 StyleBox["a",
  FontFamily->"Courier"],
 " and ",
 StyleBox["b",
  FontFamily->"Courier"],
 " as noncommutative variables."
}], "Text",
 CellTags->"AntiCommutator"],

Cell[BoxData[
 RowBox[{"DeclareNonCommutative", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Input",
 CellTags->"AntiCommutator",
 CellLabel->"In[26]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AntiCommutator", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Input",
 CellTags->"AntiCommutator",
 CellLabel->"In[27]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", "a", ",", "\[MediumSpace]", "b", "}"}], 
  TraditionalForm]], "Output",
 CellTags->"AntiCommutator",
 CellLabel->"Out[27]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommutatorExplicit", "[", "%", "]"}]], "Input",
 CellTags->"AntiCommutator",
 CellLabel->"In[28]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"a", ".", "b"}], "+", 
   RowBox[{"b", ".", "a"}]}], TraditionalForm]], "Output",
 CellTags->"AntiCommutator",
 CellLabel->"Out[28]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommutatorExplicit", "[", 
  RowBox[{"AntiCommutator", "[", 
   RowBox[{
    RowBox[{"a", "+", "b"}], ",", 
    RowBox[{"a", "-", 
     RowBox[{"2", "b"}]}]}], " ", "]"}], "]"}]], "Input",
 CellTags->"AntiCommutator",
 CellLabel->"In[29]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "-", 
      RowBox[{"2", " ", "b"}]}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{"a", "+", "b"}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "+", "b"}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{"a", "-", 
      RowBox[{"2", " ", "b"}]}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"AntiCommutator",
 CellLabel->"Out[29]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotSimplify", "[", 
  RowBox[{"AntiCommutator", "[", 
   RowBox[{
    RowBox[{"a", "+", "b"}], ",", 
    RowBox[{"a", "-", 
     RowBox[{"2", "b"}]}]}], " ", "]"}], "]"}]], "Input",
 CellTags->"AntiCommutator",
 CellLabel->"In[30]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"a", ".", "b"}]}], "-", 
   RowBox[{"b", ".", "a"}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"a", ".", "a"}]}], "-", 
   RowBox[{"4", " ", 
    RowBox[{"b", ".", "b"}]}]}], TraditionalForm]], "Output",
 CellTags->"AntiCommutator",
 CellLabel->"Out[30]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"DeclareNonCommutative", "[", 
  RowBox[{"c", ",", "d", ",", 
   OverscriptBox["c", "~"], ",", 
   OverscriptBox["d", "~"]}], "]"}]], "Input",
 CellTags->"AntiCommutator",
 CellLabel->"In[31]:="],

Cell["Defining {c,d} = z results in replacements of c.d by z-d.c.", "Text",
 CellTags->"AntiCommutator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"AntiCommutator", "[", 
   RowBox[{"c", ",", "d"}], "]"}], " ", "=", " ", "z"}]], "Input",
 CellTags->"AntiCommutator",
 CellLabel->"In[32]:="],

Cell[BoxData[
 FormBox["z", TraditionalForm]], "Output",
 CellTags->"AntiCommutator",
 CellLabel->"Out[32]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotSimplify", "[", " ", 
  RowBox[{"d", " ", ".", " ", "c", " ", ".", " ", "d"}], " ", "]"}]], "Input",\

 CellTags->"AntiCommutator",
 CellLabel->"In[33]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"d", " ", "z"}], "-", 
   RowBox[{"d", ".", "d", ".", "c"}]}], TraditionalForm]], "Output",
 CellTags->"AntiCommutator",
 CellLabel->"Out[33]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"AntiCommutator", "[", 
   RowBox[{
    OverscriptBox["d", "~"], ",", 
    OverscriptBox["c", "~"]}], "]"}], " ", "=", " ", 
  OverscriptBox["z", "~"]}]], "Input",
 CellTags->"AntiCommutator",
 CellLabel->"In[34]:="],

Cell[BoxData[
 FormBox[
  OverscriptBox["z", "~"], TraditionalForm]], "Output",
 CellTags->"AntiCommutator",
 CellLabel->"Out[34]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotSimplify", "[", " ", 
  RowBox[{
   OverscriptBox["d", "~"], " ", ".", " ", 
   OverscriptBox["c", "~"], " ", ".", " ", 
   OverscriptBox["d", "~"]}], " ", "]"}]], "Input",
 CellTags->"AntiCommutator",
 CellLabel->"In[35]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    OverscriptBox["d", "~"], " ", 
    OverscriptBox["z", "~"]}], "-", 
   RowBox[{
    OverscriptBox["c", "~"], ".", 
    OverscriptBox["d", "~"], ".", 
    OverscriptBox["d", "~"]}]}], TraditionalForm]], "Output",
 CellTags->"AntiCommutator",
 CellLabel->"Out[35]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"UnDeclareNonCommutative", "[", 
  RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", 
   OverscriptBox["c", "~"], ",", 
   OverscriptBox["d", "~"]}], "]"}]], "Input",
 CellTags->"AntiCommutator",
 CellLabel->"In[36]:="],

Cell[BoxData[
 RowBox[{"Unset", "[", 
  RowBox[{"AntiCommutator", "[", 
   RowBox[{"c", ",", "d"}], "]"}], "]"}]], "Input",
 CellTags->"AntiCommutator",
 CellLabel->"In[37]:="],

Cell[BoxData[
 RowBox[{"Unset", "[", 
  RowBox[{"AntiCommutator", "[", 
   RowBox[{
    OverscriptBox["d", "~"], ",", 
    OverscriptBox["c", "~"]}], "]"}], "]"}]], "Input",
 CellTags->"AntiCommutator",
 CellLabel->"In[38]:="]
}, Open  ]],

Cell["AntiQuarkField", "ObjectName",
 CellTags->"AntiQuarkField"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"AntiQuarkField"],

Cell["\<\
AntiQuarkField is the name of a fermionic field. AntiQuarkField is just a \
name with no functional properties. Only typeset rules are attached.\
\>", "Text",
 CellTags->"AntiQuarkField"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["QuantumField",
  BaseStyle->"AddOnsLink",
  ButtonData:>"QuantumField",
  ButtonNote->"QuantumField"],
 ", ",
 ButtonBox["QuarkField",
  BaseStyle->"AddOnsLink",
  ButtonData:>"QuarkField",
  ButtonNote->"QuarkField"],
 "."
}], "Text",
 CellTags->"AntiQuarkField"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"AntiQuarkField"],

Cell[CellGroupData[{

Cell[BoxData["AntiQuarkField"], "Input",
 CellTags->"AntiQuarkField",
 CellLabel->"In[39]:="],

Cell[BoxData[
 FormBox[
  OverscriptBox["\[Psi]", "_"], TraditionalForm]], "Output",
 CellTags->"AntiQuarkField",
 CellLabel->"Out[39]="]
}, Open  ]]
}, Open  ]],

Cell["AntiSymmetrize", "ObjectName",
 CellTags->"AntiSymmetrize"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"AntiSymmetrize"],

Cell["\<\
AntiSymmetrize[expr, {a1, a2, ...}] antisymmetrizes expr with respect to the \
variables a1,a2, ... \
\>", "Text",
 CellTags->"AntiSymmetrize"],

Cell[TextData[{
 "See also: ",
 ButtonBox["Symmetrize",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Symmetrize",
  ButtonNote->"Symmetrize"],
 "."
}], "Text",
 CellTags->"AntiSymmetrize"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"AntiSymmetrize"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AntiSymmetrize", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"a", ",", "b"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b"}], "}"}]}], "]"}]], "Input",
 CellTags->"AntiSymmetrize",
 CellLabel->"In[40]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f", "(", 
      RowBox[{"a", ",", "b"}], ")"}], "-", 
     RowBox[{"f", "(", 
      RowBox[{"b", ",", "a"}], ")"}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"AntiSymmetrize",
 CellLabel->"Out[40]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AntiSymmetrize", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]], "Input",
 CellTags->"AntiSymmetrize",
 CellLabel->"In[41]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "6"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f", "(", 
      RowBox[{"x", ",", "y", ",", "z"}], ")"}], "-", 
     RowBox[{"f", "(", 
      RowBox[{"x", ",", "z", ",", "y"}], ")"}], "-", 
     RowBox[{"f", "(", 
      RowBox[{"y", ",", "x", ",", "z"}], ")"}], "+", 
     RowBox[{"f", "(", 
      RowBox[{"y", ",", "z", ",", "x"}], ")"}], "+", 
     RowBox[{"f", "(", 
      RowBox[{"z", ",", "x", ",", "y"}], ")"}], "-", 
     RowBox[{"f", "(", 
      RowBox[{"z", ",", "y", ",", "x"}], ")"}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"AntiSymmetrize",
 CellLabel->"Out[41]="]
}, Open  ]]
}, Open  ]],

Cell["Anti5", "ObjectName",
 CellTags->"Anti5"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Anti5"],

Cell[TextData[{
 "Anti5[exp] anticommutes all ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
 "in exp to the right. Anti5[exp, n] anticommutes all ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Gamma]", 
    RowBox[{"5", " "}]], TraditionalForm]]],
 "n times to the right. Anti5[exp, -n] anticommutes all ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
 " n times to the left."
}], "Text",
 CellTags->"Anti5"],

Cell[TextData[{
 "The naive ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
 "scheme is used."
}], "Text",
 CellTags->"Anti5"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracOrder",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracOrder",
  ButtonNote->"DiracOrder"],
 ", ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 ", ",
 ButtonBox["DiracTrick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrick",
  ButtonNote->"DiracTrick"],
 "."
}], "Text",
 CellTags->"Anti5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Anti5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracMatrix", "[", 
   RowBox[{"5", ",", "\[Mu]"}], "]"}], " "}]], "Input",
 CellTags->"Anti5",
 CellLabel->"In[42]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "5"], 
   SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
 CellTags->"Anti5",
 CellLabel->"Out[42]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Anti5", "[", "%", "]"}]], "Input",
 CellTags->"Anti5",
 CellLabel->"In[43]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], ".", 
    SuperscriptBox["\[Gamma]", "5"]}]}], TraditionalForm]], "Output",
 CellTags->"Anti5",
 CellLabel->"Out[43]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Anti5", "[", 
  RowBox[{"%", ",", 
   RowBox[{"-", "1"}]}], "]"}]], "Input",
 CellTags->"Anti5",
 CellLabel->"In[44]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "5"], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"Anti5",
 CellLabel->"Out[44]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracMatrix", "[", 
  RowBox[{
  "5", ",", "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Delta]"}], 
  "]"}]], "Input",
 CellTags->"Anti5",
 CellLabel->"In[45]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "5"], 
   SuperscriptBox["\[Gamma]", "\[Alpha]"], 
   SuperscriptBox["\[Gamma]", "\[Beta]"], 
   SuperscriptBox["\[Gamma]", "\[Gamma]"], 
   SuperscriptBox["\[Gamma]", "\[Delta]"]}], TraditionalForm]], "Output",
 CellTags->"Anti5",
 CellLabel->"Out[45]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Anti5", "[", 
  RowBox[{"%", ",", "2"}], "]"}]], "Input",
 CellTags->"Anti5",
 CellLabel->"In[46]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "5"], 
   SuperscriptBox["\[Gamma]", "\[Alpha]"], 
   SuperscriptBox["\[Gamma]", "\[Beta]"], 
   SuperscriptBox["\[Gamma]", "\[Gamma]"], 
   SuperscriptBox["\[Gamma]", "\[Delta]"]}], TraditionalForm]], "Output",
 CellTags->"Anti5",
 CellLabel->"Out[46]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Anti5", "[", 
  RowBox[{"%%", ",", "Infinity"}], "]"}]], "Input",
 CellTags->"Anti5",
 CellLabel->"In[47]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "5"], 
   SuperscriptBox["\[Gamma]", "\[Alpha]"], 
   SuperscriptBox["\[Gamma]", "\[Beta]"], 
   SuperscriptBox["\[Gamma]", "\[Gamma]"], 
   SuperscriptBox["\[Gamma]", "\[Delta]"]}], TraditionalForm]], "Output",
 CellTags->"Anti5",
 CellLabel->"Out[47]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Anti5", "[", 
  RowBox[{"%", ",", 
   RowBox[{"-", "Infinity"}]}], "]"}]], "Input",
 CellTags->"Anti5",
 CellLabel->"In[48]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "5"], 
   SuperscriptBox["\[Gamma]", "\[Alpha]"], 
   SuperscriptBox["\[Gamma]", "\[Beta]"], 
   SuperscriptBox["\[Gamma]", "\[Gamma]"], 
   SuperscriptBox["\[Gamma]", "\[Delta]"]}], TraditionalForm]], "Output",
 CellTags->"Anti5",
 CellLabel->"Out[48]="]
}, Open  ]],

Cell[TextData[{
 "In the naive ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
 "- scheme D-dimensional ",
 Cell[BoxData[
  FormBox["\[Gamma]", TraditionalForm]]],
 "-matrices anticommute with ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
 "."
}], "Text",
 CellTags->"Anti5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GAD", "[", 
  RowBox[{"5", ",", "\[Mu]"}], "]"}]], "Input",
 CellTags->"Anti5",
 CellLabel->"In[49]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "5"], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
 CellTags->"Anti5",
 CellLabel->"Out[49]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Anti5", "[", "%", "]"}]], "Input",
 CellTags->"Anti5",
 CellLabel->"In[50]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], ".", 
    SuperscriptBox["\[Gamma]", "5"]}]}], TraditionalForm]], "Output",
 CellTags->"Anti5",
 CellLabel->"Out[50]="]
}, Open  ]]
}, Open  ]],

Cell["Apart2", "ObjectName",
 CellTags->"Apart2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Apart2"],

Cell["\<\
Apart2[expr] partial fractions FeynAmpDenominators (and FAD's).\
\>", "Text",
 CellTags->"Apart2"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FAD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FAD",
  ButtonNote->"FAD"],
 ", ",
 ButtonBox["FeynAmpDenominator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynAmpDenominator",
  ButtonNote->"FeynAmpDenominator"],
 "."
}], "Text",
 CellTags->"Apart2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Apart2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FAD", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"q", ",", "m"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "M"}], "}"}], ",", 
   RowBox[{"q", "-", "p"}]}], "]"}]], "Input",
 CellTags->"Apart2",
 CellLabel->"In[51]:="],

Cell[BoxData[
 FormBox[
  FractionBox["1", 
   RowBox[{
    RowBox[{"(", 
     InterpretationBox[
      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"q", "-", "p"}], ")"}], "2"], 
       "\[InvisibleSpace]", "\<\"]\"\>"}],
      SequenceForm["[", (-$CellContext`p + $CellContext`q)^2, "]"],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
       SuperscriptBox["q", "2"], "\[InvisibleSpace]", "\<\"-\"\>", 
       "\[InvisibleSpace]", 
       SuperscriptBox["m", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
      SequenceForm["[", $CellContext`q^2, "-", $CellContext`m^2, "]"],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
       SuperscriptBox["q", "2"], "\[InvisibleSpace]", "\<\"-\"\>", 
       "\[InvisibleSpace]", 
       SuperscriptBox["M", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
      SequenceForm["[", $CellContext`q^2, "-", $CellContext`M^2, "]"],
      Editable->False], ")"}]}]], TraditionalForm]], "Output",
 CellTags->"Apart2",
 CellLabel->"Out[51]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Apart2", "[", "%", "]"}]], "Input",
 CellTags->"Apart2",
 CellLabel->"In[52]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["q", "2"], "-", 
        SuperscriptBox["m", "2"]}], ")"}], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "-", 
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["q", "2"], "-", 
        SuperscriptBox["M", "2"]}], ")"}], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"q", "-", "p"}], ")"}], "2"]}]]}], 
   RowBox[{
    SuperscriptBox["m", "2"], "-", 
    SuperscriptBox["M", "2"]}]], TraditionalForm]], "Output",
 CellTags->"Apart2",
 CellLabel->"Out[52]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"FCE", "[", "%", "]"}], "]"}]], "Input",
 CellTags->"Apart2",
 CellLabel->"In[53]:="],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"FAD", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"q", ",", "m"}], "}"}], ",", 
     RowBox[{
      RowBox[{"-", "p"}], "+", "q"}]}], "]"}], "-", 
   RowBox[{"FAD", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"q", ",", "M"}], "}"}], ",", 
     RowBox[{
      RowBox[{"-", "p"}], "+", "q"}]}], "]"}]}], 
  RowBox[{
   SuperscriptBox["m", "2"], "-", 
   SuperscriptBox["M", "2"]}]]], "Output",
 CellTags->"Apart2",
 CellLabel->"Out[53]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["A0", "ObjectName",
 PageBreakAbove->True,
 CellTags->"A0"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"A0"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"A0", "[", 
    SuperscriptBox["m", "2"], "]"}], TraditionalForm]]],
 "is the Passarino-Veltman one-point integral ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["A", "0"], "."}], TraditionalForm]]]
}], "Text",
 CellTags->"A0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", " ", "A0", "]"}]], "Input",
 CellTags->"A0",
 CellLabel->"In[54]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"A0ToB0", "\[Rule]", "False"}], "}"}], TraditionalForm]], "Output",\

 CellTags->"A0",
 CellLabel->"Out[54]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["B0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B0",
  ButtonNote->"B0"],
 ", ",
 ButtonBox["C0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"C0",
  ButtonNote->"C0"],
 ", ",
 ButtonBox["D0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"D0",
  ButtonNote->"D0"],
 ", ",
 ButtonBox["PaVe",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVe",
  ButtonNote->"PaVe"],
 "."
}], "Text",
 CellTags->"A0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"A0"],

Cell[TextData[{
 "By default ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "0"], TraditionalForm]]],
 " is not expressed in terms of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["B", "0"], TraditionalForm]]],
 "."
}], "Text",
 CellTags->"A0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A0", "[", 
  SuperscriptBox["m", "2"], "]"}]], "Input",
 CellTags->"A0",
 CellLabel->"In[55]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    SubscriptBox["\<\"A\"\>", "\<\"0\"\>"],
    TraditionalForm], "(", 
   FormBox[
    SuperscriptBox["m", "2"],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"A0",
 CellLabel->"Out[55]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"A0", ",", 
    RowBox[{"A0ToB0", "\[Rule]", "True"}]}], "]"}], ";"}]], "Input",
 CellTags->"A0",
 CellLabel->"In[56]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A0", "[", 
  SuperscriptBox["m", "2"], "]"}]], "Input",
 CellTags->"A0",
 CellLabel->"In[57]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["m", "2"], " ", 
    RowBox[{
     SubscriptBox["B", "0"], "(", "0", ",", 
     SuperscriptBox["m", "2"], ",", 
     SuperscriptBox["m", "2"], ")"}]}], "+", 
   SuperscriptBox["m", "2"]}], TraditionalForm]], "Output",
 CellTags->"A0",
 CellLabel->"Out[57]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"A0", ",", 
    RowBox[{"A0ToB0", "\[Rule]", "False"}]}], "]"}], ";"}]], "Input",
 CellTags->"A0",
 CellLabel->"In[58]:="],

Cell[TextData[{
 "According to the rules of dimensional regularization ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["A", "0"], "(", "0", ")"}], TraditionalForm]]],
 " is set to 0."
}], "Text",
 CellTags->"A0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A0", "[", "0", "]"}]], "Input",
 CellTags->"A0",
 CellLabel->"In[59]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"A0",
 CellLabel->"Out[59]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A0", "[", 
  RowBox[{"SmallVariable", "[", 
   RowBox[{"M", "^", "2"}], "]"}], "]"}]], "Input",
 CellTags->"A0",
 CellLabel->"In[60]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"A0",
 CellLabel->"Out[60]="]
}, Open  ]]
}, Open  ]],

Cell["A0ToB0", "ObjectName",
 PageBreakAbove->True,
 CellTags->"A0ToB0"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"A0ToB0"],

Cell[TextData[{
 "A0ToB0 is an option for A0. If set to True, A0[",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["m",
     FontSlant->"Plain"], "2"], TraditionalForm]]],
 "] is expressed by (1 + B0[0, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["m",
     FontSlant->"Plain"], "2"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["m",
     FontSlant->"Plain"], "2"], TraditionalForm]]],
 "]) ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["m",
     FontSlant->"Plain"], "2"], TraditionalForm]]],
 "."
}], "Text",
 CellTags->"A0ToB0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", " ", "A0", "]"}]], "Input",
 CellTags->"A0ToB0",
 CellLabel->"In[61]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"A0ToB0", "\[Rule]", "False"}], "}"}], TraditionalForm]], "Output",\

 CellTags->"A0ToB0",
 CellLabel->"Out[61]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["A0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"A0",
  ButtonNote->"A0"],
 ", ",
 ButtonBox["B0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B0",
  ButtonNote->"B0"],
 ", ",
 ButtonBox["C0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"C0",
  ButtonNote->"C0"],
 ", ",
 ButtonBox["D0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"D0",
  ButtonNote->"D0"],
 ", ",
 ButtonBox["PaVe",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVe",
  ButtonNote->"PaVe"],
 "."
}], "Text",
 CellTags->"A0ToB0"]
}, Open  ]],

Cell["BackgroundGluonVertex", "ObjectName",
 CellTags->"BackgroundGluonVertex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"BackgroundGluonVertex"],

Cell[TextData[{
 "BackgroundGluonVertex[{p,mu,a}, {q,nu,b}, {k,la,c}] or \
BackgroundGluonVertex[ p,mu,a , q,nu,b , k,la,c ] yields the 3-gluon vertex \
in the background field gauge, where the first set of arguments corresponds \
to the external background field. BackgroundGluonVertex[{p,mu,a}, {q,nu,b}, \
{k,la,c}, {s,si,d}] or BackgroundGluonVertex[{mu,a}, {nu,b}, {la,c}, {",
 "si",
 ",d}] or BackgroundGluonVertex[p,mu,a , q,nu,b , k,la,c , s,si,d] or \
BackgroundGluonVertex[ mu,a , nu,b , la,c , si,d ] yields the 4-gluon vertex, \
with {p,mu,a} and {k,la,c} denoting the external background fields. The \
gauge, dimension and the name of the coupling constant are determined by the \
options Gauge, Dimension and CouplingConstant. The Feynman rules are taken \
from L.Abbot ",
 StyleBox["NPB ",
  FontWeight->"Bold"],
 "185 (1981), 189-203; except that all momenta are incoming. Note that Abbots \
coupling constant convention is consistent with the default setting of \
GluonVertex."
}], "Text",
 CellTags->"BackgroundGluonVertex"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "BackgroundGluonVertex", "]"}]], "Input",
 CellTags->"BackgroundGluonVertex",
 CellLabel->"In[62]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}], ",", 
    RowBox[{"Gauge", "\[Rule]", "1"}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"BackgroundGluonVertex",
 CellLabel->"Out[62]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["GluonVertex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonVertex",
  ButtonNote->"GluonVertex"],
 "."
}], "Text",
 CellTags->"BackgroundGluonVertex"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"BackgroundGluonVertex"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BackgroundGluonVertex", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "\[Lambda]", ",", "c"}], "}"}]}], "]"}]], "Input",
 CellTags->"BackgroundGluonVertex",
 CellLabel->"In[63]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["g", "s"], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FormBox[
         RowBox[{
          RowBox[{"-", "k"}], "+", "p", "-", "q"}],
         TraditionalForm], ")"}], 
       FormBox[
        FormBox["\[Lambda]",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Lambda]", "\[Mu]"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FormBox[
         RowBox[{"k", "-", "p", "+", "q"}],
         TraditionalForm], ")"}], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Lambda]", "\[Nu]"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FormBox[
         RowBox[{"q", "-", "k"}],
         TraditionalForm], ")"}], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"BackgroundGluonVertex",
 CellLabel->"Out[63]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BackgroundGluonVertex", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "\[Lambda]", ",", "c"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "\[Sigma]", ",", "d"}], "}"}]}], "]"}]], "Input",
 CellTags->"BackgroundGluonVertex",
 CellLabel->"In[64]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   SubsuperscriptBox["g", "s", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u6",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u6",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Lambda]", "\[Sigma]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Nu]"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Lambda]", "\[Nu]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Sigma]"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Lambda]", "\[Mu]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Nu]", "\[Sigma]"}]]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u6",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u6",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Lambda]", "\[Sigma]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Nu]"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Lambda]", "\[Nu]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Sigma]"}]]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u6",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u6",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Lambda]", "\[Sigma]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Nu]"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Lambda]", "\[Nu]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Sigma]"}]]}], "+", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Lambda]", "\[Mu]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Nu]", "\[Sigma]"}]]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"BackgroundGluonVertex",
 CellLabel->"Out[64]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BackgroundGluonVertex", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "\[Lambda]", ",", "c"}], "}"}], ",", 
   RowBox[{"Gauge", "\[Rule]", "\[Alpha]"}]}], "]"}]], "Input",
 CellTags->"BackgroundGluonVertex",
 CellLabel->"In[65]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["g", "s"], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FormBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["k", "\[Alpha]"]}], "+", "p", "-", "q"}],
         TraditionalForm], ")"}], 
       FormBox[
        FormBox["\[Lambda]",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Lambda]", "\[Mu]"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FormBox[
         RowBox[{"k", "-", "p", "+", 
          FractionBox["q", "\[Alpha]"]}],
         TraditionalForm], ")"}], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Lambda]", "\[Nu]"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FormBox[
         RowBox[{"q", "-", "k"}],
         TraditionalForm], ")"}], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"BackgroundGluonVertex",
 CellLabel->"Out[65]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BackgroundGluonVertex", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "\[Lambda]", ",", "c"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "\[Sigma]", ",", "d"}], "}"}], ",", 
   RowBox[{"Gauge", "\[Rule]", "\[Alpha]"}]}], "]"}]], "Input",
 CellTags->"BackgroundGluonVertex",
 CellLabel->"In[66]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   SubsuperscriptBox["g", "s", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u7",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u7",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["g", 
            RowBox[{"\[Lambda]", "\[Nu]"}]], " ", 
           SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[Sigma]"}]]}], "\[Alpha]"]}], "+", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Lambda]", "\[Sigma]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Nu]"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Lambda]", "\[Mu]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Nu]", "\[Sigma]"}]]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u7",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u7",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["g", 
           RowBox[{"\[Lambda]", "\[Sigma]"}]], " ", 
          SuperscriptBox["g", 
           RowBox[{"\[Mu]", "\[Nu]"}]]}], "\[Alpha]"], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Lambda]", "\[Nu]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Sigma]"}]]}], "+", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Lambda]", "\[Mu]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Nu]", "\[Sigma]"}]]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u7",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u7",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Lambda]", "\[Sigma]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Nu]"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Lambda]", "\[Nu]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Sigma]"}]]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"BackgroundGluonVertex",
 CellLabel->"Out[66]="]
}, Open  ]]
}, Open  ]],

Cell["Bracket", "ObjectName",
 CellTags->"Bracket"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Bracket"],

Cell["Bracket is an option of Convolute.", "Text",
 CellTags->"Bracket"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Convolute",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Convolute",
  ButtonNote->"Convolute"],
 "."
}], "Text",
 CellTags->"Bracket"]
}, Open  ]],

Cell["BReduce", "ObjectName",
 PageBreakAbove->True,
 CellTags->"BReduce"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"BReduce"],

Cell["\<\
BReduce is an option for B0, B00, B1, B11 determining whether reductions to \
A0 and B0 will be done. \
\>", "Text",
 CellTags->"BReduce"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["A0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"A0",
  ButtonNote->"A0"],
 ", ",
 ButtonBox["B0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B0",
  ButtonNote->"B0"],
 ", ",
 ButtonBox["B00",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B00",
  ButtonNote->"B00"],
 ", ",
 ButtonBox["B1",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B1",
  ButtonNote->"B1"],
 ", ",
 ButtonBox["B11",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B11",
  ButtonNote->"B11"],
 "."
}], "Text",
 CellTags->"BReduce"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"BReduce"],

Cell[TextData[{
 "By default ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["B", "0"], TraditionalForm]]],
 " is not expressed in terms of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "0"], TraditionalForm]]],
 "."
}], "Text",
 CellTags->"BReduce"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B0", "[", 
  RowBox[{"0", ",", "s", ",", "s"}], "]"}]], "Input",
 CellTags->"BReduce",
 CellLabel->"In[67]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["B", "0"], "(", "0", ",", "s", ",", "s", ")"}], 
  TraditionalForm]], "Output",
 CellTags->"BReduce",
 CellLabel->"Out[67]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B0", "//", "Options"}]], "Input",
 CellLabel->"In[68]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"BReduce", "\[Rule]", "False"}], ",", 
    RowBox[{"B0Unique", "\[Rule]", "False"}], ",", 
    RowBox[{"B0Real", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellLabel->"Out[68]="]
}, Open  ]],

Cell["\<\
With BReduce\[Rule]True, transformation is done.\
\>", "Text",
 CellTags->"BReduce"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B0", "[", 
  RowBox[{"0", ",", "s", ",", "s", ",", 
   RowBox[{"BReduce", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"BReduce",
 CellLabel->"In[69]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     FormBox[
      SubscriptBox["\<\"A\"\>", "\<\"0\"\>"],
      TraditionalForm], "(", "s", ")"}], "s"], "-", "1"}], 
  TraditionalForm]], "Output",
 CellTags->"BReduce",
 CellLabel->"Out[69]="]
}, Open  ]]
}, Open  ]],

Cell["B0", "ObjectName",
 CellTags->"B0"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"B0"],

Cell[TextData[{
 "B0[pp, ma^2, mb^2] is the Passarino-Veltman two-point integral ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["B", "0"], TraditionalForm]]],
 ". All arguments are scalars and have dimension mass^2. If the option \
BReduce is set to True certain B0's are reduced to A0's. Setting the option \
B0Unique to True simplifies B0[a,0,a] and B0[0,0,a]."
}], "Text",
 CellTags->"B0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "B0", "]"}]], "Input",
 CellTags->"B0",
 CellLabel->"In[70]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"BReduce", "\[Rule]", "False"}], ",", 
    RowBox[{"B0Unique", "\[Rule]", "False"}], ",", 
    RowBox[{"B0Real", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"B0",
 CellLabel->"Out[70]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["B1",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B1",
  ButtonNote->"B1"],
 ", ",
 ButtonBox["B00",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B00",
  ButtonNote->"B00"],
 ", ",
 ButtonBox["B11",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B11",
  ButtonNote->"B11"],
 ", ",
 ButtonBox["PaVe",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVe",
  ButtonNote->"PaVe"],
 "."
}], "Text",
 CellTags->"B0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"B0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B0", "[", 
  RowBox[{
   RowBox[{"SP", "[", 
    RowBox[{"p", ",", "p"}], "]"}], ",", 
   SuperscriptBox["m", "2"], ",", 
   SuperscriptBox["m", "2"]}], "]"}]], "Input",
 CellTags->"B0",
 CellLabel->"In[71]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["B", "0"], "(", 
   FormBox[
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"],
    TraditionalForm], ",", 
   SuperscriptBox["m", "2"], ",", 
   SuperscriptBox["m", "2"], ")"}], TraditionalForm]], "Output",
 CellTags->"B0",
 CellLabel->"Out[71]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"B0", ",", 
    RowBox[{"B0Unique", "\[Rule]", "True"}], ",", 
    RowBox[{"B0Real", "\[Rule]", "True"}]}], "]"}], ";"}]], "Input",
 CellTags->"B0",
 CellLabel->"In[72]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B0", "[", 
  RowBox[{"0", ",", "0", ",", 
   SuperscriptBox["m", "2"]}], "]"}]], "Input",
 CellTags->"B0",
 CellLabel->"In[73]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["B", "0"], "(", "0", ",", 
    SuperscriptBox["m", "2"], ",", 
    SuperscriptBox["m", "2"], ")"}], "+", "1"}], TraditionalForm]], "Output",
 CellTags->"B0",
 CellLabel->"Out[73]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B0", "[", 
  RowBox[{
   SuperscriptBox["m", "2"], ",", "0", ",", 
   SuperscriptBox["m", "2"]}], "]"}]], "Input",
 CellTags->"B0",
 CellLabel->"In[74]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["B", "0"], "(", "0", ",", 
    SuperscriptBox["m", "2"], ",", 
    SuperscriptBox["m", "2"], ")"}], "+", "2"}], TraditionalForm]], "Output",
 CellTags->"B0",
 CellLabel->"Out[74]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B0", "[", 
  RowBox[{"0", ",", 
   RowBox[{"m", "^", "2"}], ",", 
   RowBox[{"m", "^", "2"}]}], "]"}]], "Input",
 CellTags->"B0",
 CellLabel->"In[75]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["B", "0"], "(", "0", ",", 
   SuperscriptBox["m", "2"], ",", 
   SuperscriptBox["m", "2"], ")"}], TraditionalForm]], "Output",
 CellTags->"B0",
 CellLabel->"Out[75]="]
}, Open  ]]
}, Open  ]],

Cell["B0Real", "ObjectName",
 PageBreakAbove->True,
 CellTags->"B0Real"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"B0Real"],

Cell["\<\
B0Real is an option of B0 (default False). If set to True, B0 is assumed to \
be real and the relation B0[a,0,a] = 2 + B0[0,a,a]  is applied.\
\>", "Text",
 CellTags->"B0Real"],

Cell[TextData[{
 "See also: ",
 ButtonBox["B0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B0",
  ButtonNote->"B0"],
 "."
}], "Text",
 CellTags->"B0Real"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"B0Real"],

Cell["By default the arguments are not assumed real.", "Text",
 CellTags->"B0Real"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B0", "[", 
  RowBox[{"s", ",", "0", ",", "s"}], "]"}]], "Input",
 CellTags->"B0Real",
 CellLabel->"In[76]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["B", "0"], "(", "0", ",", "s", ",", "s", ")"}], "+", "2"}], 
  TraditionalForm]], "Output",
 CellTags->"B0Real",
 CellLabel->"Out[76]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B0", "//", "Options"}]], "Input",
 CellTags->"B0Real",
 CellLabel->"In[77]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"BReduce", "\[Rule]", "False"}], ",", 
    RowBox[{"B0Unique", "\[Rule]", "True"}], ",", 
    RowBox[{"B0Real", "\[Rule]", "True"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"B0Real",
 CellLabel->"Out[77]="]
}, Open  ]],

Cell["\<\
With B0Real\[Rule]True, transformation is done.\
\>", "Text",
 CellTags->"B0Real"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B0", "[", 
  RowBox[{"s", ",", "0", ",", "s", ",", 
   RowBox[{"B0Real", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"B0Real",
 CellLabel->"In[78]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["B", "0"], "(", "0", ",", "s", ",", "s", ")"}], "+", "2"}], 
  TraditionalForm]], "Output",
 CellTags->"B0Real",
 CellLabel->"Out[78]="]
}, Open  ]]
}, Open  ]],

Cell["B0Unique", "ObjectName",
 PageBreakAbove->True,
 CellTags->"B0Unique"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"B0Unique"],

Cell["\<\
B0Unique is an option of B0. If set to True, B0[0,0,m2] is replaced with \
(B0[0,m2,m2]+1) and B0[m2,0,m2] simplifies to (B0[0,m2,m2]+2).\
\>", "Text",
 CellTags->"B0Unique"],

Cell[TextData[{
 "See also: ",
 ButtonBox["B0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B0",
  ButtonNote->"B0"],
 "."
}], "Text",
 CellTags->"B0Unique"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"B0Unique"],

Cell["By default transformation is done.", "Text",
 CellTags->"B0Unique"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B0", "[", 
  RowBox[{"0", ",", "0", ",", "s"}], "]"}]], "Input",
 CellTags->"B0Unique",
 CellLabel->"In[79]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["B", "0"], "(", "0", ",", "s", ",", "s", ")"}], "+", "1"}], 
  TraditionalForm]], "Output",
 CellTags->"B0Unique",
 CellLabel->"Out[79]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B0", "//", "Options"}]], "Input",
 CellTags->"B0Unique",
 CellLabel->"In[80]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"BReduce", "\[Rule]", "False"}], ",", 
    RowBox[{"B0Unique", "\[Rule]", "True"}], ",", 
    RowBox[{"B0Real", "\[Rule]", "True"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"B0Unique",
 CellLabel->"Out[80]="]
}, Open  ]],

Cell["\<\
With B0Real\[Rule]False, nothing happens.\
\>", "Text",
 CellTags->"B0Unique"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B0", "[", 
  RowBox[{"0", ",", "0", ",", "s", ",", 
   RowBox[{"B0Unique", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"B0Unique",
 CellLabel->"In[81]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["B", "0"], "(", "0", ",", "0", ",", "s", ")"}], 
  TraditionalForm]], "Output",
 CellTags->"B0Unique",
 CellLabel->"Out[81]="]
}, Open  ]]
}, Open  ]],

Cell["B00", "ObjectName",
 CellTags->"B00"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"B00"],

Cell[TextData[{
 "B00[pp, ma^2,mb^2] is the Passarino-Veltman ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["B", "00"], TraditionalForm]]],
 "-function, i.e., the coefficient function of the metric tensor. All \
arguments are scalars and have dimension mass^2."
}], "Text",
 CellTags->"B00"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "B00", "]"}]], "Input",
 CellTags->"B00",
 CellLabel->"In[82]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"BReduce", "\[Rule]", "True"}], "}"}], TraditionalForm]], "Output",\

 CellTags->"B00",
 CellLabel->"Out[82]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["B0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B0",
  ButtonNote->"B0"],
 ", ",
 ButtonBox["B1",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B1",
  ButtonNote->"B1"],
 ", ",
 ButtonBox["PaVe",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVe",
  ButtonNote->"PaVe"],
 "."
}], "Text",
 CellTags->"B00"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"B00"],

Cell[TextData[{
 "Remember that SP[p] is a short hand input for ScalarProduct[p,p], i.e., ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["p", "2"], TraditionalForm]]],
 "."
}], "Text",
 CellTags->"B00"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SP", "[", "p", "]"}]], "Input",
 CellTags->"B00",
 CellLabel->"In[83]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   FormBox["p",
    TraditionalForm], "2"], TraditionalForm]], "Output",
 CellTags->"B00",
 CellLabel->"Out[83]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B00", "[", 
  RowBox[{
   RowBox[{"SP", "[", "p", "]"}], ",", 
   SuperscriptBox["m", "2"], ",", 
   SuperscriptBox["M", "2"]}], "]"}]], "Input",
 CellTags->"B00",
 CellLabel->"In[84]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["m", "2"], "-", 
         SuperscriptBox["M", "2"], "+", 
         FormBox[
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], "2"],
          TraditionalForm]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["M", "2"], "-", 
             SuperscriptBox["m", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SubscriptBox["B", "0"], "(", 
              FormBox[
               SuperscriptBox[
                FormBox["p",
                 TraditionalForm], "2"],
               TraditionalForm], ",", 
              SuperscriptBox["m", "2"], ",", 
              SuperscriptBox["M", "2"], ")"}], "-", 
             RowBox[{
              SubscriptBox["B", "0"], "(", "0", ",", 
              SuperscriptBox["m", "2"], ",", 
              SuperscriptBox["M", "2"], ")"}]}], ")"}]}], 
          RowBox[{"2", " ", 
           FormBox[
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], "2"],
            TraditionalForm]}]], "-", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{
           SubscriptBox["B", "0"], "(", 
           FormBox[
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], "2"],
            TraditionalForm], ",", 
           SuperscriptBox["m", "2"], ",", 
           SuperscriptBox["M", "2"], ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       FormBox[
        SubscriptBox["\<\"A\"\>", "\<\"0\"\>"],
        TraditionalForm], "(", 
       FormBox[
        SuperscriptBox["M", "2"],
        TraditionalForm], ")"}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "3"], " ", 
    SuperscriptBox["m", "2"], " ", 
    RowBox[{
     SubscriptBox["B", "0"], "(", 
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], ",", 
     SuperscriptBox["m", "2"], ",", 
     SuperscriptBox["M", "2"], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "18"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["m", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["M", "2"]}], "-", 
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm]}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"B00",
 CellLabel->"Out[84]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B00", "[", 
  RowBox[{
   RowBox[{"SP", "[", "p", "]"}], ",", 
   SuperscriptBox["m", "2"], ",", 
   SuperscriptBox["m", "2"]}], "]"}]], "Input",
 CellTags->"B00",
 CellLabel->"In[85]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["\<\"A\"\>", "\<\"0\"\>"],
        TraditionalForm], "(", 
       FormBox[
        SuperscriptBox["m", "2"],
        TraditionalForm], ")"}], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       FormBox[
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"],
        TraditionalForm], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", 
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["m", "2"], ")"}]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "3"], " ", 
    SuperscriptBox["m", "2"], " ", 
    RowBox[{
     SubscriptBox["B", "0"], "(", 
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], ",", 
     SuperscriptBox["m", "2"], ",", 
     SuperscriptBox["m", "2"], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "18"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"6", " ", 
       SuperscriptBox["m", "2"]}], "-", 
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm]}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"B00",
 CellLabel->"Out[85]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B00", "[", 
  RowBox[{
   RowBox[{"SP", "[", "p", "]"}], ",", 
   SuperscriptBox["m", "2"], ",", 
   SuperscriptBox["M", "2"], ",", 
   RowBox[{"BReduce", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"B00",
 CellLabel->"In[86]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    SubscriptBox["\<\"B\"\>", "\<\"00\"\>"],
    TraditionalForm], "(", 
   FormBox[
    FormBox[
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"],
     TraditionalForm],
    TraditionalForm], 
   RowBox[{",", " "}], 
   FormBox[
    SuperscriptBox["m", "2"],
    TraditionalForm], 
   RowBox[{",", " "}], 
   FormBox[
    SuperscriptBox["M", "2"],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"B00",
 CellLabel->"Out[86]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B00", "[", 
  RowBox[{"0", ",", 
   SuperscriptBox["m", "2"], ",", 
   SuperscriptBox["m", "2"]}], "]"}]], "Input",
 CellTags->"B00",
 CellLabel->"In[87]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "3"], " ", 
    SuperscriptBox["m", "2"], " ", 
    RowBox[{
     SubscriptBox["B", "0"], "(", "0", ",", 
     SuperscriptBox["m", "2"], ",", 
     SuperscriptBox["m", "2"], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\<\"A\"\>", "\<\"0\"\>"],
      TraditionalForm], "(", 
     FormBox[
      SuperscriptBox["m", "2"],
      TraditionalForm], ")"}]}], "+", 
   FractionBox[
    SuperscriptBox["m", "2"], "3"]}], TraditionalForm]], "Output",
 CellTags->"B00",
 CellLabel->"Out[87]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B00", "[", 
  RowBox[{
   RowBox[{"SmallVariable", "[", 
    SuperscriptBox["M", "2"], "]"}], ",", 
   SuperscriptBox["m", "2"], ",", 
   SuperscriptBox["m", "2"]}], "]"}]], "Input",
 CellTags->"B00",
 CellLabel->"In[88]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "3"], " ", 
    SuperscriptBox["m", "2"], " ", 
    RowBox[{
     SubscriptBox["B", "0"], "(", 
     SuperscriptBox["M", "2"], ",", 
     SuperscriptBox["m", "2"], ",", 
     SuperscriptBox["m", "2"], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\<\"A\"\>", "\<\"0\"\>"],
      TraditionalForm], "(", 
     FormBox[
      SuperscriptBox["m", "2"],
      TraditionalForm], ")"}]}], "+", 
   FractionBox[
    SuperscriptBox["m", "2"], "3"]}], TraditionalForm]], "Output",
 CellTags->"B00",
 CellLabel->"Out[88]="]
}, Open  ]]
}, Open  ]],

Cell["B1", "ObjectName",
 CellTags->"B1"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"B1"],

Cell[TextData[{
 "B1[pp, ma^2, mb^2] the Passarino-Veltman ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["B", "1"], TraditionalForm]]],
 "-function. All arguments are scalars and have dimension mass^2."
}], "Text",
 CellTags->"B1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "B1", "]"}]], "Input",
 CellTags->"B1",
 CellLabel->"In[89]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"BReduce", "\[Rule]", "True"}], "}"}], TraditionalForm]], "Output",\

 CellTags->"B1",
 CellLabel->"Out[89]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["B0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B0",
  ButtonNote->"B0"],
 ", ",
 ButtonBox["B00",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B00",
  ButtonNote->"B00"],
 ", ",
 ButtonBox["B11",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B11",
  ButtonNote->"B11"],
 ", ",
 ButtonBox["PaVe",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVe",
  ButtonNote->"PaVe"],
 ", ",
 ButtonBox["PaVeReduce",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVeReduce",
  ButtonNote->"PaVeReduce"],
 "."
}], "Text",
 CellTags->"B1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"B1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B1", "[", 
  RowBox[{
   RowBox[{"SP", "[", "p", "]"}], ",", 
   SuperscriptBox["m", "2"], ",", 
   SuperscriptBox["M", "2"]}], "]"}]], "Input",
 CellTags->"B1",
 CellLabel->"In[90]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["M", "2"], "-", 
       SuperscriptBox["m", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["B", "0"], "(", 
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["M", "2"], ")"}], "-", 
       RowBox[{
        SubscriptBox["B", "0"], "(", "0", ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["M", "2"], ")"}]}], ")"}]}], 
    RowBox[{"2", " ", 
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm]}]], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{
     SubscriptBox["B", "0"], "(", 
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], ",", 
     SuperscriptBox["m", "2"], ",", 
     SuperscriptBox["M", "2"], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"B1",
 CellLabel->"Out[90]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B1", "[", 
  RowBox[{
   RowBox[{"SP", "[", "p", "]"}], ",", 
   SuperscriptBox["m", "2"], ",", 
   SuperscriptBox["M", "2"], ",", 
   RowBox[{"BReduce", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"B1",
 CellLabel->"In[91]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["B", "1"], "(", 
   FormBox[
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"],
    TraditionalForm], ",", 
   SuperscriptBox["m", "2"], ",", 
   SuperscriptBox["M", "2"], ")"}], TraditionalForm]], "Output",
 CellTags->"B1",
 CellLabel->"Out[91]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"B1", ",", 
    RowBox[{"BReduce", "\[Rule]", "True"}]}], "]"}], ";"}]], "Input",
 CellTags->"B1",
 CellLabel->"In[92]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B1", "[", 
  RowBox[{
   RowBox[{"SP", "[", "p", "]"}], ",", 
   SuperscriptBox["m", "2"], ",", 
   SuperscriptBox["m", "2"]}], "]"}]], "Input",
 CellTags->"B1",
 CellLabel->"In[93]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", 
   RowBox[{
    SubscriptBox["B", "0"], "(", 
    FormBox[
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"],
     TraditionalForm], ",", 
    SuperscriptBox["m", "2"], ",", 
    SuperscriptBox["m", "2"], ")"}]}], TraditionalForm]], "Output",
 CellTags->"B1",
 CellLabel->"Out[93]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B1", "[", 
  RowBox[{
   SuperscriptBox["m", "2"], ",", 
   SuperscriptBox["m", "2"], ",", "0"}], "]"}]], "Input",
 CellTags->"B1",
 CellLabel->"In[94]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SubscriptBox["B", "0"], "(", "0", ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["m", "2"], ")"}]}], "-", "2"}], ")"}]}], "-", 
   FractionBox["1", "2"]}], TraditionalForm]], "Output",
 CellTags->"B1",
 CellLabel->"Out[94]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B1", "[", 
  RowBox[{"0", ",", "0", ",", 
   SuperscriptBox["m", "2"]}], "]"}]], "Input",
 CellTags->"B1",
 CellLabel->"In[95]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SubscriptBox["B", "0"], "(", "0", ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["m", "2"], ")"}]}], "-", "1"}], ")"}]}], "+", 
   FractionBox["1", "4"]}], TraditionalForm]], "Output",
 CellTags->"B1",
 CellLabel->"Out[95]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B1", "[", 
  RowBox[{"pp", ",", 
   RowBox[{"SmallVariable", "[", 
    SubsuperscriptBox["m", "e", "2"], "]"}], ",", 
   SubsuperscriptBox["m", "2", "2"]}], "]"}]], "Input",
 CellTags->"B1",
 CellLabel->"In[96]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SubsuperscriptBox["m", "2", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["B", "0"], "(", "pp", ",", 
        SubsuperscriptBox["m", "e", "2"], ",", 
        SubsuperscriptBox["m", "2", "2"], ")"}], "-", 
       RowBox[{
        SubscriptBox["B", "0"], "(", "0", ",", 
        SubsuperscriptBox["m", "e", "2"], ",", 
        SubsuperscriptBox["m", "2", "2"], ")"}]}], ")"}]}], 
    RowBox[{"2", " ", "pp"}]], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{
     SubscriptBox["B", "0"], "(", "pp", ",", 
     SubsuperscriptBox["m", "e", "2"], ",", 
     SubsuperscriptBox["m", "2", "2"], ")"}]}]}], TraditionalForm]], "Output",\

 CellTags->"B1",
 CellLabel->"Out[96]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B1", "[", 
  RowBox[{
   RowBox[{"SmallVariable", "[", 
    SubsuperscriptBox["m", "e", "2"], "]"}], ",", 
   RowBox[{"SmallVariable", "[", 
    SubsuperscriptBox["m", "e", "2"], "]"}], ",", "0"}], "]"}]], "Input",
 CellTags->"B1",
 CellLabel->"In[97]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SubscriptBox["B", "0"], "(", "0", ",", 
        SubsuperscriptBox["m", "e", "2"], ",", 
        SubsuperscriptBox["m", "e", "2"], ")"}]}], "-", "2"}], ")"}]}], "-", 
   FractionBox["1", "2"]}], TraditionalForm]], "Output",
 CellTags->"B1",
 CellLabel->"Out[97]="]
}, Open  ]]
}, Open  ]],

Cell["B11", "ObjectName",
 CellTags->"B11"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"B11"],

Cell[TextData[{
 "B11[pp, ma^2, mb^2] is the Passarino-Veltman ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["B", "11"], TraditionalForm]]],
 "-function, i.e., the coefficient function of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["p", "\[Mu]"], " ", 
    SuperscriptBox["p", "\[Nu]"]}], TraditionalForm]]],
 ". All arguments are scalars and have dimension mass",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Null]", "2"], TraditionalForm]]],
 "."
}], "Text",
 CellTags->"B11"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "B11", "]"}]], "Input",
 CellTags->"B11",
 CellLabel->"In[98]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"BReduce", "\[Rule]", "True"}], "}"}], TraditionalForm]], "Output",\

 CellTags->"B11",
 CellLabel->"Out[98]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["B0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B0",
  ButtonNote->"B0"],
 ", ",
 ButtonBox["B00",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B00",
  ButtonNote->"B00"],
 ", ",
 ButtonBox["B1",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B1",
  ButtonNote->"B1"],
 ", ",
 ButtonBox["PaVe",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVe",
  ButtonNote->"PaVe"],
 "."
}], "Text",
 CellTags->"B11"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"B11"],

Cell[TextData[{
 "Remember that SP[p] is a short hand input for ScalarProduct[p,p], i.e. ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["p", "2"], "."}], TraditionalForm]]]
}], "Text",
 CellTags->"B11"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SP", "[", "p", "]"}]], "Input",
 CellTags->"B11",
 CellLabel->"In[99]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   FormBox["p",
    TraditionalForm], "2"], TraditionalForm]], "Output",
 CellTags->"B11",
 CellLabel->"Out[99]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B11", "[", 
  RowBox[{
   RowBox[{"SP", "[", "p", "]"}], ",", 
   SuperscriptBox["m", "2"], ",", 
   SuperscriptBox["M", "2"]}], "]"}]], "Input",
 CellTags->"B11",
 CellLabel->"In[100]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", 
    RowBox[{"3", " ", 
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm]}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["m", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"-", 
        RowBox[{
         SubscriptBox["B", "0"], "(", 
         FormBox[
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], "2"],
          TraditionalForm], ",", 
         SuperscriptBox["m", "2"], ",", 
         SuperscriptBox["M", "2"], ")"}]}], ")"}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["m", "2"], "-", 
        SuperscriptBox["M", "2"], "+", 
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["M", "2"], "-", 
            SuperscriptBox["m", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SubscriptBox["B", "0"], "(", 
             FormBox[
              SuperscriptBox[
               FormBox["p",
                TraditionalForm], "2"],
              TraditionalForm], ",", 
             SuperscriptBox["m", "2"], ",", 
             SuperscriptBox["M", "2"], ")"}], "-", 
            RowBox[{
             SubscriptBox["B", "0"], "(", "0", ",", 
             SuperscriptBox["m", "2"], ",", 
             SuperscriptBox["M", "2"], ")"}]}], ")"}]}], 
         RowBox[{"2", " ", 
          FormBox[
           SuperscriptBox[
            FormBox["p",
             TraditionalForm], "2"],
           TraditionalForm]}]], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{
          SubscriptBox["B", "0"], "(", 
          FormBox[
           SuperscriptBox[
            FormBox["p",
             TraditionalForm], "2"],
           TraditionalForm], ",", 
          SuperscriptBox["m", "2"], ",", 
          SuperscriptBox["M", "2"], ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      FormBox[
       SubscriptBox["\<\"A\"\>", "\<\"0\"\>"],
       TraditionalForm], "(", 
      FormBox[
       SuperscriptBox["M", "2"],
       TraditionalForm], ")"}], "+", 
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"3", " ", 
          SuperscriptBox["m", "2"]}]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["M", "2"]}], "+", 
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"B11",
 CellLabel->"Out[100]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B11", "[", 
  RowBox[{
   RowBox[{"SP", "[", "p", "]"}], ",", 
   SuperscriptBox["m", "2"], ",", 
   SuperscriptBox["m", "2"]}], "]"}]], "Input",
 CellTags->"B11",
 CellLabel->"In[101]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FormBox[
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"],
        TraditionalForm], "-", 
       SuperscriptBox["m", "2"]}], ")"}], " ", 
     RowBox[{
      SubscriptBox["B", "0"], "(", 
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], ",", 
      SuperscriptBox["m", "2"], ",", 
      SuperscriptBox["m", "2"], ")"}]}], "+", 
    RowBox[{
     FormBox[
      SubscriptBox["\<\"A\"\>", "\<\"0\"\>"],
      TraditionalForm], "(", 
     FormBox[
      SuperscriptBox["m", "2"],
      TraditionalForm], ")"}], "+", 
    RowBox[{
     FractionBox["1", "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       FormBox[
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"],
        TraditionalForm], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["m", "2"]}]}], ")"}]}]}], 
   RowBox[{"3", " ", 
    FormBox[
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"],
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"B11",
 CellLabel->"Out[101]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetOptions", "[", 
  RowBox[{"B11", ",", 
   RowBox[{"BReduce", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"B11",
 CellLabel->"In[102]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"BReduce", "\[Rule]", "False"}], "}"}], TraditionalForm]], "Output",\

 CellTags->"B11",
 CellLabel->"Out[102]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B11", "[", 
  RowBox[{
   RowBox[{"SP", "[", "p", "]"}], ",", 
   SuperscriptBox["m", "2"], ",", 
   SuperscriptBox["M", "2"]}], "]"}]], "Input",
 CellTags->"B11",
 CellLabel->"In[103]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    SubscriptBox["\<\"B\"\>", "\<\"11\"\>"],
    TraditionalForm], "(", 
   FormBox[
    FormBox[
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"],
     TraditionalForm],
    TraditionalForm], 
   RowBox[{",", " "}], 
   FormBox[
    SuperscriptBox["m", "2"],
    TraditionalForm], 
   RowBox[{",", " "}], 
   FormBox[
    SuperscriptBox["M", "2"],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"B11",
 CellLabel->"Out[103]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetOptions", "[", 
  RowBox[{"B11", ",", 
   RowBox[{"BReduce", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"B11",
 CellLabel->"In[104]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"BReduce", "\[Rule]", "True"}], "}"}], TraditionalForm]], "Output",\

 CellTags->"B11",
 CellLabel->"Out[104]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B11", "[", 
  RowBox[{"0", ",", 
   SuperscriptBox["m", "2"], ",", 
   SuperscriptBox["m", "2"]}], "]"}]], "Input",
 CellTags->"B11",
 CellLabel->"In[105]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "3"], " ", 
   RowBox[{
    SubscriptBox["B", "0"], "(", "0", ",", 
    SuperscriptBox["m", "2"], ",", 
    SuperscriptBox["m", "2"], ")"}]}], TraditionalForm]], "Output",
 CellTags->"B11",
 CellLabel->"Out[105]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B11", "[", 
  RowBox[{
   RowBox[{"SmallVariable", "[", 
    SuperscriptBox["M", "2"], "]"}], ",", 
   SuperscriptBox["m", "2"], ",", 
   SuperscriptBox["m", "2"]}], "]"}]], "Input",
 CellTags->"B11",
 CellLabel->"In[106]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "3"], " ", 
   RowBox[{
    SubscriptBox["B", "0"], "(", 
    SuperscriptBox["M", "2"], ",", 
    SuperscriptBox["m", "2"], ",", 
    SuperscriptBox["m", "2"], ")"}]}], TraditionalForm]], "Output",
 CellTags->"B11",
 CellLabel->"Out[106]="]
}, Open  ]]
}, Open  ]],

Cell["CA", "ObjectName",
 CellTags->"CA"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"CA"],

Cell[TextData[{
 "CA is one of the Casimir operator eigenvalues of SU(",
 StyleBox["N",
  FontSlant->"Italic"],
 ") (CA = ",
 StyleBox["N",
  FontSlant->"Italic"],
 ")."
}], "Text",
 CellTags->"CA"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["CF",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CF",
  ButtonNote->"CF"],
 ", ",
 ButtonBox["SUNSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNSimplify",
  ButtonNote->"SUNSimplify"],
 "."
}], "Text",
 CellTags->"CA"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"CA"],

Cell[CellGroupData[{

Cell[BoxData["CA"], "Input",
 CellTags->"CA",
 CellLabel->"In[107]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["C", "A"], TraditionalForm]], "Output",
 CellTags->"CA",
 CellLabel->"Out[107]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{"CA", ",", 
   RowBox[{"SUNNToCACF", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"CA",
 CellLabel->"In[108]:="],

Cell[BoxData[
 FormBox["N", TraditionalForm]], "Output",
 CellTags->"CA",
 CellLabel->"Out[108]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["SUNN"], "Input",
 CellTags->"CA",
 CellLabel->"In[109]:="],

Cell[BoxData[
 FormBox["N", TraditionalForm]], "Output",
 CellTags->"CA",
 CellLabel->"Out[109]="]
}, Open  ]]
}, Open  ]],

Cell["Calc", "ObjectName",
 CellTags->"Calc"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Calc"],

Cell["\<\
Calc[exp] performs several basic simplifications. Calc[exp] is the same as \
DotSimplify[DiracSimplify[Contract[DiracSimplify[Explicit[ \
SUNSimplify[Trick[exp], Explicit\[Rule]False] ]]]]].\
\>", "Text",
 CellTags->"Calc"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 ", ",
 ButtonBox["DiracTrick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrick",
  ButtonNote->"DiracTrick"],
 ", ",
 ButtonBox["Trick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Trick",
  ButtonNote->"Trick"],
 "."
}], "Text",
 CellTags->"Calc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Examples"], "Subsubsection",
 CellTags->"Calc"],

Cell[TextData[{
 "This calculates ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Gamma]", "\[Mu]"], 
    SubscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]]],
 " in 4 dimensions and ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["g", "\[Nu]", "\[Nu]"], TraditionalForm]]],
 " in D dimensions."
}], "Text",
 CellTags->"Calc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"GA", "[", 
     RowBox[{"\[Mu]", ",", "\[Mu]"}], "]"}], ",", " ", 
    RowBox[{"MTD", "[", 
     RowBox[{"\[Nu]", ",", "\[Nu]"}], "]"}]}], "}"}], "]"}]], "Input",
 CellTags->"Calc",
 CellLabel->"In[110]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"4", ",", "D"}], "}"}], TraditionalForm]], "Output",
 CellTags->"Calc",
 CellLabel->"Out[110]="]
}, Open  ]],

Cell[TextData[{
 "This simplifies ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["f", "abc"], " ", 
    RowBox[{
     SubscriptBox["f", "abe"], "."}]}], TraditionalForm]]]
}], "Text",
 CellTags->"Calc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", 
  RowBox[{
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", "e"}], "]"}]}], "]"}]], "Input",
 CellTags->"Calc",
 CellLabel->"In[111]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "A"], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"Calc",
 CellLabel->"Out[111]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FV", "[", 
   RowBox[{
    RowBox[{"p", "+", "r"}], ",", "\[Mu]"}], "]"}], " ", 
  RowBox[{"MT", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], " ", 
  RowBox[{"FV", "[", 
   RowBox[{
    RowBox[{"q", "-", "p"}], ",", "\[Nu]"}], "]"}]}]], "Input",
 CellTags->"Calc",
 CellLabel->"In[112]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["g", 
    RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
   RowBox[{"(", 
    SuperscriptBox[
     FormBox[
      RowBox[{"q", "-", "p"}],
      TraditionalForm], "\[Nu]"], ")"}], " ", 
   RowBox[{"(", 
    SuperscriptBox[
     FormBox[
      RowBox[{"p", "+", "r"}],
      TraditionalForm], "\[Mu]"], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Calc",
 CellLabel->"Out[112]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", "%", "]"}]], "Input",
 CellTags->"Calc",
 CellLabel->"In[113]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FormBox["p",
     TraditionalForm], "\[CenterDot]", 
    FormBox["q",
     TraditionalForm]}], "-", 
   RowBox[{
    FormBox["p",
     TraditionalForm], "\[CenterDot]", 
    FormBox["r",
     TraditionalForm]}], "-", 
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], "2"], "+", 
   RowBox[{
    FormBox["q",
     TraditionalForm], "\[CenterDot]", 
    FormBox["r",
     TraditionalForm]}]}], TraditionalForm]], "Output",
 CellTags->"Calc",
 CellLabel->"Out[113]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GluonVertex", "[", 
  RowBox[{"p", ",", "1", ",", "q", ",", "2", ",", 
   RowBox[{
    RowBox[{"-", "p"}], "-", "q"}], ",", "3"}], "]"}]], "Input",
 CellTags->"Calc",
 CellLabel->"In[114]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["ci1",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["ci2",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["ci3",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{
    SuperscriptBox["V", 
     RowBox[{
      FormBox[
       FormBox["li1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["li2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["li3",
        TraditionalForm],
       TraditionalForm]}]], "(", 
    RowBox[{
     FormBox["p",
      TraditionalForm], 
     RowBox[{",", " "}], 
     FormBox["q",
      TraditionalForm], 
     RowBox[{",", " "}], 
     FormBox[
      RowBox[{
       RowBox[{"-", "p"}], "-", "q"}],
      TraditionalForm]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Calc",
 CellLabel->"Out[114]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", 
  RowBox[{
   RowBox[{"%", " ", 
    RowBox[{"FVD", "[", 
     RowBox[{"p", ",", "li1"}], "]"}]}], " ", 
   RowBox[{"FVD", "[", 
    RowBox[{"q", ",", "li2"}], "]"}], " ", 
   RowBox[{"FVD", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "p"}], "-", "q"}], ",", "li3"}], "]"}]}], "]"}]], "Input",
 CellTags->"Calc",
 CellLabel->"In[115]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"Calc",
 CellLabel->"Out[115]="]
}, Open  ]]
}, Open  ]],

Cell["CalcColorFactor", "ObjectName",
 CellTags->"CalcColorFactor"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"CalcColorFactor"],

Cell["\<\
CalcColorFactor[expr] calculates the color factor of expr.  CalcColorFactor \
is useful for application on FeynArts produced amplitudes. CalcColorFactor is \
just a macro function for CalcColorFactor[x_] := 
If[FreeQ2[FeynCalcInternal[x], SUNIndex],  x, 
                    SUNSimplify[SUNSimplify[  (If[ !FreeQ[#1, DiracGamma], \
DiracTrick[#1], #1] & )[  SUNSimplify[x]], Explicit -> False], Explicit -> \
True]].\
\>", "Text",
 CellTags->"CalcColorFactor"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["SUNSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNSimplify",
  ButtonNote->"SUNSimplify"],
 "."
}], "Text",
 CellTags->"CalcColorFactor"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CalcColorFactor", "[", 
  RowBox[{
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", "d"}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[116]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "A"], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellLabel->"Out[116]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Amplitude", "[", "\"\<q2se2\>\"", "]"}]], "Input",
 CellLabel->"In[117]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[CapitalPi]", 
     RowBox[{
      SubscriptBox["c", "1"], 
      SubscriptBox["c", "3"]}], 
     RowBox[{
      SubscriptBox["\[Lambda]", "1"], 
      SubscriptBox["\[Lambda]", "3"]}]], "(", "q2", ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["\[CapitalPi]", 
     RowBox[{
      SubscriptBox["c", "9"], 
      SubscriptBox["c", "11"]}], 
     RowBox[{
      SubscriptBox["\[Lambda]", "9"], 
      SubscriptBox["\[Lambda]", "11"]}]], "(", "q2", ")"}], " ", 
   RowBox[{
    SubsuperscriptBox["Q", 
     SubscriptBox["c", "11"], 
     SubscriptBox["\[Lambda]", "11"]], ".", 
    RowBox[{
     SubscriptBox["\[CapitalPi]", "q"], "(", 
     FormBox[
      RowBox[{"p", "-", "q2"}],
      TraditionalForm], ")"}], ".", 
    SubsuperscriptBox["Q", 
     SubscriptBox["c", "1"], 
     SubscriptBox["\[Lambda]", "1"]]}], " ", 
   RowBox[{"(", 
    RowBox[{"-", 
     RowBox[{"tr", "(", 
      FormBox[
       RowBox[{"2", " ", 
        SubscriptBox["T", "f"], " ", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[CapitalPi]", "q"], "(", 
          FormBox[
           RowBox[{"-", "q1"}],
           TraditionalForm], ")"}], ".", 
         SubsuperscriptBox["Q", 
          SubscriptBox["c", "9"], 
          SubscriptBox["\[Lambda]", "9"]], ".", 
         RowBox[{
          SubscriptBox["\[CapitalPi]", "q"], "(", 
          FormBox[
           RowBox[{"q2", "-", "q1"}],
           TraditionalForm], ")"}], ".", 
         SubsuperscriptBox["Q", 
          SubscriptBox["c", "3"], 
          SubscriptBox["\[Lambda]", "3"]]}]}],
       TraditionalForm], ")"}]}], ")"}]}], TraditionalForm]], "Output",
 CellLabel->"Out[117]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CalcColorFactor", "@", 
  RowBox[{"Explicit", "@", "%"}]}]], "Input",
 CellLabel->"In[118]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["1", 
       SuperscriptBox["q2", "2"]], ")"}], "2"], " ", 
    SubscriptBox["C", "F"], " ", 
    SubscriptBox["T", "f"], " ", 
    SuperscriptBox["g", 
     RowBox[{
      SubscriptBox["\[Lambda]", "1"], 
      SubscriptBox["\[Lambda]", "3"]}]], " ", 
    SuperscriptBox["g", 
     RowBox[{
      SubscriptBox["\[Lambda]", "9"], 
      SubscriptBox["\[Lambda]", "11"]}]], " ", 
    SubsuperscriptBox["g", "s", "4"], " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Lambda]", "11"],
        TraditionalForm],
       TraditionalForm]], ".", 
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", "(", 
       FormBox[
        RowBox[{"p", "-", "q2"}],
        TraditionalForm], ")"}], ")"}], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Lambda]", "1"],
        TraditionalForm],
       TraditionalForm]]}], " ", 
    RowBox[{"tr", "(", 
     FormBox[
      RowBox[{"-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FormBox["\<\"\[Gamma]\"\>",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q1",
           TraditionalForm]}], ")"}], ".", 
        SuperscriptBox["\[Gamma]", 
         FormBox[
          FormBox[
           SubscriptBox["\[Lambda]", "9"],
           TraditionalForm],
          TraditionalForm]], ".", 
        RowBox[{"(", 
         RowBox[{
          FormBox["\<\"\[Gamma]\"\>",
           TraditionalForm], "\[CenterDot]", "(", 
          FormBox[
           RowBox[{"q1", "-", "q2"}],
           TraditionalForm], ")"}], ")"}], ".", 
        SuperscriptBox["\[Gamma]", 
         FormBox[
          FormBox[
           SubscriptBox["\[Lambda]", "3"],
           TraditionalForm],
          TraditionalForm]]}]}],
      TraditionalForm], ")"}]}], 
   RowBox[{
    SuperscriptBox["q1", "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"p", "-", "q2"}], ")"}], "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q2", "-", "q1"}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellLabel->"Out[118]="]
}, Open  ]],

Cell[TextData[{
 "See also:  ",
 ButtonBox["ScalarProductCancel",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ScalarProductCancel",
  ButtonNote->"ScalarProductCancel"],
 ", ",
 ButtonBox["Series2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Series2",
  ButtonNote->"Series2"],
 ", ",
 ButtonBox["TID",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TID",
  ButtonNote->"TID"],
 "."
}], "Text",
 CellTags->"Collecting"]
}, Open  ]],

Cell["CalculateCounterTerm ***unfinished***", "ObjectName",
 CellTags->"CalculateCounterTerm"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"CalculateCounterTerm"],

Cell["CalculateCounterTerm[exp, k] calculates the residue of exp.", "Text",
 CellTags->"CalculateCounterTerm"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Examples"], "Subsubsection",
 CellTags->"CalculateCounterTerm"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "CalculateCounterTerm"}]], "Input",
 CellTags->"CalculateCounterTerm",
 CellLabel->"In[119]:="],

Cell[BoxData[
 StyleBox["\<\"CalculateCounterTerm[exp, k] calculates the residue of \
exp.\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->{"CalculateCounterTerm", "Info3522790126-4590919"}]
}, Open  ]]
}, Open  ]],

Cell["CancelQP", "ObjectName",
 CellTags->"CancelQP"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"CancelQP"],

Cell[TextData[{
 "CancelQP is an option for OneLoop. If set to True, cancelation of all ",
 StyleBox["q",
  FontSlant->"Italic"],
 ".",
 StyleBox["p",
  FontSlant->"Italic"],
 "'s and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["q", "2"], TraditionalForm]]],
 " is performed."
}], "Text",
 CellTags->"CancelQP"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Examples"], "Subsubsection",
 CellTags->"CancelQP"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"SPD", "[", 
     RowBox[{
      RowBox[{"p", "+", 
       RowBox[{"2", "q2"}]}], ",", 
      RowBox[{"p", "+", "q2"}]}], "]"}], " ", 
    RowBox[{"FAD", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"q2", "-", "p"}], ",", "m"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q2", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q2", ",", "M"}], "}"}]}], "]"}]}], "//", "FCI"}]}]], "Input",
 CellTags->"CancelQP",
 CellLabel->"In[120]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"(", 
    FormBox[
     RowBox[{"p", "+", "q2"}],
     TraditionalForm], ")", "\[CenterDot]", "(", 
    FormBox[
     RowBox[{"p", "+", 
      RowBox[{"2", " ", "q2"}]}],
     TraditionalForm], ")"}], 
   RowBox[{
    SuperscriptBox["q2", "2"], ".", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["M", "2"]}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"q2", "-", "p"}], ")"}], "2"], "-", 
      SuperscriptBox["m", "2"]}], ")"}]}]], TraditionalForm]], "Output",
 CellTags->"CancelQP",
 CellLabel->"Out[120]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OneLoop", "[", 
  RowBox[{"q2", ",", "t", ",", 
   RowBox[{"CancelQP", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"CancelQP",
 CellLabel->"In[121]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SuperscriptBox["\[Pi]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", 
       SuperscriptBox["m", "2"], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], ",", "0", ",", 
        SuperscriptBox["m", "2"], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["M", "2"]}]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["m", "2"]}], "-", 
         RowBox[{"7", " ", 
          SuperscriptBox["M", "2"]}]}], ")"}], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["M", "2"], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["M", "2"]}]], "-", 
     FractionBox[
      RowBox[{"5", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], ",", "0", ",", 
        SuperscriptBox["m", "2"], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["M", "2"]}]], "+", 
     FractionBox[
      RowBox[{"5", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["M", "2"], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["M", "2"]}]], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       RowBox[{
        FormBox[
         SubscriptBox["\<\"A\"\>", "\<\"0\"\>"],
         TraditionalForm], "(", 
        FormBox[
         SuperscriptBox["M", "2"],
         TraditionalForm], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["M", "2"]}]]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"CancelQP",
 CellLabel->"Out[121]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OneLoop", "[", 
  RowBox[{"q2", ",", "t", ",", 
   RowBox[{"CancelQP", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"CancelQP",
 CellLabel->"In[122]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SuperscriptBox["\[Pi]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"8", " ", 
        RowBox[{"PaVe", "(", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{"{", 
           SuperscriptBox[
            FormBox["p",
             TraditionalForm], "2"], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            SuperscriptBox["m", "2"]}], "}"}]}], ")"}]}], 
       SuperscriptBox["M", "2"]]}], "+", 
     FractionBox[
      RowBox[{"8", " ", 
       RowBox[{"PaVe", "(", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{"{", 
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], "2"], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           SuperscriptBox["m", "2"], ",", 
           SuperscriptBox["M", "2"]}], "}"}]}], ")"}]}], 
      SuperscriptBox["M", "2"]], "+", 
     FractionBox[
      RowBox[{"17", " ", 
       SuperscriptBox["m", "2"], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], ",", "0", ",", 
        SuperscriptBox["m", "2"], ")"}]}], 
      RowBox[{"6", " ", 
       SuperscriptBox["M", "2"]}]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"13", " ", 
          SuperscriptBox["m", "2"]}], "-", 
         RowBox[{"17", " ", 
          SuperscriptBox["M", "2"]}]}], ")"}], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["M", "2"], ")"}]}], 
      RowBox[{"6", " ", 
       SuperscriptBox["M", "2"]}]], "-", 
     FractionBox[
      RowBox[{"19", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], ",", "0", ",", 
        SuperscriptBox["m", "2"], ")"}]}], 
      RowBox[{"6", " ", 
       SuperscriptBox["M", "2"]}]], "+", 
     FractionBox[
      RowBox[{"19", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["M", "2"], ")"}]}], 
      RowBox[{"6", " ", 
       SuperscriptBox["M", "2"]}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["m", "2"], "-", 
          SuperscriptBox["M", "2"]}], ")"}], "2"], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", "0", ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["M", "2"], ")"}]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["M", "2"], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["m", "2"], "-", 
          SuperscriptBox["M", "2"]}], ")"}], "2"], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["M", "2"], ")"}]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["M", "2"], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{"13", " ", 
       SuperscriptBox["m", "2"], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", "0", ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["m", "2"], ")"}]}], 
      RowBox[{"6", " ", 
       SuperscriptBox["M", "2"]}]], "-", 
     FractionBox[
      RowBox[{"13", " ", 
       SuperscriptBox["m", "2"], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", "0", ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["M", "2"], ")"}]}], 
      RowBox[{"6", " ", 
       SuperscriptBox["M", "2"]}]], "+", 
     RowBox[{
      FractionBox["13", "6"], " ", 
      RowBox[{
       SubscriptBox["B", "0"], "(", "0", ",", 
       SuperscriptBox["m", "2"], ",", 
       SuperscriptBox["M", "2"], ")"}]}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["m", "4"], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", "0", ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["m", "2"], ")"}]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["M", "2"], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["m", "4"], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], ",", "0", ",", 
        SuperscriptBox["m", "2"], ")"}]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["M", "2"], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        FormBox[
         SubscriptBox["\<\"A\"\>", "\<\"0\"\>"],
         TraditionalForm], "(", 
        FormBox[
         SuperscriptBox["m", "2"],
         TraditionalForm], ")"}]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["M", "2"]}]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{
        FormBox[
         SubscriptBox["\<\"A\"\>", "\<\"0\"\>"],
         TraditionalForm], "(", 
        FormBox[
         SuperscriptBox["M", "2"],
         TraditionalForm], ")"}]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["M", "2"]}]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["m", "4"]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["M", "2"], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{"13", " ", 
       SuperscriptBox["m", "2"]}], 
      RowBox[{"6", " ", 
       SuperscriptBox["M", "2"]}]], "-", 
     FractionBox["4", "3"]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"CancelQP",
 CellLabel->"Out[122]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"SPD", "[", 
     RowBox[{"q2", ",", "p"}], "]"}], 
    RowBox[{"SPD", "[", 
     RowBox[{"q1", ",", "p"}], "]"}], " ", 
    RowBox[{"FAD", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q1", ",", "m"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q2", ",", "m"}], "}"}], ",", 
      RowBox[{"q1", "-", "p"}], ",", 
      RowBox[{"q2", "-", "p"}], ",", 
      RowBox[{"q2", "-", "q1"}]}], "]"}]}], "//", "FCI"}]}]], "Input",
 CellTags->"CancelQP",
 CellLabel->"In[123]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q1",
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q2",
      TraditionalForm]}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["m", "2"]}], ")"}], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q1", "-", "p"}], ")"}], "2"], ".", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["m", "2"]}], ")"}], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q2", "-", "p"}], ")"}], "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q2", "-", "q1"}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellTags->"CancelQP",
 CellLabel->"Out[123]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OneLoop", "[", 
  RowBox[{"q2", ",", "t", ",", 
   RowBox[{"CancelQP", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"CancelQP",
 CellLabel->"In[124]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SuperscriptBox["\[Pi]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["m", "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q1",
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["\<\"C\"\>", "\<\"0\"\>"],
          TraditionalForm], "(", 
         FormBox[
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], "2"],
          TraditionalForm], ",", 
         FormBox[
          SuperscriptBox[
           FormBox["q1",
            TraditionalForm], "2"],
          TraditionalForm], ",", 
         FormBox[
          RowBox[{
           RowBox[{"-", 
            RowBox[{"2", " ", 
             RowBox[{
              FormBox["p",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q1",
               TraditionalForm]}]}]}], "+", 
           SuperscriptBox[
            FormBox["p",
             TraditionalForm], "2"], "+", 
           SuperscriptBox[
            FormBox["q1",
             TraditionalForm], "2"]}],
          TraditionalForm], ",", 
         FormBox["0",
          TraditionalForm], ",", 
         FormBox["0",
          TraditionalForm], ",", 
         FormBox[
          SuperscriptBox["m", "2"],
          TraditionalForm], ")"}]}], 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["m", "2"], "-", 
          SuperscriptBox[
           FormBox["q1",
            TraditionalForm], "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"2", " ", 
            RowBox[{
             FormBox["p",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q1",
              TraditionalForm]}]}]}], "+", 
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], "2"], "+", 
          SuperscriptBox[
           FormBox["q1",
            TraditionalForm], "2"]}], ")"}]}]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q1",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox[
         SubscriptBox["\<\"C\"\>", "\<\"0\"\>"],
         TraditionalForm], "(", 
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], ",", 
        FormBox[
         SuperscriptBox[
          FormBox["q1",
           TraditionalForm], "2"],
         TraditionalForm], ",", 
        FormBox[
         RowBox[{
          RowBox[{"-", 
           RowBox[{"2", " ", 
            RowBox[{
             FormBox["p",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q1",
              TraditionalForm]}]}]}], "+", 
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], "2"], "+", 
          SuperscriptBox[
           FormBox["q1",
            TraditionalForm], "2"]}],
         TraditionalForm], ",", 
        FormBox["0",
         TraditionalForm], ",", 
        FormBox["0",
         TraditionalForm], ",", 
        FormBox[
         SuperscriptBox["m", "2"],
         TraditionalForm], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["m", "2"], "-", 
         SuperscriptBox[
          FormBox["q1",
           TraditionalForm], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"2", " ", 
           RowBox[{
            FormBox["p",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q1",
             TraditionalForm]}]}]}], "+", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"], "+", 
         SuperscriptBox[
          FormBox["q1",
           TraditionalForm], "2"]}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q1",
         TraditionalForm]}], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", 
        SuperscriptBox[
         FormBox["q1",
          TraditionalForm], "2"], ",", "0", ",", 
        SuperscriptBox["m", "2"], ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["m", "2"], "-", 
         SuperscriptBox[
          FormBox["q1",
           TraditionalForm], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"2", " ", 
           RowBox[{
            FormBox["p",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q1",
             TraditionalForm]}]}]}], "+", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"], "+", 
         SuperscriptBox[
          FormBox["q1",
           TraditionalForm], "2"]}], ")"}]}]], "-", 
     FractionBox[
      RowBox[{
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q1",
         TraditionalForm]}], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"2", " ", 
           RowBox[{
            FormBox["p",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q1",
             TraditionalForm]}]}]}], "+", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"], "+", 
         SuperscriptBox[
          FormBox["q1",
           TraditionalForm], "2"]}], ",", "0", ",", "0", ")"}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["m", "2"], "-", 
         SuperscriptBox[
          FormBox["q1",
           TraditionalForm], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"2", " ", 
           RowBox[{
            FormBox["p",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q1",
             TraditionalForm]}]}]}], "+", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"], "+", 
         SuperscriptBox[
          FormBox["q1",
           TraditionalForm], "2"]}], ")"}]}]]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"CancelQP",
 CellLabel->"Out[124]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OneLoop", "[", 
  RowBox[{"q2", ",", "t", ",", 
   RowBox[{"CancelQP", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"CancelQP",
 CellLabel->"In[125]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SuperscriptBox["\[Pi]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q1",
           TraditionalForm]}],
         TraditionalForm], "2"], " ", 
       RowBox[{"PaVe", "(", 
        RowBox[{"2", ",", 
         RowBox[{"{", 
          RowBox[{
           SuperscriptBox[
            FormBox["p",
             TraditionalForm], "2"], ",", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"2", " ", 
              RowBox[{
               FormBox["p",
                TraditionalForm], "\[CenterDot]", 
               FormBox["q1",
                TraditionalForm]}]}]}], "+", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], "2"], "+", 
            SuperscriptBox[
             FormBox["q1",
              TraditionalForm], "2"]}], ",", 
           SuperscriptBox[
            FormBox["q1",
             TraditionalForm], "2"]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", 
           SuperscriptBox["m", "2"]}], "}"}]}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["m", "2"], "-", 
         SuperscriptBox[
          FormBox["q1",
           TraditionalForm], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"2", " ", 
           RowBox[{
            FormBox["p",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q1",
             TraditionalForm]}]}]}], "+", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"], "+", 
         SuperscriptBox[
          FormBox["q1",
           TraditionalForm], "2"]}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q1",
         TraditionalForm]}], " ", 
       RowBox[{"PaVe", "(", 
        RowBox[{"1", ",", 
         RowBox[{"{", 
          RowBox[{
           SuperscriptBox[
            FormBox["p",
             TraditionalForm], "2"], ",", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"2", " ", 
              RowBox[{
               FormBox["p",
                TraditionalForm], "\[CenterDot]", 
               FormBox["q1",
                TraditionalForm]}]}]}], "+", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], "2"], "+", 
            SuperscriptBox[
             FormBox["q1",
              TraditionalForm], "2"]}], ",", 
           SuperscriptBox[
            FormBox["q1",
             TraditionalForm], "2"]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", 
           SuperscriptBox["m", "2"]}], "}"}]}], ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["m", "2"], "-", 
         SuperscriptBox[
          FormBox["q1",
           TraditionalForm], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"2", " ", 
           RowBox[{
            FormBox["p",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q1",
             TraditionalForm]}]}]}], "+", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"], "+", 
         SuperscriptBox[
          FormBox["q1",
           TraditionalForm], "2"]}], ")"}]}]]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"CancelQP",
 CellLabel->"Out[125]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "t", "]"}]], "Input",
 CellTags->"CancelQP",
 CellLabel->"In[126]:="]
}, Open  ]],

Cell["Cases2", "ObjectName",
 CellTags->"Cases2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Cases2"],

Cell["\<\
Cases2[expr, f] returns a list of all objects in expr with head f. \
Cases2[expr,f] is equivalent to Cases2[{expr},f[___],Infinity]//Union. \
Cases2[expr, f, g, ...] or Cases2[expr, {f,g, ...}] is equivalent to \
Cases[{expr},f[___] | g[___] ...] .\
\>", "Text",
 CellTags->"Cases2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Examples"], "Subsubsection",
 CellTags->"Cases2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Cases2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "a", "]"}], "+", 
    SuperscriptBox[
     RowBox[{"f", "[", "b", "]"}], "2"], "+", 
    RowBox[{"f", "[", 
     RowBox[{"c", ",", "d"}], "]"}]}], ",", "f"}], "]"}]], "Input",
 CellTags->"Cases2",
 CellLabel->"In[127]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"f", "(", "a", ")"}], ",", 
    RowBox[{"f", "(", "b", ")"}], ",", 
    RowBox[{"f", "(", 
     RowBox[{"c", ",", "d"}], ")"}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"Cases2",
 CellLabel->"Out[127]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Cases2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", "x", "]"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"y", "-", "z"}], "]"}]}], "+", 
    RowBox[{"g", "[", "y", "]"}]}], ",", "Sin", ",", "g"}], "]"}]], "Input",
 CellTags->"Cases2",
 CellLabel->"In[128]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"g", "(", "y", ")"}], ",", 
    RowBox[{"sin", "(", "x", ")"}], ",", 
    RowBox[{"sin", "(", 
     RowBox[{"y", "-", "z"}], ")"}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"Cases2",
 CellLabel->"Out[128]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Cases2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", "x", "]"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"y", "-", "z"}], "]"}]}], "+", 
    RowBox[{"g", "[", "x", "]"}], "+", 
    RowBox[{"g", "[", 
     RowBox[{"a", ",", "b", ",", "c"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"Sin", ",", "g"}], "}"}]}], "]"}]], "Input",
 CellTags->"Cases2",
 CellLabel->"In[129]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"g", "(", "x", ")"}], ",", 
    RowBox[{"g", "(", 
     RowBox[{"a", ",", "b", ",", "c"}], ")"}], ",", 
    RowBox[{"sin", "(", "x", ")"}], ",", 
    RowBox[{"sin", "(", 
     RowBox[{"y", "-", "z"}], ")"}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"Cases2",
 CellLabel->"Out[129]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Cases2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"DiracSlash", "[", "p", "]"}], ".", 
     RowBox[{"DiracSlash", "[", "q", "]"}]}], "+", 
    RowBox[{"ScalarProduct", "[", 
     RowBox[{"p", ",", "p"}], "]"}]}], ",", "Dot"}], "]"}]], "Input",
 CellTags->"Cases2",
 CellLabel->"In[130]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["p",
       TraditionalForm]}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}], ")"}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"Cases2",
 CellLabel->"Out[130]="]
}, Open  ]]
}, Open  ]],

Cell["CF", "ObjectName",
 CellTags->"CF"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"CF"],

Cell[TextData[{
 "CF is one of the Casimir operator eigenvalues of SU(",
 StyleBox["N",
  FontSlant->"Italic"],
 ") (CF = (",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["N", "2"], TraditionalForm]]],
 "-1)/(2 ",
 StyleBox["N",
  FontSlant->"Italic"],
 "))."
}], "Text",
 CellTags->"CF"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["CA",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CA",
  ButtonNote->"CA"],
 ", ",
 ButtonBox["SUNSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNSimplify",
  ButtonNote->"SUNSimplify"],
 "."
}], "Text",
 CellTags->"CF"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"CF"],

Cell[CellGroupData[{

Cell[BoxData["CF"], "Input",
 CellTags->"CF",
 CellLabel->"In[131]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["C", "F"], TraditionalForm]], "Output",
 CellTags->"CF",
 CellLabel->"Out[131]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{"CF", ",", " ", 
   RowBox[{"SUNNToCACF", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"CF",
 CellLabel->"In[132]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["N", "2"], "-", "1"}], 
   RowBox[{"2", " ", "N"}]], TraditionalForm]], "Output",
 CellTags->"CF",
 CellLabel->"Out[132]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "InputForm"}]], "Input",
 CellLabel->"In[133]:="],

Cell["(-1 + SUNN^2)/(2*SUNN)", "Output",
 CellLabel->"Out[133]//InputForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["SUNN"], "Input",
 CellTags->"CF",
 CellLabel->"In[134]:="],

Cell[BoxData[
 FormBox["N", TraditionalForm]], "Output",
 CellTags->"CF",
 CellLabel->"Out[134]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"SUNN", "^", "2"}], "-", "1"}], ",", " ", 
   RowBox[{"SUNNToCACF", " ", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"CF",
 CellLabel->"In[135]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", 
   SubscriptBox["C", "A"], " ", 
   SubscriptBox["C", "F"]}], TraditionalForm]], "Output",
 CellTags->"CF",
 CellLabel->"Out[135]="]
}, Open  ]]
}, Open  ]],

Cell["ChangeDimension", "ObjectName",
 CellTags->"ChangeDimension"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ChangeDimension"],

Cell["\<\
ChangeDimension[exp, dim] changes all LorentzIndex and Momenta in exp to \
dimension dim (and also Levi-Civita-tensors, Dirac slashes and Dirac \
matrices).\
\>", "Text",
 CellTags->"ChangeDimension"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["LorentzIndex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LorentzIndex",
  ButtonNote->"LorentzIndex"],
 ", ",
 ButtonBox["Momentum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Momentum",
  ButtonNote->"Momentum"],
 ", ",
 ButtonBox["DiracGamma",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGamma",
  ButtonNote->"DiracGamma"],
 ", ",
 ButtonBox["Eps",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Eps",
  ButtonNote->"Eps"],
 "."
}], "Text",
 CellTags->"ChangeDimension"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ChangeDimension"],

Cell["\<\
Remember that LorentzIndex[mu, 4] is simplified to LorentzIndex[mu] and \
Momentum[p, 4] to Momentum[p]. Thus the fullowing objects are defined in four \
dimensions.\
\>", "Text",
 CellTags->"ChangeDimension"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", " ", 
   RowBox[{"Momentum", "[", "p", "]"}]}], "}"}]], "Input",
 CellTags->"ChangeDimension",
 CellLabel->"In[136]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FormBox["\[Mu]",
     TraditionalForm], ",", "p"}], "}"}], TraditionalForm]], "Output",
 CellTags->"ChangeDimension",
 CellLabel->"Out[136]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ChangeDimension", "[", 
  RowBox[{"%", ",", " ", "D"}], "]"}]], "Input",
 CellTags->"ChangeDimension",
 CellLabel->"In[137]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FormBox["\[Mu]",
     TraditionalForm], ",", "p"}], "}"}], TraditionalForm]], "Output",
 CellTags->"ChangeDimension",
 CellLabel->"Out[137]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"ChangeDimension",
 CellLabel->"In[138]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
   RowBox[{"Momentum", "[", 
    RowBox[{"p", ",", "D"}], "]"}]}], "}"}]], "Output",
 CellTags->"ChangeDimension",
 CellLabel->"Out[138]//StandardForm="]
}, Open  ]],

Cell["\<\
This changes all non-4-dimensional objects to 4-dimensional ones.\
\>", "Text",
 CellTags->"ChangeDimension"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ChangeDimension", "[", 
   RowBox[{"%%", ",", " ", "4"}], "]"}], " ", "//", " ", 
  "StandardForm"}]], "Input",
 CellTags->"ChangeDimension",
 CellLabel->"In[139]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"Momentum", "[", "p", "]"}]}], "}"}]], "Output",
 CellTags->"ChangeDimension",
 CellLabel->"Out[139]//StandardForm="]
}, Open  ]],

Cell["Consider the following list of 4- and D-dimensional object.", "Text",
 CellTags->"ChangeDimension"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"GA", "[", 
     RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], " ", 
    RowBox[{"MT", "[", 
     RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], ",", " ", 
   RowBox[{
    RowBox[{"GAD", "[", 
     RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], " ", 
    RowBox[{"MTD", "[", 
     RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], " ", 
    RowBox[{"f", "[", "D", "]"}]}]}], "}"}]], "Input",
 CellTags->"ChangeDimension",
 CellLabel->"In[140]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
      SuperscriptBox["\[Gamma]", "\[Nu]"]}], " ", 
     SuperscriptBox["g", 
      RowBox[{"\[Mu]", "\[Nu]"}]]}], ",", 
    RowBox[{
     RowBox[{"f", "(", "D", ")"}], " ", 
     RowBox[{
      SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
      SuperscriptBox["\[Gamma]", "\[Nu]"]}], " ", 
     SuperscriptBox["g", 
      RowBox[{"\[Mu]", "\[Nu]"}]]}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"ChangeDimension",
 CellLabel->"Out[140]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracTrick", "[", 
  RowBox[{"Contract", "[", "%", "]"}], "]"}]], "Input",
 CellTags->"ChangeDimension",
 CellLabel->"In[141]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]]}], ",", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]]}], " ", 
     RowBox[{"f", "(", "D", ")"}]}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"ChangeDimension",
 CellLabel->"Out[141]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracTrick", "[", 
  RowBox[{"Contract", "[", 
   RowBox[{"ChangeDimension", "[", 
    RowBox[{"%%", ",", "n"}], "]"}], "]"}], "]"}]], "Input",
 CellTags->"ChangeDimension",
 CellLabel->"In[142]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]]}], ",", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]]}], " ", 
     RowBox[{"f", "(", "D", ")"}]}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"ChangeDimension",
 CellLabel->"Out[142]="]
}, Open  ]],

Cell["\<\
Any explicit occurence of D (like in f(D)) is not replaced by ChangeDimension.\
\>", "Text",
 CellTags->"ChangeDimension"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"LeviCivita", ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], ";"}]], "Input",
 CellTags->"ChangeDimension",
 CellLabel->"In[143]:="],

Cell["\<\
The option Dimension of Eps must be changed too, since with the default \
setting Dimension\[Rule]4 the arguments of Eps are automatically changed to 4 \
dimensions.\
\>", "Text",
 CellTags->"ChangeDimension"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Eps", ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], ";"}]], "Input",
 CellTags->"ChangeDimension",
 CellLabel->"In[144]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1", " ", "=", " ", 
  RowBox[{"LeviCivita", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
   "]"}]}]], "Input",
 CellTags->"ChangeDimension",
 CellLabel->"In[145]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Rho]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Sigma]",
      TraditionalForm],
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"ChangeDimension",
 CellLabel->"Out[145]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2", " ", "=", " ", 
  RowBox[{"ChangeDimension", "[", 
   RowBox[{"a1", ",", "4"}], "]"}]}]], "Input",
 CellTags->"ChangeDimension",
 CellLabel->"In[146]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Rho]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Sigma]",
      TraditionalForm],
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"ChangeDimension",
 CellLabel->"Out[146]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor2", "[", 
  RowBox[{"Contract", "[", 
   SuperscriptBox["a1", "2"], "]"}], "]"}]], "Input",
 CellTags->"ChangeDimension",
 CellLabel->"In[147]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", "D"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"2", "-", "D"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"3", "-", "D"}], ")"}], " ", "D"}], TraditionalForm]], "Output",
 CellTags->"ChangeDimension",
 CellLabel->"Out[147]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", 
  SuperscriptBox["a2", "2"], "]"}]], "Input",
 CellTags->"ChangeDimension",
 CellLabel->"In[148]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", "24"}], TraditionalForm]], "Output",
 CellTags->"ChangeDimension",
 CellLabel->"Out[148]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Eps", ",", 
    RowBox[{"Dimension", "\[Rule]", "4"}]}], "]"}], ";"}]], "Input",
 CellTags->"ChangeDimension",
 CellLabel->"In[149]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"a1", ",", "a2"}], "]"}], ";"}]], "Input",
 CellTags->"ChangeDimension",
 CellLabel->"In[150]:="]
}, Open  ]],

Cell["ChargeConjugationMatrix", "ObjectName",
 CellTags->"ChargeConjugationMatrix"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ChargeConjugationMatrix"],

Cell[TextData[{
 "ChargeConjugationMatrix denotes the charge conjugation matrix ",
 StyleBox["C",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellTags->"ChargeConjugationMatrix"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["ChargeConjugationMatrixInv",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ChargeConjugationMatrixInv",
  ButtonNote->"ChargeConjugationMatrixInv"],
 "."
}], "Text",
 CellTags->"ChargeConjugationMatrix"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ChargeConjugationMatrix"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ChargeConjugationMatrix", ".", 
  RowBox[{"DiracMatrix", "[", "\[Mu]", "]"}], ".", 
  "ChargeConjugationMatrixInv"}]], "Input",
 CellTags->"ChargeConjugationMatrix",
 CellLabel->"In[151]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"C", ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   RowBox[{"(", 
    RowBox[{"-", "C"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"ChargeConjugationMatrix",
 CellLabel->"Out[151]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", "%", "]"}]], "Input",
 CellTags->"ChargeConjugationMatrix",
 CellLabel->"In[152]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   SubsuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], "T"]}], TraditionalForm]], "Output",
 CellTags->"ChargeConjugationMatrix",
 CellLabel->"Out[152]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ChargeConjugationMatrix", ".", 
  RowBox[{"DiracGamma", "[", "5", "]"}], ".", 
  "ChargeConjugationMatrixInv"}]], "Input",
 CellTags->"ChargeConjugationMatrix",
 CellLabel->"In[153]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"C", ".", 
   SuperscriptBox["\[Gamma]", "5"], ".", 
   RowBox[{"(", 
    RowBox[{"-", "C"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"ChargeConjugationMatrix",
 CellLabel->"Out[153]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", "%", "]"}]], "Input",
 CellTags->"ChargeConjugationMatrix",
 CellLabel->"In[154]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox["\[Gamma]", 
   FormBox["5",
    TraditionalForm], "T"], TraditionalForm]], "Output",
 CellTags->"ChargeConjugationMatrix",
 CellLabel->"Out[154]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ChargeConjugationMatrix", "^", "2"}]], "Input",
 CellTags->"ChargeConjugationMatrix",
 CellLabel->"In[155]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", "1"}], TraditionalForm]], "Output",
 CellTags->"ChargeConjugationMatrix",
 CellLabel->"Out[155]="]
}, Open  ]]
}, Open  ]],

Cell["ChargeConjugationMatrixInv", "ObjectName",
 CellTags->"ChargeConjugationMatrixInv"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ChargeConjugationMatrixInv"],

Cell["\<\
ChargeConjugationMatrixInv is the inverse of ChargeConjugationMatrix. It is \
substituted immediately by -ChargeConjugationMatrix.\
\>", "Text",
 CellTags->"ChargeConjugationMatrixInv"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["ChargeConjugationMatrix",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ChargeConjugationMatrix",
  ButtonNote->"ChargeConjugationMatrix"],
 "."
}], "Text",
 CellTags->"ChargeConjugationMatrixInv"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ChargeConjugationMatrixInv"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ChargeConjugationMatrix", ".", 
  RowBox[{"DiracMatrix", "[", "\[Mu]", "]"}], ".", 
  "ChargeConjugationMatrixInv"}]], "Input",
 CellTags->"ChargeConjugationMatrixInv",
 CellLabel->"In[156]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"C", ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   RowBox[{"(", 
    RowBox[{"-", "C"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"ChargeConjugationMatrixInv",
 CellLabel->"Out[156]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", "%", "]"}]], "Input",
 CellTags->"ChargeConjugationMatrixInv",
 CellLabel->"In[157]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   SubsuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], "T"]}], TraditionalForm]], "Output",
 CellTags->"ChargeConjugationMatrixInv",
 CellLabel->"Out[157]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ChargeConjugationMatrix", ".", 
  RowBox[{"DiracGamma", "[", "5", "]"}], ".", 
  "ChargeConjugationMatrixInv"}]], "Input",
 CellTags->"ChargeConjugationMatrixInv",
 CellLabel->"In[158]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"C", ".", 
   SuperscriptBox["\[Gamma]", "5"], ".", 
   RowBox[{"(", 
    RowBox[{"-", "C"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"ChargeConjugationMatrixInv",
 CellLabel->"Out[158]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", "%", "]"}]], "Input",
 CellTags->"ChargeConjugationMatrixInv",
 CellLabel->"In[159]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox["\[Gamma]", 
   FormBox["5",
    TraditionalForm], "T"], TraditionalForm]], "Output",
 CellTags->"ChargeConjugationMatrixInv",
 CellLabel->"Out[159]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ChargeConjugationMatrix", ".", 
  "ChargeConjugationMatrixInv"}]], "Input",
 CellTags->"ChargeConjugationMatrixInv",
 CellLabel->"In[160]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"C", ".", 
   RowBox[{"(", 
    RowBox[{"-", "C"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"ChargeConjugationMatrixInv",
 CellLabel->"Out[160]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "Calc"}]], "Input",
 CellTags->"ChargeConjugationMatrixInv",
 CellLabel->"In[161]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   RowBox[{"C", ".", "C"}]}], TraditionalForm]], "Output",
 CellTags->"ChargeConjugationMatrixInv",
 CellLabel->"Out[161]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ChargeConjugationMatrixInv", "^", "2"}]], "Input",
 CellTags->"ChargeConjugationMatrixInv",
 CellLabel->"In[162]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", "1"}], TraditionalForm]], "Output",
 CellTags->"ChargeConjugationMatrixInv",
 CellLabel->"Out[162]="]
}, Open  ]]
}, Open  ]],

Cell["CheckContext", "ObjectName",
 CellTags->"CheckContext"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"CheckContext"],

Cell["\<\
CheckContext[string] yields True if the packaged associated with string is \
already loaded, and False otherwise.\
\>", "Text",
 CellTags->"CheckContext"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["MakeContext",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MakeContext",
  ButtonNote->"MakeContext"],
 ", ",
 ButtonBox["$FeynCalcStuff",
  BaseStyle->"AddOnsLink",
  ButtonData:>"$FeynCalcStuff",
  ButtonNote->"$FeynCalcStuff"],
 "."
}], "Text",
 CellTags->"CheckContext"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"CheckContext"],

Cell["\<\
If a FeynCalc symbol has not been used, the corresponding subpackage has not \
been loaded:\
\>", "Text",
 CellTags->"CheckContext"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckContext", "[", "\"\<CompleteSquare\>\"", "]"}]], "Input",
 CellTags->"CheckContext",
 CellLabel->"In[163]:="],

Cell[BoxData[
 FormBox["False", TraditionalForm]], "Output",
 CellTags->"CheckContext",
 CellLabel->"Out[163]="]
}, Open  ]],

Cell["Using it makes FeynCalc load the subpackage:", "Text",
 CellTags->"CheckContext"],

Cell[CellGroupData[{

Cell[BoxData["CompleteSquare"], "Input",
 CellTags->"CheckContext",
 CellLabel->"In[164]:="],

Cell[BoxData[
 FormBox["CompleteSquare", TraditionalForm]], "Output",
 CellTags->"CheckContext",
 CellLabel->"Out[164]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckContext", "[", "\"\<CompleteSquare\>\"", "]"}]], "Input",
 CellTags->"CheckContext",
 CellLabel->"In[165]:="],

Cell[BoxData[
 FormBox["True", TraditionalForm]], "Output",
 CellTags->"CheckContext",
 CellLabel->"Out[165]="]
}, Open  ]]
}, Open  ]],

Cell["CheckDB", "ObjectName",
 CellTags->"CheckDB"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellTags->"CheckDB"],

Cell["\<\
CheckDB[exp, fil] saves [with Put] or retrieves [with Get] exp from a file \
fil. It checks if the setting of the option Directory is a valid directory \
name and if fil is a valid file name and does exist. If it does, Get[fil] is \
executed. If fil does not exist, exp gets evaluated and saved to  fil. Saving \
and evaluating can be further controlled with the options ForceSave and \
NoSave. If the option Check is set to False  the return value is what is \
evaluated [see above]. If Check is set to True the return value is True or \
False depending on whether the evaluation of exp agrees with what is loaded \
from fil or fil does not exist.  Default value of Check : False. NOTICE : If \
fil ends with \".Gen\" or \".Mod\", the   setting of Directory is ignored and \
fil is  saved in the \"CouplingVectors\"  subdirectory of \"Phi\". If fil \
ends with  \".Fac\", the setting of Directory is  ignored and fil is saved in \
the \"Factors\" subdirectory of \"Phi\". If fil is a file   name with full \
path, the setting of  Directory is also ignored.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "CheckDB", "]"}]], "Input",
 CellTags->"CheckDB",
 CellLabel->"In[166]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Directory", "\[RuleDelayed]", 
     RowBox[{"ToFileName", "[", 
      RowBox[{
       RowBox[{"{", "$FeynCalcDirectory", "}"}], ",", "\<\"fcdb\"\>"}], 
      "]"}]}], ",", 
    RowBox[{"ForceSave", "\[Rule]", "False"}], ",", 
    RowBox[{"NoSave", "\[Rule]", "False"}], ",", 
    RowBox[{"Check", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"CheckDB",
 CellLabel->"Out[166]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Attributes", "[", "CheckDB", "]"}]], "Input",
 CellTags->"CheckDB",
 CellLabel->"In[167]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", "HoldFirst", "}"}], TraditionalForm]], "Output",
 CellTags->"CheckDB",
 CellLabel->"Out[167]="]
}, Open  ]],

Cell["\<\
The first time the Table function is evaluated and the result saved into the \
test.s file.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckDB", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{"\"\<test \>\"", ",", "i"}], "]"}], ";", "i"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}]}], "]"}], ",", "\"\<test.s\>\""}], 
  "]"}]], "Input",
 CellLabel->"In[168]:="],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"test \"\>", "\[InvisibleSpace]", "1"}],
   SequenceForm["test ", 1],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"test \"\>", "\[InvisibleSpace]", "2"}],
   SequenceForm["test ", 2],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"1", ",", "2"}], "}"}], TraditionalForm]], "Output",
 CellLabel->"Out[168]="]
}, Open  ]],

Cell["\<\
Executing the same a second time will just load the result from test.s and \
not evaluate the Table function.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CheckDB", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"WriteString", "[", 
       RowBox[{"\"\<stdout\>\"", ",", "\"\<test\>\""}], "]"}], ";", "i"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2"}], "}"}]}], "]"}], ",", "\"\<test.s\>\""}], 
  "]"}]], "Input",
 CellTags->"CheckDB",
 CellLabel->"In[169]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"1", ",", "2"}], "}"}], TraditionalForm]], "Output",
 CellTags->"CheckDB",
 CellLabel->"Out[169]="]
}, Open  ]],

Cell["This shows the actual saved value of test.s.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{
   RowBox[{"ToFileName", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"$FeynCalcDirectory", ",", "\"\<fcdb\>\""}], "}"}], ",", 
     "\"\<test.s\>\""}], "]"}], ",", "\"\<Text\>\""}], "]"}]], "Input",
 CellTags->"CheckDB",
 CellLabel->"In[170]:="],

Cell[BoxData[
 FormBox["\<\"{1, 2}\"\>", TraditionalForm]], "Output",
 CellTags->"CheckDB",
 CellLabel->"Out[170]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"DeleteFile", "[", 
  RowBox[{"ToFileName", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"$FeynCalcDirectory", ",", "\"\<fcdb\>\""}], "}"}], ",", 
    "\"\<test.s\>\""}], "]"}], "]"}]], "Input",
 CellTags->"CheckDB",
 CellLabel->"In[171]:="]
}, Open  ]],

Cell["ChiralityProjector", "ObjectName",
 CellTags->"ChiralityProjector"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ChiralityProjector"],

Cell[TextData[{
 "ChiralityProjector[+1] denotes ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"1", "/", "2"}], 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["\[Gamma]", "5"]}], ")"}]}], TraditionalForm]]],
 ". ChiralityProjector[-1] denotes ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"1", "/", "2"}], 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["\[Gamma]", "5"]}], ")"}]}], TraditionalForm]]],
 "."
}], "Text",
 CellTags->"ChiralityProjector"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracGamma",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGamma",
  ButtonNote->"DiracGamma"],
 ", ",
 ButtonBox["DiracMatrix",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracMatrix",
  ButtonNote->"DiracMatrix"],
 ", ",
 ButtonBox["FCI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCI",
  ButtonNote->"FCI"],
 "."
}], "Text",
 CellTags->"ChiralityProjector"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ChiralityProjector"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ChiralityProjector", "[", 
    RowBox[{"+", "1"}], "]"}], ",", 
   RowBox[{"ChiralityProjector", "[", 
    RowBox[{"-", "1"}], "]"}]}], "}"}]], "Input",
 CellTags->"ChiralityProjector",
 CellLabel->"In[172]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    SuperscriptBox["\[Gamma]", "6"], ",", 
    SuperscriptBox["\[Gamma]", "7"]}], "}"}], TraditionalForm]], "Output",
 CellTags->"ChiralityProjector",
 CellLabel->"Out[172]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FCI", "[", "%", "]"}]], "Input",
 CellTags->"ChiralityProjector",
 CellLabel->"In[173]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    SuperscriptBox["\[Gamma]", "6"], ",", 
    SuperscriptBox["\[Gamma]", "7"]}], "}"}], TraditionalForm]], "Output",
 CellTags->"ChiralityProjector",
 CellLabel->"Out[173]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSimplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"DiracSubstitute67", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"ChiralityProjector",
 CellLabel->"In[174]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     FractionBox[
      SuperscriptBox["\[Gamma]", "5"], "2"], "+", 
     FractionBox["1", "2"]}], ",", 
    RowBox[{
     FractionBox["1", "2"], "-", 
     FractionBox[
      SuperscriptBox["\[Gamma]", "5"], "2"]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"ChiralityProjector",
 CellLabel->"Out[174]="]
}, Open  ]]
}, Open  ]],

Cell["Chisholm", "ObjectName",
 CellTags->"Chisholm"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Chisholm"],

Cell["\<\
Chisholm[x] substitutes products of three Dirac matrices or slashes by the \
Chisholm identity.\
\>", "Text",
 CellTags->"Chisholm"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["EpsChisholm",
  BaseStyle->"AddOnsLink",
  ButtonData:>"EpsChisholm",
  ButtonNote->"EpsChisholm"],
 ", ",
 ButtonBox["ChisholmSpinor",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ChisholmSpinor",
  ButtonNote->"ChisholmSpinor"],
 "."
}], "Text",
 CellTags->"Chisholm"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Chisholm"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Chisholm", "[", 
  RowBox[{"GA", "[", 
   RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Mu]", ",", "\[Nu]"}], "]"}], 
  "]"}]], "Input",
 CellTags->"Chisholm",
 CellLabel->"In[175]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["$MU$2386",
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", "5"]}], " ", 
     SuperscriptBox["\[Epsilon]", 
      RowBox[{
       FormBox[
        FormBox["\[Alpha]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["\[Beta]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["$MU$2386",
         TraditionalForm],
        TraditionalForm]}]]}]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Alpha]", "\[Beta]"}]]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Beta]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Alpha]", "\[Mu]"}]]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Alpha]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Beta]", "\[Mu]"}]]}]}], TraditionalForm]], "Output",
 CellTags->"Chisholm",
 CellLabel->"Out[175]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{"DiracMatrix", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]"}], "]"}]}]], "Input",
 CellTags->"Chisholm",
 CellLabel->"In[176]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], 
   SuperscriptBox["\[Gamma]", "\[Nu]"], 
   SuperscriptBox["\[Gamma]", "\[Rho]"]}], TraditionalForm]], "Output",
 CellTags->"Chisholm",
 CellLabel->"Out[176]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", " ", "=", 
  RowBox[{"Chisholm", "[", "t1", "]"}]}]], "Input",
 CellTags->"Chisholm",
 CellLabel->"In[177]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["$MU$2422",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", "5"]}], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["$MU$2422",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]]}], "-", 
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Rho]"}]]}], "+", 
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Rho]"}]]}]}], TraditionalForm]], "Output",
 CellTags->"Chisholm",
 CellLabel->"Out[177]="]
}, Open  ]],

Cell["The $MU$ variables are unique indices.", "Text",
 CellTags->"Chisholm"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", 
  RowBox[{"t1", ".", "t1"}], "]"}]], "Input",
 CellTags->"Chisholm",
 CellLabel->"In[178]:="],

Cell[BoxData[
 FormBox["16", TraditionalForm]], "Output",
 CellTags->"Chisholm",
 CellLabel->"Out[178]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t3", " ", "=", 
  RowBox[{"Chisholm", "[", "t1", "]"}]}]], "Input",
 CellTags->"Chisholm",
 CellLabel->"In[179]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["$MU$2453",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", "5"]}], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["$MU$2453",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]]}], "-", 
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Rho]"}]]}], "+", 
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Rho]"}]]}]}], TraditionalForm]], "Output",
 CellTags->"Chisholm",
 CellLabel->"Out[179]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", 
  RowBox[{"t2", ".", "t3"}], "]"}]], "Input",
 CellTags->"Chisholm",
 CellLabel->"In[180]:="],

Cell[BoxData[
 FormBox["16", TraditionalForm]], "Output",
 CellTags->"Chisholm",
 CellLabel->"Out[180]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t4", "=", 
  RowBox[{"DiracSlash", "[", 
   RowBox[{"a", ",", "b", ",", "c"}], "]"}]}]], "Input",
 CellTags->"Chisholm",
 CellLabel->"In[181]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["a",
      TraditionalForm]}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["b",
      TraditionalForm]}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["c",
      TraditionalForm]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Chisholm",
 CellLabel->"Out[181]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Chisholm", "[", "t4", "]"}]], "Input",
 CellTags->"Chisholm",
 CellLabel->"In[182]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     FormBox["a",
      TraditionalForm], "\[CenterDot]", 
     FormBox["b",
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["c",
      TraditionalForm]}]}], "-", 
   RowBox[{
    RowBox[{
     FormBox["a",
      TraditionalForm], "\[CenterDot]", 
     FormBox["c",
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["b",
      TraditionalForm]}]}], "+", 
   RowBox[{
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["a",
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox["b",
      TraditionalForm], "\[CenterDot]", 
     FormBox["c",
      TraditionalForm]}]}], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["$MU$2493",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", "5"]}], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["$MU$2493",
        TraditionalForm],
       TraditionalForm], 
      FormBox["a",
       TraditionalForm], 
      FormBox["b",
       TraditionalForm], 
      FormBox["c",
       TraditionalForm]}]]}]}], TraditionalForm]], "Output",
 CellTags->"Chisholm",
 CellLabel->"Out[182]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1", "=", 
  RowBox[{"GA", "[", 
   RowBox[{
   "\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]", ",", "\[Tau]", ",", 
    "\[Kappa]"}], "]"}]}]], "Input",
 CellTags->"Chisholm",
 CellLabel->"In[183]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Rho]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Sigma]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Tau]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Kappa]"]}], TraditionalForm]], "Output",
 CellTags->"Chisholm",
 CellLabel->"Out[183]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2", " ", "=", 
  RowBox[{"Chisholm", "[", "a1", "]"}]}]], "Input",
 CellTags->"Chisholm",
 CellLabel->"In[184]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Tau]",
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Kappa]",
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", "5"]}], " ", 
     SuperscriptBox["\[Epsilon]", 
      RowBox[{
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]}]]}]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", "5"]}], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Tau]",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Tau]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Rho]"}]]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Tau]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Rho]"}]]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Tau]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Sigma]"}]]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Tau]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Sigma]"}]]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Tau]"}]]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Tau]"}]]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Tau]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Rho]", "\[Sigma]"}]]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Tau]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Rho]", "\[Sigma]"}]]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Tau]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Rho]", "\[Sigma]"}]]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Rho]", "\[Tau]"}]]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Rho]", "\[Tau]"}]]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Sigma]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Rho]", "\[Tau]"}]]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Sigma]", "\[Tau]"}]]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Sigma]", "\[Tau]"}]]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Sigma]", "\[Tau]"}]]}], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["$MU$2515",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", "5"]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Sigma]", "\[Tau]"}]], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["$MU$2515",
        TraditionalForm],
       TraditionalForm]}]]}], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["$MU$2537",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", "5"]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Tau]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["$MU$2537",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["$MU$2548",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", "5"]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Tau]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["$MU$2548",
        TraditionalForm],
       TraditionalForm]}]]}], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["$MU$2559",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", "5"]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Tau]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["$MU$2559",
        TraditionalForm],
       TraditionalForm]}]]}]}], TraditionalForm]], "Output",
 CellTags->"Chisholm",
 CellLabel->"Out[184]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3", " ", "=", 
  RowBox[{"Chisholm", "[", "a1", "]"}]}]], "Input",
 CellTags->"Chisholm",
 CellLabel->"In[185]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Tau]",
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Kappa]",
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", "5"]}], " ", 
     SuperscriptBox["\[Epsilon]", 
      RowBox[{
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]}]]}]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", "5"]}], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Tau]",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Tau]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Rho]"}]]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Tau]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Rho]"}]]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Tau]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Sigma]"}]]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Tau]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Sigma]"}]]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Tau]"}]]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Tau]"}]]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Tau]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Rho]", "\[Sigma]"}]]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Tau]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Rho]", "\[Sigma]"}]]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Tau]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Rho]", "\[Sigma]"}]]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Rho]", "\[Tau]"}]]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Rho]", "\[Tau]"}]]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Sigma]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Rho]", "\[Tau]"}]]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Sigma]", "\[Tau]"}]]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Sigma]", "\[Tau]"}]]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Sigma]", "\[Tau]"}]]}], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["$MU$2643",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", "5"]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Sigma]", "\[Tau]"}]], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["$MU$2643",
        TraditionalForm],
       TraditionalForm]}]]}], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["$MU$2665",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", "5"]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Tau]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["$MU$2665",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["$MU$2676",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", "5"]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Tau]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["$MU$2676",
        TraditionalForm],
       TraditionalForm]}]]}], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["$MU$2687",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Kappa]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", "5"]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Tau]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["$MU$2687",
        TraditionalForm],
       TraditionalForm]}]]}]}], TraditionalForm]], "Output",
 CellTags->"Chisholm",
 CellLabel->"Out[185]="]
}, Open  ]],

Cell["Check that both a1.a1 and a2.a3 give the same.", "Text",
 CellTags->"Chisholm"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", 
  RowBox[{"a1", ".", "a1"}], "]"}]], "Input",
 CellTags->"Chisholm",
 CellLabel->"In[186]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", "2048"}], TraditionalForm]], "Output",
 CellTags->"Chisholm",
 CellLabel->"Out[186]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", 
  RowBox[{"a2", ".", "a3"}], "]"}]], "Input",
 CellTags->"Chisholm",
 CellLabel->"In[187]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", "2048"}], TraditionalForm]], "Output",
 CellTags->"Chisholm",
 CellLabel->"Out[187]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "t1", ",", "t2", ",", "t3", ",", "t4", ",", "a1", ",", "a2", ",", "a3"}], 
  "]"}]], "Input",
 CellTags->"Chisholm",
 CellLabel->"In[188]:="]
}, Open  ]],

Cell["ChisholmSpinor", "ObjectName",
 CellTags->"ChisholmSpinor"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ChisholmSpinor"],

Cell["\<\
ChisholmSpinor[x] uses the Chisholm identity on a DiraGamma between spinors. \
As an optional second argument 1 or 2 may be given, indicating that \
ChisholmSpinor should only act on the first resp. second part of a product of \
spinor chains.\
\>", "Text",
 CellTags->"ChisholmSpinor"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["EpsChisholm",
  BaseStyle->"AddOnsLink",
  ButtonData:>"EpsChisholm",
  ButtonNote->"EpsChisholm"],
 ", ",
 ButtonBox["Chisholm",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Chisholm",
  ButtonNote->"Chisholm"],
 "."
}], "Text",
 CellTags->"ChisholmSpinor"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ChisholmSpinor"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Spinor", "[", 
   RowBox[{"p1", ",", "m1"}], "]"}], ".", 
  RowBox[{"DiracGamma", "[", 
   RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ".", 
  RowBox[{"Spinor", "[", 
   RowBox[{"p2", ",", "m2"}], "]"}]}]], "Input",
 CellTags->"ChisholmSpinor",
 CellLabel->"In[189]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[CurlyPhi]", "(", 
    FormBox["p1",
     TraditionalForm], ",", "m1", ")"}], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   RowBox[{"\[CurlyPhi]", "(", 
    FormBox["p2",
     TraditionalForm], ",", "m2", ")"}]}], TraditionalForm]], "Output",
 CellTags->"ChisholmSpinor",
 CellLabel->"Out[189]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "ChisholmSpinor"}]], "Input",
 CellTags->"ChisholmSpinor",
 CellLabel->"In[190]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[Epsilon]", 
      RowBox[{
       FormBox[
        FormBox["alpha20",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox["p1",
        TraditionalForm], 
       FormBox["p2",
        TraditionalForm]}]], " ", 
     RowBox[{
      RowBox[{"\[CurlyPhi]", "(", 
       FormBox["p1",
        TraditionalForm], ",", "m1", ")"}], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["alpha20",
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", "5"], ".", 
      RowBox[{"\[CurlyPhi]", "(", 
       FormBox["p2",
        TraditionalForm], ",", "m2", ")"}]}]}], 
    RowBox[{
     FormBox["p1",
      TraditionalForm], "\[CenterDot]", 
     FormBox["p2",
      TraditionalForm]}]], "-", 
   FractionBox[
    RowBox[{"m1", " ", "m2", " ", 
     RowBox[{
      RowBox[{"\[CurlyPhi]", "(", 
       FormBox["p1",
        TraditionalForm], ",", "m1", ")"}], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], ".", 
      RowBox[{"\[CurlyPhi]", "(", 
       FormBox["p2",
        TraditionalForm], ",", "m2", ")"}]}]}], 
    RowBox[{
     FormBox["p1",
      TraditionalForm], "\[CenterDot]", 
     FormBox["p2",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"m2", " ", 
     SuperscriptBox[
      FormBox["p1",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     RowBox[{
      RowBox[{"\[CurlyPhi]", "(", 
       FormBox["p1",
        TraditionalForm], ",", "m1", ")"}], ".", 
      RowBox[{"\[CurlyPhi]", "(", 
       FormBox["p2",
        TraditionalForm], ",", "m2", ")"}]}]}], 
    RowBox[{
     FormBox["p1",
      TraditionalForm], "\[CenterDot]", 
     FormBox["p2",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"m1", " ", 
     SuperscriptBox[
      FormBox["p2",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     RowBox[{
      RowBox[{"\[CurlyPhi]", "(", 
       FormBox["p1",
        TraditionalForm], ",", "m1", ")"}], ".", 
      RowBox[{"\[CurlyPhi]", "(", 
       FormBox["p2",
        TraditionalForm], ",", "m2", ")"}]}]}], 
    RowBox[{
     FormBox["p1",
      TraditionalForm], "\[CenterDot]", 
     FormBox["p2",
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"ChisholmSpinor",
 CellLabel->"Out[190]="]
}, Open  ]]
}, Open  ]],

Cell["ClearScalarProducts", "ObjectName",
 CellTags->"ClearScalarProducts"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ClearScalarProducts"],

Cell["\<\
ClearScalarProducts removes all user-performed specific settings for \
ScalarProduct's.\
\>", "Text",
 CellTags->"ClearScalarProducts"],

Cell[TextData[{
 "See also: ",
 ButtonBox["ScalarProduct",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ScalarProduct",
  ButtonNote->"ScalarProduct"],
 ", ",
 ButtonBox["Pair",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Pair",
  ButtonNote->"Pair"],
 ", ",
 ButtonBox["SP",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SP",
  ButtonNote->"SP"],
 ", ",
 ButtonBox["SPD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SPD",
  ButtonNote->"SPD"],
 "."
}], "Text",
 CellTags->"ClearScalarProducts"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ClearScalarProducts"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ScalarProduct", "[", 
   RowBox[{"p", ",", "p"}], "]"}], "=", 
  RowBox[{"m", "^", "2"}]}]], "Input",
 CellTags->"ClearScalarProducts",
 CellLabel->"In[191]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["m", "2"], TraditionalForm]], "Output",
 CellTags->"ClearScalarProducts",
 CellLabel->"Out[191]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", "p", "]"}], ",", 
   RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]], "Input",
 CellTags->"ClearScalarProducts",
 CellLabel->"In[192]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["m", "2"], TraditionalForm]], "Output",
 CellTags->"ClearScalarProducts",
 CellLabel->"Out[192]="]
}, Open  ]],

Cell[BoxData["ClearScalarProducts"], "Input",
 CellTags->"ClearScalarProducts",
 CellLabel->"In[193]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", "p", "]"}], ",", 
   RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]], "Input",
 CellTags->"ClearScalarProducts",
 CellLabel->"In[194]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   FormBox["p",
    TraditionalForm], "2"], TraditionalForm]], "Output",
 CellTags->"ClearScalarProducts",
 CellLabel->"Out[194]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScalarProduct", "[", 
  RowBox[{"p", ",", "p"}], "]"}]], "Input",
 CellTags->"ClearScalarProducts",
 CellLabel->"In[195]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   FormBox["p",
    TraditionalForm], "2"], TraditionalForm]], "Output",
 CellTags->"ClearScalarProducts",
 CellLabel->"Out[195]="]
}, Open  ]]
}, Open  ]],

Cell["Collecting", "ObjectName",
 CellTags->"Collecting"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Collecting"],

Cell["\<\
Collecting is an option of ScalarProductCancel, Series2, TID and related \
functions. Setting it to True will trigger some kind of collecting of the \
result.\
\>", "Text",
 CellTags->"Collecting"],

Cell[TextData[{
 "See also:  ",
 ButtonBox["ScalarProductCancel",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ScalarProductCancel",
  ButtonNote->"ScalarProductCancel"],
 ", ",
 ButtonBox["Series2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Series2",
  ButtonNote->"Series2"],
 ", ",
 ButtonBox["TID",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TID",
  ButtonNote->"TID"],
 "."
}], "Text",
 CellTags->"Collecting"]
}, Open  ]],

Cell["Collect2", "ObjectName",
 CellTags->"Collect2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Collect2"],

Cell["\<\
Collect2[expr, x] collects together terms which are not free of any \
occurrence of x. Collect2[expr, {x1, x2, ...}] (or also Collect2[expr, x1, \
x2, ...]) collects together terms which are not free of any occurrence of x1, \
x2, .... The coefficients are put over a common denominator. If expr is \
expanded before collecting depends on the option Factoring, which may be set \
to Factor, Factor2, or any other function, which is applied to the \
coefficients. If expr is already expanded with respect to x (x1,x2, ...), the \
option Expanding can be set to False.\
\>", "Text",
 CellTags->"Collect2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Collect2", "]"}]], "Input",
 CellTags->"Collect2",
 CellLabel->"In[196]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Denominator", "\[Rule]", "False"}], ",", 
    RowBox[{"Dot", "\[Rule]", "False"}], ",", 
    RowBox[{"Expanding", "\[Rule]", "True"}], ",", 
    RowBox[{"Factoring", "\[Rule]", "Factor"}], ",", 
    RowBox[{"IsolateNames", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Collect2",
 CellLabel->"Out[196]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Isolate",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Isolate",
  ButtonNote->"Isolate"],
 "."
}], "Text",
 CellTags->"Collect2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Collect2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect2", "[", 
  RowBox[{
   RowBox[{"t1", "=", 
    RowBox[{"a", "+", 
     RowBox[{"r", " ", "a"}], "+", 
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"f", "[", "a", "]"}]}], "-", 
     RowBox[{"k", " ", 
      RowBox[{"f", "[", "a", "]"}]}], "+", 
     FractionBox["x", "2"], "-", 
     FractionBox["y", "w"]}]}], ",", "a"}], "]"}]], "Input",
 CellTags->"Collect2",
 CellLabel->"In[197]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"k", "-", "1"}], ")"}], " ", "k", " ", 
    RowBox[{"f", "(", "a", ")"}]}], "+", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{"r", "+", "1"}], ")"}]}], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"w", " ", "x"}], "-", 
     RowBox[{"2", " ", "y"}]}], 
    RowBox[{"2", " ", "w"}]]}], TraditionalForm]], "Output",
 CellTags->"Collect2",
 CellLabel->"Out[197]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect2", "[", 
  RowBox[{"t1", ",", "a", ",", 
   RowBox[{"Factoring", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"Collect2",
 CellLabel->"In[198]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "-", "k"}], ")"}], " ", 
    RowBox[{"f", "(", "a", ")"}]}], "+", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{"r", "+", "1"}], ")"}]}], "-", 
   FractionBox["y", "w"], "+", 
   FractionBox["x", "2"]}], TraditionalForm]], "Output",
 CellTags->"Collect2",
 CellLabel->"Out[198]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect2", "[", 
  RowBox[{"t1", ",", "a", ",", 
   RowBox[{"Factoring", "\[Rule]", "Factor"}]}], "]"}]], "Input",
 CellTags->"Collect2",
 CellLabel->"In[199]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"k", "-", "1"}], ")"}], " ", "k", " ", 
    RowBox[{"f", "(", "a", ")"}]}], "+", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{"r", "+", "1"}], ")"}]}], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"w", " ", "x"}], "-", 
     RowBox[{"2", " ", "y"}]}], 
    RowBox[{"2", " ", "w"}]]}], TraditionalForm]], "Output",
 CellTags->"Collect2",
 CellLabel->"Out[199]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", "a", " ", 
     RowBox[{"(", 
      RowBox[{"b", "-", "a"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"h", "-", "1"}], ")"}]}], "-", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"e", " ", "a"}], "-", "c"}], ")"}]}], "+", 
    SuperscriptBox["b", "2"]}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b"}], "}"}]}], "]"}]], "Input",
 CellTags->"Collect2",
 CellLabel->"In[200]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"h", "-", "1"}], ")"}]}]}], "-", 
   RowBox[{"a", " ", 
    SuperscriptBox["b", "2"], " ", "e"}], "+", 
   RowBox[{"2", " ", "a", " ", "b", " ", 
    RowBox[{"(", 
     RowBox[{"h", "-", "1"}], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox["b", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"c", "+", "1"}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Collect2",
 CellLabel->"Out[200]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect2", "[", 
  RowBox[{
   RowBox[{"Expand", "[", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "b", "-", "c", "-", "d"}], ")"}], "5"], "]"}], ",", 
   "a", ",", 
   RowBox[{"IsolateNames", "\[Rule]", "L"}]}], "]"}]], "Input",
 CellTags->"Collect2",
 CellLabel->"In[201]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["a", "5"], "-", 
   RowBox[{"5", " ", 
    SuperscriptBox["a", "4"], " ", 
    TagBox[
     RowBox[{"L", "(", "21", ")"}],
     HoldForm]}], "+", 
   RowBox[{"10", " ", 
    SuperscriptBox["a", "3"], " ", 
    SuperscriptBox[
     TagBox[
      RowBox[{"L", "(", "21", ")"}],
      HoldForm], "2"]}], "-", 
   RowBox[{"10", " ", 
    SuperscriptBox["a", "2"], " ", 
    SuperscriptBox[
     TagBox[
      RowBox[{"L", "(", "21", ")"}],
      HoldForm], "3"]}], "+", 
   RowBox[{"5", " ", "a", " ", 
    SuperscriptBox[
     TagBox[
      RowBox[{"L", "(", "21", ")"}],
      HoldForm], "4"]}], "-", 
   SuperscriptBox[
    TagBox[
     RowBox[{"L", "(", "21", ")"}],
     HoldForm], "5"]}], TraditionalForm]], "Output",
 CellTags->"Collect2",
 CellLabel->"Out[201]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ReleaseHold", "[", "%", "]"}]], "Input",
 CellTags->"Collect2",
 CellLabel->"In[202]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["a", "5"], "-", 
   RowBox[{"5", " ", 
    SuperscriptBox["a", "4"], " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", "c", "+", "d"}], ")"}]}], "+", 
   RowBox[{"10", " ", 
    SuperscriptBox["a", "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "+", "c", "+", "d"}], ")"}], "2"]}], "-", 
   RowBox[{"10", " ", 
    SuperscriptBox["a", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "+", "c", "+", "d"}], ")"}], "3"]}], "+", 
   RowBox[{"5", " ", "a", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "+", "c", "+", "d"}], ")"}], "4"]}], "-", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"b", "+", "c", "+", "d"}], ")"}], "5"]}], 
  TraditionalForm]], "Output",
 CellTags->"Collect2",
 CellLabel->"Out[202]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"t1", ",", "L"}], "]"}]], "Input",
 CellTags->"Collect2",
 CellLabel->"In[203]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect2", "[", 
  RowBox[{
   RowBox[{"Expand", "[", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "b", "-", "c"}], ")"}], "3"], "]"}], ",", "a", ",", 
   RowBox[{"Factoring", "\[Rule]", "fun"}]}], "]"}]], "Input",
 CellTags->"Collect2",
 CellLabel->"In[204]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "3"], " ", 
    RowBox[{"fun", "(", "1", ")"}]}], "+", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"fun", "(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"3", " ", "b"}]}], "-", 
      RowBox[{"3", " ", "c"}]}], ")"}]}], "+", 
   RowBox[{"a", " ", 
    RowBox[{"fun", "(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"6", " ", "b", " ", "c"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "2"]}]}], ")"}]}], "+", 
   RowBox[{"fun", "(", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["b", "3"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["b", "2"], " ", "c"}], "-", 
     RowBox[{"3", " ", "b", " ", 
      SuperscriptBox["c", "2"]}], "-", 
     SuperscriptBox["c", "3"]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Collect2",
 CellLabel->"Out[204]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", " ", "/.", " ", 
  RowBox[{"fun", "\[Rule]", "FactorTerms"}]}]], "Input",
 CellTags->"Collect2",
 CellLabel->"In[205]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["a", "3"], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", "c"}], ")"}]}], "+", 
   RowBox[{"3", " ", "a", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      RowBox[{"2", " ", "b", " ", "c"}], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}], "-", 
   SuperscriptBox["b", "3"], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox["b", "2"], " ", "c"}], "-", 
   RowBox[{"3", " ", "b", " ", 
    SuperscriptBox["c", "2"]}], "-", 
   SuperscriptBox["c", "3"]}], TraditionalForm]], "Output",
 CellTags->"Collect2",
 CellLabel->"Out[205]="]
}, Open  ]]
}, Open  ]],

Cell["Collect3", "ObjectName",
 CellTags->"Collect3"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Collect3"],

Cell[TextData[{
 "Collect3[expr, {x, y, ...}] collects terms involving the same powers of \
monomials ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["x",
     FontSlant->"Plain"], 
    SubscriptBox[
     StyleBox["n",
      FontSlant->"Plain"], "1"]], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["y",
     FontSlant->"Plain"], 
    SubscriptBox[
     StyleBox["n",
      FontSlant->"Plain"], "2"]], TraditionalForm]]],
 " ... An option Factor \[Rule] True/False can be  given, which factors the \
coefficients. The option Head (default Plus) determines the applied function \
to the list of monomials  mulitplied by their coefficients."
}], "Text",
 CellTags->"Collect3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Collect3", "]"}]], "Input",
 CellTags->"Collect3",
 CellLabel->"In[206]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Factoring", "\[Rule]", "False"}], ",", 
    RowBox[{"Head", "\[Rule]", "Plus"}]}], "}"}], TraditionalForm]], "Output",\

 CellTags->"Collect3",
 CellLabel->"Out[206]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Collect2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Collect2",
  ButtonNote->"Collect2"],
 ", ",
 ButtonBox["Isolate",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Isolate",
  ButtonNote->"Isolate"],
 "."
}], "Text",
 CellTags->"Collect3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Collect3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect3", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", "a", " ", 
     RowBox[{"(", 
      RowBox[{"b", "-", "a"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"h", "-", "1"}], ")"}]}], "-", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"e", " ", "a"}], "-", "c"}], ")"}]}], "+", 
    SuperscriptBox["b", "2"]}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b"}], "}"}]}], "]"}]], "Input",
 CellTags->"Collect3",
 CellLabel->"In[207]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"2", "-", 
      RowBox[{"2", " ", "h"}]}], ")"}]}], "-", 
   RowBox[{"a", " ", 
    SuperscriptBox["b", "2"], " ", "e"}], "+", 
   RowBox[{"a", " ", "b", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "h"}], "-", "2"}], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox["b", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"c", "+", "1"}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Collect3",
 CellLabel->"Out[207]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect3", "[", 
  RowBox[{
   RowBox[{"Expand", "[", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "b", "-", "c", "-", "d"}], ")"}], "5"], "]"}], ",", 
   RowBox[{"{", "a", "}"}]}], "]"}]], "Input",
 CellTags->"Collect3",
 CellLabel->"In[208]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["a", "5"], "+", 
   RowBox[{
    SuperscriptBox["a", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"5", " ", "b"}]}], "-", 
      RowBox[{"5", " ", "c"}], "-", 
      RowBox[{"5", " ", "d"}]}], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox["a", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"10", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"20", " ", "b", " ", "c"}], "+", 
      RowBox[{"20", " ", "b", " ", "d"}], "+", 
      RowBox[{"10", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"20", " ", "c", " ", "d"}], "+", 
      RowBox[{"10", " ", 
       SuperscriptBox["d", "2"]}]}], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"10", " ", 
        SuperscriptBox["b", "3"]}]}], "-", 
      RowBox[{"30", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"30", " ", 
       SuperscriptBox["b", "2"], " ", "d"}], "-", 
      RowBox[{"30", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"60", " ", "b", " ", "c", " ", "d"}], "-", 
      RowBox[{"30", " ", "b", " ", 
       SuperscriptBox["d", "2"]}], "-", 
      RowBox[{"10", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"30", " ", 
       SuperscriptBox["c", "2"], " ", "d"}], "-", 
      RowBox[{"30", " ", "c", " ", 
       SuperscriptBox["d", "2"]}], "-", 
      RowBox[{"10", " ", 
       SuperscriptBox["d", "3"]}]}], ")"}]}], "+", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"5", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"20", " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"20", " ", 
       SuperscriptBox["b", "3"], " ", "d"}], "+", 
      RowBox[{"30", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"60", " ", 
       SuperscriptBox["b", "2"], " ", "c", " ", "d"}], "+", 
      RowBox[{"30", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["d", "2"]}], "+", 
      RowBox[{"20", " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"60", " ", "b", " ", 
       SuperscriptBox["c", "2"], " ", "d"}], "+", 
      RowBox[{"60", " ", "b", " ", "c", " ", 
       SuperscriptBox["d", "2"]}], "+", 
      RowBox[{"20", " ", "b", " ", 
       SuperscriptBox["d", "3"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"20", " ", 
       SuperscriptBox["c", "3"], " ", "d"}], "+", 
      RowBox[{"30", " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox["d", "2"]}], "+", 
      RowBox[{"20", " ", "c", " ", 
       SuperscriptBox["d", "3"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["d", "4"]}]}], ")"}]}], "-", 
   SuperscriptBox["b", "5"], "-", 
   RowBox[{"5", " ", 
    SuperscriptBox["b", "4"], " ", "c"}], "-", 
   RowBox[{"5", " ", 
    SuperscriptBox["b", "4"], " ", "d"}], "-", 
   RowBox[{"10", " ", 
    SuperscriptBox["b", "3"], " ", 
    SuperscriptBox["c", "2"]}], "-", 
   RowBox[{"20", " ", 
    SuperscriptBox["b", "3"], " ", "c", " ", "d"}], "-", 
   RowBox[{"10", " ", 
    SuperscriptBox["b", "3"], " ", 
    SuperscriptBox["d", "2"]}], "-", 
   RowBox[{"10", " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "3"]}], "-", 
   RowBox[{"30", " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "2"], " ", "d"}], "-", 
   RowBox[{"30", " ", 
    SuperscriptBox["b", "2"], " ", "c", " ", 
    SuperscriptBox["d", "2"]}], "-", 
   RowBox[{"10", " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["d", "3"]}], "-", 
   RowBox[{"5", " ", "b", " ", 
    SuperscriptBox["c", "4"]}], "-", 
   RowBox[{"20", " ", "b", " ", 
    SuperscriptBox["c", "3"], " ", "d"}], "-", 
   RowBox[{"30", " ", "b", " ", 
    SuperscriptBox["c", "2"], " ", 
    SuperscriptBox["d", "2"]}], "-", 
   RowBox[{"20", " ", "b", " ", "c", " ", 
    SuperscriptBox["d", "3"]}], "-", 
   RowBox[{"5", " ", "b", " ", 
    SuperscriptBox["d", "4"]}], "-", 
   SuperscriptBox["c", "5"], "-", 
   RowBox[{"5", " ", 
    SuperscriptBox["c", "4"], " ", "d"}], "-", 
   RowBox[{"10", " ", 
    SuperscriptBox["c", "3"], " ", 
    SuperscriptBox["d", "2"]}], "-", 
   RowBox[{"10", " ", 
    SuperscriptBox["c", "2"], " ", 
    SuperscriptBox["d", "3"]}], "-", 
   RowBox[{"5", " ", "c", " ", 
    SuperscriptBox["d", "4"]}], "-", 
   SuperscriptBox["d", "5"]}], TraditionalForm]], "Output",
 CellTags->"Collect3",
 CellLabel->"Out[208]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect3", "[", 
  RowBox[{
   RowBox[{"Expand", "[", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "b", "-", "c", "-", "d"}], ")"}], "5"], "]"}], ",", 
   RowBox[{"{", "a", "}"}], ",", 
   RowBox[{"Factoring", "->", "Factor"}]}], "]"}]], "Input",
 CellLabel->"In[209]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["a", "5"], "-", 
   RowBox[{"5", " ", 
    SuperscriptBox["a", "4"], " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", "c", "+", "d"}], ")"}]}], "+", 
   RowBox[{"10", " ", 
    SuperscriptBox["a", "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "+", "c", "+", "d"}], ")"}], "2"]}], "-", 
   RowBox[{"10", " ", 
    SuperscriptBox["a", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "+", "c", "+", "d"}], ")"}], "3"]}], "+", 
   RowBox[{"5", " ", "a", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "+", "c", "+", "d"}], ")"}], "4"]}], "-", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"b", "+", "c", "+", "d"}], ")"}], "5"]}], 
  TraditionalForm]], "Output",
 CellLabel->"Out[209]="]
}, Open  ]]
}, Open  ]],

Cell["Combine", "ObjectName",
 CellTags->"Combine"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Combine"],

Cell["\<\
Combine[expr]puts terms in a sum over a common denominator,and cancels \
factors in the result. Combine is similar to Together, but accepts the option \
Expanding and works usually better than Together for polynomials involving \
rationals with sums in the denominator.\
\>", "Text",
 CellTags->"Combine"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Combine", "]"}]], "Input",
 CellTags->"Combine",
 CellLabel->"In[210]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"Expanding", "\[Rule]", "False"}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Combine",
 CellLabel->"Out[210]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Factor2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Factor2",
  ButtonNote->"Factor2"],
 "."
}], "Text",
 CellTags->"Combine"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Combine"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Combine", "[", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"c", "-", "d"}], ")"}]}], "e"], "+", "g"}], "]"}]], "Input",
 CellTags->"Combine",
 CellLabel->"In[211]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"c", "-", "d"}], ")"}]}], "+", 
    RowBox[{"e", " ", "g"}]}], "e"], TraditionalForm]], "Output",
 CellTags->"Combine",
 CellLabel->"Out[211]="]
}, Open  ]],

Cell["\<\
Here the result from Together where the numerator is automatically expanded.\
\>", "Text",
 CellTags->"Combine"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Together", "[", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"c", "-", "d"}], ")"}]}], "e"], "+", "g"}], "]"}]], "Input",
 CellTags->"Combine",
 CellLabel->"In[212]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"a", " ", "c"}], "-", 
    RowBox[{"a", " ", "d"}], "-", 
    RowBox[{"b", " ", "c"}], "+", 
    RowBox[{"b", " ", "d"}], "+", 
    RowBox[{"e", " ", "g"}]}], "e"], TraditionalForm]], "Output",
 CellTags->"Combine",
 CellLabel->"Out[212]="]
}, Open  ]],

Cell["\<\
If the option Expanding is set to True, the result of Combine is the same as \
Together, but uses a slightly different algorithm.\
\>", "Text",
 CellTags->"Combine"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Combine", "[", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"c", "-", "d"}], ")"}]}], "e"], "+", "g"}], ",", 
   RowBox[{"Expanding", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"Combine",
 CellLabel->"In[213]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"a", " ", "c"}], "-", 
    RowBox[{"a", " ", "d"}], "-", 
    RowBox[{"b", " ", "c"}], "+", 
    RowBox[{"b", " ", "d"}], "+", 
    RowBox[{"e", " ", "g"}]}], "e"], TraditionalForm]], "Output",
 CellTags->"Combine",
 CellLabel->"Out[213]="]
}, Open  ]]
}, Open  ]],

Cell["CombineGraphs", "ObjectName",
 CellTags->"CombineGraphs"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"CombineGraphs"],

Cell["CombineGraphs is an option for OneLoopSum.", "Text",
 CellTags->"CombineGraphs"],

Cell[TextData[{
 "See also:  ",
 ButtonBox["OneLoopSum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoopSum",
  ButtonNote->"OneLoopSum"],
 "."
}], "Text",
 CellTags->"CombineGraphs"]
}, Open  ]],

Cell["Commutator", "ObjectName",
 CellTags->"Commutator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Commutator"],

Cell["\<\
Commutator[x, y] = c defines the commutator between the non-commuting objects \
x and y. \
\>", "Text",
 CellTags->"Commutator"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["AntiCommutator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"AntiCommutator",
  ButtonNote->"AntiCommutator"],
 ", ",
 ButtonBox["CommutatorExplicit",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CommutatorExplicit",
  ButtonNote->"CommutatorExplicit"],
 ", ",
 ButtonBox["DeclareNonCommutative",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DeclareNonCommutative",
  ButtonNote->"DeclareNonCommutative"],
 ", ",
 ButtonBox["DotSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DotSimplify",
  ButtonNote->"DotSimplify"],
 "."
}], "Text",
 CellTags->"Commutator"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Commutator"],

Cell[BoxData[
 RowBox[{"DeclareNonCommutative", "[", 
  RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]], "Input",
 CellTags->"Commutator",
 CellLabel->"In[214]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Commutator", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Input",
 CellTags->"Commutator",
 CellLabel->"In[215]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"[", "\[NoBreak]", "a", "\[NoBreak]", ",", "b", "\[NoBreak]", "]"}],
   TraditionalForm]], "Output",
 CellTags->"Commutator",
 CellLabel->"Out[215]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommutatorExplicit", "[", "%", "]"}]], "Input",
 CellTags->"Commutator",
 CellLabel->"In[216]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"a", ".", "b"}], "-", 
   RowBox[{"b", ".", "a"}]}], TraditionalForm]], "Output",
 CellTags->"Commutator",
 CellLabel->"Out[216]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DotSimplify", "[", 
   RowBox[{"Commutator", "[", 
    RowBox[{
     RowBox[{"a", "+", "b"}], ",", 
     RowBox[{"c", "+", "d"}]}], "]"}], "]"}], " "}]], "Input",
 CellTags->"Commutator",
 CellLabel->"In[217]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"a", ".", "c"}], "-", 
   RowBox[{"c", ".", "a"}], "+", 
   RowBox[{"a", ".", "d"}], "-", 
   RowBox[{"d", ".", "a"}], "+", 
   RowBox[{"b", ".", "c"}], "-", 
   RowBox[{"c", ".", "b"}], "+", 
   RowBox[{"b", ".", "d"}], "-", 
   RowBox[{"d", ".", "b"}]}], TraditionalForm]], "Output",
 CellTags->"Commutator",
 CellLabel->"Out[217]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"UnDeclareNonCommutative", "[", 
  RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]], "Input",
 CellTags->"Commutator",
 CellLabel->"In[218]:="],

Cell["Verify the Jacobi identity.", "Text",
 CellTags->"Commutator"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Chi]", "=", "Commutator"}], ";", " ", 
  RowBox[{"DeclareNonCommutative", "[", 
   RowBox[{"x", ",", "y", ",", "z"}], "]"}], ";"}]], "Input",
 CellTags->"Commutator",
 CellLabel->"In[219]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Chi]", "[", 
   RowBox[{"x", ",", 
    RowBox[{"\[Chi]", "[", 
     RowBox[{"y", ",", "z"}], "]"}]}], "]"}], "+", 
  RowBox[{"\[Chi]", "[", 
   RowBox[{"y", ",", 
    RowBox[{"\[Chi]", "[", 
     RowBox[{"z", ",", "x"}], "]"}]}], "]"}], "+", 
  RowBox[{"\[Chi]", "[", 
   RowBox[{"z", ",", 
    RowBox[{"\[Chi]", "[", 
     RowBox[{"x", ",", "y"}], "]"}]}], "]"}]}]], "Input",
 CellTags->"Commutator",
 CellLabel->"In[220]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"[", "\[NoBreak]", "x", "\[NoBreak]", ",", 
    FormBox[
     RowBox[{
     "[", "\[NoBreak]", "y", "\[NoBreak]", ",", "z", "\[NoBreak]", "]"}],
     TraditionalForm], "\[NoBreak]", "]"}], "+", 
   RowBox[{"[", "\[NoBreak]", "y", "\[NoBreak]", ",", 
    FormBox[
     RowBox[{
     "[", "\[NoBreak]", "z", "\[NoBreak]", ",", "x", "\[NoBreak]", "]"}],
     TraditionalForm], "\[NoBreak]", "]"}], "+", 
   RowBox[{"[", "\[NoBreak]", "z", "\[NoBreak]", ",", 
    FormBox[
     RowBox[{
     "[", "\[NoBreak]", "x", "\[NoBreak]", ",", "y", "\[NoBreak]", "]"}],
     TraditionalForm], "\[NoBreak]", "]"}]}], TraditionalForm]], "Output",
 CellTags->"Commutator",
 CellLabel->"Out[220]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotSimplify", "[", "%", "]"}]], "Input",
 CellTags->"Commutator",
 CellLabel->"In[221]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"Commutator",
 CellLabel->"Out[221]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "\[Chi]", "]"}]], "Input",
 CellTags->"Commutator",
 CellLabel->"In[222]:="],

Cell[BoxData[
 RowBox[{"UnDeclareNonCommutative", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Input",
 CellTags->"Commutator",
 CellLabel->"In[223]:="]
}, Open  ]],

Cell["CommutatorExplicit", "ObjectName",
 CellTags->"CommutatorExplicit"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"CommutatorExplicit"],

Cell["\<\
CommutatorExplicit[exp] substitutes any Commutator and AntiCommutator in exp \
by their definitions.\
\>", "Text",
 CellTags->"CommutatorExplicit"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Calc",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Calc",
  ButtonNote->"Calc"],
 ", ",
 ButtonBox["DotSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DotSimplify",
  ButtonNote->"DotSimplify"],
 "."
}], "Text",
 CellTags->"CommutatorExplicit"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"CommutatorExplicit"],

Cell[BoxData[
 RowBox[{"DeclareNonCommutative", "[", 
  RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]], "Input",
 CellTags->"CommutatorExplicit",
 CellLabel->"In[224]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Commutator", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Input",
 CellTags->"CommutatorExplicit",
 CellLabel->"In[225]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"[", "\[NoBreak]", "a", "\[NoBreak]", ",", "b", "\[NoBreak]", "]"}],
   TraditionalForm]], "Output",
 CellTags->"CommutatorExplicit",
 CellLabel->"Out[225]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommutatorExplicit", "[", "%", "]"}]], "Input",
 CellTags->"CommutatorExplicit",
 CellLabel->"In[226]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"a", ".", "b"}], "-", 
   RowBox[{"b", ".", "a"}]}], TraditionalForm]], "Output",
 CellTags->"CommutatorExplicit",
 CellLabel->"Out[226]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AntiCommutator", "[", 
  RowBox[{
   RowBox[{"a", "-", "c"}], ",", 
   RowBox[{"b", "-", "d"}]}], "]"}]], "Input",
 CellTags->"CommutatorExplicit",
 CellLabel->"In[227]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   FormBox[
    RowBox[{"a", "-", "c"}],
    TraditionalForm], ",", "\[MediumSpace]", 
   FormBox[
    RowBox[{"b", "-", "d"}],
    TraditionalForm], "}"}], TraditionalForm]], "Output",
 CellTags->"CommutatorExplicit",
 CellLabel->"Out[227]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommutatorExplicit", "[", "%", "]"}]], "Input",
 CellTags->"CommutatorExplicit",
 CellLabel->"In[228]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "-", "c"}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{"b", "-", "d"}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"b", "-", "d"}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{"a", "-", "c"}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"CommutatorExplicit",
 CellLabel->"Out[228]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CommutatorExplicit", "[", "%%", "]"}], "//", 
  "DotSimplify"}]], "Input",
 CellTags->"CommutatorExplicit",
 CellLabel->"In[229]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"a", ".", "b"}], "+", 
   RowBox[{"b", ".", "a"}], "-", 
   RowBox[{"a", ".", "d"}], "-", 
   RowBox[{"d", ".", "a"}], "-", 
   RowBox[{"b", ".", "c"}], "-", 
   RowBox[{"c", ".", "b"}], "+", 
   RowBox[{"c", ".", "d"}], "+", 
   RowBox[{"d", ".", "c"}]}], TraditionalForm]], "Output",
 CellTags->"CommutatorExplicit",
 CellLabel->"Out[229]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"UnDeclareNonCommutative", "[", 
  RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]], "Input",
 CellTags->"CommutatorExplicit",
 CellLabel->"In[230]:="]
}, Open  ]],

Cell["CompleteSquare", "ObjectName",
 CellTags->"CompleteSquare"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"CompleteSquare"],

Cell[TextData[{
 "Completes the square of a second order polynomial in the momentum x. \
CompleteSquare[",
 "a",
 " ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["p",
     FontSlant->"Plain"], "2"], TraditionalForm]]],
 "+",
 "b",
 " ",
 "p",
 "+",
 "c",
 ", ",
 "p",
 "] \[Rule] -",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["b",
     FontSlant->"Plain"], "2"], TraditionalForm]]],
 "/(4 ",
 "a",
 ")+",
 "c",
 "+",
 "a",
 " (",
 "b",
 "/(2 ",
 "a",
 ")+",
 "x",
 ")^2. CompleteSquare[",
 "a",
 " ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["p",
     FontSlant->"Plain"], "2"], TraditionalForm]]],
 "+",
 "b",
 " ",
 "p",
 "+",
 "c",
 ", ",
 "p",
 ", ",
 "q",
 "] \[Rule] {-",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["b",
     FontSlant->"Plain"], "2"], TraditionalForm]]],
 "/(4 ",
 "a",
 ")+",
 "c",
 "+",
 "a",
 " ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    StyleBox["q",
     FontSlant->"Plain"], "2"], TraditionalForm]]],
 ", ",
 "q",
 "\[Rule]",
 "b",
 "/(2 ",
 "a",
 ")+",
 "p",
 "}."
}], "Text",
 CellTags->"CompleteSquare"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"CompleteSquare"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{
   RowBox[{"5", 
    RowBox[{"SP", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"2", "p"}], "+", 
       RowBox[{"3", "r"}]}], ",", 
      RowBox[{"p", "+", "r"}]}], "]"}]}], "//", "FCI"}]}]], "Input",
 CellLabel->"In[231]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"5", " ", 
   RowBox[{"(", 
    FormBox[
     RowBox[{"p", "+", "r"}],
     TraditionalForm], ")", "\[CenterDot]", "(", 
    FormBox[
     RowBox[{
      RowBox[{"2", " ", "p"}], "+", 
      RowBox[{"3", " ", "r"}]}],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellLabel->"Out[231]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", "=", 
  RowBox[{"CompleteSquare", "[", 
   RowBox[{"t1", ",", "p"}], "]"}]}]], "Input",
 CellTags->"CompleteSquare",
 CellLabel->"In[232]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"10", " ", 
    RowBox[{"(", 
     TagBox[
      FormBox[
       RowBox[{"p", "+", 
        FractionBox[
         RowBox[{"5", " ", "r"}], "4"]}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ")", ".", "(", 
     TagBox[
      FormBox[
       RowBox[{"p", "+", 
        FractionBox[
         RowBox[{"5", " ", "r"}], "4"]}],
       TraditionalForm],
      TraditionalForm,
      Editable->True], ")"}]}], "-", 
   FractionBox[
    RowBox[{"5", " ", 
     SuperscriptBox[
      FormBox["r",
       TraditionalForm], "2"]}], "8"]}], TraditionalForm]], "Output",
 CellTags->"CompleteSquare",
 CellLabel->"Out[232]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"t1", "-", "t2"}], "//", "ScalarProductExpand"}], "//", 
  "Expand"}]], "Input",
 CellTags->"CompleteSquare",
 CellLabel->"In[233]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"CompleteSquare",
 CellLabel->"Out[233]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompleteSquare", "[", 
  RowBox[{"t1", ",", "p", ",", "q"}], "]"}]], "Input",
 CellTags->"CompleteSquare",
 CellLabel->"In[234]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"10", " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], "2"]}], "-", 
     FractionBox[
      RowBox[{"5", " ", 
       SuperscriptBox[
        FormBox["r",
         TraditionalForm], "2"]}], "8"]}], ",", 
    RowBox[{"q", "\[Rule]", 
     RowBox[{"p", "+", 
      FractionBox[
       RowBox[{"5", " ", "r"}], "4"]}]}]}], "}"}], TraditionalForm]], "Output",\

 CellTags->"CompleteSquare",
 CellLabel->"Out[234]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"t1", ",", "t2"}], "]"}]], "Input",
 CellTags->"CompleteSquare",
 CellLabel->"In[235]:="]
}, Open  ]],

Cell["ComplexConjugate", "ObjectName",
 CellTags->"ComplexConjugate"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ComplexConjugate"],

Cell["\<\
ComplexConjugate[expr] complex conjugates expr. It operates on fermion lines, \
i.e., products of Spinor[..] .DiracMatrix[..] . Spinor[..], and changes all \
occuring LorentzIndex[mu] into LorentzIndex[ComplexIndex[mu]]. For taking the \
spin sum (i.e. constructing the traces) use FermionSpinSum. WARNING: In expr \
should be NO explicit I's in denominators!\
\>", "Text",
 CellTags->"ComplexConjugate"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["ComplexIndex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ComplexIndex",
  ButtonNote->"ComplexIndex"],
 ", ",
 ButtonBox["FermionSpinSum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FermionSpinSum",
  ButtonNote->"FermionSpinSum"],
 ", ",
 ButtonBox["LorentzIndex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LorentzIndex",
  ButtonNote->"LorentzIndex"],
 "."
}], "Text",
 CellTags->"ComplexConjugate"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ComplexConjugate"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ComplexConjugate", "[", 
  RowBox[{"MetricTensor", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "]"}]], "Input",
 CellTags->"ComplexConjugate",
 CellLabel->"In[236]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["g", 
   RowBox[{"\[Mu]", "\[Nu]"}]], TraditionalForm]], "Output",
 CellTags->"ComplexConjugate",
 CellLabel->"Out[236]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
 CellTags->"ComplexConjugate",
 CellLabel->"In[237]:="],

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], "]"}]], "Output",
 CellTags->"ComplexConjugate",
 CellLabel->"Out[237]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GA", "[", 
  RowBox[{"\[Mu]", ",", "\[Nu]", ",", "5"}], "]"}]], "Input",
 CellTags->"ComplexConjugate",
 CellLabel->"In[238]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
   SuperscriptBox["\[Gamma]", "5"]}], TraditionalForm]], "Output",
 CellTags->"ComplexConjugate",
 CellLabel->"Out[238]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ComplexConjugate", "[", "%", "]"}]], "Input",
 CellTags->"ComplexConjugate",
 CellLabel->"In[239]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   RowBox[{
    SuperscriptBox["\[Gamma]", "5"], ".", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], ".", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"ComplexConjugate",
 CellLabel->"Out[239]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNTrace", "[", 
  RowBox[{"SUNT", "[", 
   RowBox[{"a", ",", "b", ",", "c"}], "]"}], "]"}]], "Input",
 CellTags->"ComplexConjugate",
 CellLabel->"In[240]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"tr", "(", 
   FormBox[
    RowBox[{
     SubscriptBox["T", 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]]}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"ComplexConjugate",
 CellLabel->"Out[240]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ComplexConjugate", "[", "%", "]"}]], "Input",
 CellTags->"ComplexConjugate",
 CellLabel->"In[241]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"tr", "(", 
   FormBox[
    RowBox[{
     SubscriptBox["T", 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]]}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"ComplexConjugate",
 CellLabel->"Out[241]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ComplexConjugate", "[", 
  RowBox[{"SUNF", "[", 
   RowBox[{"a", ",", "b", ",", "c"}], "]"}], "]"}]], "Input",
 CellTags->"ComplexConjugate",
 CellLabel->"In[242]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["f", 
   RowBox[{
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["b",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["c",
      TraditionalForm],
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"ComplexConjugate",
 CellLabel->"Out[242]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"FCE", "[", 
   RowBox[{"ComplexConjugate", "[", 
    RowBox[{"MetricTensor", "[", 
     RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "]"}], "]"}], "]"}]], "Input",
 CellTags->"ComplexConjugate",
 CellLabel->"In[243]:="],

Cell[BoxData[
 RowBox[{"MT", "[", 
  RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]], "Output",
 CellTags->"ComplexConjugate",
 CellLabel->"Out[243]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SpinorUBar", "[", 
   RowBox[{"k1", ",", "m"}], "]"}], ".", 
  RowBox[{"GA", "[", "\[Lambda]", "]"}], ".", 
  RowBox[{"SpinorU", "[", 
   RowBox[{"p1", ",", "m"}], "]"}]}]], "Input",
 CellTags->"ComplexConjugate",
 CellLabel->"In[244]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FormBox[
     OverscriptBox["\<\"u\"\>", "_"],
     TraditionalForm], "(", "k1", ",", "m", ")"}], ".", 
   SuperscriptBox["\[Gamma]", "\[Lambda]"], ".", 
   RowBox[{"u", "(", "p1", ",", "m", ")"}]}], TraditionalForm]], "Output",
 CellTags->"ComplexConjugate",
 CellLabel->"Out[244]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ComplexConjugate", "[", "%", "]"}]], "Input",
 CellTags->"ComplexConjugate",
 CellLabel->"In[245]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[CurlyPhi]", "(", 
    FormBox["p1",
     TraditionalForm], ",", "m", ")"}], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Lambda]",
      TraditionalForm],
     TraditionalForm]], ".", 
   RowBox[{"\[CurlyPhi]", "(", 
    FormBox["k1",
     TraditionalForm], ",", "m", ")"}]}], TraditionalForm]], "Output",
 CellTags->"ComplexConjugate",
 CellLabel->"Out[245]="]
}, Open  ]],

Cell["\<\
Notice that SpinorUBar and SpinorU are only input functions. Internally they \
are converted to Spinor objects.\
\>", "Text",
 CellTags->"ComplexConjugate"]
}, Open  ]],

Cell["Contract", "ObjectName",
 CellTags->"Contract"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Contract"],

Cell["\<\
Contract[expr] contracts pairs of Lorentz indices of metric tensors, \
four-vectors and (depending on the optionEpsContract) of Levi-Civita tensors \
in expr. For the contraction of Dirac matrices with each other use \
DiracSimplify. Contract[exp1, exp2] contracts (exp1*exp2), where exp1 and \
exp2 may be larger products of sums of metric tensors and 4-vectors. \
\>", "Text",
 CellTags->"Contract"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Contract", "]"}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[246]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Collecting", "\[Rule]", "True"}], ",", 
    RowBox[{"Contract3", "\[Rule]", "True"}], ",", 
    RowBox[{"EpsContract", "\[Rule]", "True"}], ",", 
    RowBox[{"Expanding", "\[Rule]", "True"}], ",", 
    RowBox[{"Factoring", "\[Rule]", "False"}], ",", 
    RowBox[{"FeynCalcInternal", "\[Rule]", "True"}], ",", 
    RowBox[{"MomentumCombine", "\[Rule]", "True"}], ",", 
    RowBox[{"Rename", "\[Rule]", "False"}], ",", 
    RowBox[{"Schouten", "\[Rule]", "0"}]}], "}"}], TraditionalForm]], "Output",\

 CellTags->"Contract",
 CellLabel->"Out[246]="]
}, Open  ]],

Cell["\<\
The option setting Contract3 can be set to True resulting in a faster \
algorithm to contract products of tensors.\
\>", "Text"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Pair",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Pair",
  ButtonNote->"Pair"],
 ", ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 ", ",
 ButtonBox["MomentumCombine",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MomentumCombine",
  ButtonNote->"MomentumCombine"],
 "."
}], "Text",
 CellTags->"Contract"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Contract"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MetricTensor", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], " ", 
  RowBox[{"FourVector", "[", 
   RowBox[{"p", ",", "\[Mu]"}], "]"}]}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[247]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["p", "\[Mu]"], " ", 
   SuperscriptBox["g", 
    RowBox[{"\[Mu]", "\[Nu]"}]]}], TraditionalForm]], "Output",
 CellTags->"Contract",
 CellLabel->"Out[247]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", "%", "]"}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[248]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   FormBox["p",
    TraditionalForm], 
   FormBox[
    FormBox["\[Nu]",
     TraditionalForm],
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"Contract",
 CellLabel->"Out[248]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FourVector", "[", 
   RowBox[{"p", ",", "\[Mu]"}], "]"}], 
  RowBox[{"DiracMatrix", "[", "\[Mu]", "]"}]}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[249]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubscriptBox["p", "\[Mu]"]}], TraditionalForm]], "Output",
 CellTags->"Contract",
 CellLabel->"Out[249]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", "%", "]"}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[250]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["\<\"\[Gamma]\"\>",
    TraditionalForm], "\[CenterDot]", 
   FormBox["p",
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"Contract",
 CellLabel->"Out[250]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MetricTensor", "[", 
  RowBox[{"\[Mu]", ",", "\[Mu]"}], "]"}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[251]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["g", 
   RowBox[{"\[Mu]", "\[Mu]"}]], TraditionalForm]], "Output",
 CellTags->"Contract",
 CellLabel->"Out[251]="]
}, Open  ]],

Cell["The default dimension for MetricTensor is 4.", "Text",
 CellTags->"Contract"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", "%", "]"}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[252]:="],

Cell[BoxData[
 FormBox["4", TraditionalForm]], "Output",
 CellTags->"Contract",
 CellLabel->"Out[252]="]
}, Open  ]],

Cell["\<\
A short way to enter D-dimensional metric tensors is given by MTD. The \".\" \
as multiplication operator is not necessary but just convenient for \
typesetting.\
\>", "Text",
 CellTags->"Contract"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MTD", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], " ", ".", " ", 
  RowBox[{"MTD", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[253]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["g", 
    RowBox[{"\[Mu]", "\[Nu]"}]], ".", 
   SuperscriptBox["g", 
    RowBox[{"\[Mu]", "\[Nu]"}]]}], TraditionalForm]], "Output",
 CellTags->"Contract",
 CellLabel->"Out[253]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", "%", "]"}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[254]:="],

Cell[BoxData[
 FormBox["D", TraditionalForm]], "Output",
 CellTags->"Contract",
 CellLabel->"Out[254]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MTD", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], " ", ".", " ", 
  RowBox[{"MTD", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[255]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["g", 
    RowBox[{"\[Mu]", "\[Nu]"}]], ".", 
   SuperscriptBox["g", 
    RowBox[{"\[Mu]", "\[Nu]"}]]}], TraditionalForm]], "Output",
 CellTags->"Contract",
 CellLabel->"Out[255]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FourVector", "[", 
   RowBox[{"p", ",", "\[Mu]"}], "]"}], " ", 
  RowBox[{"FourVector", "[", 
   RowBox[{"q", ",", "\[Mu]"}], "]"}]}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[256]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["p", "\[Mu]"], " ", 
   SubscriptBox["q", "\[Mu]"]}], TraditionalForm]], "Output",
 CellTags->"Contract",
 CellLabel->"Out[256]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", "%", " ", "]"}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[257]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["p",
    TraditionalForm], "\[CenterDot]", 
   FormBox["q",
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"Contract",
 CellLabel->"Out[257]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FourVector", "[", 
   RowBox[{
    RowBox[{"p", "-", "q"}], ",", "\[Mu]"}], "]"}], " ", 
  RowBox[{"FourVector", "[", 
   RowBox[{
    RowBox[{"a", "-", "b"}], ",", "\[Mu]"}], "]"}]}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[258]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox[
    RowBox[{"(", 
     FormBox[
      TagBox[
       RowBox[{"a", "-", "b"}],
       HoldForm],
      TraditionalForm], ")"}], "\[Mu]"], " ", 
   SubscriptBox[
    RowBox[{"(", 
     FormBox[
      TagBox[
       RowBox[{"p", "-", "q"}],
       HoldForm],
      TraditionalForm], ")"}], "\[Mu]"]}], TraditionalForm]], "Output",
 CellTags->"Contract",
 CellLabel->"Out[258]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", "%", "]"}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[259]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FormBox["a",
     TraditionalForm], "\[CenterDot]", 
    FormBox["p",
     TraditionalForm]}], "-", 
   RowBox[{
    FormBox["a",
     TraditionalForm], "\[CenterDot]", 
    FormBox["q",
     TraditionalForm]}], "-", 
   RowBox[{
    FormBox["b",
     TraditionalForm], "\[CenterDot]", 
    FormBox["p",
     TraditionalForm]}], "+", 
   RowBox[{
    FormBox["b",
     TraditionalForm], "\[CenterDot]", 
    FormBox["q",
     TraditionalForm]}]}], TraditionalForm]], "Output",
 CellTags->"Contract",
 CellLabel->"Out[259]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LeviCivita", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Sigma]"}], "]"}], 
  " ", 
  RowBox[{"FourVector", "[", 
   RowBox[{"p", ",", "\[Sigma]"}], "]"}]}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[260]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["p", "\[Sigma]"], " ", 
   SuperscriptBox["\[Epsilon]", 
    RowBox[{
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Alpha]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"Contract",
 CellLabel->"Out[260]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", "%", "]"}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[261]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{
    FormBox[
     FormBox["\[Alpha]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox["p",
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"Contract",
 CellLabel->"Out[261]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LeviCivita", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Beta]"}], "]"}], 
  " ", 
  RowBox[{"LeviCivita", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Sigma]"}], "]"}], 
  " "}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[262]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Epsilon]", 
    RowBox[{
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Alpha]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Beta]",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   SuperscriptBox["\[Epsilon]", 
    RowBox[{
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Alpha]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"Contract",
 CellLabel->"Out[262]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", "%", "]"}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[263]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "6"}], " ", 
   SuperscriptBox["g", 
    RowBox[{"\[Beta]", "\[Sigma]"}]]}], TraditionalForm]], "Output",
 CellTags->"Contract",
 CellLabel->"Out[263]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Eps", ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], ";", 
  RowBox[{
   RowBox[{"LCD", "[", 
    RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Beta]"}], "]"}], 
   " ", 
   RowBox[{"LCD", "[", 
    RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Sigma]"}], 
    "]"}]}]}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[264]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Epsilon]", 
    RowBox[{"\[Mu]", "\[Nu]", "\[Alpha]", "\[Beta]"}]], " ", 
   SuperscriptBox["\[Epsilon]", 
    RowBox[{"\[Mu]", "\[Nu]", "\[Alpha]", "\[Sigma]"}]]}], 
  TraditionalForm]], "Output",
 CellTags->"Contract",
 CellLabel->"Out[264]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Contract", "[", "%", "]"}], "//", "Factor2"}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[265]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", "D"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"2", "-", "D"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"3", "-", "D"}], ")"}], " ", 
   SuperscriptBox["g", 
    RowBox[{"\[Beta]", "\[Sigma]"}]]}], TraditionalForm]], "Output",
 CellTags->"Contract",
 CellLabel->"Out[265]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Eps", ",", 
    RowBox[{"Dimension", "\[Rule]", "4"}]}], "]"}], ";"}]], "Input",
 CellTags->"Contract",
 CellLabel->"In[266]:="]
}, Open  ]],

Cell["Contract1", "ObjectName",
 CellTags->"Contract1"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Contract1"],

Cell["\<\
For covariant calculations it is not necessary to distinguish between co- and \
contravariant indices (except for the Levi-Civita tensor).
Therefore normally no distinction is made between upper and lower indices.
Howere, if needed, one can use Upper and Lower and then a distuction is made:
Contract1[exp] contracts Upper and Lower indices. Neither Upper and Upper nor \
Lower and Lower indices are contracted.\
\>", "Text",
 CellTags->"Contract1"],

Cell[TextData[{
 "See also:  ",
 ButtonBox["LorentzIndex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LorentzIndex",
  ButtonNote->"LorentzIndex"],
 ", ",
 ButtonBox["Lower",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Lower",
  ButtonNote->"Lower"],
 ", ",
 ButtonBox["Upper",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Upper",
  ButtonNote->"Upper"],
 "."
}], "Text",
 CellTags->"Contract1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Contract1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"FV", "[", 
     RowBox[{"p", ",", 
      RowBox[{"Lower", "[", "\[Mu]", "]"}]}], "]"}], 
    RowBox[{"FV", "[", 
     RowBox[{"q", ",", 
      RowBox[{"Upper", "[", "\[Mu]", "]"}]}], "]"}]}], "//", "FCI"}], "//", 
  "Contract1"}]], "Input",
 CellTags->"Contract1",
 CellLabel->"In[267]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["p",
    TraditionalForm], "\[CenterDot]", 
   FormBox["q",
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"Contract1",
 CellLabel->"Out[267]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"FV", "[", 
     RowBox[{"p", ",", 
      RowBox[{"Upper", "[", "\[Mu]", "]"}]}], "]"}], 
    RowBox[{"FV", "[", 
     RowBox[{"q", ",", 
      RowBox[{"Upper", "[", "\[Mu]", "]"}]}], "]"}]}], "//", "FCI"}], "//", 
  "Contract1"}]], "Input",
 CellTags->"Contract1",
 CellLabel->"In[268]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], 
    FormBox[
     FormBox[
      RowBox[{"Upper", "(", "\[Mu]", ")"}],
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox[
    FormBox["q",
     TraditionalForm], 
    FormBox[
     FormBox[
      RowBox[{"Upper", "(", "\[Mu]", ")"}],
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"Contract1",
 CellLabel->"Out[268]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MT", "[", 
    RowBox[{
     RowBox[{"Lower", "[", "\[Mu]", "]"}], ",", 
     RowBox[{"Upper", "[", "\[Mu]", "]"}]}], "]"}], "//", "FCI"}], "//", 
  "Contract1"}]], "Input",
 CellTags->"Contract1",
 CellLabel->"In[269]:="],

Cell[BoxData[
 FormBox["4", TraditionalForm]], "Output",
 CellTags->"Contract1",
 CellLabel->"Out[269]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MT", "[", 
    RowBox[{
     RowBox[{"Upper", "[", "\[Mu]", "]"}], ",", 
     RowBox[{"Upper", "[", "\[Mu]", "]"}]}], "]"}], "//", "FCI"}], "//", 
  "Contract1"}]], "Input",
 CellTags->"Contract1",
 CellLabel->"In[270]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["g", 
   RowBox[{
    FormBox[
     RowBox[{"Upper", "(", "\[Mu]", ")"}],
     TraditionalForm], 
    FormBox[
     RowBox[{"Upper", "(", "\[Mu]", ")"}],
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"Contract1",
 CellLabel->"Out[270]="]
}, Open  ]]
}, Open  ]],

Cell["Convolute", "ObjectName",
 CellTags->"Convolute"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Convolute"],

Cell[TextData[{
 "Convolute[f, g, x] convolutes ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 ") and ",
 StyleBox["g",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 "), i.e., ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], 
    RowBox[{
     SubscriptBox[
      StyleBox[
       RowBox[{
        StyleBox["d",
         FontSlant->"Plain"], 
        StyleBox["x",
         FontSlant->"Italic"]}]], "1"], " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       SubscriptBox[
        StyleBox[
         RowBox[{
          StyleBox["d",
           FontSlant->"Plain"], "x"}]], "2"], " ", 
       RowBox[{"\[Delta]", "(", 
        RowBox[{"x", " ", "-", " ", 
         RowBox[{
          SubscriptBox["x", "1"], " ", 
          SubscriptBox["x", "2"]}]}], ")"}], " ", 
       RowBox[{"f", "(", 
        SubscriptBox["x", "1"], ")"}], " ", 
       RowBox[{
        RowBox[{"g", "(", 
         SubscriptBox["x", "2"], ")"}], " ", "."}]}]}]}]}], TraditionalForm]]],
 " Convolute[f, g] is equivalent to Convolute[f, g, x]. Convolute[exp, {x1, \
x2}] assumes that exp is polynomial in x1 and x2. Convolute uses \
table-look-up and does not do any integral calculations, only linear \
algebra."
}], "Text",
 CellTags->"Convolute"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Convolute", "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[271]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Bracket", "\[Rule]", 
     RowBox[{"{", 
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], "}"}]}], ",", 
    RowBox[{"FinalSubstitutions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"PlusDistribution", "\[Rule]", "Identity"}], "}"}]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[271]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["PlusDistribution",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PlusDistribution",
  ButtonNote->"PlusDistribution"],
 ", ",
 ButtonBox["ConvoluteTable",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ConvoluteTable",
  ButtonNote->"ConvoluteTable"],
 "."
}], "Text",
 CellTags->"Convolute"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Convolute"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{"1", ",", "1"}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[272]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   RowBox[{"log", "(", "x", ")"}]}], TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[272]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{"x", ",", "x"}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[273]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "x"}], " ", 
   RowBox[{"log", "(", "x", ")"}]}], TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[273]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{"1", ",", "x"}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[274]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"1", "-", "x"}], TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[274]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{"1", ",", 
   FractionBox["1", 
    RowBox[{"1", "-", "x"}]]}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[275]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"log", "(", 
    RowBox[{"1", "-", "x"}], ")"}], "-", 
   RowBox[{"log", "(", "x", ")"}]}], TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[275]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{"1", ",", 
   RowBox[{"PlusDistribution", "[", 
    FractionBox["1", 
     RowBox[{"1", "-", "x"}]], "]"}]}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[276]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"log", "(", 
    RowBox[{"1", "-", "x"}], ")"}], "-", 
   RowBox[{"log", "(", "x", ")"}]}], TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[276]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", "-", "x"}]], ",", "x"}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[277]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "x"}], "+", 
   RowBox[{"x", " ", 
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "-", 
   RowBox[{"x", " ", 
    RowBox[{"log", "(", "x", ")"}]}], "+", "1"}], TraditionalForm]], "Output",\

 CellTags->"Convolute",
 CellLabel->"Out[277]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", "-", "x"}]], ",", 
   FractionBox["1", 
    RowBox[{"1", "-", "x"}]]}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[278]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
     RowBox[{"\[Delta]", "(", 
      FormBox[
       RowBox[{"1", "-", "x"}],
       TraditionalForm], ")"}]}]}], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], 
    RowBox[{"1", "-", "x"}]], "-", 
   FractionBox[
    RowBox[{"log", "(", "x", ")"}], 
    RowBox[{"1", "-", "x"}]]}], TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[278]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{"1", ",", 
   RowBox[{"Log", "[", 
    RowBox[{"1", "-", "x"}], "]"}]}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[279]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
     "PolyLog"]}], "-", 
   RowBox[{
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}], " ", 
    RowBox[{"log", "(", "x", ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[279]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{"1", ",", 
   RowBox[{"x", " ", 
    RowBox[{"Log", "[", 
     RowBox[{"1", "-", "x"}], "]"}]}]}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[280]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"x", "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "x"}], ")"}], " ", 
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "-", "1"}], TraditionalForm]], "Output",\

 CellTags->"Convolute",
 CellLabel->"Out[280]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", "-", "x"}]], ",", 
   RowBox[{"Log", "[", 
    RowBox[{"1", "-", "x"}], "]"}]}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[281]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[Zeta]", "(", "2", ")"}]}], "+", 
   RowBox[{
    SuperscriptBox["log", "2"], "(", 
    RowBox[{"1", "-", "x"}], ")"}], "-", 
   RowBox[{
    RowBox[{"log", "(", "x", ")"}], " ", 
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[281]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", "-", "x"}]], ",", 
   RowBox[{"x", " ", 
    RowBox[{"Log", "[", 
     RowBox[{"1", "-", "x"}], "]"}]}]}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[282]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     RowBox[{"\[Zeta]", "(", "2", ")"}], " ", "x"}]}], "+", "x", "+", 
   RowBox[{"x", " ", 
    RowBox[{
     SuperscriptBox["log", "2"], "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "x"}], ")"}], " ", 
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "-", 
   RowBox[{"x", " ", 
    RowBox[{"log", "(", "x", ")"}], " ", 
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "-", "1"}], TraditionalForm]], "Output",\

 CellTags->"Convolute",
 CellLabel->"Out[282]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"Log", "[", 
     RowBox[{"1", "-", "x"}], "]"}], 
    RowBox[{"1", "-", "x"}]], ",", "x"}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[283]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "x"}], " ", 
    TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
     "PolyLog"]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "x", " ", 
    RowBox[{
     SuperscriptBox["log", "2"], "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "x"}], ")"}], " ", 
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "-", 
   RowBox[{"x", " ", 
    RowBox[{"log", "(", "x", ")"}], " ", 
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "+", 
   RowBox[{"x", " ", 
    RowBox[{"log", "(", "x", ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[283]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{"1", ",", 
   RowBox[{"x", " ", 
    RowBox[{"Log", "[", "x", "]"}]}]}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[284]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"x", "+", 
   RowBox[{"x", " ", 
    RowBox[{"(", 
     RowBox[{"-", 
      RowBox[{"log", "(", "x", ")"}]}], ")"}]}], "-", "1"}], 
  TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[284]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{
   RowBox[{"Log", "[", 
    RowBox[{"1", "-", "x"}], "]"}], ",", "x"}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[285]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "x"}], ")"}], " ", 
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "+", 
   RowBox[{"x", " ", 
    RowBox[{"log", "(", "x", ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[285]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", "-", "x"}]], ",", 
   FractionBox[
    RowBox[{"Log", "[", "x", "]"}], 
    RowBox[{"1", "-", "x"}]]}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[286]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "x"}], ")"}], " ", 
     RowBox[{"log", "(", "x", ")"}]}], 
    RowBox[{"1", "-", "x"}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["log", "2"], "(", "x", ")"}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "x"}], ")"}]}]]}], TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[286]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{"1", ",", 
   RowBox[{"Log", "[", "x", "]"}]}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[287]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", 
   RowBox[{
    SuperscriptBox["log", "2"], "(", "x", ")"}]}], TraditionalForm]], "Output",\

 CellTags->"Convolute",
 CellLabel->"Out[287]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{"x", ",", " ", 
   RowBox[{"x", " ", 
    RowBox[{"Log", "[", "x", "]"}]}]}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[288]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", "x", " ", 
   RowBox[{
    SuperscriptBox["log", "2"], "(", "x", ")"}]}], TraditionalForm]], "Output",\

 CellTags->"Convolute",
 CellLabel->"Out[288]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", "-", "x"}]], ",", 
   RowBox[{"Log", "[", "x", "]"}]}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[289]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
    "PolyLog"], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{
     SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
   RowBox[{
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}], " ", 
    RowBox[{"log", "(", "x", ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[289]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{"1", ",", 
   FractionBox[
    RowBox[{"Log", "[", "x", "]"}], 
    RowBox[{"1", "-", "x"}]]}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[290]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
     "PolyLog"]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{
     SuperscriptBox["log", "2"], "(", "x", ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[290]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", "-", "x"}]], ",", 
   RowBox[{"x", " ", 
    RowBox[{"Log", "[", "x", "]"}]}]}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[291]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"x", " ", 
    TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
     "PolyLog"]}], "+", "x", "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "x", " ", 
    RowBox[{
     SuperscriptBox["log", "2"], "(", "x", ")"}]}], "-", 
   RowBox[{"x", " ", 
    RowBox[{"log", "(", "x", ")"}]}], "+", 
   RowBox[{"x", " ", 
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}], " ", 
    RowBox[{"log", "(", "x", ")"}]}], "-", "1"}], TraditionalForm]], "Output",\

 CellTags->"Convolute",
 CellLabel->"Out[291]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"Log", "[", "x", "]"}], 
    RowBox[{"1", "-", "x"}]], ",", "x"}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[292]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "x"}], " ", 
    TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
     "PolyLog"]}], "-", "x", "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "x", " ", 
    RowBox[{
     SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
   RowBox[{"log", "(", "x", ")"}], "+", "1"}], TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[292]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{"1", ",", 
   RowBox[{"x", " ", 
    RowBox[{"Log", "[", "x", "]"}]}]}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[293]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"x", "+", 
   RowBox[{"x", " ", 
    RowBox[{"(", 
     RowBox[{"-", 
      RowBox[{"log", "(", "x", ")"}]}], ")"}]}], "-", "1"}], 
  TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[293]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{
   RowBox[{"Log", "[", "x", "]"}], ",", "x"}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[294]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "x"}], "+", 
   RowBox[{"log", "(", "x", ")"}], "+", "1"}], TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[294]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", "-", "x"}]], ",", 
   FractionBox[
    RowBox[{"Log", "[", 
     RowBox[{"1", "-", "x"}], "]"}], 
    RowBox[{"1", "-", "x"}]]}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[295]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"\[Zeta]", "(", "2", ")"}], 
     RowBox[{"1", "-", "x"}]]}], "+", 
   RowBox[{
    TemplateBox[{"3"},
     "Zeta"], " ", 
    RowBox[{"\[Delta]", "(", 
     FormBox[
      RowBox[{"1", "-", "x"}],
      TraditionalForm], ")"}]}], "+", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{
      SuperscriptBox["log", "2"], "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "x"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"log", "(", "x", ")"}], " ", 
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], 
    RowBox[{"1", "-", "x"}]]}], TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[295]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"Log", "[", 
     RowBox[{"1", "-", "x"}], "]"}], 
    RowBox[{"1", "-", "x"}]], ",", 
   RowBox[{"Log", "[", 
    RowBox[{"1", "-", "x"}], "]"}]}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[296]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"3",RowBox[{"1", "-", "x"}]},
    "PolyLog"], "+", 
   RowBox[{"2", " ", 
    TemplateBox[{"3","x"},
     "PolyLog"]}], "+", 
   RowBox[{
    TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
     "PolyLog"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"log", "(", "x", ")"}], "-", 
      RowBox[{"log", "(", 
       RowBox[{"1", "-", "x"}], ")"}]}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"log", "(", 
       RowBox[{"1", "-", "x"}], ")"}], "+", 
      RowBox[{"log", "(", "x", ")"}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{
     SuperscriptBox["log", "3"], "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"log", "(", "x", ")"}], " ", 
    RowBox[{
     SuperscriptBox["log", "2"], "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["log", "2"], "(", "x", ")"}], " ", 
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "-", 
   TemplateBox[{"3"},
    "Zeta"]}], TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[296]="]
}, Open  ]]
}, Open  ]],

Cell["ConvoluteTable ", "ObjectName",
 CellTags->"ConvoluteTable"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ConvoluteTable"],

Cell["\<\
ConvoluteTable[f, g, x] yields the convolution of f and g. ConvoluteTable is \
called by Convolute.\
\>", "Text",
 CellTags->"ConvoluteTable"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Convolute", "]"}]], "Input",
 CellTags->"ConvoluteTable",
 CellLabel->"In[297]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Bracket", "\[Rule]", 
     RowBox[{"{", 
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], "}"}]}], ",", 
    RowBox[{"FinalSubstitutions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"PlusDistribution", "\[Rule]", "Identity"}], "}"}]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"ConvoluteTable",
 CellLabel->"Out[297]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["PlusDistribution",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PlusDistribution",
  ButtonNote->"PlusDistribution"],
 ", ",
 ButtonBox["Convolute",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Convolute",
  ButtonNote->"Convolute"],
 "."
}], "Text",
 CellTags->"ConvoluteTable"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ConvoluteTable"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ConvoluteTable", "[", 
  RowBox[{"1", ",", "1"}], "]"}]], "Input",
 CellTags->"ConvoluteTable",
 CellLabel->"In[298]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   RowBox[{"log", "(", "x", ")"}]}], TraditionalForm]], "Output",
 CellTags->"ConvoluteTable",
 CellLabel->"Out[298]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ConvoluteTable", "[", 
  RowBox[{"x", ",", "x"}], "]"}]], "Input",
 CellTags->"ConvoluteTable",
 CellLabel->"In[299]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "x"}], " ", 
   RowBox[{"log", "(", "x", ")"}]}], TraditionalForm]], "Output",
 CellTags->"ConvoluteTable",
 CellLabel->"Out[299]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ConvoluteTable", "[", 
  RowBox[{"1", ",", "x"}], "]"}]], "Input",
 CellTags->"ConvoluteTable",
 CellLabel->"In[300]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"1", "-", "x"}], TraditionalForm]], "Output",
 CellTags->"ConvoluteTable",
 CellLabel->"Out[300]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ConvoluteTable", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"Log", "[", 
     RowBox[{"1", "-", "x"}], "]"}], 
    RowBox[{"1", "-", "x"}]], ",", "1"}], "]"}]], "Input",
 CellTags->"Convolute",
 CellLabel->"In[301]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
     "PolyLog"]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{
     SuperscriptBox["log", "2"], "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"log", "(", "x", ")"}], " ", 
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Convolute",
 CellLabel->"Out[301]="]
}, Open  ]]
}, Open  ]],

Cell["CovariantFieldDerivative", "ObjectName",
 CellTags->"CovariantFieldDerivative"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"CovariantFieldDerivative"],

Cell["\<\
CovariantFieldDerivative[f[x],x,{li1,li2,...},opts] is a covariant derivative \
of f[x] with respect to space-time variables x and with Lorentz indices li1, \
li2,... CovariantFieldDerivative has only typesetting definitions by default. \
The user is must supply his/her own definition of the actual function.\
\>", "Text",
 CellTags->"CovariantFieldDerivative"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["CovariantD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CovariantD",
  ButtonNote->"CovariantD"],
 ", ",
 ButtonBox["ExpandPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExpandPartialD",
  ButtonNote->"ExpandPartialD"],
 ", ",
 ButtonBox["FieldDerivative",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FieldDerivative",
  ButtonNote->"FieldDerivative"],
 "."
}], "Text",
 CellTags->"CovariantFieldDerivative"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"CovariantFieldDerivative"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CovariantFieldDerivative", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"QuantumField", "[", 
     RowBox[{"A", ",", 
      RowBox[{"{", "\[Mu]", "}"}]}], "]"}], "[", "x", "]"}], ",", "x", ",", 
   RowBox[{"{", "\[Mu]", "}"}]}], "]"}]], "Input",
 CellTags->"CovariantFieldDerivative",
 CellLabel->"In[302]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox[
    TagBox[
     StyleBox["\<\"\[ScriptCapitalD]\"\>",
      FontSlant->"Italic"],
     StyleForm[#, FontSlant -> "Italic"]& ], 
    TagBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm,
     Editable->True]], "(", 
   TagBox[
    FormBox[
     RowBox[{
      SubscriptBox["A", "\[Mu]"], "(", "x", ")"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ")"}], TraditionalForm]], "Output",
 CellTags->"CovariantFieldDerivative",
 CellLabel->"Out[302]="]
}, Open  ]]
}, Open  ]],

Cell["CounterT", "ObjectName",
 CellTags->"CounterT"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"CounterT"],

Cell["\<\
CounterT is a factor used by GluonPropagator and QuarkPropagator when \
CounterTerms is set to All.\
\>", "Text",
 CellTags->"CounterT"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["CounterTerm",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CounterTerm",
  ButtonNote->"CounterTerm"],
 ", ",
 ButtonBox["GluonPropagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonPropagator",
  ButtonNote->"GluonPropagator"],
 ", ",
 ButtonBox["QuarkPropagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"QuarkPropagator",
  ButtonNote->"QuarkPropagator"],
 "."
}], "Text",
 CellTags->"CounterT"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"CounterT"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GluonPropagator", "[", 
  RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b", ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}], ",", 
   RowBox[{"CounterTerm", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellTags->"CounterT",
 CellLabel->"In[303]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"CounterT", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["C", "A"], " ", 
        SubsuperscriptBox["g", "s", "2"], " ", 
        SubscriptBox["S", "n"], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["a",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"10", " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]",
               TraditionalForm],
              TraditionalForm]]}], "3"], "-", 
          RowBox[{
           FractionBox["10", "3"], " ", 
           SuperscriptBox[
            FormBox["p",
             TraditionalForm], "2"], " ", 
           SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[Nu]"}]]}]}], ")"}]}], 
       TagBox["\[CurlyEpsilon]",
        TraditionalForm]], "+", 
      FractionBox[
       RowBox[{"\[ImaginaryI]", " ", 
        SubscriptBox["T", "f"], " ", 
        SubsuperscriptBox["g", "s", "2"], " ", 
        SubscriptBox["S", "n"], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["a",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["4", "3"], " ", 
           SuperscriptBox[
            FormBox["p",
             TraditionalForm], "2"], " ", 
           SuperscriptBox["g", 
            RowBox[{"\[Mu]", "\[Nu]"}]]}], "-", 
          FractionBox[
           RowBox[{"4", " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]",
               TraditionalForm],
              TraditionalForm]]}], "3"]}], ")"}]}], 
       TagBox["\[CurlyEpsilon]",
        TraditionalForm]]}], ")"}]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"\[Mu]", "\[Nu]"}]]}], 
    SuperscriptBox["p", "2"]]}], TraditionalForm]], "Output",
 CellTags->"CounterT",
 CellLabel->"Out[303]="]
}, Open  ]]
}, Open  ]],

Cell["CounterTerm", "ObjectName",
 CellTags->"CounterTerm"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"CounterTerm"],

Cell["\<\
CounterTerm[name] is a database of counter terms. CounterTerm is also an \
option for the Feynman rule functions QuarkGluonVertex, GluonPropagator, \
QuarkPropagator.\
\>", "Text",
 CellTags->"CounterTerm"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["CounterT",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CounterT",
  ButtonNote->"CounterT"],
 ", ",
 ButtonBox["QuarkGluonVertex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"QuarkGluonVertex",
  ButtonNote->"QuarkGluonVertex"],
 ", ",
 ButtonBox["GluonPropagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonPropagator",
  ButtonNote->"GluonPropagator"],
 ", ",
 ButtonBox["QuarkPropagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"QuarkPropagator",
  ButtonNote->"QuarkPropagator"],
 "."
}], "Text",
 CellTags->"CounterTerm"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"CounterTerm"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CounterTerm", "[", "Zm", "]"}]], "Input",
 CellTags->"CounterTerm",
 CellLabel->"In[304]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SubscriptBox["C", "F"], " ", 
     SubsuperscriptBox["g", "s", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"11", " ", 
             SubscriptBox["C", "A"]}], "2"], "+", 
           FractionBox[
            RowBox[{"9", " ", 
             SubscriptBox["C", "F"]}], "2"], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["N", "f"], " ", 
            SubscriptBox["T", "f"]}]}], ")"}]}], 
        SuperscriptBox[
         TagBox["\[CurlyEpsilon]",
          TraditionalForm], "2"]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{"97", " ", 
             SubscriptBox["C", "A"]}], "12"], "+", 
           FractionBox[
            RowBox[{"3", " ", 
             SubscriptBox["C", "F"]}], "4"], "-", 
           FractionBox[
            RowBox[{"5", " ", 
             SubscriptBox["N", "f"], " ", 
             SubscriptBox["T", "f"]}], "3"]}], ")"}]}], 
        TagBox["\[CurlyEpsilon]",
         TraditionalForm]]}], ")"}]}], 
    RowBox[{"256", " ", 
     SuperscriptBox["\[Pi]", "4"]}]], "+", 
   FractionBox[
    RowBox[{"3", " ", 
     SubscriptBox["C", "F"], " ", 
     SubsuperscriptBox["g", "s", "2"]}], 
    RowBox[{"8", " ", 
     SuperscriptBox["\[Pi]", "2"], " ", 
     TagBox["\[CurlyEpsilon]",
      TraditionalForm]}]], "+", "1"}], TraditionalForm]], "Output",
 CellTags->"CounterTerm",
 CellLabel->"Out[304]="]
}, Open  ]]
}, Open  ]],

Cell["CouplingConstant", "ObjectName",
 CellTags->"CouplingConstant"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"CouplingConstant"],

Cell["\<\
In general, CouplingConstant is an option for several Feynman rule functions \
and for CovariantD and FieldStrength.
In the convention of the subpackage PHI, CouplingConstant is also the head of \
coupling constants.  CouplingConstant takes three extra optional arguments, \
with head RenormalizationState, RenormalizationScheme and ExpansionState \
respectively.  E.g. CouplingConstant[QED[1]] is the unit charge, \
CouplingConstant[ChPT2[4],1] is the first of the coupling constants of the \
lagrangian ChPT2[4].  CouplingConstant[a_,b_,c___][i_] := \
CouplingConstant[a,b,RenormalizationState[i],c].\
\>", "Text",
 CellTags->"CouplingConstant"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["CovariantD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CovariantD",
  ButtonNote->"CovariantD"],
 ", ",
 ButtonBox["FieldStrength",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FieldStrength",
  ButtonNote->"FieldStrength"],
 "."
}], "Text",
 CellTags->"CouplingConstant"]
}, Open  ]],

Cell["CovariantD", "ObjectName",
 CellTags->"CovariantD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"CovariantD"],

Cell["\<\
CovariantD[mu] is a generic covariant derivative with Lorentz index mu. With \
the option-setting Explicit \[Rule] True, an explicit expression for a \
fermionic field is returned, depending on the setting on the other options.
CovariantD[x, mu] is a generic covariant derivative with respect to x^mu.
CovariantD[mu, a, b] is a covariant derivative for a bosonic field; acting on \
QuantumField[f,{},{a,b}], where f is some field name and a and b are two \
SU(N) indices. Again, with the option-setting Explicit \[Rule] True, an \
explicit expression is returned, depending on the setting on the other options.
CovariantD[OPEDelta, a, b] is a short form for  \
CovariantD[mu,a,b]*FourVector[OPEDelta, mu]. CovariantD[{OPEDelta, a, b}, \
{n}] yields the product of n operators, where n is an integer.  \
CovariantD[OPEDelta, a, b, {m, n}]  gives the expanded form of \
CovariantD[OPEDelta, a, b]^m up to order g^n for the gluon, where n is an \
integer and g the coupling constant  indicated by the setting of the option \
CouplingConstant. CovariantD[OPEDelta, {m, n}] gives the expanded form of  \
CovariantD[OPEDelta]^m up to order g^n of the fermionic field.\
\>", "Text",
 CellTags->"CovariantD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "CovariantD", "]"}]], "Input",
 CellTags->"CovariantD",
 CellLabel->"In[305]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}], ",", 
    RowBox[{"DummyIndex", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"Explicit", "\[Rule]", "False"}], ",", 
    RowBox[{"PartialD", "\[Rule]", "RightPartialD"}], ",", 
    RowBox[{"QuantumField", "\[Rule]", "A"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"CovariantD",
 CellLabel->"Out[305]="]
}, Open  ]],

Cell["\<\
 Possible settings of PartialD are: LeftPartialD, LeftRigthPartialD, \
RightPartialD. The default setting of QuantumField is GaugeField.\
\>", "Text",
 CellTags->"CovariantD"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["LeftPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LeftPartialD",
  ButtonNote->"LeftPartialD"],
 ", ",
 ButtonBox["LeftRightPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LeftRightPartialD",
  ButtonNote->"LeftRightPartialD"],
 ", ",
 ButtonBox["RightPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RightPartialD",
  ButtonNote->"RightPartialD"],
 "."
}], "Text",
 CellTags->"CovariantD"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"CovariantD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CovariantD", "[", "\[Mu]", "]"}]], "Input",
 CellTags->"CovariantD",
 CellLabel->"In[306]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["D", "\[Mu]"], TraditionalForm]], "Output",
 CellTags->"CovariantD",
 CellLabel->"Out[306]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CovariantD", "[", 
  RowBox[{"\[Mu]", ",", "a", ",", "b"}], "]"}]], "Input",
 CellTags->"CovariantD",
 CellLabel->"In[307]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox["D", "\[Mu]", 
   RowBox[{"a", "b"}]], TraditionalForm]], "Output",
 CellTags->"CovariantD",
 CellLabel->"Out[307]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CovariantD", "[", 
  RowBox[{"\[Mu]", ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"CovariantD",
 CellLabel->"In[308]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[RightArrow]"], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["g", "s"], " ", 
    RowBox[{
     SubscriptBox["T", 
      FormBox[
       FormBox[
        InterpretationBox[
         SubscriptBox["c", "1"],
         Subscripted[
          $CellContext`c[1]],
         Editable->False],
        TraditionalForm],
       TraditionalForm]], ".", 
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox[
        InterpretationBox[
         SubscriptBox["c", "1"],
         Subscripted[
          $CellContext`c[1]],
         Editable->False],
        TraditionalForm],
       TraditionalForm]]}]}]}], TraditionalForm]], "Output",
 CellTags->"CovariantD",
 CellLabel->"Out[308]="]
}, Open  ]],

Cell["\<\
The first argument of CovariantD is intepreted as type LorentzIndex, except \
for OPEDelta, which is type Momentum.\
\>", "Text",
 CellTags->"CovariantD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CovariantD", "[", "OPEDelta", "]"}]], "Input",
 CellTags->"CovariantD",
 CellLabel->"In[309]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["D", 
   FormBox["\[CapitalDelta]",
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"CovariantD",
 CellLabel->"Out[309]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CovariantD", "[", 
  RowBox[{"OPEDelta", ",", "a", ",", "b"}], "]"}]], "Input",
 CellTags->"CovariantD",
 CellLabel->"In[310]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox["D", 
   FormBox["\[CapitalDelta]",
    TraditionalForm], 
   RowBox[{"a", "b"}]], TraditionalForm]], "Output",
 CellTags->"CovariantD",
 CellLabel->"Out[310]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CovariantD", "[", 
  RowBox[{"OPEDelta", ",", "a", ",", "b", ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"CovariantD",
 CellLabel->"In[311]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Delta]", 
     RowBox[{"a", "b"}]], " ", 
    SubscriptBox[
     OverscriptBox["\[PartialD]", "\[RightArrow]"], 
     FormBox["\[CapitalDelta]",
      TraditionalForm]]}], "-", 
   RowBox[{
    SubscriptBox["g", "s"], " ", 
    SubsuperscriptBox[
     FormBox["A",
      TraditionalForm], 
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox[
       InterpretationBox[
        SubscriptBox["c", "2"],
        Subscripted[
         $CellContext`c[2]],
        Editable->False],
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{"a", "b", 
      FormBox[
       InterpretationBox[
        SubscriptBox["c", "2"],
        Subscripted[
         $CellContext`c[2]],
        Editable->False],
       TraditionalForm]}]]}]}], TraditionalForm]], "Output",
 CellTags->"CovariantD",
 CellLabel->"Out[311]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CovariantD", "[", 
  RowBox[{"OPEDelta", ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"CovariantD",
 CellLabel->"In[312]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[RightArrow]"], 
    FormBox["\[CapitalDelta]",
     TraditionalForm]], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["g", "s"], " ", 
    RowBox[{
     SubscriptBox["T", 
      FormBox[
       FormBox[
        InterpretationBox[
         SubscriptBox["c", "3"],
         Subscripted[
          $CellContext`c[3]],
         Editable->False],
        TraditionalForm],
       TraditionalForm]], ".", 
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox["\[CapitalDelta]",
       TraditionalForm], 
      FormBox[
       FormBox[
        InterpretationBox[
         SubscriptBox["c", "3"],
         Subscripted[
          $CellContext`c[3]],
         Editable->False],
        TraditionalForm],
       TraditionalForm]]}]}]}], TraditionalForm]], "Output",
 CellTags->"CovariantD",
 CellLabel->"Out[312]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CovariantD", "[", 
  RowBox[{"OPEDelta", ",", "a", ",", "b", ",", 
   RowBox[{"{", "2", "}"}]}], "]"}]], "Input",
 CellTags->"CovariantD",
 CellLabel->"In[313]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Delta]", 
       RowBox[{"a", "c22"}]], " ", 
      SubscriptBox[
       OverscriptBox["\[PartialD]", "\[RightArrow]"], 
       FormBox["\[CapitalDelta]",
        TraditionalForm]]}], "-", 
     RowBox[{
      SubscriptBox["g", "s"], " ", 
      SubsuperscriptBox[
       FormBox["A",
        TraditionalForm], 
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["e23",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubscriptBox["f", 
       RowBox[{"a", "c22", "e23"}]]}]}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Delta]", 
       RowBox[{"b", "c22"}]], " ", 
      SubscriptBox[
       OverscriptBox["\[PartialD]", "\[RightArrow]"], 
       FormBox["\[CapitalDelta]",
        TraditionalForm]]}], "-", 
     RowBox[{
      SubscriptBox["g", "s"], " ", 
      SubsuperscriptBox[
       FormBox["A",
        TraditionalForm], 
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["e24",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubscriptBox["f", 
       RowBox[{"c22", "b", "e24"}]]}]}], ")"}]}], TraditionalForm]], "Output",\

 CellTags->"CovariantD",
 CellLabel->"Out[313]="]
}, Open  ]],

Cell[TextData[{
 "This gives",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     RowBox[{"m", " ", "times", " ", 
      SubscriptBox[
       OverscriptBox["\[PartialD]", "\[RightArrow]"], "\[CapitalDelta]"]}], 
     ",", " "}]}], TraditionalForm]]],
 "the partial derivative ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[RightArrow]"], 
    RowBox[{"\[Mu]", " "}]], TraditionalForm]]],
 "contracted with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[CapitalDelta]", "\[Mu]"], "."}], TraditionalForm]]]
}], "Text",
 CellTags->"CovariantD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CovariantD", "[", 
  RowBox[{"OPEDelta", ",", "a", ",", "b", ",", 
   RowBox[{"{", 
    RowBox[{"OPEm", ",", "0"}], "}"}]}], "]"}]], "Input",
 CellTags->"CovariantD",
 CellLabel->"In[314]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[RightArrow]"], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]], ")"}], "m"]}], TraditionalForm]], "Output",
 CellTags->"CovariantD",
 CellLabel->"Out[314]="]
}, Open  ]],

Cell[TextData[{
 "The expansion up to first order in the coupling constant ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["g", "s"], " ", 
    RowBox[{
     RowBox[{"(", "thesumistheFeynCalcOPESum", ")"}], "."}]}], 
   TraditionalForm]]]
}], "Text",
 CellTags->"CovariantD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CovariantD", "[", 
  RowBox[{"OPEDelta", ",", "a", ",", "b", ",", 
   RowBox[{"{", 
    RowBox[{"OPEm", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"CovariantD",
 CellLabel->"In[315]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      SubscriptBox[
       OverscriptBox["\[PartialD]", "\[RightArrow]"], 
       FormBox["\[CapitalDelta]",
        TraditionalForm]], ")"}], "m"]}], "-", 
   RowBox[{
    SubscriptBox["g", "s"], " ", 
    FormBox[
     TagBox[
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "0"}], 
        RowBox[{
         RowBox[{"-", "1"}], "+", "m"}]], 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           SubscriptBox[
            OverscriptBox["\[PartialD]", "\[RightArrow]"], 
            FormBox["\[CapitalDelta]",
             TraditionalForm]], ")"}], "i"], ".", 
         SubsuperscriptBox[
          FormBox["A",
           TraditionalForm], 
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox[
           FormBox[
            InterpretationBox[
             SubscriptBox["c", "1"],
             Subscripted[
              $CellContext`c[1]],
             Editable->False],
            TraditionalForm],
           TraditionalForm]], ".", 
         SuperscriptBox[
          RowBox[{"(", 
           SubscriptBox[
            OverscriptBox["\[PartialD]", "\[RightArrow]"], 
            FormBox["\[CapitalDelta]",
             TraditionalForm]], ")"}], 
          RowBox[{
           RowBox[{"-", "1"}], "-", "i", "+", "m"}]]}], " ", 
        SubscriptBox["f", 
         RowBox[{
          FormBox[
           FormBox["a",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox[
            InterpretationBox[
             SubscriptBox["c", "1"],
             Subscripted[
              $CellContext`c[1]],
             Editable->False],
            TraditionalForm],
           TraditionalForm]}]]}]}],
      HoldForm],
     TraditionalForm]}]}], TraditionalForm]], "Output",
 CellTags->"CovariantD",
 CellLabel->"Out[315]="]
}, Open  ]],

Cell[TextData[{
 "The expansion up to second order in the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["g", "s"], "."}], TraditionalForm]]]
}], "Text",
 CellTags->"CovariantD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CovariantD", "[", 
  RowBox[{"OPEDelta", ",", "a", ",", "b", ",", 
   RowBox[{"{", 
    RowBox[{"OPEm", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellTags->"CovariantD",
 CellLabel->"In[316]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SubsuperscriptBox["g", "s", "2"], " ", 
     FormBox[
      TagBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"j", "=", "0"}], 
         RowBox[{
          RowBox[{"-", "2"}], "+", "m"}]], 
        RowBox[{"(", 
         FormBox[
          TagBox[
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"i", "=", "0"}], "j"], 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                SubscriptBox[
                 OverscriptBox["\[PartialD]", "\[RightArrow]"], 
                 FormBox["\[CapitalDelta]",
                  TraditionalForm]], ")"}], "i"], ".", 
              SubsuperscriptBox[
               FormBox["A",
                TraditionalForm], 
               FormBox["\[CapitalDelta]",
                TraditionalForm], 
               FormBox[
                FormBox[
                 InterpretationBox[
                  SubscriptBox["c", "1"],
                  Subscripted[
                   $CellContext`c[1]],
                  Editable->False],
                 TraditionalForm],
                TraditionalForm]], ".", 
              SuperscriptBox[
               RowBox[{"(", 
                SubscriptBox[
                 OverscriptBox["\[PartialD]", "\[RightArrow]"], 
                 FormBox["\[CapitalDelta]",
                  TraditionalForm]], ")"}], 
               RowBox[{
                RowBox[{"-", "i"}], "+", "j"}]], ".", 
              SubsuperscriptBox[
               FormBox["A",
                TraditionalForm], 
               FormBox["\[CapitalDelta]",
                TraditionalForm], 
               FormBox[
                FormBox[
                 InterpretationBox[
                  SubscriptBox["c", "2"],
                  Subscripted[
                   $CellContext`c[2]],
                  Editable->False],
                 TraditionalForm],
                TraditionalForm]], ".", 
              SuperscriptBox[
               RowBox[{"(", 
                SubscriptBox[
                 OverscriptBox["\[PartialD]", "\[RightArrow]"], 
                 FormBox["\[CapitalDelta]",
                  TraditionalForm]], ")"}], 
               RowBox[{
                RowBox[{"-", "2"}], "-", "j", "+", "m"}]]}], " ", 
             SubscriptBox["f", 
              RowBox[{
               FormBox[
                FormBox["a",
                 TraditionalForm],
                TraditionalForm], 
               FormBox[
                FormBox[
                 InterpretationBox[
                  SubscriptBox["c", "1"],
                  Subscripted[
                   $CellContext`c[1]],
                  Editable->False],
                 TraditionalForm],
                TraditionalForm], 
               FormBox[
                FormBox[
                 InterpretationBox[
                  SubscriptBox["e", "1"],
                  Subscripted[
                   $CellContext`e[1]],
                  Editable->False],
                 TraditionalForm],
                TraditionalForm]}]], " ", 
             SubscriptBox["f", 
              RowBox[{
               FormBox[
                FormBox["b",
                 TraditionalForm],
                TraditionalForm], 
               FormBox[
                FormBox[
                 InterpretationBox[
                  SubscriptBox["c", "2"],
                  Subscripted[
                   $CellContext`c[2]],
                  Editable->False],
                 TraditionalForm],
                TraditionalForm], 
               FormBox[
                FormBox[
                 InterpretationBox[
                  SubscriptBox["e", "1"],
                  Subscripted[
                   $CellContext`e[1]],
                  Editable->False],
                 TraditionalForm],
                TraditionalForm]}]]}]}],
           HoldForm],
          TraditionalForm], ")"}]}],
       HoldForm],
      TraditionalForm]}]}], "-", 
   RowBox[{
    SubscriptBox["g", "s"], " ", 
    FormBox[
     TagBox[
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "0"}], 
        RowBox[{
         RowBox[{"-", "1"}], "+", "m"}]], 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           SubscriptBox[
            OverscriptBox["\[PartialD]", "\[RightArrow]"], 
            FormBox["\[CapitalDelta]",
             TraditionalForm]], ")"}], "i"], ".", 
         SubsuperscriptBox[
          FormBox["A",
           TraditionalForm], 
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox[
           FormBox[
            InterpretationBox[
             SubscriptBox["c", "1"],
             Subscripted[
              $CellContext`c[1]],
             Editable->False],
            TraditionalForm],
           TraditionalForm]], ".", 
         SuperscriptBox[
          RowBox[{"(", 
           SubscriptBox[
            OverscriptBox["\[PartialD]", "\[RightArrow]"], 
            FormBox["\[CapitalDelta]",
             TraditionalForm]], ")"}], 
          RowBox[{
           RowBox[{"-", "1"}], "-", "i", "+", "m"}]]}], " ", 
        SubscriptBox["f", 
         RowBox[{
          FormBox[
           FormBox["a",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox[
            InterpretationBox[
             SubscriptBox["c", "1"],
             Subscripted[
              $CellContext`c[1]],
             Editable->False],
            TraditionalForm],
           TraditionalForm]}]]}]}],
      HoldForm],
     TraditionalForm]}], "+", 
   RowBox[{
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      SubscriptBox[
       OverscriptBox["\[PartialD]", "\[RightArrow]"], 
       FormBox["\[CapitalDelta]",
        TraditionalForm]], ")"}], "m"]}]}], TraditionalForm]], "Output",
 CellTags->"CovariantD",
 CellLabel->"Out[316]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 SuperscriptBox[
  RowBox[{"CovariantD", "[", 
   RowBox[{"OPEDelta", ",", "a", ",", "b"}], "]"}], "OPEm"]], "Input",
 CellTags->"CovariantD",
 CellLabel->"In[317]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   RowBox[{"(", 
    SubsuperscriptBox["D", 
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     RowBox[{"a", "b"}]], ")"}], "m"], TraditionalForm]], "Output",
 CellTags->"CovariantD",
 CellLabel->"Out[317]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CovariantD", "[", 
  RowBox[{"OPEDelta", ",", 
   RowBox[{"{", 
    RowBox[{"OPEm", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellTags->"CovariantD",
 CellLabel->"In[318]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SubsuperscriptBox["g", "s", "2"], " ", 
     FormBox[
      TagBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"j", "=", "0"}], 
         RowBox[{
          RowBox[{"-", "2"}], "+", "m"}]], 
        RowBox[{"(", 
         FormBox[
          TagBox[
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"i", "=", "0"}], "j"], 
            RowBox[{
             SubscriptBox["T", 
              FormBox[
               FormBox[
                InterpretationBox[
                 SubscriptBox["c", "1"],
                 Subscripted[
                  $CellContext`c[1]],
                 Editable->False],
                TraditionalForm],
               TraditionalForm]], ".", 
             SubscriptBox["T", 
              FormBox[
               FormBox[
                InterpretationBox[
                 SubscriptBox["c", "2"],
                 Subscripted[
                  $CellContext`c[2]],
                 Editable->False],
                TraditionalForm],
               TraditionalForm]], ".", 
             SuperscriptBox[
              RowBox[{"(", 
               SubscriptBox[
                OverscriptBox["\[PartialD]", "\[RightArrow]"], 
                FormBox["\[CapitalDelta]",
                 TraditionalForm]], ")"}], "i"], ".", 
             SubsuperscriptBox[
              FormBox["A",
               TraditionalForm], 
              FormBox["\[CapitalDelta]",
               TraditionalForm], 
              FormBox[
               FormBox[
                InterpretationBox[
                 SubscriptBox["c", "1"],
                 Subscripted[
                  $CellContext`c[1]],
                 Editable->False],
                TraditionalForm],
               TraditionalForm]], ".", 
             SuperscriptBox[
              RowBox[{"(", 
               SubscriptBox[
                OverscriptBox["\[PartialD]", "\[RightArrow]"], 
                FormBox["\[CapitalDelta]",
                 TraditionalForm]], ")"}], 
              RowBox[{
               RowBox[{"-", "i"}], "+", "j"}]], ".", 
             SubsuperscriptBox[
              FormBox["A",
               TraditionalForm], 
              FormBox["\[CapitalDelta]",
               TraditionalForm], 
              FormBox[
               FormBox[
                InterpretationBox[
                 SubscriptBox["c", "2"],
                 Subscripted[
                  $CellContext`c[2]],
                 Editable->False],
                TraditionalForm],
               TraditionalForm]], ".", 
             SuperscriptBox[
              RowBox[{"(", 
               SubscriptBox[
                OverscriptBox["\[PartialD]", "\[RightArrow]"], 
                FormBox["\[CapitalDelta]",
                 TraditionalForm]], ")"}], 
              RowBox[{
               RowBox[{"-", "2"}], "-", "j", "+", "m"}]]}]}],
           HoldForm],
          TraditionalForm], ")"}]}],
       HoldForm],
      TraditionalForm]}]}], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["g", "s"], " ", 
    FormBox[
     TagBox[
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "0"}], 
        RowBox[{
         RowBox[{"-", "1"}], "+", "m"}]], 
       RowBox[{
        SubscriptBox["T", 
         FormBox[
          FormBox[
           InterpretationBox[
            SubscriptBox["c", "1"],
            Subscripted[
             $CellContext`c[1]],
            Editable->False],
           TraditionalForm],
          TraditionalForm]], ".", 
        SuperscriptBox[
         RowBox[{"(", 
          SubscriptBox[
           OverscriptBox["\[PartialD]", "\[RightArrow]"], 
           FormBox["\[CapitalDelta]",
            TraditionalForm]], ")"}], "i"], ".", 
        SubsuperscriptBox[
         FormBox["A",
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox[
           InterpretationBox[
            SubscriptBox["c", "1"],
            Subscripted[
             $CellContext`c[1]],
            Editable->False],
           TraditionalForm],
          TraditionalForm]], ".", 
        SuperscriptBox[
         RowBox[{"(", 
          SubscriptBox[
           OverscriptBox["\[PartialD]", "\[RightArrow]"], 
           FormBox["\[CapitalDelta]",
            TraditionalForm]], ")"}], 
         RowBox[{
          RowBox[{"-", "1"}], "-", "i", "+", "m"}]]}]}],
      HoldForm],
     TraditionalForm]}], "+", 
   SuperscriptBox[
    RowBox[{"(", 
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[RightArrow]"], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]], ")"}], "m"]}], TraditionalForm]], "Output",
 CellTags->"CovariantD",
 CellLabel->"Out[318]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CovariantD", "[", 
   RowBox[{"OPEDelta", ",", 
    RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"CovariantD",
 CellLabel->"In[319]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", "Gstrong", " ", 
   RowBox[{
    RowBox[{"SUNT", "[", 
     RowBox[{"SUNIndex", "[", 
      InterpretationBox[
       SubscriptBox["c", "4"],
       Subscripted[
        $CellContext`c[4]],
       Editable->False], "]"}], "]"}], ".", 
    RowBox[{"QuantumField", "[", 
     RowBox[{"GaugeField", ",", 
      RowBox[{"Momentum", "[", "OPEDelta", "]"}], ",", 
      RowBox[{"SUNIndex", "[", 
       InterpretationBox[
        SubscriptBox["c", "4"],
        Subscripted[
         $CellContext`c[4]],
        Editable->False], "]"}]}], "]"}]}]}], "+", 
  RowBox[{"RightPartialD", "[", 
   RowBox[{"Momentum", "[", "OPEDelta", "]"}], "]"}]}]], "Output",
 CellTags->"CovariantD",
 CellLabel->"Out[319]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CovariantD", "[", 
   RowBox[{"\[Mu]", ",", "a", ",", "b", ",", 
    RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"CovariantD",
 CellLabel->"In[320]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RightPartialD", "[", 
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], " ", 
   RowBox[{"SUNDelta", "[", 
    RowBox[{"a", ",", "b"}], "]"}]}], "-", 
  RowBox[{"Gstrong", " ", 
   RowBox[{"QuantumField", "[", 
    RowBox[{"GaugeField", ",", 
     RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
     RowBox[{"SUNIndex", "[", 
      InterpretationBox[
       SubscriptBox["c", "5"],
       Subscripted[
        $CellContext`c[5]],
       Editable->False], "]"}]}], "]"}], " ", 
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", 
     InterpretationBox[
      SubscriptBox["c", "5"],
      Subscripted[
       $CellContext`c[5]],
      Editable->False]}], "]"}]}]}]], "Output",
 CellTags->"CovariantD",
 CellLabel->"Out[320]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["CrossProduct", "ObjectName",
 CellTags->"CrossProduct"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"CrossProduct"],

Cell["\<\
CrossProduct[a, b] denotes the three-dimensional cross-product of the \
three-vectors a and b.\
\>", "Text",
 CellTags->"CrossProduct"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DotProduct",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DotProduct",
  ButtonNote->"DotProduct"],
 ", ",
 ButtonBox["ThreeVector",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ThreeVector",
  ButtonNote->"ThreeVector"],
 "."
}], "Text",
 CellTags->"CrossProduct"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"CrossProduct"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CrossProduct", "[", 
  RowBox[{
   RowBox[{"ThreeVector", "[", "a", "]"}], ",", 
   RowBox[{"CrossProduct", "[", 
    RowBox[{
     RowBox[{"ThreeVector", "[", "b", "]"}], ",", 
     RowBox[{"ThreeVector", "[", "c", "]"}]}], "]"}]}], "]"}]], "Input",
 CellTags->"CrossProduct",
 CellLabel->"In[321]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    OverscriptBox["b", "\[RightVector]"], " ", 
    RowBox[{
     FormBox[
      OverscriptBox["a", "\[RightVector]"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      OverscriptBox["c", "\[RightVector]"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    OverscriptBox["c", "\[RightVector]"], " ", 
    RowBox[{
     FormBox[
      OverscriptBox["a", "\[RightVector]"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      OverscriptBox["b", "\[RightVector]"],
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 CellTags->"CrossProduct",
 CellLabel->"Out[321]="]
}, Open  ]]
}, Open  ]],

Cell["C0", "ObjectName",
 CellTags->"C0"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"C0"],

Cell[TextData[{
 "C0[p10, p12, p20, m1^2, m2^2, m3^2] is the scalar Passarino-Veltman ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["C", "0"], TraditionalForm]]],
 "function. The convention for the arguments is that if the denominator of \
the integrand has the form ([q^2-m1^2] [(q+p1)^2-m2^2] [(q+p2)^2-m3^2]), the \
first three arguments of C0 are the scalar products p10 = p1^2, p12 = \
(p1-p2).(p1-p2), p20 = p2^2."
}], "Text",
 CellTags->"C0"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["B0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B0",
  ButtonNote->"B0"],
 ", ",
 ButtonBox["D0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"D0",
  ButtonNote->"D0"],
 ", ",
 ButtonBox["PaVe",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVe",
  ButtonNote->"PaVe"],
 ", ",
 ButtonBox["PaVeOrder",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVeOrder",
  ButtonNote->"PaVeOrder"],
 "."
}], "Text",
 CellTags->"C0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"C0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"C0", "[", 
  RowBox[{"a", ",", "b", ",", "c", ",", " ", "m12", ",", "m22", ",", "m32"}], 
  "]"}]], "Input",
 CellTags->"C0",
 CellLabel->"In[322]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    SubscriptBox["\<\"C\"\>", "\<\"0\"\>"],
    TraditionalForm], "(", "a", ",", "b", ",", "c", ",", "m12", ",", "m22", 
   ",", "m32", ")"}], TraditionalForm]], "Output",
 CellTags->"C0",
 CellLabel->"Out[322]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"C0", "[", 
   RowBox[{"b", ",", "a", ",", "c", ",", "m32", ",", "m22", ",", "m12"}], 
   "]"}], "//", "PaVeOrder"}]], "Input",
 CellTags->"C0",
 CellLabel->"In[323]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    SubscriptBox["\<\"C\"\>", "\<\"0\"\>"],
    TraditionalForm], "(", "a", ",", "b", ",", "c", ",", "m12", ",", "m22", 
   ",", "m32", ")"}], TraditionalForm]], "Output",
 CellTags->"C0",
 CellLabel->"Out[323]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PaVeOrder", "[", 
  RowBox[{
   RowBox[{"C0", "[", 
    RowBox[{"b", ",", "a", ",", "c", ",", "m32", ",", "m22", ",", "m12"}], 
    "]"}], ",", 
   RowBox[{"PaVeOrderList", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"c", ",", "a"}], "}"}]}]}], "]"}]], "Input",
 CellTags->"C0",
 CellLabel->"In[324]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    SubscriptBox["\<\"C\"\>", "\<\"0\"\>"],
    TraditionalForm], "(", "b", ",", "c", ",", "a", ",", "m22", ",", "m32", 
   ",", "m12", ")"}], TraditionalForm]], "Output",
 CellTags->"C0",
 CellLabel->"Out[324]="]
}, Open  ]]
}, Open  ]],

Cell["DataType", "ObjectName",
 CellTags->"DataType"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DataType"],

Cell["\<\
DataType[exp, type] = True defines the object exp to have data-type type. \
DataType[exp1, exp2, ..., type] defines the objects exp1, exp2, ...to have \
data-type type. The default setting is DataType[__, _] := False. To assign a \
certain data-type, do, e.g., DataType[x, PositiveInteger] = True.\
\>", "Text",
 CellTags->"DataType"],

Cell[TextData[{
 "Currently used DataTypes: ",
 ButtonBox["NonCommutative",
  BaseStyle->"AddOnsLink",
  ButtonData:>"NonCommutative",
  ButtonNote->"NonCommutative"],
 ", ",
 ButtonBox["PositiveInteger",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PositiveInteger",
  ButtonNote->"PositiveInteger"],
 ", ",
 ButtonBox["NegativeInteger",
  BaseStyle->"AddOnsLink",
  ButtonData:>"NegativeInteger",
  ButtonNote->"NegativeInteger"],
 ", ",
 ButtonBox["PositiveNumber",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PositiveNumber",
  ButtonNote->"PositiveNumber"],
 ", ",
 ButtonBox["FreeIndex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FreeIndex",
  ButtonNote->"FreeIndex"],
 ", ",
 ButtonBox["GrassmannParity",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GrassmannParity",
  ButtonNote->"GrassmannParity"]
}], "Text",
 CellTags->"DataType"],

Cell[TextData[{
 "PHI adds the DataTypes: ",
 ButtonBox["UMatrix",
  BaseStyle->"AddOnsLink",
  ButtonData:>"UMatrix",
  ButtonNote->"UMatrix"],
 ", ",
 ButtonBox["UScalar",
  BaseStyle->"AddOnsLink",
  ButtonData:>"UScalar",
  ButtonNote->"UScalar"],
 "."
}], "Text",
 CellTags->"DataType"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DeclareNonCommutative",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DeclareNonCommutative",
  ButtonNote->"DeclareNonCommutative"],
 "."
}], "Text",
 CellTags->"DataType"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DataType"],

Cell["NonCommutative is just a data-type.", "Text",
 CellTags->"DataType"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DataType", "[", 
    RowBox[{"f", ",", "g", ",", " ", "NonCommutative"}], "]"}], " ", "=", " ",
    "True"}], ";"}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[325]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{
   RowBox[{"f", ".", "g"}], "-", 
   RowBox[{"g", ".", 
    RowBox[{"(", 
     RowBox[{"2", "a"}], ")"}], ".", "f"}]}]}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[326]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"f", ".", "g"}], "-", 
   RowBox[{"g", ".", 
    RowBox[{"(", 
     RowBox[{"2", " ", "a"}], ")"}], ".", "f"}]}], TraditionalForm]], "Output",\

 CellTags->"DataType",
 CellLabel->"Out[326]="]
}, Open  ]],

Cell["\<\
Since \"f \"and \"g\" have DataType NonCommutative the function DotSimplify \
extracts only \"a\" out of the noncommutative product.\
\>", "Text",
 CellTags->"DataType"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotSimplify", "[", "t", "]"}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[327]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"f", ".", "g"}], "-", 
   RowBox[{"2", " ", "a", " ", 
    RowBox[{"g", ".", "f"}]}]}], TraditionalForm]], "Output",
 CellTags->"DataType",
 CellLabel->"Out[327]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DataType", "[", 
    RowBox[{"m", ",", "odd"}], "]"}], "=", 
   RowBox[{
    RowBox[{"DataType", "[", 
     RowBox[{"a", ",", "even"}], "]"}], "=", "True"}]}], ";"}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[328]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ptest1", "[", "x_", "]"}], ":=", 
   RowBox[{"x", "/.", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n_"], "/;", 
      RowBox[{"DataType", "[", 
       RowBox[{"n", ",", "odd"}], "]"}]}], "\[RuleDelayed]", 
     RowBox[{"-", "1"}]}]}]}], ";"}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[329]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ptest2", "[", "x_", "]"}], ":=", 
   RowBox[{"x", "/.", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n_"], "/;", 
      RowBox[{"DataType", "[", 
       RowBox[{"n", ",", "even"}], "]"}]}], "\[RuleDelayed]", "1"}]}]}], 
  ";"}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[330]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", "m"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", "a"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", "z"}]}]}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[331]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "a"], "+", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "m"], "+", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "z"]}], TraditionalForm]], "Output",
 CellTags->"DataType",
 CellLabel->"Out[331]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptest1", "[", "t", "]"}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[332]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "a"], "+", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "z"], "-", "1"}], TraditionalForm]], "Output",\

 CellTags->"DataType",
 CellLabel->"Out[332]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptest2", "[", "%", "]"}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[333]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"-", "1"}], ")"}], "z"], TraditionalForm]], "Output",
 CellTags->"DataType",
 CellLabel->"Out[333]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"ptest1", ",", "ptest2", ",", "t", ",", "a", ",", "m"}], "]"}], 
  ";"}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[334]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DataType", "[", 
    RowBox[{"m", ",", "ganzeZahl"}], "]"}], "=", "True"}], ";"}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[335]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "x_", "]"}], ":=", 
   RowBox[{"x", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "^", "p_"}], "/;", 
       RowBox[{"DataType", "[", 
        RowBox[{"p", ",", "ganzeZahl"}], "]"}]}], "\[RuleDelayed]", "1"}], 
     "}"}]}]}], ";"}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[336]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"test", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", "m"}], "+", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "^", "n"}], " ", "x"}]}]}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[337]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "m"], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], " ", "x"}]}], 
  TraditionalForm]], "Output",
 CellTags->"DataType",
 CellLabel->"Out[337]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", "test", "]"}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[338]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "n"], " ", "x"}], "+", "1"}], 
  TraditionalForm]], "Output",
 CellTags->"DataType",
 CellLabel->"Out[338]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"f", ",", "test"}], "]"}], ";"}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[339]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DataType", "[", 
    RowBox[{"f", ",", "g", ",", " ", "NonCommutative"}], "]"}], " ", "=", " ",
    "False"}], ";"}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[340]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DataType", "[", 
    RowBox[{"m", ",", "odd"}], "]"}], "=", 
   RowBox[{
    RowBox[{"DataType", "[", 
     RowBox[{"a", ",", "even"}], "]"}], "=", "False"}]}], ";"}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[341]:="],

Cell["\<\
Certain FeynCalc objects have DataType PositiveInteger set to True.\
\>", "Text",
 CellTags->"DataType"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DataType", "[", 
  RowBox[{"OPEm", ",", "PositiveInteger"}], "]"}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[342]:="],

Cell[BoxData[
 FormBox["True", TraditionalForm]], "Output",
 CellTags->"DataType",
 CellLabel->"Out[342]="]
}, Open  ]],

Cell["PowerSimplify uses the DataType information.", "Text",
 CellTags->"DataType"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PowerSimplify", "[", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"-", "1"}], ")"}], "^", 
   RowBox[{"(", 
    RowBox[{"2", "OPEm"}], ")"}]}], "]"}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[343]:="],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellTags->"DataType",
 CellLabel->"Out[343]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PowerSimplify", "[", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"-", " ", 
     RowBox[{"SO", "[", "q", "]"}]}], ")"}], "^", "OPEm"}], "]"}]], "Input",
 CellTags->"DataType",
 CellLabel->"In[344]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "m"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[CapitalDelta]\"\>",
       TraditionalForm], 
      FormBox["\<\"\[CenterDot]\"\>",
       TraditionalForm], 
      FormBox["q",
       TraditionalForm]}], ")"}], "m"]}], TraditionalForm]], "Output",
 CellTags->"DataType",
 CellLabel->"Out[344]="]
}, Open  ]]
}, Open  ]],

Cell["DB0", "ObjectName",
 CellTags->"DB0"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DB0"],

Cell["\<\
DB0[p2, m1^2, m2^2] is the derivative of the two-point function B0[p2, m1^2, \
m2^2] with respect to p2.\
\>", "Text",
 CellTags->"DB0"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["B0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B0",
  ButtonNote->"B0"],
 "."
}], "Text",
 CellTags->"DB0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DB0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"B0", "[", 
    RowBox[{
     SubscriptBox["p", "2"], ",", 
     SuperscriptBox[
      SubscriptBox["m", "1"], "2"], ",", 
     SuperscriptBox[
      SubscriptBox["m", "2"], "2"]}], "]"}], ",", 
   SubscriptBox["p", "2"]}], "]"}]], "Input",
 CellTags->"DB0",
 CellLabel->"In[345]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"DB0", "(", 
   RowBox[{
    SubscriptBox["p", "2"], ",", 
    SubsuperscriptBox["m", "1", "2"], ",", 
    SubsuperscriptBox["m", "2", "2"]}], ")"}], TraditionalForm]], "Output",
 CellTags->"DB0",
 CellLabel->"Out[345]="]
}, Open  ]]
}, Open  ]],

Cell["DB1", "ObjectName",
 CellTags->"DB1"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DB1"],

Cell["\<\
DB1[p2,m1^2,m2^2] is the derivative of B1[p2,m1^2,m2^2] with respect to p2.\
\>", "Text",
 CellTags->"DB1"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["B1",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B1",
  ButtonNote->"B1"],
 "."
}], "Text",
 CellTags->"DB1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DB1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"B1", "[", 
    RowBox[{
     SubscriptBox["p", "2"], ",", 
     SuperscriptBox[
      SubscriptBox["m", "1"], "2"], ",", 
     SuperscriptBox[
      SubscriptBox["m", "2"], "2"]}], "]"}], ",", 
   SubscriptBox["p", "2"]}], "]"}]], "Input",
 CellTags->"DB1",
 CellLabel->"In[346]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["m", "2", "2"], "-", 
        SubsuperscriptBox["m", "1", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubscriptBox["B", "0"], "(", 
         SubscriptBox["p", "2"], ",", 
         SubsuperscriptBox["m", "1", "2"], ",", 
         SubsuperscriptBox["m", "2", "2"], ")"}], "-", 
        RowBox[{
         SubscriptBox["B", "0"], "(", "0", ",", 
         SubsuperscriptBox["m", "1", "2"], ",", 
         SubsuperscriptBox["m", "2", "2"], ")"}]}], ")"}]}], 
     RowBox[{"2", " ", 
      SubsuperscriptBox["p", "2", "2"]}]]}], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["m", "2", "2"], "-", 
       SubsuperscriptBox["m", "1", "2"]}], ")"}], " ", 
     RowBox[{"DB0", "(", 
      RowBox[{
       SubscriptBox["p", "2"], ",", 
       SubsuperscriptBox["m", "1", "2"], ",", 
       SubsuperscriptBox["m", "2", "2"]}], ")"}]}], 
    RowBox[{"2", " ", 
     SubscriptBox["p", "2"]}]], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"DB0", "(", 
     RowBox[{
      SubscriptBox["p", "2"], ",", 
      SubsuperscriptBox["m", "1", "2"], ",", 
      SubsuperscriptBox["m", "2", "2"]}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"DB1",
 CellLabel->"Out[346]="]
}, Open  ]]
}, Open  ]],

Cell["DeclareNonCommutative", "ObjectName",
 CellTags->"DeclareNonCommutative"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DeclareNonCommutative"],

Cell["\<\
DeclareNonCommutative[a, b, ...] declares a,b, ... to be non-commutative, \
i.e., DataType[a,b, ..., NonCommutative] is set to True.\
\>", "Text",
 CellTags->"DeclareNonCommutative"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DataType",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DataType",
  ButtonNote->"DataType"],
 ", ",
 ButtonBox["UnDeclareNonCommutative",
  BaseStyle->"AddOnsLink",
  ButtonData:>"UnDeclareNonCommutative",
  ButtonNote->"UnDeclareNonCommutative"],
 "."
}], "Text",
 CellTags->"DeclareNonCommutative"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DeclareNonCommutative"],

Cell[BoxData[
 RowBox[{"DeclareNonCommutative", "[", "x", "]"}]], "Input",
 CellTags->"DeclareNonCommutative",
 CellLabel->"In[347]:="],

Cell["\<\
As a side effect of DeclareNonCommutative x is declared to be of data type \
NonCommutative.\
\>", "Text",
 CellTags->"DeclareNonCommutative"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DataType", "[", 
  RowBox[{"x", ",", "NonCommutative"}], "]"}]], "Input",
 CellTags->"DeclareNonCommutative",
 CellLabel->"In[348]:="],

Cell[BoxData[
 FormBox["True", TraditionalForm]], "Output",
 CellTags->"DeclareNonCommutative",
 CellLabel->"Out[348]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"DeclareNonCommutative", "[", 
  RowBox[{"y", ",", "z"}], "]"}]], "Input",
 CellTags->"DeclareNonCommutative",
 CellLabel->"In[349]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DataType", "[", 
  RowBox[{"a", ",", "x", ",", "y", ",", "z", ",", "NonCommutative"}], 
  "]"}]], "Input",
 CellTags->"DeclareNonCommutative",
 CellLabel->"In[350]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"DeclareNonCommutative",
 CellLabel->"Out[350]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"UnDeclareNonCommutative", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Input",
 CellTags->"DeclareNonCommutative",
 CellLabel->"In[351]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DataType", "[", 
  RowBox[{"a", ",", "x", ",", "y", ",", "z", ",", "NonCommutative"}], 
  "]"}]], "Input",
 CellTags->"DeclareNonCommutative",
 CellLabel->"In[352]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"DeclareNonCommutative",
 CellLabel->"Out[352]="]
}, Open  ]]
}, Open  ]],

Cell["DeltaFunction", "ObjectName",
 CellTags->"DeltaFunction"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DeltaFunction"],

Cell[TextData[{
 " DeltaFunction[x] is the Dirac delta-function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Delta]", "(", "x", ")"}], TraditionalForm]]],
 ".\n*** After version 4 of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", there is a built-in function, DiracDelta, with comparable properties. \
***"
}], "Text",
 CellTags->"DeltaFunction"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Convolute",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Convolute",
  ButtonNote->"Convolute"],
 ", ",
 ButtonBox["DeltaFunctionPrime",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DeltaFunctionPrime",
  ButtonNote->"DeltaFunctionPrime"],
 ", ",
 ButtonBox["Integrate2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Integrate2",
  ButtonNote->"Integrate2"],
 ", ",
 ButtonBox["SimplifyDeltaFunction",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SimplifyDeltaFunction",
  ButtonNote->"SimplifyDeltaFunction"],
 "."
}], "Text",
 CellTags->"DeltaFunction"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DeltaFunction"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DeltaFunction", "[", 
  RowBox[{"1", "-", "x"}], "]"}]], "Input",
 CellTags->"DeltaFunction",
 CellLabel->"In[353]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[Delta]", "(", 
   FormBox[
    RowBox[{"1", "-", "x"}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"DeltaFunction",
 CellLabel->"Out[353]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"DeltaFunction", "[", 
     RowBox[{"1", "-", "x"}], "]"}], " ", 
    RowBox[{"f", "[", "x", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"DeltaFunction",
 CellLabel->"In[354]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"f", "(", "1", ")"}], TraditionalForm]], "Output",
 CellTags->"DeltaFunction",
 CellLabel->"Out[354]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"DeltaFunction", "[", "x", "]"}], " ", 
    RowBox[{"f", "[", "x", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"DeltaFunction",
 CellLabel->"In[355]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"f", "(", "0", ")"}], TraditionalForm]], "Output",
 CellTags->"DeltaFunction",
 CellLabel->"Out[355]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"DeltaFunction", "[", 
     RowBox[{"1", "-", "x"}], "]"}], " ", 
    RowBox[{"f", "[", "x", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"DeltaFunction",
 CellLabel->"In[356]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"f", "(", "1", ")"}], TraditionalForm]], "Output",
 CellTags->"DeltaFunction",
 CellLabel->"Out[356]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Convolute", "[", 
  RowBox[{
   RowBox[{"DeltaFunction", "[", 
    RowBox[{"1", "-", "x"}], "]"}], ",", "x"}], "]"}]], "Input",
 CellTags->"DeltaFunction",
 CellLabel->"In[357]:="],

Cell[BoxData[
 FormBox["x", TraditionalForm]], "Output",
 CellTags->"DeltaFunction",
 CellLabel->"Out[357]="]
}, Open  ]]
}, Open  ]],

Cell["DeltaFunctionDoublePrime", "ObjectName",
 CellTags->"DeltaFunctionDoublePrime"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DeltaFunctionDoublePrime"],

Cell[TextData[{
 " DeltaFunctionDoublePrime[1-x] is the second derivative of the Dirac \
delta-function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Delta]", "(", "x", ")"}], TraditionalForm]]],
 "."
}], "Text",
 CellTags->"DeltaFunctionDoublePrime"],

Cell[TextData[{
 "See also: ",
 ButtonBox["DeltaFunctionPrime",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DeltaFunctionPrime",
  ButtonNote->"DeltaFunctionPrime"],
 "."
}], "Text",
 CellTags->"DeltaFunctionDoublePrime"]
}, Open  ]],

Cell["DeltaFunctionPrime", "ObjectName",
 CellTags->"DeltaFunctionPrime"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DeltaFunctionPrime"],

Cell[TextData[{
 " DeltaFunctionPrime[1-x] is the derivative of the Dirac delta-function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Delta]", "(", "x", ")"}], TraditionalForm]]],
 "."
}], "Text",
 CellTags->"DeltaFunctionPrime"],

Cell[TextData[{
 "See also: ",
 ButtonBox["Convolute",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Convolute",
  ButtonNote->"Convolute"],
 ", ",
 ButtonBox["DeltaFunction",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DeltaFunction",
  ButtonNote->"DeltaFunction"],
 ", ",
 ButtonBox["Integrate2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Integrate2",
  ButtonNote->"Integrate2"],
 ", ",
 ButtonBox["SimplifyDeltaFunction",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SimplifyDeltaFunction",
  ButtonNote->"SimplifyDeltaFunction"],
 "."
}], "Text",
 CellTags->"DeltaFunctionPrime"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DeltaFunctionPrime"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DeltaFunctionPrime", "[", 
  RowBox[{"1", "-", "x"}], "]"}]], "Input",
 CellTags->"DeltaFunctionPrime",
 CellLabel->"In[358]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Delta]", "\[Prime]"], "(", 
   FormBox[
    RowBox[{"1", "-", "x"}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"DeltaFunctionPrime",
 CellLabel->"Out[358]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"DeltaFunctionPrime", "[", 
     RowBox[{"1", "-", "x"}], "]"}], " ", 
    RowBox[{"f", "[", "x", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"DeltaFunctionPrime",
 CellLabel->"In[359]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["f", "\[Prime]",
    MultilineFunction->None], "(", "1", ")"}], TraditionalForm]], "Output",
 CellTags->"DeltaFunctionPrime",
 CellLabel->"Out[359]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"DeltaFunctionPrime", "[", 
     RowBox[{"1", "-", "x"}], "]"}], " ", 
    SuperscriptBox["x", "2"]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"DeltaFunctionPrime",
 CellLabel->"In[360]:="],

Cell[BoxData[
 FormBox["2", TraditionalForm]], "Output",
 CellTags->"DeltaFunctionPrime",
 CellLabel->"Out[360]="]
}, Open  ]]
}, Open  ]],

Cell["DenominatorOrder", "ObjectName",
 CellTags->"DenominatorOrder"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DenominatorOrder"],

Cell["\<\
DenominatorOrder is an option for OneLoop, if set to True the \
PropagatorDenominator will be ordered in a standard way.\
\>", "Text",
 CellTags->"DenominatorOrder"],

Cell[TextData[{
 "See also: ",
 ButtonBox["OneLoop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoop",
  ButtonNote->"OneLoop"],
 ", ",
 ButtonBox["PropagatorDenominator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PropagatorDenominator",
  ButtonNote->"PropagatorDenominator"],
 "."
}], "Text",
 CellTags->"DenominatorOrder"]
}, Open  ]],

Cell["Dimension", "ObjectName",
 CellTags->"Dimension"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Dimension"],

Cell["\<\
Dimension is an option of several functions and denotes the number of \
space-time dimensions. Possible settings are: 4, n, d, D, ... ,the variable \
does not matter, but it should have Head Symbol.\
\>", "Text",
 CellTags->"Dimension"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "MetricTensor", "]"}]], "Input",
 CellTags->"Dimension",
 CellLabel->"In[361]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Dimension", "\[Rule]", "4"}], ",", 
    RowBox[{"FeynCalcInternal", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Dimension",
 CellLabel->"Out[361]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MetricTensor", "[", 
   RowBox[{"m", ",", "n", ",", 
    RowBox[{"Dimension", "\[Rule]", "d"}]}], "]"}], 
  RowBox[{"DiracMatrix", "[", 
   RowBox[{"\[Alpha]", ",", 
    RowBox[{"Dimension", "\[Rule]", "d"}]}], "]"}]}]], "Input",
 CellTags->"Dimension",
 CellLabel->"In[362]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Alpha]",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"m", "n"}]]}], TraditionalForm]], "Output",
 CellTags->"Dimension",
 CellLabel->"Out[362]="]
}, Open  ]],

Cell["\<\
The dimension of the indices is not shown by default but can be inspected \
easily.\
\>", "Text",
 CellTags->"Dimension"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MetricTensor", "[", 
    RowBox[{"m", ",", "n", ",", 
     RowBox[{"Dimension", "\[Rule]", "d"}]}], "]"}], 
   RowBox[{"DiracMatrix", "[", 
    RowBox[{"\[Alpha]", ",", 
     RowBox[{"Dimension", "\[Rule]", "d"}]}], "]"}]}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"Dimension",
 CellLabel->"In[363]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracGamma", "[", 
   RowBox[{
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Alpha]", ",", "d"}], "]"}], ",", "d"}], "]"}], " ", 
  RowBox[{"MetricTensor", "[", 
   RowBox[{"m", ",", "n", ",", 
    RowBox[{"Dimension", "\[Rule]", "d"}]}], "]"}]}]], "Output",
 CellTags->"Dimension",
 CellLabel->"Out[363]//StandardForm="]
}, Open  ]],

Cell["\<\
Setting the global variable $LorentzIndices to True will display the \
dimension (if different from 4) as a subscript.\
\>", "Text",
 CellTags->"Dimension"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$LorentzIndices", "=", "True"}], ";"}]], "Input",
 CellTags->"Dimension",
 CellLabel->"In[364]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MetricTensor", "[", 
   RowBox[{"\[Alpha]", ",", "\[Beta]", ",", 
    RowBox[{"Dimension", "\[Rule]", "n"}]}], "]"}], 
  RowBox[{"DiracMatrix", "[", 
   RowBox[{"\[Alpha]", ",", 
    RowBox[{"Dimension", "\[Rule]", "n"}]}], "]"}]}]], "Input",
 CellTags->"Dimension",
 CellLabel->"In[365]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", 
    FormBox[
     SubscriptBox[
      FormBox["\[Alpha]",
       TraditionalForm], 
      FormBox["n",
       TraditionalForm]],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{
     FormBox[
      SubscriptBox[
       FormBox["\[Alpha]",
        TraditionalForm], 
       FormBox["n",
        TraditionalForm]],
      TraditionalForm], 
     FormBox[
      SubscriptBox[
       FormBox["\[Beta]",
        TraditionalForm], 
       FormBox["n",
        TraditionalForm]],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"Dimension",
 CellLabel->"Out[365]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"Dimension",
 CellLabel->"In[366]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracGamma", "[", 
   RowBox[{
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Alpha]", ",", "n"}], "]"}], ",", "n"}], "]"}], " ", 
  RowBox[{"MetricTensor", "[", 
   RowBox[{"\[Alpha]", ",", "\[Beta]", ",", 
    RowBox[{"Dimension", "\[Rule]", "n"}]}], "]"}]}]], "Output",
 CellTags->"Dimension",
 CellLabel->"Out[366]//StandardForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"$LorentzIndices", "=", "False"}], ";"}]], "Input",
 CellTags->"Dimension",
 CellLabel->"In[367]:="]
}, Open  ]],

Cell["DimensionalReduction", "ObjectName",
 CellTags->"DimensionalReduction"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DimensionalReduction"],

Cell["\<\
DimensionalReduction is an option for TID and OneLoopSimplify.\
\>", "Text",
 CellTags->"DimensionalReduction"],

Cell[TextData[{
 "See also: ",
 ButtonBox["TID",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TID",
  ButtonNote->"TID"],
 ", ",
 ButtonBox["OneLoopSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoopSimplify",
  ButtonNote->"OneLoopSimplify"],
 "."
}], "Text",
 CellTags->"DimensionalReduction"]
}, Open  ]],

Cell["DiracBasis", "ObjectName",
 CellTags->"DiracBasis"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracBasis"],

Cell["\<\
DiracBasis[any] is a head which is wrapped around Dirac structures (and the \
1) as a result of the function DiracReduce. Eventually you want to substitute \
DiracBasis by Identity (or set: DiracBasis[1] = S; \
DiracBasis[DiracMatrix[mu]] = P; etc.).\
\>", "Text",
 CellTags->"DiracBasis"],

Cell[TextData[{
 "See also: ",
 ButtonBox["DiracReduce",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracReduce",
  ButtonNote->"DiracReduce"],
 "."
}], "Text",
 CellTags->"DiracBasis"]
}, Open  ]],

Cell["DiracCanonical", "ObjectName",
 CellTags->"DiracCanonical"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracCanonical"],

Cell["\<\
DiracCanonical is an option for DiracSimplify. If set to True DiracSimplify \
uses the function DiracOrder internally.\
\>", "Text",
 CellTags->"DiracCanonical"],

Cell[TextData[{
 "See also: ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 "."
}], "Text",
 CellTags->"DiracCanonical"]
}, Open  ]],

Cell["DiracEquation", "ObjectName",
 CellTags->"DiracEquation"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracEquation"],

Cell["\<\
DiracEquation[exp] applies the Dirac equation without expanding exp. If that \
is needed, use DiracSimplify.\
\>", "Text",
 CellTags->"DiracEquation"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 "."
}], "Text",
 CellTags->"DiracEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DiracEquation"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Spinor", "[", 
   RowBox[{
    RowBox[{"Momentum", "[", "p", "]"}], ",", "m", ",", "1"}], "]"}], ".", 
  RowBox[{"DiracGamma", "[", 
   RowBox[{"Momentum", "[", "p", "]"}], "]"}]}]], "Input",
 CellTags->"DiracEquation",
 CellLabel->"In[368]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[CurlyPhi]", "(", 
    FormBox["p",
     TraditionalForm], ",", "m", ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["p",
      TraditionalForm]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"DiracEquation",
 CellLabel->"Out[368]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracEquation", "[", "%", "]"}]], "Input",
 CellTags->"DiracEquation",
 CellLabel->"In[369]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"m", " ", 
   RowBox[{"\[CurlyPhi]", "(", 
    FormBox["p",
     TraditionalForm], ",", "m", ")"}]}], TraditionalForm]], "Output",
 CellTags->"DiracEquation",
 CellLabel->"Out[369]="]
}, Open  ]]
}, Open  ]],

Cell["DiracGamma", "ObjectName",
 CellTags->"DiracGamma"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracGamma"],

Cell[TextData[{
 "DiracGamma[x, dim] is the head of all Dirac matrices and slashes (in the \
internal representation). Use DiracMatrix (or GA, GAD) and DiracSlash (or GS, \
GSD) for manual (short) input. DiracGamma[x, 4] simplifies to DiracGamma[x]. \
DiracGamma[5] is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
 ". DiracGamma[6] is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["\[Gamma]", "5"]}], ")"}], "/", "2."}], 
   TraditionalForm]]],
 " DiracGamma[7] is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SuperscriptBox["\[Gamma]", "5"]}], ")"}], "/", "2."}], TraditionalForm]]]
}], "Text",
 CellTags->"DiracGamma"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracGammaExpand",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGammaExpand",
  ButtonNote->"DiracGammaExpand"],
 ", ",
 ButtonBox["DiracMatrix",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracMatrix",
  ButtonNote->"DiracMatrix"],
 ", ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 ", ",
 ButtonBox["DiracSlash",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSlash",
  ButtonNote->"DiracSlash"],
 ", ",
 ButtonBox["DiracTrick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrick",
  ButtonNote->"DiracTrick"],
 "."
}], "Text",
 CellTags->"DiracGamma"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DiracGamma"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracGamma", "[", "5", "]"}]], "Input",
 CellTags->"DiracGamma",
 CellLabel->"In[370]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Gamma]", "5"], TraditionalForm]], "Output",
 CellTags->"DiracGamma",
 CellLabel->"Out[370]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracGamma", "[", 
  RowBox[{"LorentzIndex", "[", "\[Alpha]", "]"}], "]"}]], "Input",
 CellTags->"DiracGamma",
 CellLabel->"In[371]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Gamma]", 
   FormBox[
    FormBox["\[Alpha]",
     TraditionalForm],
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"DiracGamma",
 CellLabel->"Out[371]="]
}, Open  ]],

Cell[TextData[{
 "A Dirac-slash, i.e., ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Gamma]", "\[Mu]"], 
    SubscriptBox["q", "\[Mu]"]}], TraditionalForm]]],
 ", is displayed as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Gamma]", "\[CenterDot]", "q"}], TraditionalForm]]],
 "."
}], "Text",
 CellTags->"DiracGamma"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracGamma", "[", 
   RowBox[{"Momentum", "[", "q", "]"}], "]"}], " "}]], "Input",
 CellTags->"DiracGamma",
 CellLabel->"In[372]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["\<\"\[Gamma]\"\>",
    TraditionalForm], "\[CenterDot]", 
   FormBox["q",
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"DiracGamma",
 CellLabel->"Out[372]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracGamma", "[", 
   RowBox[{"Momentum", "[", "q", "]"}], "]"}], " ", ".", " ", 
  RowBox[{"DiracGamma", "[", 
   RowBox[{"Momentum", "[", 
    RowBox[{"p", "-", "q"}], "]"}], "]"}]}]], "Input",
 CellTags->"DiracGamma",
 CellLabel->"In[373]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", "(", 
     FormBox[
      RowBox[{"p", "-", "q"}],
      TraditionalForm], ")"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"DiracGamma",
 CellLabel->"Out[373]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracGamma", "[", 
   RowBox[{
    RowBox[{"Momentum", "[", 
     RowBox[{"q", ",", "D"}], "]"}], ",", "D"}], "]"}], " "}]], "Input",
 CellTags->"DiracGamma",
 CellLabel->"In[374]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["\<\"\[Gamma]\"\>",
    TraditionalForm], "\[CenterDot]", 
   FormBox["q",
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"DiracGamma",
 CellLabel->"Out[374]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1", "=", 
  RowBox[{
   RowBox[{"GS", "[", 
    RowBox[{"p", "-", "q"}], "]"}], ".", 
   RowBox[{"GS", "[", "p", "]"}]}]}]], "Input",
 CellTags->"DiracGamma",
 CellLabel->"In[375]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "(", 
     FormBox[
      RowBox[{"p", "-", "q"}],
      TraditionalForm], ")"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"DiracGamma",
 CellLabel->"Out[375]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2", "=", 
  RowBox[{"DiracGammaExpand", "[", "a1", "]"}]}]], "Input",
 CellTags->"DiracGamma",
 CellLabel->"In[376]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["p",
       TraditionalForm]}], "-", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["p",
      TraditionalForm]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"DiracGamma",
 CellLabel->"Out[376]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3", "=", 
  RowBox[{
   RowBox[{"GAD", "[", "\[Mu]", "]"}], ".", 
   RowBox[{"GSD", "[", 
    RowBox[{"p", "-", "q"}], "]"}], ".", 
   RowBox[{"GSD", "[", "q", "]"}], ".", 
   RowBox[{"GAD", "[", "\[Mu]", "]"}]}]}]], "Input",
 CellTags->"DiracGamma",
 CellLabel->"In[377]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "(", 
     FormBox[
      RowBox[{"p", "-", "q"}],
      TraditionalForm], ")"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "q"}], ")"}], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
 CellTags->"DiracGamma",
 CellLabel->"Out[377]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4", "=", 
  RowBox[{"DiracTrick", "[", "a3", "]"}]}]], "Input",
 CellTags->"DiracGamma",
 CellLabel->"In[378]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "(", 
     FormBox[
      RowBox[{"p", "-", "q"}],
      TraditionalForm], ")"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "q"}], ")"}], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
 CellTags->"DiracGamma",
 CellLabel->"Out[378]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a5", "=", 
  RowBox[{"DiracSimplify", "[", "a4", "]"}]}]], "Input",
 CellTags->"DiracGamma",
 CellLabel->"In[379]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"D", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}], ")"}], ".", 
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}], ")"}]}]}], "-", 
   RowBox[{"D", " ", 
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], "2"]}], "-", 
   RowBox[{"4", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}], ")"}], ".", 
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}], ")"}]}]}], "+", 
   RowBox[{"4", " ", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 CellTags->"DiracGamma",
 CellLabel->"Out[379]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"a1", ",", "a2", ",", "a3", ",", "a4", ",", "a5"}], "]"}]], "Input",\

 CellTags->"DiracGamma",
 CellLabel->"In[380]:="]
}, Open  ]],

Cell["DiracGammaCombine", "ObjectName",
 CellTags->"DiracGammaCombine"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracGammaCombine"],

Cell["\<\
DiracGammaCombine[exp] is (nearly) the inverse operation to DiracGammaExpand.\
\
\>", "Text",
 CellTags->"DiracGammaCombine"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracGamma",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGamma",
  ButtonNote->"DiracGamma"],
 ", ",
 ButtonBox["DiracGammaExpand",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGammaExpand",
  ButtonNote->"DiracGammaExpand"],
 ", ",
 ButtonBox["DiracMatrix",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracMatrix",
  ButtonNote->"DiracMatrix"],
 ", ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 ", ",
 ButtonBox["DiracSlash",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSlash",
  ButtonNote->"DiracSlash"],
 ", ",
 ButtonBox["DiracTrick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrick",
  ButtonNote->"DiracTrick"],
 "."
}], "Text",
 CellTags->"DiracGammaCombine"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DiracGammaCombine"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracGammaCombine", "[", 
  RowBox[{
   RowBox[{"GS", "[", "p", "]"}], " ", "+", " ", 
   RowBox[{"GS", "[", "q", "]"}]}], "]"}]], "Input",
 CellTags->"DiracGammaCombine",
 CellLabel->"In[381]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["\<\"\[Gamma]\"\>",
    TraditionalForm], "\[CenterDot]", "(", 
   FormBox[
    RowBox[{"p", "+", "q"}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"DiracGammaCombine",
 CellLabel->"Out[381]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
 CellTags->"DiracGammaCombine",
 CellLabel->"In[382]:="],

Cell[BoxData[
 RowBox[{"DiracGamma", "[", 
  RowBox[{"Momentum", "[", 
   RowBox[{"p", "+", "q"}], "]"}], "]"}]], "Output",
 CellTags->"DiracGammaCombine",
 CellLabel->"Out[382]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracGammaCombine", "[", 
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{"GS", "[", "p", "]"}]}], " ", "-", " ", 
   RowBox[{"2", " ", 
    RowBox[{"GS", "[", "q", "]"}]}]}], "]"}]], "Input",
 CellTags->"DiracGammaCombine",
 CellLabel->"In[383]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["\<\"\[Gamma]\"\>",
    TraditionalForm], "\[CenterDot]", "(", 
   FormBox[
    RowBox[{
     RowBox[{"2", " ", "p"}], "-", 
     RowBox[{"2", " ", "q"}]}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"DiracGammaCombine",
 CellLabel->"Out[383]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
 CellTags->"DiracGammaCombine",
 CellLabel->"In[384]:="],

Cell[BoxData[
 RowBox[{"DiracGamma", "[", 
  RowBox[{"Momentum", "[", 
   RowBox[{
    RowBox[{"2", " ", "p"}], "-", 
    RowBox[{"2", " ", "q"}]}], "]"}], "]"}]], "Output",
 CellTags->"DiracGammaCombine",
 CellLabel->"Out[384]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracGammaExpand", "[", "%%", "]"}]], "Input",
 CellTags->"DiracGammaCombine",
 CellLabel->"In[385]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["p",
      TraditionalForm]}]}], "-", 
   RowBox[{"2", " ", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 CellTags->"DiracGammaCombine",
 CellLabel->"Out[385]="]
}, Open  ]]
}, Open  ]],

Cell["DiracGammaExpand", "ObjectName",
 CellTags->"DiracGammaExpand"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracGammaExpand"],

Cell["\<\
DiracGammaExpand[exp] expands all DiracGamma[Momentum[a+b+..]] in exp into \
(DiracGamma[Momentum[a]] + DiracGamma[Momentum[b]] + ...).\
\>", "Text",
 CellTags->"DiracGammaExpand"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracGamma",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGamma",
  ButtonNote->"DiracGamma"],
 ", ",
 ButtonBox["DiracGammaCombine",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGammaCombine",
  ButtonNote->"DiracGammaCombine"],
 ", ",
 ButtonBox["DiracMatrix",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracMatrix",
  ButtonNote->"DiracMatrix"],
 ", ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 ", ",
 ButtonBox["DiracSlash",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSlash",
  ButtonNote->"DiracSlash"],
 ", ",
 ButtonBox["DiracTrick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrick",
  ButtonNote->"DiracTrick"],
 "."
}], "Text",
 CellTags->"DiracGammaExpand"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DiracGammaExpand"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{
   RowBox[{"DiracGamma", "[", 
    RowBox[{"Momentum", "[", "q", "]"}], "]"}], " ", ".", " ", 
   RowBox[{"DiracGamma", "[", 
    RowBox[{"Momentum", "[", 
     RowBox[{"p", "-", "q"}], "]"}], "]"}]}]}]], "Input",
 CellTags->"DiracGammaExpand",
 CellLabel->"In[386]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", "(", 
     FormBox[
      RowBox[{"p", "-", "q"}],
      TraditionalForm], ")"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"DiracGammaExpand",
 CellLabel->"Out[386]="]
}, Open  ]],

Cell["\<\
Momentum is the head of p-q, i.e., it is treated as one four-momentum.\
\>", "Text",
 CellTags->"DiracGammaExpand"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", "t", "]"}]], "Input",
 CellTags->"DiracGammaExpand",
 CellLabel->"In[387]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracGamma", "[", 
   RowBox[{"Momentum", "[", "q", "]"}], "]"}], ".", 
  RowBox[{"DiracGamma", "[", 
   RowBox[{"Momentum", "[", 
    RowBox[{"p", "-", "q"}], "]"}], "]"}]}]], "Output",
 CellTags->"DiracGammaExpand",
 CellLabel->"Out[387]//StandardForm="]
}, Open  ]],

Cell["With DiracGammaExpand the Momentum[p-q] gets expanded.", "Text",
 CellTags->"DiracGammaExpand"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracGammaExpand", "[", "t", "]"}]], "Input",
 CellTags->"DiracGammaExpand",
 CellLabel->"In[388]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["p",
       TraditionalForm]}], "-", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"DiracGammaExpand",
 CellLabel->"Out[388]="]
}, Open  ]],

Cell["The inverse operation is DiracGammaCombine.", "Text",
 CellTags->"DiracGammaExpand"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"DiracGammaCombine", "[", 
   RowBox[{"DiracGammaExpand", "[", "t", "]"}], "]"}], "]"}]], "Input",
 CellTags->"DiracGammaExpand",
 CellLabel->"In[389]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracGamma", "[", 
   RowBox[{"Momentum", "[", "q", "]"}], "]"}], ".", 
  RowBox[{"DiracGamma", "[", 
   RowBox[{"Momentum", "[", 
    RowBox[{"p", "-", "q"}], "]"}], "]"}]}]], "Output",
 CellTags->"DiracGammaExpand",
 CellLabel->"Out[389]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"DiracGammaExpand", "[", "t", "]"}], "]"}]], "Input",
 CellTags->"DiracGammaExpand",
 CellLabel->"In[390]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracGamma", "[", 
   RowBox[{"Momentum", "[", "q", "]"}], "]"}], ".", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"DiracGamma", "[", 
     RowBox[{"Momentum", "[", "p", "]"}], "]"}], "-", 
    RowBox[{"DiracGamma", "[", 
     RowBox[{"Momentum", "[", "q", "]"}], "]"}]}], ")"}]}]], "Output",
 CellTags->"DiracGammaExpand",
 CellLabel->"Out[390]//StandardForm="]
}, Open  ]],

Cell["In order to do non-commutative expansion use DiracSimplify.", "Text",
 CellTags->"DiracGammaExpand"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSimplify", "[", "t", "]"}]], "Input",
 CellTags->"DiracGammaExpand",
 CellLabel->"In[391]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["p",
       TraditionalForm]}], ")"}]}], "-", 
   SuperscriptBox[
    FormBox["q",
     TraditionalForm], "2"]}], TraditionalForm]], "Output",
 CellTags->"DiracGammaExpand",
 CellLabel->"Out[391]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "t", "]"}]], "Input",
 CellTags->"DiracGammaExpand",
 CellLabel->"In[392]:="]
}, Open  ]],

Cell["DiracGammaT", "ObjectName",
 CellTags->"DiracGammaT"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracGammaT"],

Cell["\<\
DiracGammaT[x] denotes the transpose of DiracGamma[x]. \
Transpose[DiracGammaT[x]] gives DiracGamma[x]. Note that x must have Head \
LorentzIndex or Momentum.\
\>", "Text",
 CellTags->"DiracGammaT"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracGamma",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGamma",
  ButtonNote->"DiracGamma"],
 "."
}], "Text",
 CellTags->"DiracGammaT"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DiracGammaT"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracGammaT", "[", 
  RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}]], "Input",
 CellTags->"DiracGammaT",
 CellLabel->"In[393]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox["\[Gamma]", 
   FormBox[
    FormBox["\[Mu]",
     TraditionalForm],
    TraditionalForm], "T"], TraditionalForm]], "Output",
 CellTags->"DiracGammaT",
 CellLabel->"Out[393]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Transpose", "[", "%", "]"}]], "Input",
 CellTags->"DiracGammaT",
 CellLabel->"In[394]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Gamma]", 
   FormBox[
    FormBox["\[Mu]",
     TraditionalForm],
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"DiracGammaT",
 CellLabel->"Out[394]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GS", "[", "p", "]"}], "//", "FCI"}], "//", "Transpose"}]], "Input",\

 CellTags->"DiracGammaT",
 CellLabel->"In[395]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   RowBox[{"(", "\[Gamma]", "\[CenterDot]", 
    FormBox["p",
     TraditionalForm], ")"}], "T"], TraditionalForm]], "Output",
 CellTags->"DiracGammaT",
 CellLabel->"Out[395]="]
}, Open  ]]
}, Open  ]],

Cell["DiracMatrix", "ObjectName",
 CellTags->"DiracMatrix"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracMatrix"],

Cell[TextData[{
 "DiracMatrix[",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "] denotes a Dirac gamma matrix with Lorentz index ",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 ". DiracMatrix[",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Mu]", ",", "\[Nu]", ","}], " "}], TraditionalForm]]],
 "...] is a product of ",
 Cell[BoxData[
  FormBox["\[Gamma]", TraditionalForm]]],
 " matrices with Lorentz indices ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Mu]", ",", " ", "\[Nu]", ",", " ", "..."}], TraditionalForm]]],
 " DiracMatrix[5] is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
 ". DiracMatrix[6] is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "/", "2"}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     RowBox[{"+", " ", 
      SuperscriptBox["\[Gamma]", "5"]}], "/", "2"}]}], TraditionalForm]]],
 ". DiracMatrix[7] is",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"1", "/", "2"}]}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     RowBox[{"-", " ", 
      SuperscriptBox["\[Gamma]", "5"]}], "/", "2"}]}], TraditionalForm]]],
 "."
}], "Text",
 CellTags->"DiracMatrix"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracGammaExpand",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGammaExpand",
  ButtonNote->"DiracGammaExpand"],
 ", ",
 ButtonBox["DiracGamma",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGamma",
  ButtonNote->"DiracGamma"],
 ", ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 ", ",
 ButtonBox["DiracSlash",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSlash",
  ButtonNote->"DiracSlash"],
 ", ",
 ButtonBox["DiracTrick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrick",
  ButtonNote->"DiracTrick"],
 ", ",
 ButtonBox["GA",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GA",
  ButtonNote->"GA"],
 ", ",
 ButtonBox["GAD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GAD",
  ButtonNote->"GAD"],
 ", ",
 ButtonBox["GS",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GS",
  ButtonNote->"GS"],
 ", ",
 ButtonBox["GSD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GSD",
  ButtonNote->"GSD"],
 "."
}], "Text",
 CellTags->"DiracMatrix"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DiracMatrix"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracMatrix", "[", "\[Mu]", "]"}]], "Input",
 CellTags->"DiracMatrix",
 CellLabel->"In[396]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Gamma]", 
   FormBox[
    FormBox["\[Mu]",
     TraditionalForm],
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"DiracMatrix",
 CellLabel->"Out[396]="]
}, Open  ]],

Cell[TextData[{
 "This is how to enter the non-commutative product of two ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]]}], TraditionalForm]]],
 ". The ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Dot \".\" is used as non-commutative multiplication operator."
}], "Text",
 CellTags->"DiracMatrix"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracMatrix", "[", "\[Mu]", "]"}], ".", 
  RowBox[{"DiracMatrix", "[", "\[Nu]", "]"}]}]], "Input",
 CellTags->"DiracMatrix",
 CellLabel->"In[397]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"DiracMatrix",
 CellLabel->"Out[397]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracMatrix", "[", "\[Alpha]", "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"DiracMatrix",
 CellLabel->"In[398]:="],

Cell[BoxData[
 RowBox[{"DiracGamma", "[", 
  RowBox[{"LorentzIndex", "[", "\[Alpha]", "]"}], "]"}]], "Output",
 CellTags->"DiracMatrix",
 CellLabel->"Out[398]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracMatrix", "[", "\[Mu]", "]"}], "//", "FCE"}]], "Input",
 CellTags->"DiracMatrix",
 CellLabel->"In[399]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Gamma]", "\[Mu]"], TraditionalForm]], "Output",
 CellTags->"DiracMatrix",
 CellLabel->"Out[399]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"DiracMatrix",
 CellLabel->"In[400]:="],

Cell[BoxData[
 RowBox[{"GA", "[", "\[Mu]", "]"}]], "Output",
 CellTags->"DiracMatrix",
 CellLabel->"Out[400]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GAD", "[", "\[Mu]", "]"}]], "Input",
 CellTags->"DiracMatrix",
 CellLabel->"In[401]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Gamma]", "\[Mu]"], TraditionalForm]], "Output",
 CellTags->"DiracMatrix",
 CellLabel->"Out[401]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"%", "//", "FCI"}], "//", "StandardForm"}]], "Input",
 CellTags->"DiracMatrix",
 CellLabel->"In[402]:="],

Cell[BoxData[
 RowBox[{"DiracGamma", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", "D"}], "]"}]], "Output",
 CellTags->"DiracMatrix",
 CellLabel->"Out[402]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GA", "[", 
  RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]"}], "]"}]], "Input",
 CellTags->"DiracMatrix",
 CellLabel->"In[403]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Rho]"]}], TraditionalForm]], "Output",
 CellTags->"DiracMatrix",
 CellLabel->"Out[403]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GA", "[", 
   RowBox[{"a", " ", ".", " ", "b"}], "]"}], "//", "FCI"}]], "Input",
 CellTags->"DiracMatrix",
 CellLabel->"In[404]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["b",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"DiracMatrix",
 CellLabel->"Out[404]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"DiracMatrix",
 CellLabel->"In[405]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracGamma", "[", 
   RowBox[{"LorentzIndex", "[", "a", "]"}], "]"}], ".", 
  RowBox[{"DiracGamma", "[", 
   RowBox[{"LorentzIndex", "[", "b", "]"}], "]"}]}]], "Output",
 CellTags->"DiracMatrix",
 CellLabel->"Out[405]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["DiracOrder", "ObjectName",
 CellTags->"DiracOrder"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracOrder"],

Cell["\<\
DiracOrder[expr] orders the Dirac matrices in expr alphabetically. \
DiracOrder[expr,orderlist] orders the Dirac matrices in expr according to \
orderlist.\
\>", "Text",
 CellTags->"DiracOrder"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 ", ",
 ButtonBox["DiracTrick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrick",
  ButtonNote->"DiracTrick"],
 "."
}], "Text",
 CellTags->"DiracOrder"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DiracOrder"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", " ", "=", " ", 
  RowBox[{"GA", "[", 
   RowBox[{"\[Beta]", ",", "\[Alpha]"}], "]"}]}]], "Input",
 CellTags->"DiracOrder",
 CellLabel->"In[406]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Beta]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Alpha]"]}], TraditionalForm]], "Output",
 CellTags->"DiracOrder",
 CellLabel->"Out[406]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracOrder", "[", "t1", "]"}]], "Input",
 CellTags->"DiracOrder",
 CellLabel->"In[407]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Alpha]", "\[Beta]"}]]}], "-", 
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Alpha]",
       TraditionalForm],
      TraditionalForm]], ".", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Beta]",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"DiracOrder",
 CellLabel->"Out[407]="]
}, Open  ]],

Cell["This is a string of Dirac matrices in D dimensions. ", "Text",
 CellTags->"DiracOrder"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", "=", 
  RowBox[{"GAD", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Mu]"}], "]"}]}]], "Input",
 CellTags->"DiracOrder",
 CellLabel->"In[408]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
 CellTags->"DiracOrder",
 CellLabel->"Out[408]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracOrder", "[", "t1", "]"}]], "Input",
 CellTags->"DiracOrder",
 CellLabel->"In[409]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Alpha]", "\[Beta]"}]]}], "-", 
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Alpha]",
       TraditionalForm],
      TraditionalForm]], ".", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Beta]",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"DiracOrder",
 CellLabel->"Out[409]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t3", "=", 
  RowBox[{"GA", "[", 
   RowBox[{"5", ",", "\[Mu]", ",", "\[Nu]"}], "]"}]}]], "Input",
 CellTags->"DiracOrder",
 CellLabel->"In[410]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "5"], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"]}], TraditionalForm]], "Output",
 CellTags->"DiracOrder",
 CellLabel->"Out[410]="]
}, Open  ]],

Cell[TextData[{
 "By default ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Gamma]", 
    RowBox[{"5", " "}]], TraditionalForm]]],
 "is moved to the right."
}], "Text",
 CellTags->"DiracOrder"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracOrder", "[", "t3", "]"}]], "Input",
 CellTags->"DiracOrder",
 CellLabel->"In[411]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", "5"]}], TraditionalForm]], "Output",
 CellTags->"DiracOrder",
 CellLabel->"Out[411]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t4", "=", 
  RowBox[{"GA", "[", 
   RowBox[{"6", ",", "\[Mu]", ",", "7"}], "]"}]}]], "Input",
 CellTags->"DiracOrder",
 CellLabel->"In[412]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "6"], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "7"]}], TraditionalForm]], "Output",
 CellTags->"DiracOrder",
 CellLabel->"Out[412]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracOrder", "[", "t4", "]"}]], "Input",
 CellTags->"DiracOrder",
 CellLabel->"In[413]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", "7"]}], TraditionalForm]], "Output",
 CellTags->"DiracOrder",
 CellLabel->"Out[413]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t5", "=", 
  RowBox[{"GA", "[", 
   RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Delta]"}], "]"}]}]], "Input",
 CellTags->"DiracOrder",
 CellLabel->"In[414]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Alpha]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Beta]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Delta]"]}], TraditionalForm]], "Output",
 CellTags->"DiracOrder",
 CellLabel->"Out[414]="]
}, Open  ]],

Cell[TextData[{
 "This orders the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Gamma]", "\[Alpha]"], 
    SuperscriptBox["\[Gamma]", "\[Beta]"], 
    SuperscriptBox["\[Gamma]", "\[Delta]"]}], TraditionalForm]]],
 " in reverse order."
}], "Text",
 CellTags->"DiracOrder"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracOrder", "[", 
  RowBox[{"t5", ",", 
   RowBox[{"{", 
    RowBox[{"\[Delta]", ",", "\[Beta]", ",", "\[Alpha]"}], "}"}]}], 
  "]"}]], "Input",
 CellTags->"DiracOrder",
 CellLabel->"In[415]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Delta]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Beta]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Alpha]",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Delta]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Alpha]", "\[Beta]"}]]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Beta]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Alpha]", "\[Delta]"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Alpha]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Beta]", "\[Delta]"}]]}]}], TraditionalForm]], "Output",
 CellTags->"DiracOrder",
 CellLabel->"Out[415]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracOrder", "[", "%", "]"}]], "Input",
 CellTags->"DiracOrder",
 CellLabel->"In[416]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Alpha]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Beta]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Delta]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"DiracOrder",
 CellLabel->"Out[416]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5"}], "]"}], 
  ";"}]], "Input",
 CellTags->"DiracOrder",
 CellLabel->"In[417]:="]
}, Open  ]],

Cell["DiracReduce", "ObjectName",
 CellTags->"DiracReduce"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracReduce"],

Cell["\<\
DiracReduce[exp] reduces all four-dimensional Dirac matrices in exp to the \
standard basis (S,P,V,A,T) using the Chisholm identity (see Chisholm). In the \
result the basic Dirac structures are wrapped with a head DiracBasis. I.e., S \
corresponds to DiracBasis[1], P : DiracBasis[DiracMatrix[5]], V: \
DiracBasis[DiracMatrix[mu]], A: DiracBasis[DiracMatrix[mu, 5]], T: \
DiracBasis[DiracSigma[DiracMatrix[mu, nu]]]. By default DiracBasis is \
substituted to Identity. Notice that the result of DiracReduce is given in \
the FeynCalcExternal-way, i.e.,evtl. you may have to use FeynCalcInternal on \
the result.\
\>", "Text",
 CellTags->"DiracReduce"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "DiracReduce", "]"}]], "Input",
 CellTags->"DiracReduce",
 CellLabel->"In[418]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Factoring", "\[Rule]", "False"}], ",", 
    RowBox[{"FinalSubstitutions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"DiracBasis", "\[Rule]", "Identity"}], "}"}]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"DiracReduce",
 CellLabel->"Out[418]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 "."
}], "Text",
 CellTags->"DiracReduce"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DiracReduce"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", " ", "=", " ", 
  RowBox[{"GA", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}]], "Input",
 CellTags->"DiracReduce",
 CellLabel->"In[419]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"]}], TraditionalForm]], "Output",
 CellTags->"DiracReduce",
 CellLabel->"Out[419]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracReduce", "[", "t1", "]"}]], "Input",
 CellTags->"DiracReduce",
 CellLabel->"In[420]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["g", 
    RowBox[{"\[Mu]", "\[Nu]"}]], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["\[Sigma]", 
     RowBox[{"\[Mu]", "\[Nu]"}]]}]}], TraditionalForm]], "Output",
 CellTags->"DiracReduce",
 CellLabel->"Out[420]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", "=", 
  RowBox[{"DiracMatrix", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]"}], "]"}]}]], "Input",
 CellTags->"DiracReduce",
 CellLabel->"In[421]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], 
   SuperscriptBox["\[Gamma]", "\[Nu]"], 
   SuperscriptBox["\[Gamma]", "\[Rho]"]}], TraditionalForm]], "Output",
 CellTags->"DiracReduce",
 CellLabel->"Out[421]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracReduce", "[", "t2", "]"}]], "Input",
 CellTags->"DiracReduce",
 CellLabel->"In[422]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      RowBox[{"$MU", "\[InvisibleApplication]", 
       RowBox[{"(", "1", ")"}]}]], ".", 
     SuperscriptBox["\[Gamma]", "5"]}], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{"\[Mu]", "\[Nu]", "\[Rho]", 
      FormBox[
       RowBox[{"$MU", "\[InvisibleApplication]", 
        RowBox[{"(", "1", ")"}]}],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    SuperscriptBox["\[Gamma]", "\[Rho]"], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]]}], "-", 
   RowBox[{
    SuperscriptBox["\[Gamma]", "\[Nu]"], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Rho]"}]]}], "+", 
   RowBox[{
    SuperscriptBox["\[Gamma]", "\[Mu]"], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Rho]"}]]}]}], TraditionalForm]], "Output",
 CellTags->"DiracReduce",
 CellLabel->"Out[422]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t3", "=", 
  RowBox[{"DiracMatrix", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
   "]"}]}]], "Input",
 CellTags->"DiracReduce",
 CellLabel->"In[423]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], 
   SuperscriptBox["\[Gamma]", "\[Nu]"], 
   SuperscriptBox["\[Gamma]", "\[Rho]"], 
   SuperscriptBox["\[Gamma]", "\[Sigma]"]}], TraditionalForm]], "Output",
 CellTags->"DiracReduce",
 CellLabel->"Out[423]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t4", "=", 
  RowBox[{"DiracReduce", "[", "t3", "]"}]}]], "Input",
 CellTags->"DiracReduce",
 CellLabel->"In[424]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[Gamma]", "5"], " ", 
     SuperscriptBox["\[Epsilon]", 
      RowBox[{"\[Mu]", "\[Nu]", "\[Rho]", "\[Sigma]"}]]}]}], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["\[Sigma]", 
     RowBox[{"\[Rho]", "\[Sigma]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["\[Sigma]", 
     RowBox[{"\[Nu]", "\[Sigma]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Rho]"}]]}], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
    SuperscriptBox["\[Sigma]", 
     RowBox[{"\[Nu]", "\[Rho]"}]]}], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["\[Sigma]", 
     RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Rho]"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Sigma]"}]], " ", 
    SuperscriptBox["\[Sigma]", 
     RowBox[{"\[Mu]", "\[Rho]"}]]}], "-", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Rho]", "\[Sigma]"}]], " ", 
    SuperscriptBox["\[Sigma]", 
     RowBox[{"\[Mu]", "\[Nu]"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Rho]"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Sigma]"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Rho]", "\[Sigma]"}]]}]}], TraditionalForm]], "Output",
 CellTags->"DiracReduce",
 CellLabel->"Out[424]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t5", " ", "=", 
  RowBox[{"Calc", "[", 
   RowBox[{"DiracSimplify", "[", 
    RowBox[{"DiracSigmaExplicit", "[", 
     RowBox[{"t4", ".", "t4"}], "]"}], "]"}], "]"}]}]], "Input",
 CellTags->"DiracReduce",
 CellLabel->"In[425]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", "128"}], TraditionalForm]], "Output",
 CellTags->"DiracReduce",
 CellLabel->"Out[425]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", 
  RowBox[{"t4", ".", "t4"}], "]"}]], "Input",
 CellTags->"DiracReduce",
 CellLabel->"In[426]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", "128"}], TraditionalForm]], "Output",
 CellTags->"DiracReduce",
 CellLabel->"Out[426]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4"}], "]"}]], "Input",
 CellTags->"DiracReduce",
 CellLabel->"In[427]:="]
}, Open  ]],

Cell["DiracSigma", "ObjectName",
 CellTags->"DiracSigma"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracSigma"],

Cell["\<\
DiracSigma[a, b] stands for i/2*(a . b - b . a) in 4 dimensions. a and b must \
have Head DiracGamma, DiracMatrix or DiracSlash. Only antisymmetry is \
implemented.\
\>", "Text",
 CellTags->"DiracSigma"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracSigmaExplicit",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSigmaExplicit",
  ButtonNote->"DiracSigmaExplicit"],
 "."
}], "Text",
 CellTags->"DiracSigma"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DiracSigma"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{"DiracSigma", "[", 
   RowBox[{
    RowBox[{"GA", "[", "\[Alpha]", "]"}], ",", 
    RowBox[{"GA", "[", "\[Beta]", "]"}]}], "]"}]}]], "Input",
 CellTags->"DiracSigma",
 CellLabel->"In[428]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Sigma]", 
   RowBox[{"\[Alpha]", "\[Beta]"}]], TraditionalForm]], "Output",
 CellTags->"DiracSigma",
 CellLabel->"Out[428]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSigmaExplicit", "[", "t1", "]"}]], "Input",
 CellTags->"DiracSigma",
 CellLabel->"In[429]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Alpha]",
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Beta]",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Beta]",
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Alpha]",
         TraditionalForm],
        TraditionalForm]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"DiracSigma",
 CellLabel->"Out[429]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", "=", 
  RowBox[{"DiracSigma", "[", 
   RowBox[{
    RowBox[{"GA", "[", "\[Beta]", "]"}], ",", 
    RowBox[{"GA", "[", "\[Alpha]", "]"}]}], "]"}]}]], "Input",
 CellTags->"DiracSigma",
 CellLabel->"In[430]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   SuperscriptBox["\[Sigma]", 
    RowBox[{"\[Alpha]", "\[Beta]"}]]}], TraditionalForm]], "Output",
 CellTags->"DiracSigma",
 CellLabel->"Out[430]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t3", "=", 
  RowBox[{"DiracSigma", "[", 
   RowBox[{
    RowBox[{"GS", "[", "p", "]"}], ",", 
    RowBox[{"GS", "[", "q", "]"}]}], "]"}]}]], "Input",
 CellTags->"DiracSigma",
 CellLabel->"In[431]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Sigma]", 
   RowBox[{"p", "q"}]], TraditionalForm]], "Output",
 CellTags->"DiracSigma",
 CellLabel->"Out[431]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSigmaExplicit", "[", "t3", "]"}]], "Input",
 CellTags->"DiracSigma",
 CellLabel->"In[432]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FormBox["\<\"\[Gamma]\"\>",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{
        FormBox["\<\"\[Gamma]\"\>",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FormBox["\<\"\[Gamma]\"\>",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{
        FormBox["\<\"\[Gamma]\"\>",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"DiracSigma",
 CellLabel->"Out[432]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"t1", ",", "t2", ",", "t3"}], "]"}]], "Input",
 CellTags->"DiracSigma",
 CellLabel->"In[433]:="]
}, Open  ]],

Cell["DiracSigmaExplicit", "ObjectName",
 CellTags->"DiracSigmaExplicit"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracSigmaExplicit"],

Cell["\<\
DiracSigmaExplicit[exp] inserts in exp for all DiracSigma its definition. \
DiracSigmaExplict is also an option of DiracSimplify.\
\>", "Text",
 CellTags->"DiracSigmaExplicit"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracSigma",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSigma",
  ButtonNote->"DiracSigma"],
 "."
}], "Text",
 CellTags->"DiracSigmaExplicit"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DiracSigmaExplicit"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSigma", "[", 
  RowBox[{
   RowBox[{"GA", "[", "\[Alpha]", "]"}], ",", 
   RowBox[{"GA", "[", "\[Beta]", "]"}]}], "]"}]], "Input",
 CellTags->"DiracSigmaExplicit",
 CellLabel->"In[434]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Sigma]", 
   RowBox[{"\[Alpha]", "\[Beta]"}]], TraditionalForm]], "Output",
 CellTags->"DiracSigmaExplicit",
 CellLabel->"Out[434]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSigmaExplicit", "[", "%", "]"}]], "Input",
 CellTags->"DiracSigmaExplicit",
 CellLabel->"In[435]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Alpha]",
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Beta]",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Beta]",
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Alpha]",
         TraditionalForm],
        TraditionalForm]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"DiracSigmaExplicit",
 CellLabel->"Out[435]="]
}, Open  ]]
}, Open  ]],

Cell["DiracSimpCombine", "ObjectName",
 CellTags->"DiracSimpCombine"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracSimpCombine"],

Cell["\<\
DiracSimpCombine is an option for DiracSimplify. If set to True, sums of \
DiracGamma's will be merged as much as possible in DiracGamma[ .. + .. + ]'s.\
\
\>", "Text",
 CellTags->"DiracSimpCombine"],

Cell[TextData[{
 "See also: ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 "."
}], "Text",
 CellTags->"DiracSimpCombine"]
}, Open  ]],

Cell["DiracSimplify", "ObjectName",
 CellTags->"DiracSimplify"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracSimplify"],

Cell["\<\
DiracSimplify[expr] simplifies products of Dirac matrices in expr and expands \
non-commutative products. Double Lorentz indices and four vectors are \
contracted. The Dirac equation is applied. All DiracMatrix[5], DiracMatrix[6] \
and DiracMatrix[7] are moved to the right. The order of the other Dirac \
matrices is not changed.\
\>", "Text",
 CellTags->"DiracSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "DiracSimplify", "]"}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[436]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"DiracCanonical", "\[Rule]", "False"}], ",", 
    RowBox[{"DiracSigmaExplicit", "\[Rule]", "True"}], ",", 
    RowBox[{"DiracSimpCombine", "\[Rule]", "False"}], ",", 
    RowBox[{"DiracSubstitute67", "\[Rule]", "False"}], ",", 
    RowBox[{"Expanding", "\[Rule]", "True"}], ",", 
    RowBox[{"Factoring", "\[Rule]", "False"}], ",", 
    RowBox[{"FeynCalcInternal", "\[Rule]", "False"}], ",", 
    RowBox[{"InsideDiracTrace", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"DiracSimplify",
 CellLabel->"Out[436]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Calc",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Calc",
  ButtonNote->"Calc"],
 ", ",
 ButtonBox["DiracGammaExpand",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGammaExpand",
  ButtonNote->"DiracGammaExpand"],
 ", ",
 ButtonBox["DiracTrick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrick",
  ButtonNote->"DiracTrick"],
 "."
}], "Text",
 CellTags->"DiracSimplify"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DiracSimplify"],

Cell["This is a string of Dirac matrices in four dimensions. ", "Text",
 CellTags->"DiracSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{"GA", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Mu]"}], "]"}]}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[437]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
 CellTags->"DiracSimplify",
 CellLabel->"Out[437]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSimplify", "[", "t1", "]"}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[438]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"DiracSimplify",
 CellLabel->"Out[438]="]
}, Open  ]],

Cell["This is a string of Dirac matrices in D dimensions. ", "Text",
 CellTags->"DiracSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", "=", 
  RowBox[{"GAD", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Mu]"}], "]"}]}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[439]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
 CellTags->"DiracSimplify",
 CellLabel->"Out[439]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSimplify", "[", "t1", "]"}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[440]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"DiracSimplify",
 CellLabel->"Out[440]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t3", "=", 
  RowBox[{"GA", "[", 
   RowBox[{"5", ",", "\[Mu]", ",", "\[Nu]"}], "]"}]}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[441]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "5"], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"]}], TraditionalForm]], "Output",
 CellTags->"DiracSimplify",
 CellLabel->"Out[441]="]
}, Open  ]],

Cell[TextData[{
 "By default ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
 "is moved to the right."
}], "Text",
 CellTags->"DiracSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSimplify", "[", "t3", "]"}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[442]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", "5"]}], TraditionalForm]], "Output",
 CellTags->"DiracSimplify",
 CellLabel->"Out[442]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t4", "=", 
  RowBox[{"GA", "[", 
   RowBox[{"6", ",", "\[Mu]", ",", "7"}], "]"}]}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[443]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "6"], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "7"]}], TraditionalForm]], "Output",
 CellTags->"DiracSimplify",
 CellLabel->"Out[443]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSimplify", "[", "t4", "]"}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[444]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", "7"]}], TraditionalForm]], "Output",
 CellTags->"DiracSimplify",
 CellLabel->"Out[444]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t5", "=", 
  RowBox[{
   RowBox[{"GS", "[", 
    RowBox[{"a", "+", "b"}], "]"}], " ", ".", " ", 
   RowBox[{"GS", "[", "p", "]"}], ".", 
   RowBox[{"GS", "[", "p", "]"}], ".", 
   RowBox[{"GS", "[", 
    RowBox[{"c", "+", "d"}], "]"}]}]}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[445]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "(", 
     FormBox[
      RowBox[{"a", "+", "b"}],
      TraditionalForm], ")"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "(", 
     FormBox[
      RowBox[{"c", "+", "d"}],
      TraditionalForm], ")"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"DiracSimplify",
 CellLabel->"Out[445]="]
}, Open  ]],

Cell["\<\
Contrary to DiracTrick DiracSimplify does non-commutative expansion.\
\>", "Text",
 CellTags->"DiracSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSimplify", "[", "t5", "]"}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[446]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["a",
        TraditionalForm]}], ")"}], ".", 
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["c",
        TraditionalForm]}], ")"}]}]}], "+", 
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["a",
        TraditionalForm]}], ")"}], ".", 
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["d",
        TraditionalForm]}], ")"}]}]}], "+", 
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["b",
        TraditionalForm]}], ")"}], ".", 
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["c",
        TraditionalForm]}], ")"}]}]}], "+", 
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["b",
        TraditionalForm]}], ")"}], ".", 
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["d",
        TraditionalForm]}], ")"}]}]}]}], TraditionalForm]], "Output",
 CellTags->"DiracSimplify",
 CellLabel->"Out[446]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracTrick", "[", "t5", "]"}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[447]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "(", 
     FormBox[
      RowBox[{"a", "+", "b"}],
      TraditionalForm], ")"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "(", 
     FormBox[
      RowBox[{"c", "+", "d"}],
      TraditionalForm], ")"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"DiracSimplify",
 CellLabel->"Out[447]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t6", " ", "=", " ", 
  RowBox[{
   RowBox[{"SpinorVBar", "[", "p", "]"}], " ", ".", " ", 
   RowBox[{"GS", "[", "p", "]"}], " ", ".", " ", 
   RowBox[{"SpinorUBar", "[", "q", "]"}]}]}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[448]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FormBox[
     OverscriptBox["\<\"v\"\>", "_"],
     TraditionalForm], "(", "p", ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], ")"}], ".", 
   RowBox[{
    FormBox[
     OverscriptBox["\<\"u\"\>", "_"],
     TraditionalForm], "(", "q", ")"}]}], TraditionalForm]], "Output",
 CellTags->"DiracSimplify",
 CellLabel->"Out[448]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSimplify", "[", "t6", "]"}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[449]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"DiracSimplify",
 CellLabel->"Out[449]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GAD", "@@", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"{", "\[Mu]", "}"}], ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      SubscriptBox["\[Nu]", "i"], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", "\[Mu]", "}"}]}], "]"}]}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[450]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", 
    SubscriptBox["\[Nu]", "1"]], ".", 
   SuperscriptBox["\[Gamma]", 
    SubscriptBox["\[Nu]", "2"]], ".", 
   SuperscriptBox["\[Gamma]", 
    SubscriptBox["\[Nu]", "3"]], ".", 
   SuperscriptBox["\[Gamma]", 
    SubscriptBox["\[Nu]", "4"]], ".", 
   SuperscriptBox["\[Gamma]", 
    SubscriptBox["\[Nu]", "5"]], ".", 
   SuperscriptBox["\[Gamma]", 
    SubscriptBox["\[Nu]", "6"]], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
 CellTags->"DiracSimplify",
 CellLabel->"Out[450]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSimplify", "[", "%", "]"}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[451]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"12", " ", 
     RowBox[{
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox[
         SubscriptBox["\[Nu]", "1"],
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox[
         SubscriptBox["\[Nu]", "2"],
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox[
         SubscriptBox["\[Nu]", "3"],
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox[
         SubscriptBox["\[Nu]", "4"],
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox[
         SubscriptBox["\[Nu]", "5"],
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox[
         SubscriptBox["\[Nu]", "6"],
         TraditionalForm],
        TraditionalForm]]}]}]}], "+", 
   RowBox[{"D", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "4"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "5"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "6"],
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{"4", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "4"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "5"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "6"],
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{
      SubscriptBox["\[Nu]", "1"], 
      SubscriptBox["\[Nu]", "2"]}]]}], "-", 
   RowBox[{"4", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "4"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "5"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "6"],
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{
      SubscriptBox["\[Nu]", "1"], 
      SubscriptBox["\[Nu]", "3"]}]]}], "+", 
   RowBox[{"4", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "5"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "6"],
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{
      SubscriptBox["\[Nu]", "1"], 
      SubscriptBox["\[Nu]", "4"]}]]}], "-", 
   RowBox[{"4", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "4"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "6"],
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{
      SubscriptBox["\[Nu]", "1"], 
      SubscriptBox["\[Nu]", "5"]}]]}], "+", 
   RowBox[{"4", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "4"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "5"],
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{
      SubscriptBox["\[Nu]", "1"], 
      SubscriptBox["\[Nu]", "6"]}]]}], "+", 
   RowBox[{"4", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "4"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "5"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "6"],
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{
      SubscriptBox["\[Nu]", "2"], 
      SubscriptBox["\[Nu]", "3"]}]]}], "-", 
   RowBox[{"4", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "5"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "6"],
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{
      SubscriptBox["\[Nu]", "2"], 
      SubscriptBox["\[Nu]", "4"]}]]}], "+", 
   RowBox[{"4", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "4"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "6"],
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{
      SubscriptBox["\[Nu]", "2"], 
      SubscriptBox["\[Nu]", "5"]}]]}], "-", 
   RowBox[{"4", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "4"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "5"],
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{
      SubscriptBox["\[Nu]", "2"], 
      SubscriptBox["\[Nu]", "6"]}]]}], "+", 
   RowBox[{"4", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "5"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "6"],
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{
      SubscriptBox["\[Nu]", "3"], 
      SubscriptBox["\[Nu]", "4"]}]]}], "-", 
   RowBox[{"4", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "4"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "6"],
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{
      SubscriptBox["\[Nu]", "3"], 
      SubscriptBox["\[Nu]", "5"]}]]}], "+", 
   RowBox[{"4", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "4"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "5"],
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{
      SubscriptBox["\[Nu]", "3"], 
      SubscriptBox["\[Nu]", "6"]}]]}], "+", 
   RowBox[{"4", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "6"],
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{
      SubscriptBox["\[Nu]", "4"], 
      SubscriptBox["\[Nu]", "5"]}]]}], "-", 
   RowBox[{"4", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "5"],
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{
      SubscriptBox["\[Nu]", "4"], 
      SubscriptBox["\[Nu]", "6"]}]]}], "+", 
   RowBox[{"4", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "1"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "2"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "3"],
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox[
        SubscriptBox["\[Nu]", "4"],
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{
      SubscriptBox["\[Nu]", "5"], 
      SubscriptBox["\[Nu]", "6"]}]]}]}], TraditionalForm]], "Output",
 CellTags->"DiracSimplify",
 CellLabel->"Out[451]="]
}, Open  ]],

Cell["\<\
 With the option DiracCanonical an alphabetic ordering is done.\
\>", "Text",
 CellTags->"DiracSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSimplify", "[", 
  RowBox[{
   RowBox[{"GA", "[", 
    RowBox[{"\[Nu]", ",", "\[Mu]"}], "]"}], ",", 
   RowBox[{"DiracCanonical", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[452]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]]}], "-", 
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], ".", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"DiracSimplify",
 CellLabel->"Out[452]="]
}, Open  ]],

Cell["\<\
Setting InsideDiracTrace\[Rule]True assumes that a trace is still to be taken \
later on.\
\>", "Text",
 CellTags->"DiracSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSimplify", "[", 
  RowBox[{
   RowBox[{"GA", "[", 
    RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], "]"}], 
   ",", 
   RowBox[{"InsideDiracTrace", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[453]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Rho]"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Sigma]"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Rho]", "\[Sigma]"}]]}]}], TraditionalForm]], "Output",
 CellTags->"DiracSimplify",
 CellLabel->"Out[453]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSimplify", "[", 
  RowBox[{
   RowBox[{"GA", "[", 
    RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]"}], "]"}], ",", 
   RowBox[{"InsideDiracTrace", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[454]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"DiracSimplify",
 CellLabel->"Out[454]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5", ",", "t6"}], 
  "]"}]], "Input",
 CellTags->"DiracSimplify",
 CellLabel->"In[455]:="]
}, Open  ]],

Cell["DiracSimplify2", "ObjectName",
 CellTags->"DiracSimplify2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracSimplify2"],

Cell[TextData[{
 "DiracSimplify2[exp] simplifies the Dirac structure but leaves any ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
 " untouched."
}], "Text",
 CellTags->"DiracSimplify2"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 "."
}], "Text",
 CellTags->"DiracSimplify2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DiracSimplify2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GAD", "[", 
  RowBox[{
  "\[Mu]", ",", "\[Nu]", ",", "\[Mu]", ",", "5", ",", "\[Alpha]", ",", 
   "\[Beta]", ",", "\[Alpha]"}], "]"}]], "Input",
 CellTags->"DiracSimplify2",
 CellLabel->"In[456]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "5"], ".", 
   SuperscriptBox["\[Gamma]", "\[Alpha]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Beta]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Alpha]"]}], TraditionalForm]], "Output",
 CellTags->"DiracSimplify2",
 CellLabel->"Out[456]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSimplify2", "[", "%", "]"}]], "Input",
 CellTags->"DiracSimplify2",
 CellLabel->"In[457]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", "5"], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Alpha]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Beta]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Alpha]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"DiracSimplify2",
 CellLabel->"Out[457]="]
}, Open  ]]
}, Open  ]],

Cell["DiracSlash", "ObjectName",
 CellTags->"DiracSlash"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracSlash"],

Cell[TextData[{
 "DiracSlash[p] is the contraction ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["p", "\[Mu]"], 
    SubscriptBox["\[Gamma]", 
     RowBox[{"\[Mu]", " "}]]}], TraditionalForm]]],
 "(FourVector[p, ",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "] DiracMatrix[",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "]). Products of those can be entered in the form DiracSlash[p1, p2, ...]."
}], "Text",
 CellTags->"DiracSlash"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "DiracSlash", "]"}]], "Input",
 CellTags->"DiracSlash",
 CellLabel->"In[458]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Dimension", "\[Rule]", "4"}], ",", 
    RowBox[{"FeynCalcInternal", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"DiracSlash",
 CellLabel->"Out[458]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracGammaExpand",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGammaExpand",
  ButtonNote->"DiracGammaExpand"],
 ", ",
 ButtonBox["DiracGamma",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGamma",
  ButtonNote->"DiracGamma"],
 ", ",
 ButtonBox["DiracMatrix",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracMatrix",
  ButtonNote->"DiracMatrix"],
 ", ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 ", ",
 ButtonBox["DiracTrick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrick",
  ButtonNote->"DiracTrick"],
 ", ",
 ButtonBox["GS",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GS",
  ButtonNote->"GS"],
 ", ",
 ButtonBox["GSD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GSD",
  ButtonNote->"GSD"],
 "."
}], "Text",
 CellTags->"DiracSlash"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DiracSlash"],

Cell[TextData[{
 "This is q-slash, i.e., ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Gamma]", "\[Mu]"], 
    RowBox[{
     SubscriptBox["q", "\[Mu]"], "."}]}], TraditionalForm]]]
}], "Text",
 CellTags->"DiracSlash"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSlash", "[", "q", "]"}]], "Input",
 CellTags->"DiracSlash",
 CellLabel->"In[459]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["\<\"\[Gamma]\"\>",
    TraditionalForm], "\[CenterDot]", 
   FormBox["q",
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"DiracSlash",
 CellLabel->"Out[459]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracSlash", "[", "p", "]"}], ".", 
  RowBox[{"DiracSlash", "[", "q", "]"}]}]], "Input",
 CellTags->"DiracSlash",
 CellLabel->"In[460]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["p",
      TraditionalForm]}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"DiracSlash",
 CellLabel->"Out[460]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSlash", "[", 
  RowBox[{"p", ",", "q"}], "]"}]], "Input",
 CellTags->"DiracSlash",
 CellLabel->"In[461]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["p",
      TraditionalForm]}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"DiracSlash",
 CellLabel->"Out[461]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GS", "[", "p", "]"}]], "Input",
 CellTags->"DiracSlash",
 CellLabel->"In[462]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], TraditionalForm]], "Output",
 CellTags->"DiracSlash",
 CellLabel->"Out[462]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracSlash", "[", "q", "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"DiracSlash",
 CellLabel->"In[463]:="],

Cell[BoxData[
 RowBox[{"DiracSlash", "[", "q", "]"}]], "Output",
 CellTags->"DiracSlash",
 CellLabel->"Out[463]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracSlash", "[", 
   RowBox[{"q", ",", 
    RowBox[{"Dimension", "\[Rule]", "n"}]}], "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"DiracSlash",
 CellLabel->"In[464]:="],

Cell[BoxData[
 RowBox[{"DiracSlash", "[", 
  RowBox[{"q", ",", 
   RowBox[{"Dimension", "\[Rule]", "n"}]}], "]"}]], "Output",
 CellTags->"DiracSlash",
 CellLabel->"Out[464]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["DiracSpinor", "ObjectName",
 CellTags->"DiracSpinor"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracSpinor"],

Cell["\<\
DiracSpinor is simply a quantity defined as noncommutative (with \
DeclareNonCommutative[DiracSpinor]). The convention intended is that \
DiracSpinor[p, m, ind] is a Dirac spinor for a fermion with momentum p and \
mass m and indices ind.\
\>", "Text",
 CellTags->"DiracSpinor"],

Cell[TextData[{
 "See also: ",
 ButtonBox["Spinor",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Spinor",
  ButtonNote->"Spinor"],
 "."
}], "Text",
 CellTags->"DiracSpinor"]
}, Open  ]],

Cell["DiracSubstitute67", "ObjectName",
 CellTags->"DiracSubstitute67"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracSubstitute67"],

Cell["\<\
DiracSubstitute67 is an option for DiracSimplify. If set to True the \
chirality-projectors DiracGamma[6] and DiracGamma[7] are substituted by their \
definitions.\
\>", "Text",
 CellTags->"DiracSubstitute67"],

Cell[TextData[{
 "See also: ",
 ButtonBox["DiracGamma",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGamma",
  ButtonNote->"DiracGamma"],
 ", ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 "."
}], "Text",
 CellTags->"DiracSubstitute67"]
}, Open  ]],

Cell["DiracTrace", "ObjectName",
 CellTags->"DiracTrace"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracTrace"],

Cell["\<\
DiracTrace[expr] is the head of Dirac traces. Whether the trace is evaluated \
depends on the option DiracTraceEvaluate. Direct trace evaluation should be \
performed with TR (or Tr). The argument expr may be a product of Dirac \
matrices or slashes separated by the Mathematica Dot (.).\
\>", "Text",
 CellTags->"DiracTrace"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "DiracTrace", "]"}]], "Input",
 CellTags->"DiracTrace",
 CellLabel->"In[465]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"EpsContract", "\[Rule]", "False"}], ",", 
    RowBox[{"Factoring", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"FeynCalcExternal", "\[Rule]", "False"}], ",", 
    RowBox[{"Mandelstam", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"PairCollect", "\[Rule]", "True"}], ",", 
    RowBox[{"DiracTraceEvaluate", "\[Rule]", "False"}], ",", 
    RowBox[{"Schouten", "\[Rule]", "0"}], ",", 
    RowBox[{"LeviCivitaSign", "\[RuleDelayed]", "$LeviCivitaSign"}], ",", 
    RowBox[{"TraceOfOne", "\[Rule]", "4"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"DiracTrace",
 CellLabel->"Out[465]="]
}, Open  ]],

Cell[TextData[{
 "For comments regarding ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
 "schemes see the notes for ",
 ButtonBox["TR",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TR",
  ButtonNote->"TR"],
 "."
}], "Text",
 CellTags->"DiracTrace"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["TR",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TR",
  ButtonNote->"TR"],
 "."
}], "Text",
 CellTags->"DiracTrace"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DiracTrace"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracTrace", "[", 
  RowBox[{"GA", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "]"}]], "Input",
 CellTags->"DiracTrace",
 CellLabel->"In[466]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"tr", "(", 
   FormBox[
    RowBox[{
     SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
     SuperscriptBox["\[Gamma]", "\[Nu]"]}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"DiracTrace",
 CellLabel->"Out[466]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracTrace", "[", 
  RowBox[{"GA", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], "]"}], 
  "]"}]], "Input",
 CellTags->"DiracTrace",
 CellLabel->"In[467]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"tr", "(", 
   FormBox[
    RowBox[{
     SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
     SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
     SuperscriptBox["\[Gamma]", "\[Rho]"], ".", 
     SuperscriptBox["\[Gamma]", "\[Sigma]"]}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"DiracTrace",
 CellLabel->"Out[467]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", " ", "/.", " ", 
  RowBox[{"DiracTrace", "\[Rule]", "Tr"}]}]], "Input",
 CellTags->"DiracTrace",
 CellLabel->"In[468]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Rho]"}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Sigma]"}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Rho]", "\[Sigma]"}]]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"DiracTrace",
 CellLabel->"Out[468]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracTrace", "[", 
  RowBox[{
   RowBox[{"GA", "[", 
    RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]", ",", "5"}],
     "]"}], ",", 
   RowBox[{"DiracTraceEvaluate", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"DiracTrace",
 CellLabel->"In[469]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
   SuperscriptBox["\[Epsilon]", 
    RowBox[{
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"DiracTrace",
 CellLabel->"Out[469]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracTrace", "[", 
  RowBox[{
   RowBox[{"GA", "[", 
    RowBox[{
    "\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]", ",", "\[Delta]", 
     ",", "\[Tau]", ",", "5"}], "]"}], ",", 
   RowBox[{"DiracTraceEvaluate", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"DiracTrace",
 CellLabel->"In[470]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"4", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Delta]", "\[Mu]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Delta]", "\[Nu]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Delta]", "\[Rho]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Delta]", "\[Sigma]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Delta]", "\[Tau]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Delta]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Delta]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Delta]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Tau]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Delta]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Delta]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Sigma]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Delta]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Tau]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Delta]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Rho]", "\[Sigma]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Delta]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Rho]", "\[Tau]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Delta]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Sigma]", "\[Tau]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Delta]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]}]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"DiracTrace",
 CellLabel->"Out[470]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracTrace", "[", 
  RowBox[{"GS", "[", 
   RowBox[{"p", ",", "q", ",", "r", ",", "s"}], "]"}], "]"}]], "Input",
 CellTags->"DiracTrace",
 CellLabel->"In[471]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"tr", "(", 
   FormBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], ")"}], ".", 
     RowBox[{"(", 
      RowBox[{"\[Gamma]", "\[CenterDot]", "q"}], ")"}], ".", 
     RowBox[{"(", 
      RowBox[{"\[Gamma]", "\[CenterDot]", "r"}], ")"}], ".", 
     RowBox[{"(", 
      RowBox[{"\[Gamma]", "\[CenterDot]", "s"}], ")"}]}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"DiracTrace",
 CellLabel->"Out[471]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracTrace", "[", 
  RowBox[{
   RowBox[{"GA", "[", 
    RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], ",", 
   RowBox[{"DiracTraceEvaluate", "\[Rule]", "True"}], ",", 
   RowBox[{"FCE", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"DiracTrace",
 CellLabel->"In[472]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"4", " ", 
   SuperscriptBox["g", 
    RowBox[{"\[Mu]", "\[Nu]"}]]}], TraditionalForm]], "Output",
 CellTags->"DiracTrace",
 CellLabel->"Out[472]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"DiracTrace",
 CellLabel->"In[473]:="],

Cell[BoxData[
 RowBox[{"4", " ", 
  RowBox[{"MT", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}]], "Output",
 CellTags->"DiracTrace",
 CellLabel->"Out[473]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["DiracTraceEvaluate", "ObjectName",
 CellTags->"DiracTraceEvaluate"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracTraceEvaluate"],

Cell["\<\
DiracTraceEvaluate is an option for DiracTrace and Tr. If set to False, \
DiracTrace remains unevaluated.\
\>", "Text",
 CellTags->"DiracTraceEvaluate"],

Cell[TextData[{
 "See also: ",
 ButtonBox["DiracTrace",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrace",
  ButtonNote->"DiracTrace"],
 ", ",
 ButtonBox["TR",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TR",
  ButtonNote->"TR"],
 "."
}], "Text",
 CellTags->"DiracTraceEvaluate"]
}, Open  ]],

Cell["DiracTrick", "ObjectName",
 CellTags->"DiracTrick"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DiracTrick"],

Cell["\<\
DiracTrick[exp] contracts gamma matrices with each other and performs several \
simplifications, but no expansion, use Calc or DiracSimplify for \
non-commutative expansion.\
\>", "Text",
 CellTags->"DiracTrick"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "DiracTrick", "]"}]], "Input",
 CellTags->"DiracTrick",
 CellLabel->"In[474]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"Expanding", "\[Rule]", "False"}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"DiracTrick",
 CellLabel->"Out[474]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Calc",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Calc",
  ButtonNote->"Calc"],
 ", ",
 ButtonBox["DiracGammaExpand",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGammaExpand",
  ButtonNote->"DiracGammaExpand"],
 ", ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 "."
}], "Text",
 CellTags->"DiracTrick"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DiracTrick"],

Cell["This is a string of Dirac matrices in four dimensions. ", "Text",
 CellTags->"DiracTrick"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{"GA", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Mu]"}], "]"}]}]], "Input",
 CellTags->"DiracTrick",
 CellLabel->"In[475]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
 CellTags->"DiracTrick",
 CellLabel->"Out[475]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracTrick", "[", "t1", "]"}]], "Input",
 CellTags->"DiracTrick",
 CellLabel->"In[476]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
 CellTags->"DiracTrick",
 CellLabel->"Out[476]="]
}, Open  ]],

Cell["This is a string of Dirac matrices in D dimensions. ", "Text",
 CellTags->"DiracTrick"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", "=", 
  RowBox[{"GAD", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Mu]"}], "]"}]}]], "Input",
 CellTags->"DiracTrick",
 CellLabel->"In[477]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
 CellTags->"DiracTrick",
 CellLabel->"Out[477]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracTrick", "[", "t2", "]"}]], "Input",
 CellTags->"DiracTrick",
 CellLabel->"In[478]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
 CellTags->"DiracTrick",
 CellLabel->"Out[478]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t3", "=", 
  RowBox[{"GA", "[", 
   RowBox[{"5", ",", "\[Mu]", ",", "\[Nu]"}], "]"}]}]], "Input",
 CellTags->"DiracTrick",
 CellLabel->"In[479]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "5"], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"]}], TraditionalForm]], "Output",
 CellTags->"DiracTrick",
 CellLabel->"Out[479]="]
}, Open  ]],

Cell[TextData[{
 "By default ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
 "is moved to the right."
}], "Text",
 CellTags->"DiracTrick"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracTrick", "[", "t3", "]"}]], "Input",
 CellTags->"DiracTrick",
 CellLabel->"In[480]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "5"], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"]}], TraditionalForm]], "Output",
 CellTags->"DiracTrick",
 CellLabel->"Out[480]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t4", "=", 
  RowBox[{"GA", "[", 
   RowBox[{"6", ",", "\[Mu]", ",", "7"}], "]"}]}]], "Input",
 CellTags->"DiracTrick",
 CellLabel->"In[481]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "6"], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "7"]}], TraditionalForm]], "Output",
 CellTags->"DiracTrick",
 CellLabel->"Out[481]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracTrick", "[", "t4", "]"}]], "Input",
 CellTags->"DiracTrick",
 CellLabel->"In[482]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "6"], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "7"]}], TraditionalForm]], "Output",
 CellTags->"DiracTrick",
 CellLabel->"Out[482]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t5", "=", 
  RowBox[{
   RowBox[{"GS", "[", 
    RowBox[{"a", "+", "b"}], "]"}], " ", ".", " ", 
   RowBox[{"GS", "[", "p", "]"}], ".", 
   RowBox[{"GS", "[", "p", "]"}], ".", 
   RowBox[{"GS", "[", 
    RowBox[{"c", "+", "d"}], "]"}]}]}]], "Input",
 CellTags->"DiracTrick",
 CellLabel->"In[483]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "(", 
     FormBox[
      RowBox[{"a", "+", "b"}],
      TraditionalForm], ")"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "(", 
     FormBox[
      RowBox[{"c", "+", "d"}],
      TraditionalForm], ")"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"DiracTrick",
 CellLabel->"Out[483]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracTrick", "[", "t5", "]"}]], "Input",
 CellTags->"DiracTrick",
 CellLabel->"In[484]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "(", 
     FormBox[
      RowBox[{"a", "+", "b"}],
      TraditionalForm], ")"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "(", 
     FormBox[
      RowBox[{"c", "+", "d"}],
      TraditionalForm], ")"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"DiracTrick",
 CellLabel->"Out[484]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", "t5", "]"}]], "Input",
 CellTags->"DiracTrick",
 CellLabel->"In[485]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["a",
        TraditionalForm]}], ")"}], ".", 
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["c",
        TraditionalForm]}], ")"}]}]}], "+", 
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["a",
        TraditionalForm]}], ")"}], ".", 
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["d",
        TraditionalForm]}], ")"}]}]}], "+", 
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["b",
        TraditionalForm]}], ")"}], ".", 
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["c",
        TraditionalForm]}], ")"}]}]}], "+", 
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["b",
        TraditionalForm]}], ")"}], ".", 
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["d",
        TraditionalForm]}], ")"}]}]}]}], TraditionalForm]], "Output",
 CellTags->"DiracTrick",
 CellLabel->"Out[485]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GAD", "@@", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"{", "\[Mu]", "}"}], ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      SubscriptBox["\[Nu]", "i"], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "6"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", "\[Mu]", "}"}]}], "]"}]}]], "Input",
 CellTags->"DiracTrick",
 CellLabel->"In[486]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", 
    SubscriptBox["\[Nu]", "1"]], ".", 
   SuperscriptBox["\[Gamma]", 
    SubscriptBox["\[Nu]", "2"]], ".", 
   SuperscriptBox["\[Gamma]", 
    SubscriptBox["\[Nu]", "3"]], ".", 
   SuperscriptBox["\[Gamma]", 
    SubscriptBox["\[Nu]", "4"]], ".", 
   SuperscriptBox["\[Gamma]", 
    SubscriptBox["\[Nu]", "5"]], ".", 
   SuperscriptBox["\[Gamma]", 
    SubscriptBox["\[Nu]", "6"]], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
 CellTags->"DiracTrick",
 CellLabel->"Out[486]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracTrick", "[", "%", "]"}]], "Input",
 CellTags->"DiracTrick",
 CellLabel->"In[487]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", 
    SubscriptBox["\[Nu]", "1"]], ".", 
   SuperscriptBox["\[Gamma]", 
    SubscriptBox["\[Nu]", "2"]], ".", 
   SuperscriptBox["\[Gamma]", 
    SubscriptBox["\[Nu]", "3"]], ".", 
   SuperscriptBox["\[Gamma]", 
    SubscriptBox["\[Nu]", "4"]], ".", 
   SuperscriptBox["\[Gamma]", 
    SubscriptBox["\[Nu]", "5"]], ".", 
   SuperscriptBox["\[Gamma]", 
    SubscriptBox["\[Nu]", "6"]], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]], "Output",
 CellTags->"DiracTrick",
 CellLabel->"Out[487]="]
}, Open  ]]
}, Open  ]],

Cell["Divideout", "ObjectName",
 CellTags->"Divideout"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Divideout"],

Cell["\<\
Divideout is an option for OPEInt and OPEInsert. The setting is divided out \
at the end.\
\>", "Text",
 CellTags->"Divideout"],

Cell[TextData[{
 "See also: ",
 ButtonBox["OPEInt",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OPEInt",
  ButtonNote->"OPEInt"],
 ", ",
 ButtonBox["OPEInsert",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OPEInsert",
  ButtonNote->"OPEInsert"],
 "."
}], "Text",
 CellTags->"Divideout"]
}, Open  ]],

Cell["DOT", "ObjectName",
 CellTags->"DOT"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DOT"],

Cell["\<\
DOT[a, b, ...] is the FeynCalc function for non-commutative multiplication. \
By default it is set to the Mathematica Dot functions. By setting
DOT=.
this can be disabled. Note that then non-commutative products should to be \
entered like DOT[ DiracMatrix[mu], m + DiracSlash[p], DiracMatrix[mu] ], etc.\
\
\>", "Text",
 CellTags->"DOT"],

Cell[TextData[{
 "See also: ",
 ButtonBox["DotSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DotSimplify",
  ButtonNote->"DotSimplify"],
 "."
}], "Text",
 CellTags->"DOT"]
}, Open  ]],

Cell["DotExpand", "ObjectName",
 CellTags->"DotExpand"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DotExpand"],

Cell["DotExpand[expr] expands DOT products in expr.", "Text",
 CellTags->"DotExpand"],

Cell[TextData[{
 "See also: ",
 ButtonBox["DOT",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DOT",
  ButtonNote->"DOT"],
 ", ",
 ButtonBox["DotSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DotSimplify",
  ButtonNote->"DotSimplify"],
 ", ",
 ButtonBox["DeclareNonCommutative",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DeclareNonCommutative",
  ButtonNote->"DeclareNonCommutative"],
 ", ",
 ButtonBox["UnDeclareNonCommutative",
  BaseStyle->"AddOnsLink",
  ButtonData:>"UnDeclareNonCommutative",
  ButtonNote->"UnDeclareNonCommutative"],
 "."
}], "Text",
 CellTags->"DotExpand"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DotExpand"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotExpand", "[", 
  RowBox[{"DOT", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"a", " ", "x"}], "+", 
     RowBox[{"b", " ", "y"}], "+", 
     RowBox[{"c", " ", "z"}]}], ",", 
    RowBox[{"d", "+", "e", "+", "f"}]}], "]"}], "]"}]], "Input",
 CellTags->"DotExpand",
 CellLabel->"In[488]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"a", " ", "d", " ", "x"}], "+", 
   RowBox[{"a", " ", "e", " ", "x"}], "+", 
   RowBox[{"a", " ", "f", " ", "x"}], "+", 
   RowBox[{"b", " ", "d", " ", "y"}], "+", 
   RowBox[{"b", " ", "e", " ", "y"}], "+", 
   RowBox[{"b", " ", "f", " ", "y"}], "+", 
   RowBox[{"c", " ", "d", " ", "z"}], "+", 
   RowBox[{"c", " ", "e", " ", "z"}], "+", 
   RowBox[{"c", " ", "f", " ", "z"}]}], TraditionalForm]], "Output",
 CellTags->"DotExpand",
 CellLabel->"Out[488]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"DeclareNonCommutative", "/@", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], "}"}]}], 
  ";"}]], "Input",
 CellTags->"DotExpand",
 CellLabel->"In[489]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotExpand", "[", 
  RowBox[{"DOT", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"a", " ", "x"}], "+", 
     RowBox[{"b", " ", "y"}], "+", 
     RowBox[{"c", " ", "z"}]}], ",", 
    RowBox[{"d", "+", "e", "+", "f"}]}], "]"}], "]"}]], "Input",
 CellTags->"DotExpand",
 CellLabel->"In[490]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"x", " ", 
    RowBox[{"a", ".", "d"}]}], "+", 
   RowBox[{"x", " ", 
    RowBox[{"a", ".", "e"}]}], "+", 
   RowBox[{"x", " ", 
    RowBox[{"a", ".", "f"}]}], "+", 
   RowBox[{"y", " ", 
    RowBox[{"b", ".", "d"}]}], "+", 
   RowBox[{"y", " ", 
    RowBox[{"b", ".", "e"}]}], "+", 
   RowBox[{"y", " ", 
    RowBox[{"b", ".", "f"}]}], "+", 
   RowBox[{"z", " ", 
    RowBox[{"c", ".", "d"}]}], "+", 
   RowBox[{"z", " ", 
    RowBox[{"c", ".", "e"}]}], "+", 
   RowBox[{"z", " ", 
    RowBox[{"c", ".", "f"}]}]}], TraditionalForm]], "Output",
 CellTags->"DotExpand",
 CellLabel->"Out[490]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"UnDeclareNonCommutative", "/@", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], "}"}]}], 
  ";"}]], "Input",
 CellTags->"DotExpand",
 CellLabel->"In[491]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotExpand", "[", 
  RowBox[{"DOT", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"a", " ", "x"}], "+", 
     RowBox[{"b", " ", "y"}], "+", 
     RowBox[{"c", " ", "z"}]}], ",", 
    RowBox[{"d", "+", "e", "+", "f"}]}], "]"}], "]"}]], "Input",
 CellTags->"DotExpand",
 CellLabel->"In[492]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"a", " ", "d", " ", "x"}], "+", 
   RowBox[{"a", " ", "e", " ", "x"}], "+", 
   RowBox[{"a", " ", "f", " ", "x"}], "+", 
   RowBox[{"b", " ", "d", " ", "y"}], "+", 
   RowBox[{"b", " ", "e", " ", "y"}], "+", 
   RowBox[{"b", " ", "f", " ", "y"}], "+", 
   RowBox[{"c", " ", "d", " ", "z"}], "+", 
   RowBox[{"c", " ", "e", " ", "z"}], "+", 
   RowBox[{"c", " ", "f", " ", "z"}]}], TraditionalForm]], "Output",
 CellTags->"DotExpand",
 CellLabel->"Out[492]="]
}, Open  ]]
}, Open  ]],

Cell["DotPower", "ObjectName",
 CellTags->"DotPower"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DotPower"],

Cell["\<\
DotPower is an option for DotSimplify. It determines whether non-commutative \
powers are represented by succesive multiplication or by Power.\
\>", "Text",
 CellTags->"DotPower"],

Cell[TextData[{
 "See also: ",
 ButtonBox["DotSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DotSimplify",
  ButtonNote->"DotSimplify"],
 "."
}], "Text",
 CellTags->"DotPower"]
}, Open  ]],

Cell["DotProduct", "ObjectName",
 CellTags->"DotProduct"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DotProduct"],

Cell["\<\
DotProduct[x, y] denotes the three-dimensional dot-product. If x and y have \
Head List, DotProduct[x, a] (where a is a vector) performs Sum[ x[[k]] \
a[[k]], {k, 0, 3}].\
\>", "Text",
 CellTags->"DotProduct"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["CrossProduct",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CrossProduct",
  ButtonNote->"CrossProduct"],
 ", ",
 ButtonBox["ThreeVector",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ThreeVector",
  ButtonNote->"ThreeVector"],
 "."
}], "Text",
 CellTags->"DotProduct"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DotProduct"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotProduct", "[", 
  RowBox[{
   RowBox[{"ThreeVector", "[", "a", "]"}], ",", 
   RowBox[{"3", 
    RowBox[{"ThreeVector", "[", "b", "]"}]}]}], "]"}]], "Input",
 CellTags->"DotProduct",
 CellLabel->"In[493]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"3", " ", 
   RowBox[{
    FormBox[
     OverscriptBox["a", "\[RightVector]"],
     TraditionalForm], "\[CenterDot]", 
    FormBox[
     OverscriptBox["b", "\[RightVector]"],
     TraditionalForm]}]}], TraditionalForm]], "Output",
 CellTags->"DotProduct",
 CellLabel->"Out[493]="]
}, Open  ]]
}, Open  ]],

Cell["DotSimplifyRelations", "ObjectName",
 CellTags->"DotSimplifyRelations"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DotSimplifyRelations"],

Cell["\<\
DotSimplifyRelations is an option for DotSimplify. Its setting may be a list \
of substitution rules of the form DotSimplifyRelations \[Rule] {a . b \[Rule] \
c, b^2 \[Rule] 0, ...}.\
\>", "Text",
 CellTags->"DotSimplifyRelations"],

Cell[TextData[{
 "See also: ",
 ButtonBox["DotSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DotSimplify",
  ButtonNote->"DotSimplify"],
 "."
}], "Text",
 CellTags->"DotSimplifyRelations"]
}, Open  ]],

Cell["DotSimplify", "ObjectName",
 CellTags->"DotSimplify"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DotSimplify"],

Cell["\<\
DotSimplify[expr] expands and reorders noncommutative terms in expr. \
Simplifying relations may be specified by the option DotSimplifyRelations or \
by Commutator and AntiCommutator definitions. Whether expr is expanded \
noncommutatively depends on the option Expanding.\
\>", "Text",
 CellTags->"DotSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "DotSimplify", "]"}]], "Input",
 CellTags->"DotSimplify",
 CellLabel->"In[494]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Expanding", "\[Rule]", "True"}], ",", 
    RowBox[{"DotSimplifyRelations", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"DotPower", "\[Rule]", "False"}], ",", 
    RowBox[{"FeynCalcInternal", "\[Rule]", "True"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"DotSimplify",
 CellLabel->"Out[494]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["AntiCommutator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"AntiCommutator",
  ButtonNote->"AntiCommutator"],
 ", ",
 ButtonBox["Commutator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Commutator",
  ButtonNote->"Commutator"],
 ", ",
 ButtonBox["Calc",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Calc",
  ButtonNote->"Calc"],
 "."
}], "Text",
 CellTags->"DotSimplify"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DotSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{
   RowBox[{"GA", "[", "\[Mu]", "]"}], ".", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"GS", "[", "p", "]"}]}], "-", 
     RowBox[{"GS", "[", "q", "]"}]}], ")"}], ".", 
   RowBox[{"GA", "[", "\[Nu]", "]"}]}]}]], "Input",
 CellTags->"DotSimplify",
 CellLabel->"In[495]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"\[Gamma]", "\[CenterDot]", "p"}]}], "-", 
     RowBox[{"\[Gamma]", "\[CenterDot]", "q"}]}], ")"}], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"]}], TraditionalForm]], "Output",
 CellTags->"DotSimplify",
 CellLabel->"Out[495]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotSimplify", "[", "t1", "]"}]], "Input",
 CellTags->"DotSimplify",
 CellLabel->"In[496]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], ".", 
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}], ")"}], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], ".", 
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}], ")"}], ".", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"DotSimplify",
 CellLabel->"Out[496]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"DeclareNonCommutative", "[", 
  RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "Input",
 CellTags->"DotSimplify",
 CellLabel->"In[497]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", "=", 
  RowBox[{"a", ".", 
   RowBox[{"(", 
    RowBox[{"b", "-", 
     RowBox[{"z", " ", "c"}]}], ")"}], ".", "a"}]}]], "Input",
 CellTags->"DotSimplify",
 CellLabel->"In[498]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"a", ".", 
   RowBox[{"(", 
    RowBox[{"b", "-", 
     RowBox[{"c", " ", "z"}]}], ")"}], ".", "a"}], TraditionalForm]], "Output",\

 CellTags->"DotSimplify",
 CellLabel->"Out[498]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotSimplify", "[", "t2", "]"}]], "Input",
 CellTags->"DotSimplify",
 CellLabel->"In[499]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"a", ".", "b", ".", "a"}], "-", 
   RowBox[{"z", " ", 
    RowBox[{"a", ".", "c", ".", "a"}]}]}], TraditionalForm]], "Output",
 CellTags->"DotSimplify",
 CellLabel->"Out[499]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Commutator", "[", 
   RowBox[{"a", ",", "c"}], "]"}], "=", "1"}]], "Input",
 CellTags->"DotSimplify",
 CellLabel->"In[500]:="],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellTags->"DotSimplify",
 CellLabel->"Out[500]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotSimplify", "[", "t2", "]"}]], "Input",
 CellTags->"DotSimplify",
 CellLabel->"In[501]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"a", ".", "b", ".", "a"}], "-", 
   RowBox[{"z", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c", ".", "a", ".", "a"}], "+", "a"}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"DotSimplify",
 CellLabel->"Out[501]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Commutator", "[", 
   RowBox[{"a", ",", "c"}], "]"}], "=", "."}]], "Input",
 CellTags->"DotSimplify",
 CellLabel->"In[502]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotSimplify", "[", "t2", "]"}]], "Input",
 CellTags->"DotSimplify",
 CellLabel->"In[503]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"a", ".", "b", ".", "a"}], "-", 
   RowBox[{"z", " ", 
    RowBox[{"a", ".", "c", ".", "a"}]}]}], TraditionalForm]], "Output",
 CellTags->"DotSimplify",
 CellLabel->"Out[503]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"AntiCommutator", "[", 
   RowBox[{"b", ",", "a"}], "]"}], "=", "c"}]], "Input",
 CellTags->"DotSimplify",
 CellLabel->"In[504]:="],

Cell[BoxData[
 FormBox["c", TraditionalForm]], "Output",
 CellTags->"DotSimplify",
 CellLabel->"Out[504]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotSimplify", "[", "t2", "]"}]], "Input",
 CellTags->"DotSimplify",
 CellLabel->"In[505]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"a", ".", "a", ".", "b"}]}], "-", 
   RowBox[{"z", " ", 
    RowBox[{"a", ".", "c", ".", "a"}]}], "+", 
   RowBox[{"a", ".", "c"}]}], TraditionalForm]], "Output",
 CellTags->"DotSimplify",
 CellLabel->"Out[505]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"AntiCommutator", "[", 
   RowBox[{"b", ",", "a"}], "]"}], "=", "."}]], "Input",
 CellTags->"DotSimplify",
 CellLabel->"In[506]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotSimplify", "[", 
  RowBox[{"t2", ",", 
   RowBox[{"DotSimplifyRelations", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", ".", "c"}], "\[Rule]", 
      RowBox[{"1", "/", "z"}]}], "}"}]}]}], "]"}]], "Input",
 CellTags->"DotSimplify",
 CellLabel->"In[507]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"a", ".", "b", ".", "a"}], "-", "a"}], TraditionalForm]], "Output",\

 CellTags->"DotSimplify",
 CellLabel->"Out[507]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"DeclareNonCommutative", "[", "x", "]"}]], "Input",
 CellTags->"DotSimplify",
 CellLabel->"In[508]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotSimplify", "[", 
  RowBox[{"x", ".", "x", ".", "x"}], "]"}]], "Input",
 CellTags->"DotSimplify",
 CellLabel->"In[509]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"x", ".", "x", ".", "x"}], TraditionalForm]], "Output",
 CellTags->"DotSimplify",
 CellLabel->"Out[509]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DotSimplify", "[", 
  RowBox[{
   RowBox[{"x", ".", "x", ".", "x"}], ",", 
   RowBox[{"DotPower", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"DotSimplify",
 CellLabel->"In[510]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"x", ".", "x", ".", "x"}], TraditionalForm]], "Output",
 CellTags->"DotSimplify",
 CellLabel->"Out[510]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"UnDeclareNonCommutative", "[", 
  RowBox[{"a", ",", "b", ",", "c", ",", "x"}], "]"}]], "Input",
 CellTags->"DotSimplify",
 CellLabel->"In[511]:="]
}, Open  ]],

Cell["DummyIndex", "ObjectName",
 CellTags->"DummyIndex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DummyIndex"],

Cell["\<\
DummyIndex is an option of CovariantD specifying an index to use as dummy \
summation index. If set to Automatic, unique indices are generated\
\>", "Text",
 CellTags->"DummyIndex"],

Cell[TextData[{
 "See also: ",
 ButtonBox["CovariantD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CovariantD",
  ButtonNote->"CovariantD"],
 "."
}], "Text",
 CellTags->"DummyIndex"]
}, Open  ]],

Cell["D0", "ObjectName",
 CellTags->"D0"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"D0"],

Cell[TextData[{
 "D0[ p10, p12, p23, p30, p20, p13, m1^2, m2^2, m3^2, m4^2 ] is the \
Passarino-Veltman ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["D", "0"], TraditionalForm]]],
 " function. The convention for the arguments is that if the denominator of \
the integrand has the form ([q^2-m1^2] [(q+p1)^2-m2^2] [(q+p2)^2-m3^2] \
[(q+p3)^2-m4^2] ), the first six arguments of D0 are the scalar products p10 \
= p1^2, p12 = (p1-p2)^2, p23 = (p2-p3)^2, p30 = p3^2, p20 = p2^2, p13 = \
(p1-p3)^2."
}], "Text",
 CellTags->"D0"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["B0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B0",
  ButtonNote->"B0"],
 ", ",
 ButtonBox["C0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"C0",
  ButtonNote->"C0"],
 ", ",
 ButtonBox["PaVe",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVe",
  ButtonNote->"PaVe"],
 ", ",
 ButtonBox["PaVeOrder",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVeOrder",
  ButtonNote->"PaVeOrder"],
 "."
}], "Text",
 CellTags->"D0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"D0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D0", "[", 
  RowBox[{
  "p10", ",", "p12", ",", "p23", ",", "p30", ",", "p20", ",", "p13", ",", 
   RowBox[{"m1", "^", "2"}], ",", 
   RowBox[{"m2", "^", "2"}], ",", 
   RowBox[{"m3", "^", "2"}], ",", 
   RowBox[{"m4", "^", "2"}]}], "]"}]], "Input",
 CellTags->"D0",
 CellLabel->"In[512]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    SubscriptBox["\<\"D\"\>", "\<\"0\"\>"],
    TraditionalForm], "(", "p10", ",", "p12", ",", "p23", ",", "p30", ",", 
   "p20", ",", "p13", ",", 
   FormBox[
    SuperscriptBox["m1", "2"],
    TraditionalForm], ",", 
   FormBox[
    SuperscriptBox["m2", "2"],
    TraditionalForm], ",", 
   FormBox[
    SuperscriptBox["m3", "2"],
    TraditionalForm], ",", 
   FormBox[
    SuperscriptBox["m4", "2"],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"D0",
 CellLabel->"Out[512]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PaVeOrder", "[", 
  RowBox[{
   RowBox[{"D0", "[", 
    RowBox[{
    "p10", ",", "p12", ",", "p23", ",", "p30", ",", "p20", ",", "p13", ",", 
     RowBox[{"m1", "^", "2"}], ",", 
     RowBox[{"m2", "^", "2"}], ",", 
     RowBox[{"m3", "^", "2"}], ",", 
     RowBox[{"m4", "^", "2"}]}], "]"}], ",", 
   RowBox[{"PaVeOrderList", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"p13", ",", "p20"}], "}"}]}]}], "]"}]], "Input",
 CellTags->"D0",
 CellLabel->"In[513]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    SubscriptBox["\<\"D\"\>", "\<\"0\"\>"],
    TraditionalForm], "(", "p10", ",", "p30", ",", "p23", ",", "p12", ",", 
   "p13", ",", "p20", ",", 
   FormBox[
    SuperscriptBox["m2", "2"],
    TraditionalForm], ",", 
   FormBox[
    SuperscriptBox["m1", "2"],
    TraditionalForm], ",", 
   FormBox[
    SuperscriptBox["m4", "2"],
    TraditionalForm], ",", 
   FormBox[
    SuperscriptBox["m3", "2"],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"D0",
 CellLabel->"Out[513]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PaVeOrder", "[", "%", "]"}]], "Input",
 CellTags->"D0",
 CellLabel->"In[514]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    SubscriptBox["\<\"D\"\>", "\<\"0\"\>"],
    TraditionalForm], "(", "p10", ",", "p12", ",", "p23", ",", "p30", ",", 
   "p20", ",", "p13", ",", 
   FormBox[
    SuperscriptBox["m1", "2"],
    TraditionalForm], ",", 
   FormBox[
    SuperscriptBox["m2", "2"],
    TraditionalForm], ",", 
   FormBox[
    SuperscriptBox["m3", "2"],
    TraditionalForm], ",", 
   FormBox[
    SuperscriptBox["m4", "2"],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"D0",
 CellLabel->"Out[514]="]
}, Open  ]]
}, Open  ]],

Cell["D0Convention", "ObjectName",
 CellTags->"D0Convention"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"D0Convention"],

Cell["\<\
D0Convention is an option for Write2. If set to 1, the convention for the \
arguments of D0 is changed when writing a Fortran file with Write2: The fifth \
and sixth argument of D0 are interchanged and the square root is taken of the \
last four arguments.\
\>", "Text",
 CellTags->"D0Convention"],

Cell[TextData[{
 "See also: ",
 ButtonBox["D0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"D0",
  ButtonNote->"D0"],
 ", ",
 ButtonBox["Write2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Write2",
  ButtonNote->"Write2"],
 "."
}], "Text",
 CellTags->"D0Convention"]
}, Open  ]],

Cell["Eps", "ObjectName",
 CellTags->"Eps"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Eps"],

Cell[TextData[{
 "Eps[a, b, c, d] is the head of the totally antisymmetric ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", "\[Epsilon]"}], TraditionalForm]]],
 " (Levi-Civita) tensor. The a,b, ... may have head LorentzIndex, Momentum or \
Integer. In case of integers the Levi-Civita tensor is evaluated immediately. "
}], "Text",
 CellTags->"Eps"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Eps", "]"}]], "Input",
 CellTags->"Eps",
 CellLabel->"In[515]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"Dimension", "\[Rule]", "4"}], "}"}], TraditionalForm]], "Output",
 CellTags->"Eps",
 CellLabel->"Out[515]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["EpsEvaluate",
  BaseStyle->"AddOnsLink",
  ButtonData:>"EpsEvaluate",
  ButtonNote->"EpsEvaluate"],
 ", ",
 ButtonBox["LC",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LC",
  ButtonNote->"LC"],
 ", ",
 ButtonBox["LCD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LCD",
  ButtonNote->"LCD"],
 ", ",
 ButtonBox["LeviCivita",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LeviCivita",
  ButtonNote->"LeviCivita"],
 "."
}], "Text",
 CellTags->"Eps"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Eps"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eps", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], ",", 
   RowBox[{"LorentzIndex", "[", "\[Rho]", "]"}], ",", 
   RowBox[{"LorentzIndex", "[", "\[Sigma]", "]"}]}], "]"}]], "Input",
 CellTags->"Eps",
 CellLabel->"In[516]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Rho]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Sigma]",
      TraditionalForm],
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"Eps",
 CellLabel->"Out[516]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eps", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", "p", "]"}], ",", 
   RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], ",", 
   RowBox[{"LorentzIndex", "[", "\[Rho]", "]"}], ",", 
   RowBox[{"LorentzIndex", "[", "\[Sigma]", "]"}]}], "]"}]], "Input",
 CellTags->"Eps",
 CellLabel->"In[517]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{
    FormBox["p",
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Rho]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Sigma]",
      TraditionalForm],
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"Eps",
 CellLabel->"Out[517]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Eps", "[", 
   RowBox[{"b", ",", "a", ",", "c", ",", "d"}], "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"Eps",
 CellLabel->"In[518]:="],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"Eps", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]}]], "Output",
 CellTags->"Eps",
 CellLabel->"Out[518]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eps", "[", 
  RowBox[{"0", ",", "1", ",", "2", ",", "3"}], "]"}]], "Input",
 CellTags->"Eps",
 CellLabel->"In[519]:="],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellTags->"Eps",
 CellLabel->"Out[519]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eps", "[", 
  RowBox[{"1", ",", "0", ",", "2", ",", "3"}], "]"}]], "Input",
 CellTags->"Eps",
 CellLabel->"In[520]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", "1"}], TraditionalForm]], "Output",
 CellTags->"Eps",
 CellLabel->"Out[520]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Eps", ",", 
    RowBox[{"Dimension", "\[Rule]", "4"}]}], "]"}], ";"}]], "Input",
 CellTags->"Eps",
 CellLabel->"In[521]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1", " ", "=", 
  RowBox[{"Eps", "[", 
   RowBox[{
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Nu]", ",", "D"}], "]"}], ",", 
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Rho]", ",", "D"}], "]"}], ",", 
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Sigma]", ",", "D"}], "]"}]}], "]"}]}]], "Input",
 CellTags->"Eps",
 CellLabel->"In[522]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Rho]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Sigma]",
      TraditionalForm],
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"Eps",
 CellLabel->"Out[522]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", "a1a1", "]"}]], "Input",
 CellTags->"Eps",
 CellLabel->"In[523]:="],

Cell[BoxData[
 FormBox["a1a1", TraditionalForm]], "Output",
 CellTags->"Eps",
 CellLabel->"Out[523]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Eps", ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], ";"}]], "Input",
 CellTags->"Eps",
 CellLabel->"In[524]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2", " ", "=", 
  RowBox[{"Eps", "[", 
   RowBox[{
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Nu]", ",", "D"}], "]"}], ",", 
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Rho]", ",", "D"}], "]"}], ",", 
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Sigma]", ",", "D"}], "]"}]}], "]"}]}]], "Input",
 CellTags->"Eps",
 CellLabel->"In[525]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Rho]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Sigma]",
      TraditionalForm],
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"Eps",
 CellLabel->"Out[525]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Contract", "[", "a2a2", "]"}], "//", "Factor2"}]], "Input",
 CellTags->"Eps",
 CellLabel->"In[526]:="],

Cell[BoxData[
 FormBox["a2a2", TraditionalForm]], "Output",
 CellTags->"Eps",
 CellLabel->"Out[526]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"LCD", "[", 
    RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Alpha]"}], "]"}], 
   ".", 
   RowBox[{"GAD", "[", 
    RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Alpha]"}], 
    "]"}]}]}]], "Input",
 CellLabel->"In[527]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Epsilon]", 
    RowBox[{"\[Mu]", "\[Nu]", "\[Rho]", "\[Alpha]"}]], ".", 
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Rho]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Alpha]"]}], TraditionalForm]], "Output",
 CellLabel->"Out[527]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "FCI"}]], "Input",
 CellLabel->"In[528]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Epsilon]", 
    RowBox[{
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Alpha]",
       TraditionalForm],
      TraditionalForm]}]], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Rho]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Alpha]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellLabel->"Out[528]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g5", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["\[ImaginaryI]", "24"]}], 
    RowBox[{
     RowBox[{"LCD", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Alpha]"}], "]"}], 
     ".", 
     RowBox[{"GAD", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Alpha]"}], 
      "]"}]}]}], "//", "FCI"}]}]], "Input",
 CellTags->"Eps",
 CellLabel->"In[529]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "24"]}], " ", "\[ImaginaryI]", " ", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Alpha]",
        TraditionalForm],
       TraditionalForm]}]], ".", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], ".", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], ".", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm]], ".", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Alpha]",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"Eps",
 CellLabel->"Out[529]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g5p", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["\[ImaginaryI]", "24"]}], " ", 
    RowBox[{
     RowBox[{"LCD", "[", 
      RowBox[{
       SuperscriptBox["\[Mu]", "\[Prime]",
        MultilineFunction->None], ",", 
       SuperscriptBox["\[Nu]", "\[Prime]",
        MultilineFunction->None], ",", 
       SuperscriptBox["\[Rho]", "\[Prime]",
        MultilineFunction->None], ",", 
       SuperscriptBox["\[Alpha]", "\[Prime]",
        MultilineFunction->None]}], "]"}], ".", 
     RowBox[{"GAD", "[", 
      RowBox[{
       SuperscriptBox["\[Mu]", "\[Prime]",
        MultilineFunction->None], ",", 
       SuperscriptBox["\[Nu]", "\[Prime]",
        MultilineFunction->None], ",", 
       SuperscriptBox["\[Rho]", "\[Prime]",
        MultilineFunction->None], ",", 
       SuperscriptBox["\[Alpha]", "\[Prime]",
        MultilineFunction->None]}], "]"}]}]}], "//", "FCI"}]}]], "Input",
 CellTags->"Eps",
 CellLabel->"In[530]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "24"]}], " ", "\[ImaginaryI]", " ", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox[
        SuperscriptBox["\[Mu]", "\[Prime]",
         MultilineFunction->None],
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox[
        SuperscriptBox["\[Nu]", "\[Prime]",
         MultilineFunction->None],
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox[
        SuperscriptBox["\[Rho]", "\[Prime]",
         MultilineFunction->None],
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox[
        SuperscriptBox["\[Alpha]", "\[Prime]",
         MultilineFunction->None],
        TraditionalForm],
       TraditionalForm]}]], ".", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox[
       SuperscriptBox["\[Mu]", "\[Prime]",
        MultilineFunction->None],
       TraditionalForm],
      TraditionalForm]], ".", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox[
       SuperscriptBox["\[Nu]", "\[Prime]",
        MultilineFunction->None],
       TraditionalForm],
      TraditionalForm]], ".", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox[
       SuperscriptBox["\[Rho]", "\[Prime]",
        MultilineFunction->None],
       TraditionalForm],
      TraditionalForm]], ".", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox[
       SuperscriptBox["\[Alpha]", "\[Prime]",
        MultilineFunction->None],
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"Eps",
 CellLabel->"Out[530]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g52", "=", 
  RowBox[{"Factor2", "[", 
   RowBox[{"Calc", "[", 
    RowBox[{"g5", ".", "g5p"}], "]"}], "]"}]}]], "Input",
 CellTags->"Eps",
 CellLabel->"In[531]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "24"]}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", "D"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"2", "-", "D"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"3", "-", "D"}], ")"}], " ", "D"}], TraditionalForm]], "Output",
 CellTags->"Eps",
 CellLabel->"Out[531]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g52", "/.", 
  RowBox[{"D", "\[Rule]", "4"}]}]], "Input",
 CellTags->"Eps",
 CellLabel->"In[532]:="],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellTags->"Eps",
 CellLabel->"Out[532]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"a1", ",", "a2", ",", "g5", ",", "g5p", ",", "g52"}], 
  "]"}]], "Input",
 CellTags->"Eps",
 CellLabel->"In[533]:="]
}, Open  ]],

Cell["EpsChisholm", "ObjectName",
 CellTags->"EpsChisholm"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"EpsChisholm"],

Cell["\<\
EpsChisholm[expr] substitutes for a gamma matrix contracted with a \
Levi-Civita tensor (Eps) the Chisholm identity.\
\>", "Text",
 CellTags->"EpsChisholm"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Chisholm",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Chisholm",
  ButtonNote->"Chisholm"],
 "."
}], "Text",
 CellTags->"EpsChisholm"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"EpsChisholm"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Chisholm", "[", 
  RowBox[{"GA", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], "]"}], 
  "]"}]], "Input",
 CellTags->"EpsChisholm",
 CellLabel->"In[534]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["$MU$5067",
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", "5"]}], " ", 
     SuperscriptBox["\[Epsilon]", 
      RowBox[{
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["$MU$5067",
         TraditionalForm],
        TraditionalForm]}]]}]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]]}], "-", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Rho]"}]]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], ".", 
     SuperscriptBox["\[Gamma]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Rho]"}]]}]}], TraditionalForm]], "Output",
 CellTags->"EpsChisholm",
 CellLabel->"Out[534]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EpsChisholm", "[", "%", "]"}]], "Input",
 CellTags->"EpsChisholm",
 CellLabel->"In[535]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Rho]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Sigma]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"EpsChisholm",
 CellLabel->"Out[535]="]
}, Open  ]]
}, Open  ]],

Cell["EpsContract", "ObjectName",
 CellTags->"EpsContract"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"EpsContract"],

Cell["\<\
EpsContract is an option of Contract specifying whether Levi-Civita tensors \
Eps[...] will be contracted, i.e., products of two  Eps are replaced via the \
determinant formula.\
\>", "Text",
 CellTags->"EpsContract"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Eps",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Eps",
  ButtonNote->"Eps"],
 ", ",
 ButtonBox["Contract",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Contract",
  ButtonNote->"Contract"],
 "."
}], "Text",
 CellTags->"EpsContract"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"EpsContract"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1", " ", "=", 
  RowBox[{"Eps", "[", 
   RowBox[{
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Nu]", ",", "D"}], "]"}], ",", 
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Rho]", ",", "D"}], "]"}], ",", 
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Sigma]", ",", "D"}], "]"}]}], "]"}]}]], "Input",
 CellTags->"EpsContract",
 CellLabel->"In[536]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Rho]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Sigma]",
      TraditionalForm],
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"EpsContract",
 CellLabel->"Out[536]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", 
  RowBox[{
   RowBox[{"a1", " ", "a1"}], ",", 
   RowBox[{"EpsContract", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"EpsContract",
 CellLabel->"In[537]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   RowBox[{"(", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]}]], ")"}], "2"], TraditionalForm]], "Output",
 CellTags->"EpsContract",
 CellLabel->"Out[537]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", 
  RowBox[{
   RowBox[{"a1", " ", "a1"}], ",", 
   RowBox[{"EpsContract", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"EpsContract",
 CellLabel->"In[538]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["D", "4"]}], "+", 
   RowBox[{"6", " ", 
    SuperscriptBox["D", "3"]}], "-", 
   RowBox[{"11", " ", 
    SuperscriptBox["D", "2"]}], "+", 
   RowBox[{"6", " ", "D"}]}], TraditionalForm]], "Output",
 CellTags->"EpsContract",
 CellLabel->"Out[538]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "a1", "]"}]], "Input",
 CellLabel->"In[539]:="]
}, Open  ]],

Cell["EpsDiscard", "ObjectName",
 CellTags->"EpsDiscard"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"EpsDiscard"],

Cell["\<\
EpsDiscard is an option for FeynCalc2FORM. If set to True all Levi-Civita \
tensors are replaced by 0 after contraction.\
\>", "Text",
 CellTags->"EpsDiscard"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynCalc2FORM",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalc2FORM",
  ButtonNote->"FeynCalc2FORM"],
 "."
}], "Text",
 CellTags->"EpsDiscard"]
}, Open  ]],

Cell["EpsEvaluate", "ObjectName",
 CellTags->"EpsEvaluate"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"EpsEvaluate"],

Cell["\<\
EpsEvaluate[expr] applies total antisymmetry and linearity (w.r.t. \
Momentum's) to all Levi-Civita tensors (Eps') in expr.\
\>", "Text",
 CellTags->"EpsEvaluate"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Contract",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Contract",
  ButtonNote->"Contract"],
 ", ",
 ButtonBox["Eps",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Eps",
  ButtonNote->"Eps"],
 ", ",
 ButtonBox["LeviCivita",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LeviCivita",
  ButtonNote->"LeviCivita"],
 ", ",
 ButtonBox["Trick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Trick",
  ButtonNote->"Trick"],
 "."
}], "Text",
 CellTags->"EpsEvaluate"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"EpsEvaluate"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Trick", "[", 
  RowBox[{
   RowBox[{"LeviCivita", "[", 
    RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], "]"}], 
   " ", 
   RowBox[{"FourVector", "[", 
    RowBox[{
     RowBox[{"p", "+", "q"}], ",", "\[Sigma]"}], "]"}]}], "]"}]], "Input",
 CellTags->"EpsEvaluate",
 CellLabel->"In[540]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Rho]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     RowBox[{"p", "+", "q"}],
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"EpsEvaluate",
 CellLabel->"Out[540]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EpsEvaluate", "[", "%", "]"}]], "Input",
 CellTags->"EpsEvaluate",
 CellLabel->"In[541]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Rho]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     RowBox[{"p", "+", "q"}],
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"EpsEvaluate",
 CellLabel->"Out[541]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
 CellTags->"EpsEvaluate",
 CellLabel->"In[542]:="],

Cell[BoxData[
 RowBox[{"Eps", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Nu]", ",", "D"}], "]"}], ",", 
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Rho]", ",", "D"}], "]"}], ",", 
   RowBox[{"Momentum", "[", 
    RowBox[{"p", "+", "q"}], "]"}]}], "]"}]], "Output",
 CellTags->"EpsEvaluate",
 CellLabel->"Out[542]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["EpsUncontract", "ObjectName",
 CellTags->"EpsUncontract"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"EpsUncontract"],

Cell["\<\
EpsUncontract does Uncontract on scalar products involving Eps.\
\>", "Text",
 CellTags->"EpsUncontract"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Eps",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Eps",
  ButtonNote->"Eps"],
 ", ",
 ButtonBox["Uncontract",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Uncontract",
  ButtonNote->"Uncontract"],
 "."
}], "Text",
 CellTags->"EpsUncontract"]
}, Open  ]],

Cell["Epsilon", "ObjectName",
 CellTags->"Epsilon"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Epsilon"],

Cell[TextData[{
 "Epsilon is (",
 StyleBox["n",
  FontSlant->"Italic"],
 "-4), where ",
 StyleBox["n",
  FontSlant->"Italic"],
 " is the space-time dimension. Epsilon stands for a small positive number."
}], "Text",
 CellTags->"Epsilon"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Series2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Series2",
  ButtonNote->"Series2"],
 "."
}], "Text",
 CellTags->"Epsilon"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Epsilon"],

Cell[CellGroupData[{

Cell[BoxData["Epsilon"], "Input",
 CellTags->"Epsilon",
 CellLabel->"In[543]:="],

Cell[BoxData[
 FormBox[
  TagBox["\[CurlyEpsilon]",
   TraditionalForm], TraditionalForm]], "Output",
 CellTags->"Epsilon",
 CellLabel->"Out[543]="]
}, Open  ]],

Cell["\<\
Epsilon has no functional properties, but some upvalues are changed:\
\>", "Text",
 CellTags->"Epsilon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Re", "[", "Epsilon", "]"}], " ", ">", " ", 
    RowBox[{"-", "4"}]}], ",", 
   RowBox[{
    RowBox[{"Re", "[", "Epsilon", "]"}], " ", ">", " ", 
    RowBox[{"-", "3"}]}], ",", 
   RowBox[{
    RowBox[{"Re", "[", "Epsilon", "]"}], " ", ">", " ", 
    RowBox[{"-", "2"}]}], ",", 
   RowBox[{
    RowBox[{"Re", "[", "Epsilon", "]"}], " ", ">", " ", 
    RowBox[{"-", "1"}]}], ",", 
   RowBox[{
    RowBox[{"Re", "[", "Epsilon", "]"}], " ", ">", " ", "0"}]}], 
  "}"}]], "Input",
 CellTags->"Epsilon",
 CellLabel->"In[544]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"True", ",", "True", ",", "True", ",", "True", ",", "True"}], 
   "}"}], TraditionalForm]], "Output",
 CellTags->"Epsilon",
 CellLabel->"Out[544]="]
}, Open  ]]
}, Open  ]],

Cell["EpsilonOrder", "ObjectName",
 CellTags->"EpsilonOrder"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"EpsilonOrder"],

Cell[TextData[{
 "EpsilonOrder is an option of OPEIntDelta and RHI. The setting determines \
the order ",
 "n",
 " (",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["Epsilon", 
    StyleBox["n",
     FontSlant->"Plain"]], TraditionalForm]]],
 ") which should be kept."
}], "Text",
 CellTags->"EpsilonOrder"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OPEIntDelta",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OPEIntDelta",
  ButtonNote->"OPEIntDelta"],
 ", ",
 ButtonBox["RHI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RHI",
  ButtonNote->"RHI"],
 "."
}], "Text",
 CellTags->"EpsilonOrder"]
}, Open  ]],

Cell["Expanding", "ObjectName",
 CellTags->"Expanding"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Expanding"],

Cell["\<\
Expanding is an option for Calc, Contract, DiracSimplify,DotSimplify, \
SUNSimplify, etc. As option for Contract it specifies whether expansion \
w.r.t. LorentzIndex is done BEFORE contraction. If set to False in \
DiracSimplify or SUNSimplify, only a limited set of simplifications \
(multiplicative linearity etc.) is performed.\
\>", "Text",
 CellTags->"Expanding"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Calc",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Calc",
  ButtonNote->"Calc"],
 ", ",
 ButtonBox["Contract",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Contract",
  ButtonNote->"Contract"],
 ", ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 ", ",
 ButtonBox["DotSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DotSimplify",
  ButtonNote->"DotSimplify"],
 ", ",
 ButtonBox["SUNSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNSimplify",
  ButtonNote->"SUNSimplify"],
 "."
}], "Text",
 CellTags->"Expanding"]
}, Open  ]],

Cell["ExpandPartialD", "ObjectName",
 CellTags->"ExpandPartialD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ExpandPartialD"],

Cell["\<\
ExpandPartialD[exp] expands all products of QuantumField's and partial \
differentiation operators in exp and applies the Leibniz rule.\
\>", "Text",
 CellTags->"ExpandPartialD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "ExpandPartialD", "]"}]], "Input",
 CellLabel->"In[545]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"PartialDRelations", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a$___", ".", 
       RowBox[{"\[PartialD]", "/", "\[PartialD]", 
        SuperscriptBox[
         FormBox["x$_",
          TraditionalForm], 
         FormBox[
          FormBox["mu$_",
           TraditionalForm],
          TraditionalForm]]}], ".", "b$___"}], "\[RuleDelayed]", 
      RowBox[{"a$", ".", 
       RowBox[{
        SubscriptBox[
         TagBox[
          StyleBox["\<\"\[PartialD]\"\>",
           FontSlant->"Italic"],
          StyleForm[#, FontSlant -> "Italic"]& ], 
         TagBox[
          FormBox[
           FormBox["mu$",
            TraditionalForm],
           TraditionalForm],
          TraditionalForm,
          Editable->True]], "(", 
        TagBox[
         FormBox[
          RowBox[{"Dot", "[", "b$", "]"}],
          TraditionalForm],
         TraditionalForm,
         Editable->True], ")"}]}]}], "}"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellLabel->"Out[545]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 ButtonBox["ExplicitPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExplicitPartialD",
  ButtonNote->"ExplicitPartialD"],
 ", ",
 ButtonBox["LeftPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LeftPartialD",
  ButtonNote->"LeftPartialD"],
 ", ",
 ButtonBox["LeftRightPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LeftRightPartialD",
  ButtonNote->"LeftRightPartialD"],
 ", ",
 ButtonBox["PartialDRelations",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PartialDRelations",
  ButtonNote->"PartialDRelations"],
 ", ",
 ButtonBox["RightPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RightPartialD",
  ButtonNote->"RightPartialD"],
 "."
}], "Text",
 CellTags->"ExpandPartialD"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ExpandPartialD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RightPartialD", "[", "\[Mu]", "]"}], ".", 
  RowBox[{"QuantumField", "[", 
   RowBox[{"A", ",", 
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}], ".", 
  RowBox[{"QuantumField", "[", 
   RowBox[{"A", ",", 
    RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], "]"}]}]], "Input",
 CellTags->"ExpandPartialD",
 CellLabel->"In[546]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[RightArrow]"], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SubscriptBox["A", "\[Mu]"], ".", 
   SubscriptBox["A", "\[Nu]"]}], TraditionalForm]], "Output",
 CellTags->"ExpandPartialD",
 CellLabel->"Out[546]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
 CellTags->"ExpandPartialD",
 CellLabel->"In[547]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["A", "\[Mu]"], ".", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], "\[Null]"]}]}], "+", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], "\[Null]"]}], ".", 
    SubscriptBox["A", "\[Nu]"]}]}], TraditionalForm]], "Output",
 CellTags->"ExpandPartialD",
 CellLabel->"Out[547]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"ExpandPartialD",
 CellLabel->"In[548]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"QuantumField", "[", 
    RowBox[{"A", ",", 
     RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}], ".", 
   RowBox[{"QuantumField", "[", 
    RowBox[{
     RowBox[{"PartialD", "[", 
      RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ",", "A", ",", 
     RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"QuantumField", "[", 
    RowBox[{
     RowBox[{"PartialD", "[", 
      RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ",", "A", ",", 
     RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}], ".", 
   RowBox[{"QuantumField", "[", 
    RowBox[{"A", ",", 
     RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], "]"}]}]}]], "Output",
 CellTags->"ExpandPartialD",
 CellLabel->"Out[548]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LeftRightPartialD", "[", "\[Mu]", "]"}], ".", 
  RowBox[{"QuantumField", "[", 
   RowBox[{"A", ",", 
    RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], "]"}]}]], "Input",
 CellTags->"ExpandPartialD",
 CellLabel->"In[549]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SubscriptBox["A", "\[Nu]"]}], TraditionalForm]], "Output",
 CellTags->"ExpandPartialD",
 CellLabel->"Out[549]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
 CellTags->"ExpandPartialD",
 CellLabel->"In[550]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm], "\[Null]"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], ".", 
      SubscriptBox["A", "\[Nu]"]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"ExpandPartialD",
 CellLabel->"Out[550]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"QuantumField", "[", 
   RowBox[{"A", ",", 
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}], ".", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"LeftRightPartialD", "[", "OPEDelta", "]"}], "^", "2"}], ")"}], 
  ".", 
  RowBox[{"QuantumField", "[", 
   RowBox[{"A", ",", 
    RowBox[{"LorentzIndex", "[", "\[Rho]", "]"}]}], "]"}]}]], "Input",
 CellTags->"ExpandPartialD",
 CellLabel->"In[551]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["A", "\[Mu]"], ".", 
   SubsuperscriptBox[
    OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
    FormBox["\[CapitalDelta]",
     TraditionalForm], "2"], ".", 
   SubscriptBox["A", "\[Rho]"]}], TraditionalForm]], "Output",
 CellTags->"ExpandPartialD",
 CellLabel->"Out[551]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
 CellTags->"ExpandPartialD",
 CellLabel->"In[552]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["A", "\[Mu]"], ".", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["\[PartialD]", 
           FormBox["\[CapitalDelta]",
            TraditionalForm]],
          TraditionalForm], 
         FormBox[
          SubscriptBox["\[PartialD]", 
           FormBox["\[CapitalDelta]",
            TraditionalForm]],
          TraditionalForm]}], 
        SubsuperscriptBox["A", 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], "\[Null]"]}], ")"}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", 
         FormBox["\[CapitalDelta]",
          TraditionalForm]], 
        SubsuperscriptBox["A", 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], "\[Null]"]}], ".", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         FormBox["\[CapitalDelta]",
          TraditionalForm]], 
        SubsuperscriptBox["A", 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], "\[Null]"]}]}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["\[PartialD]", 
           FormBox["\[CapitalDelta]",
            TraditionalForm]],
          TraditionalForm], 
         FormBox[
          SubscriptBox["\[PartialD]", 
           FormBox["\[CapitalDelta]",
            TraditionalForm]],
          TraditionalForm]}], 
        SubsuperscriptBox["A", 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], "\[Null]"]}], ")"}], ".", 
      SubscriptBox["A", "\[Rho]"]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"ExpandPartialD",
 CellLabel->"Out[552]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"8", " ", 
  RowBox[{
   RowBox[{"LeftRightPartialD", "[", "OPEDelta", "]"}], "^", "3"}]}]], "Input",\

 CellTags->"ExpandPartialD",
 CellLabel->"In[553]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"8", " ", 
   SubsuperscriptBox[
    OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
    FormBox["\[CapitalDelta]",
     TraditionalForm], "3"]}], TraditionalForm]], "Output",
 CellTags->"ExpandPartialD",
 CellLabel->"Out[553]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExplicitPartialD", "[", "%", "]"}]], "Input",
 CellTags->"ExpandPartialD",
 CellLabel->"In[554]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[RightArrow]"], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]], "-", 
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]]}], ")"}], "3"], TraditionalForm]], "Output",
 CellTags->"ExpandPartialD",
 CellLabel->"Out[554]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
 CellTags->"ExpandPartialD",
 CellLabel->"In[555]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]], ".", 
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]], ".", 
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]]}]}], "+", 
   RowBox[{"3", " ", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]], ".", 
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]], ".", 
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[RightArrow]"], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]]}]}], "-", 
   RowBox[{"3", " ", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]], ".", 
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[RightArrow]"], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]], ".", 
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[RightArrow]"], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]]}]}], "+", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["\[PartialD]", "\[RightArrow]"], 
     FormBox["\[CapitalDelta]",
      TraditionalForm]], ".", 
    SubscriptBox[
     OverscriptBox["\[PartialD]", "\[RightArrow]"], 
     FormBox["\[CapitalDelta]",
      TraditionalForm]], ".", 
    SubscriptBox[
     OverscriptBox["\[PartialD]", "\[RightArrow]"], 
     FormBox["\[CapitalDelta]",
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"ExpandPartialD",
 CellLabel->"Out[555]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LeviCivita", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Tau]"}], "]"}], " ", 
  
  RowBox[{"RightPartialD", "[", 
   RowBox[{"\[Alpha]", ",", "\[Mu]", ",", "\[Beta]", ",", "\[Nu]"}], 
   "]"}]}]], "Input",
 CellTags->"ExpandPartialD",
 CellLabel->"In[556]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Epsilon]", 
    RowBox[{
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Tau]",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["\[PartialD]", "\[RightArrow]"], 
     FormBox[
      FormBox["\[Alpha]",
       TraditionalForm],
      TraditionalForm]], ".", 
    SubscriptBox[
     OverscriptBox["\[PartialD]", "\[RightArrow]"], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], ".", 
    SubscriptBox[
     OverscriptBox["\[PartialD]", "\[RightArrow]"], 
     FormBox[
      FormBox["\[Beta]",
       TraditionalForm],
      TraditionalForm]], ".", 
    SubscriptBox[
     OverscriptBox["\[PartialD]", "\[RightArrow]"], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"ExpandPartialD",
 CellLabel->"Out[556]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
 CellTags->"ExpandPartialD",
 CellLabel->"In[557]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"ExpandPartialD",
 CellLabel->"Out[557]="]
}, Open  ]]
}, Open  ]],

Cell["ExpandScalarProduct, ScalarProductExpand", "ObjectName",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],

Cell["\<\
ExpandScalarProduct[expr] expands scalar products of sums of momenta in expr. \
ExpandScalarProduct does not use Expand on expr.
ScalarProductExpand=ExpandScalarProduct.\
\>", "Text",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandScalarProduct", "//", "Options"}]], "Input",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"},
 CellLabel->"In[558]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"FeynCalcInternal", "\[Rule]", "True"}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"},
 CellLabel->"Out[558]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Calc",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Calc",
  ButtonNote->"Calc"],
 ", ",
 ButtonBox["MomentumExpand",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MomentumExpand",
  ButtonNote->"MomentumExpand"],
 ", ",
 ButtonBox["MomentumCombine",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MomentumCombine",
  ButtonNote->"MomentumCombine"],
 "."
}], "Text",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"SP", "[", 
   RowBox[{
    RowBox[{"p1", "+", "p2", "+", "p3"}], ",", 
    RowBox[{"p4", "+", "p5", "+", "p6"}]}], "]"}]}]], "Input",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"},
 CellLabel->"In[559]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"(", 
   FormBox[
    RowBox[{"p1", "+", "p2", "+", "p3"}],
    TraditionalForm], ")", "\[CenterDot]", "(", 
   FormBox[
    RowBox[{"p4", "+", "p5", "+", "p6"}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"},
 CellLabel->"Out[559]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "ScalarProductExpand"}]], "Input",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"},
 CellLabel->"In[560]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FormBox["p1",
     TraditionalForm], "\[CenterDot]", 
    FormBox["p4",
     TraditionalForm]}], "+", 
   RowBox[{
    FormBox["p1",
     TraditionalForm], "\[CenterDot]", 
    FormBox["p5",
     TraditionalForm]}], "+", 
   RowBox[{
    FormBox["p1",
     TraditionalForm], "\[CenterDot]", 
    FormBox["p6",
     TraditionalForm]}], "+", 
   RowBox[{
    FormBox["p2",
     TraditionalForm], "\[CenterDot]", 
    FormBox["p4",
     TraditionalForm]}], "+", 
   RowBox[{
    FormBox["p2",
     TraditionalForm], "\[CenterDot]", 
    FormBox["p5",
     TraditionalForm]}], "+", 
   RowBox[{
    FormBox["p2",
     TraditionalForm], "\[CenterDot]", 
    FormBox["p6",
     TraditionalForm]}], "+", 
   RowBox[{
    FormBox["p3",
     TraditionalForm], "\[CenterDot]", 
    FormBox["p4",
     TraditionalForm]}], "+", 
   RowBox[{
    FormBox["p3",
     TraditionalForm], "\[CenterDot]", 
    FormBox["p5",
     TraditionalForm]}], "+", 
   RowBox[{
    FormBox["p3",
     TraditionalForm], "\[CenterDot]", 
    FormBox["p6",
     TraditionalForm]}]}], TraditionalForm]], "Output",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"},
 CellLabel->"Out[560]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SP", "[", 
  RowBox[{"p", ",", 
   RowBox[{"p", "-", "q"}]}], "]"}]], "Input",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"},
 CellLabel->"In[561]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["p",
    TraditionalForm], "\[CenterDot]", "(", 
   FormBox[
    RowBox[{"p", "-", "q"}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"},
 CellLabel->"Out[561]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandScalarProduct", "[", "%", "]"}]], "Input",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"},
 CellLabel->"In[562]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], "2"], "-", 
   RowBox[{
    FormBox["p",
     TraditionalForm], "\[CenterDot]", 
    FormBox["q",
     TraditionalForm]}]}], TraditionalForm]], "Output",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"},
 CellLabel->"Out[562]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FV", "[", 
  RowBox[{
   RowBox[{"p", "-", "q"}], ",", "\[Mu]"}], "]"}]], "Input",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"},
 CellLabel->"In[563]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   FormBox[
    RowBox[{"p", "-", "q"}],
    TraditionalForm], "\[Mu]"], TraditionalForm]], "Output",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"},
 CellLabel->"Out[563]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandScalarProduct", "[", "%", "]"}]], "Input",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"},
 CellLabel->"In[564]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], "-", 
   SuperscriptBox[
    FormBox["q",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"},
 CellLabel->"Out[564]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SP", "[", 
   RowBox[{
    RowBox[{"p", "-", "q"}], ",", 
    RowBox[{"q", "-", "r"}]}], "]"}], "//", "FCI"}]], "Input",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"},
 CellLabel->"In[565]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"(", 
   FormBox[
    RowBox[{"p", "-", "q"}],
    TraditionalForm], ")", "\[CenterDot]", "(", 
   FormBox[
    RowBox[{"q", "-", "r"}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"},
 CellLabel->"Out[565]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"Pair", "\[Rule]", "ExpandScalarProduct"}]}]], "Input",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"},
 CellLabel->"In[566]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FormBox["p",
     TraditionalForm], "\[CenterDot]", 
    FormBox["q",
     TraditionalForm]}], "-", 
   RowBox[{
    FormBox["p",
     TraditionalForm], "\[CenterDot]", 
    FormBox["r",
     TraditionalForm]}], "+", 
   RowBox[{
    FormBox["q",
     TraditionalForm], "\[CenterDot]", 
    FormBox["r",
     TraditionalForm]}], "-", 
   SuperscriptBox[
    FormBox["q",
     TraditionalForm], "2"]}], TraditionalForm]], "Output",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"},
 CellLabel->"Out[566]="]
}, Open  ]]
}, Open  ]],

Cell["Expand2", "ObjectName",
 CellTags->"Expand2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Expand2"],

Cell["\<\
Expand2[exp, x] expands all sums containing x. Expand2[exp, {x1, x2, ...}]  \
expands all sums containing x1, x2, ....\
\>", "Text",
 CellTags->"Expand2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Expand2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x1", "+", "x2", "+", "x3"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "x1"}], "+", 
       RowBox[{"3", "x2"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"y1", "+", "y2", "+", "y3"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "y1"}], "+", 
       RowBox[{"3", "y2"}]}], ")"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x1", ",", "x2"}], "}"}]}], "]"}]], "Input",
 CellTags->"Expand2",
 CellLabel->"In[567]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["x1", "2"]}], "+", 
   RowBox[{"5", " ", "x1", " ", "x2"}], "+", 
   RowBox[{"2", " ", "x1", " ", "x3"}], "+", 
   RowBox[{"3", " ", 
    SuperscriptBox["x2", "2"]}], "+", 
   RowBox[{"3", " ", "x2", " ", "x3"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "y1"}], "+", 
      RowBox[{"3", " ", "y2"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"y1", "+", "y2", "+", "y3"}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"Expand2",
 CellLabel->"Out[567]="]
}, Open  ]]
}, Open  ]],

Cell["Explicit", "ObjectName",
 CellTags->"Explicit"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Explicit"],

Cell[TextData[{
 "Explicit is an option for FieldStrength, GluonVertex, SUNF, and \
Twist2GluonOperator. If set to True the full form of the operator is \
inserted. ",
 StyleBox["Explicit[exp]",
  FontVariations->{"CompatibilityType"->0}],
 " inserts explicit expressions of GluonVertex, Twist2GluonOperator, etc., in \
exp. SUNF's are replaced by SUNTrace objects."
}], "Text",
 CellTags->"Explicit"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["GluonVertex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonVertex",
  ButtonNote->"GluonVertex"],
 ", ",
 ButtonBox["Twist2GluonOperator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Twist2GluonOperator",
  ButtonNote->"Twist2GluonOperator"],
 "."
}], "Text",
 CellTags->"Explicit"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Explicit", "//", "Options"}]], "Input",
 CellLabel->"In[568]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Gauge", "\[Rule]", "1"}], ",", 
    RowBox[{"\[CapitalOmega]", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellLabel->"Out[568]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Explicit"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GluonPropagator", "[", 
  RowBox[{"p", ",", "\[Mu]", ",", "\[Nu]"}], "]"}]], "Input",
 CellLabel->"In[569]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubsuperscriptBox["\[CapitalPi]", "g", 
    RowBox[{"\[Mu]", "\[Nu]"}]], "(", "p", ")"}], TraditionalForm]], "Output",\

 CellLabel->"Out[569]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Explicit", "[", "%", "]"}]], "Input",
 CellLabel->"In[570]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"\[Mu]", "\[Nu]"}]]}], 
    SuperscriptBox["p", "2"]]}], TraditionalForm]], "Output",
 CellLabel->"Out[570]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Explicit", "[", 
  RowBox[{
   RowBox[{"GluonPropagator", "[", 
    RowBox[{"p", ",", "\[Mu]", ",", "\[Nu]"}], "]"}], ",", 
   RowBox[{"Gauge", "\[Rule]", "\[Xi]"}]}], "]"}]], "Input",
 CellLabel->"In[571]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Xi]"}], ")"}], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox["p", "2"]], "-", 
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]]}], ")"}]}], 
   SuperscriptBox["p", "2"]], TraditionalForm]], "Output",
 CellLabel->"Out[571]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GluonVertex", "[", 
  RowBox[{
  "p", ",", "\[Mu]", ",", "a", ",", " ", "q", ",", "\[Nu]", ",", "b", ",", 
   "r", ",", "\[Rho]", ",", "c"}], "]"}]], "Input",
 CellTags->"Explicit",
 CellLabel->"In[572]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{
    SuperscriptBox["V", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm]}]], "(", 
    RowBox[{
     FormBox["p",
      TraditionalForm], 
     RowBox[{",", " "}], 
     FormBox["q",
      TraditionalForm], 
     RowBox[{",", " "}], 
     FormBox["r",
      TraditionalForm]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Explicit",
 CellLabel->"Out[572]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Explicit", "[", "%", "]"}]], "Input",
 CellTags->"Explicit",
 CellLabel->"In[573]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["g", "s"], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm]], "-", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         FormBox["r",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]], "-", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]], "-", 
        SuperscriptBox[
         FormBox["r",
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 CellTags->"Explicit",
 CellLabel->"Out[573]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b"}], 
  "]"}]], "Input",
 CellTags->"Explicit",
 CellLabel->"In[574]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     FormBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "m"],
      TraditionalForm], "+", "1"}], ")"}], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["O", 
      RowBox[{
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm], "\[VeryThinSpace]", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]}], "G2"], "(", 
     FormBox["p",
      TraditionalForm], ")"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Explicit",
 CellLabel->"Out[574]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Explicit", "[", "%", "]"}]], "Input",
 CellTags->"Explicit",
 CellLabel->"In[575]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     FormBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "m"],
      TraditionalForm], "+", "1"}], ")"}], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   FormBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}], ")"}], 
     RowBox[{"m", "-", "2"}]],
    TraditionalForm], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
      SuperscriptBox[
       FormBox[
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["p",
          TraditionalForm]}],
        TraditionalForm], "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        RowBox[{
         SuperscriptBox[
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"Explicit",
 CellLabel->"Out[575]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FieldStrength", "[", 
  RowBox[{"\[Mu]", ",", "\[Nu]", ",", "a"}], "]"}]], "Input",
 CellTags->"Explicit",
 CellLabel->"In[576]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox["F", 
   RowBox[{"\[Mu]", "\[Nu]"}], "a"], TraditionalForm]], "Output",
 CellTags->"Explicit",
 CellLabel->"Out[576]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Explicit", "[", "%", "]"}]], "Input",
 CellTags->"Explicit",
 CellLabel->"In[577]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["g", "s"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b26",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c27",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b26",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c27",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    SubscriptBox["\[PartialD]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], 
    SubsuperscriptBox[
     FormBox["A",
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    SubscriptBox["\[PartialD]", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], 
    SubsuperscriptBox[
     FormBox["A",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"Explicit",
 CellLabel->"Out[577]="]
}, Open  ]]
}, Open  ]],

Cell["ExplicitLorentzIndex", "ObjectName",
 CellTags->"ExplicitLorentzIndex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ExplicitLorentzIndex"],

Cell["\<\
ExplicitLorentzIndex[ind] is an explicit Lorentz index, i.e., ind is an \
integer.\
\>", "Text",
 CellTags->"ExplicitLorentzIndex"],

Cell[TextData[{
 "See also: ",
 ButtonBox["LorentzIndex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LorentzIndex",
  ButtonNote->"LorentzIndex"],
 ", ",
 ButtonBox["Pair",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Pair",
  ButtonNote->"Pair"],
 "."
}], "Text",
 CellTags->"ExplicitLorentzIndex"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ExplicitLorentzIndex"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", "1", "]"}], ",", 
   RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}]], "Input",
 CellTags->"ExplicitLorentzIndex",
 CellLabel->"In[578]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["g", 
   RowBox[{
    FormBox["1",
     TraditionalForm], "\[Mu]"}]], TraditionalForm]], "Output",
 CellTags->"ExplicitLorentzIndex",
 CellLabel->"Out[578]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"ExplicitLorentzIndex",
 CellLabel->"In[579]:="],

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"ExplicitLorentzIndex", "[", "1", "]"}], ",", 
   RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}]], "Output",
 CellTags->"ExplicitLorentzIndex",
 CellLabel->"Out[579]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["ExplicitPartialD", "ObjectName",
 CellTags->"ExplicitPartialD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ExplicitPartialD"],

Cell["\<\
ExplicitPartialD[exp] inserts in exp the definition for LeftRightPartialD[z] \
(and LeftRightPartialD2[z]).\
\>", "Text",
 CellTags->"ExplicitPartialD"],

Cell[TextData[{
 "See also: ",
 ButtonBox["ExpandPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExpandPartialD",
  ButtonNote->"ExpandPartialD"],
 ", ",
 ButtonBox["LeftRightPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LeftRightPartialD",
  ButtonNote->"LeftRightPartialD"],
 ", ",
 ButtonBox["LeftRightPartialD2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LeftRightPartialD2",
  ButtonNote->"LeftRightPartialD2"],
 "."
}], "Text",
 CellTags->"ExplicitPartialD"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ExplicitPartialD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExplicitPartialD", "[", " ", 
  RowBox[{"LeftRightPartialD", "[", "\[Mu]", "]"}], " ", "]"}]], "Input",
 CellTags->"ExplicitPartialD",
 CellLabel->"In[580]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[RightArrow]"], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], "-", 
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"ExplicitPartialD",
 CellLabel->"Out[580]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExplicitPartialD", "[", " ", 
  RowBox[{"LeftRightPartialD2", "[", "\[Mu]", "]"}], " ", "]"}]], "Input",
 CellTags->"ExplicitPartialD",
 CellLabel->"In[581]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], "+", 
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[RightArrow]"], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"ExplicitPartialD",
 CellLabel->"Out[581]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExplicitPartialD", "[", " ", 
  RowBox[{"LeftRightPartialD", "[", "OPEDelta", "]"}], " ", "]"}]], "Input",
 CellTags->"ExplicitPartialD",
 CellLabel->"In[582]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[RightArrow]"], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]], "-", 
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"ExplicitPartialD",
 CellLabel->"Out[582]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"16", " ", 
  RowBox[{
   RowBox[{"LeftRightPartialD", "[", "OPEDelta", "]"}], "^", "4"}]}]], "Input",\

 CellTags->"ExplicitPartialD",
 CellLabel->"In[583]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"16", " ", 
   SubsuperscriptBox[
    OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
    FormBox["\[CapitalDelta]",
     TraditionalForm], "4"]}], TraditionalForm]], "Output",
 CellTags->"ExplicitPartialD",
 CellLabel->"Out[583]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExplicitPartialD", "[", "%", "]"}]], "Input",
 CellTags->"ExplicitPartialD",
 CellLabel->"In[584]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[RightArrow]"], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]], "-", 
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]]}], ")"}], "4"], TraditionalForm]], "Output",
 CellTags->"ExplicitPartialD",
 CellLabel->"Out[584]="]
}, Open  ]]
}, Open  ]],

Cell["ExplicitSUNIndex", "ObjectName",
 CellTags->"ExplicitSUNIndex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ExplicitSUNIndex"],

Cell[TextData[{
 "ExplicitSUNIndex[ind] is a specific SU(",
 StyleBox["N",
  FontSlant->"Italic"],
 ") index, i.e., ind is an integer."
}], "Text",
 CellTags->"ExplicitSUNIndex"],

Cell[TextData[{
 "See also: ",
 ButtonBox["FCI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCI",
  ButtonNote->"FCI"],
 ", ",
 ButtonBox["SUNDelta",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNDelta",
  ButtonNote->"SUNDelta"],
 ", ",
 ButtonBox["SUNF",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNF",
  ButtonNote->"SUNF"],
 ", ",
 ButtonBox["SUNIndex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNIndex",
  ButtonNote->"SUNIndex"],
 "."
}], "Text",
 CellTags->"ExplicitSUNIndex"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ExplicitSUNIndex"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExplicitSUNIndex", "[", "1", "]"}]], "Input",
 CellTags->"ExplicitSUNIndex",
 CellLabel->"In[585]:="],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellTags->"ExplicitSUNIndex",
 CellLabel->"Out[585]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SUNDelta", "[", 
    RowBox[{"1", ",", "a"}], "]"}], "//", "FCI"}], "//", 
  "StandardForm"}]], "Input",
 CellLabel->"In[586]:="],

Cell[BoxData[
 RowBox[{"SUNDelta", "[", 
  RowBox[{
   RowBox[{"ExplicitSUNIndex", "[", "1", "]"}], ",", 
   RowBox[{"SUNIndex", "[", "a", "]"}]}], "]"}]], "Output",
 CellLabel->"Out[586]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["ExtraFactor", "ObjectName",
 CellTags->"ExtraFactor"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ExtraFactor"],

Cell["\<\
ExtraFactor is an option for FermionSpinSum. The setting ExtraFactor \[Rule] \
fa  multiplies the whole amplitude with the factor fa before squaring.\
\>", "Text",
 CellTags->"ExtraFactor"],

Cell[TextData[{
 "See also: ",
 ButtonBox["FermionSpinSum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FermionSpinSum",
  ButtonNote->"FermionSpinSum"],
 "."
}], "Text",
 CellTags->"ExtraFactor"]
}, Open  ]],

Cell["ExtraVariables", "ObjectName",
 CellTags->"ExtraVariables"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ExtraVariables"],

Cell["\<\
ExtraVariables is an option for OneLoopSum; it may be set to a list of \
variables which are also bracketed out in the result, just like B0, C0, D0 \
and  PaVe.\
\>", "Text",
 CellTags->"ExtraVariables"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OneLoop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoop",
  ButtonNote->"OneLoop"],
 ", ",
 ButtonBox["OneLoopSum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoopSum",
  ButtonNote->"OneLoopSum"],
 "."
}], "Text",
 CellTags->"ExtraVariables"]
}, Open  ]],

Cell["FactorFull", "ObjectName",
 CellTags->"FactorFull"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FactorFull"],

Cell[TextData[{
 "FactorFull is an option of Factor2 (default False). If set to False, \
products like (",
 StyleBox["a",
  FontSlant->"Italic"],
 "-",
 StyleBox["b",
  FontSlant->"Italic"],
 ") (",
 StyleBox["a",
  FontSlant->"Italic"],
 "+",
 StyleBox["b",
  FontSlant->"Italic"],
 ") will be replaced by (",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["a", "2"], TraditionalForm]]],
 "-",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["b", "2"], TraditionalForm]]],
 ")."
}], "Text",
 CellTags->"FactorFull"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Factor2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Factor2",
  ButtonNote->"Factor2"],
 "."
}], "Text",
 CellTags->"FactorFull"]
}, Open  ]],

Cell["Factoring", "ObjectName",
 CellTags->"Factoring"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Factoring"],

Cell["\<\
Factoring is an option for Collect2, Contract, Tr and more functions. If set \
to True, the result will be factored, using Factor2. If set to any function \
f, this function will be used.\
\>", "Text",
 CellTags->"Factoring"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Collect2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Collect2",
  ButtonNote->"Collect2"],
 ", ",
 ButtonBox["Contract",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Contract",
  ButtonNote->"Contract"],
 ", ",
 ButtonBox["Tr",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Tr",
  ButtonNote->"Tr"],
 "."
}], "Text",
 CellTags->"Factoring"]
}, Open  ]],

Cell["Factorout", "ObjectName",
 CellTags->"Factorout"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Factorout"],

Cell["Factorout is an option for OPEInt.", "Text",
 CellTags->"Factorout"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OPEInt",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OPEInt",
  ButtonNote->"OPEInt"],
 "."
}], "Text",
 CellTags->"Factorout"]
}, Open  ]],

Cell["FactorTime", "ObjectName",
 CellTags->"FactorTime"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FactorTime"],

Cell["\<\
FactorTime is an option for Factor2. It denotes the maximum time (in seconds) \
during which Factor2 tries to factor.\
\>", "Text",
 CellTags->"FactorTime"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Factor2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Factor2",
  ButtonNote->"Factor2"],
 "."
}], "Text",
 CellTags->"FactorTime"]
}, Open  ]],

Cell["Factor1", "ObjectName",
 CellTags->"Factor1"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Factor1"],

Cell["\<\
Factor1[poly] factorizes common terms  in the summands of poly. It uses \
basically PolynomialGCD.\
\>", "Text",
 CellTags->"Factor1"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Factor2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Factor2",
  ButtonNote->"Factor2"],
 "."
}], "Text",
 CellTags->"Factor1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Factor1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"a", "-", "x"}], ")"}], 
   RowBox[{"(", 
    RowBox[{"b", "-", "x"}], ")"}]}]}]], "Input",
 CellTags->"Factor1",
 CellLabel->"In[587]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"a", "-", "x"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"b", "-", "x"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Factor1",
 CellLabel->"Out[587]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Factor1", "[", "t1", "]"}], ",", " ", 
    RowBox[{"Factor", "[", "t1", "]"}]}], "}"}]}]], "Input",
 CellTags->"Factor1",
 CellLabel->"In[588]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "x"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"b", "-", "x"}], ")"}]}], ",", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"a", "-", "x"}], ")"}]}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", "b"}], ")"}]}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"Factor1",
 CellLabel->"Out[588]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t3", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "-", "b"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"a", "+", "b"}], ")"}]}], "]"}]}]], "Input",
 CellTags->"Factor1",
 CellLabel->"In[589]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["a", "2"], "-", 
   SuperscriptBox["b", "2"]}], TraditionalForm]], "Output",
 CellTags->"Factor1",
 CellLabel->"Out[589]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor", "[", "t3", "]"}]], "Input",
 CellTags->"Factor1",
 CellLabel->"In[590]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"a", "-", "b"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"a", "+", "b"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Factor1",
 CellLabel->"Out[590]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor1", "[", "t3", "]"}]], "Input",
 CellTags->"Factor1",
 CellLabel->"In[591]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["a", "2"], "-", 
   SuperscriptBox["b", "2"]}], TraditionalForm]], "Output",
 CellTags->"Factor1",
 CellLabel->"Out[591]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"t1", ",", "t2", ",", "t3"}], "]"}]], "Input",
 CellTags->"Factor1",
 CellLabel->"In[592]:="]
}, Open  ]],

Cell["Factor2", "ObjectName",
 CellTags->"Factor2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Factor2"],

Cell["\<\
Factor2[poly] factors a polynomial in a standard way. Factor2 works sometimes \
better than Factor on polynomials involving rationals with sums in the \
denominator. Factor2 uses Factor internally and is in general slower than \
Factor. There are four possible settings of the option Method (0,1,2,3). In \
general Factor will work faster than Factor2.\
\>", "Text",
 CellTags->"Factor2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Factor2", "]"}]], "Input",
 CellTags->"Factor2",
 CellLabel->"In[593]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"FactorFull", "\[Rule]", "False"}], ",", 
    RowBox[{"Method", "\[Rule]", "3"}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"Factor2",
 CellLabel->"Out[593]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Collect2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Collect2",
  ButtonNote->"Collect2"],
 "."
}], "Text",
 CellTags->"Factor2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Factor2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"a", "-", "x"}], ")"}], 
   RowBox[{"(", 
    RowBox[{"b", "-", "x"}], ")"}]}]}]], "Input",
 CellTags->"Factor2",
 CellLabel->"In[594]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"a", "-", "x"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"b", "-", "x"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Factor2",
 CellLabel->"Out[594]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Factor2", "[", "t1", "]"}], ",", " ", 
    RowBox[{"Factor", "[", "t1", "]"}]}], "}"}]}]], "Input",
 CellTags->"Factor2",
 CellLabel->"In[595]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "x"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"b", "-", "x"}], ")"}]}], ",", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"a", "-", "x"}], ")"}]}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", "b"}], ")"}]}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"Factor2",
 CellLabel->"Out[595]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t3", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "-", "b"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"a", "+", "b"}], ")"}]}], "]"}]}]], "Input",
 CellTags->"Factor2",
 CellLabel->"In[596]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["a", "2"], "-", 
   SuperscriptBox["b", "2"]}], TraditionalForm]], "Output",
 CellTags->"Factor2",
 CellLabel->"Out[596]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor", "[", "t3", "]"}]], "Input",
 CellTags->"Factor2",
 CellLabel->"In[597]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"a", "-", "b"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"a", "+", "b"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Factor2",
 CellLabel->"Out[597]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor2", "[", "t3", "]"}]], "Input",
 CellTags->"Factor2",
 CellLabel->"In[598]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["a", "2"], "-", 
   SuperscriptBox["b", "2"]}], TraditionalForm]], "Output",
 CellTags->"Factor2",
 CellLabel->"Out[598]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor2", "[", 
  RowBox[{"t3", ",", 
   RowBox[{"FactorFull", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"Factor2",
 CellLabel->"In[599]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"a", "-", "b"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"a", "+", "b"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Factor2",
 CellLabel->"Out[599]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"t1", ",", "t2", ",", "t3"}], "]"}]], "Input",
 CellTags->"Factor2",
 CellLabel->"In[600]:="]
}, Open  ]],

Cell["FAD", "ObjectName",
 CellTags->"FAD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FAD"],

Cell["\<\
FAD is the FeynCalc external form of FeynAmpDenominator and denotes an \
inverse propagator. FAD[q, q-p, ...] is 1/(q^2 (q-p)^2 ...). FAD[{q1,m}, \
{q1-p,m}, q2, ...] is 1/( (q1^2 - m^2) ( (q1-p)^2 - m^2 ) q2^2 ... ). \
Translation into FeynCalc internal form is performed by FeynCalcInternal.\
\>", "Text",
 CellTags->"FAD"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FAD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FAD",
  ButtonNote->"FAD"],
 ", ",
 ButtonBox["FCE",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCE",
  ButtonNote->"FCE"],
 ", ",
 ButtonBox["FCI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCI",
  ButtonNote->"FCI"],
 ", ",
 ButtonBox["FeynAmpDenominator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynAmpDenominator",
  ButtonNote->"FeynAmpDenominator"],
 ", ",
 ButtonBox["FeynAmpDenominatorSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynAmpDenominatorSimplify",
  ButtonNote->"FeynAmpDenominatorSimplify"],
 ", ",
 ButtonBox["PropagatorDenominator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PropagatorDenominator",
  ButtonNote->"PropagatorDenominator"],
 "."
}], "Text",
 CellTags->"FAD"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FAD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FAD", "[", 
  RowBox[{"q", ",", 
   RowBox[{"p", "-", "q"}]}], "]"}]], "Input",
 CellTags->"FAD",
 CellLabel->"In[601]:="],

Cell[BoxData[
 FormBox[
  FractionBox["1", 
   RowBox[{
    RowBox[{"(", 
     InterpretationBox[
      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
       SuperscriptBox["q", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
      SequenceForm["[", $CellContext`q^2, "]"],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"p", "-", "q"}], ")"}], "2"], 
       "\[InvisibleSpace]", "\<\"]\"\>"}],
      SequenceForm["[", ($CellContext`p - $CellContext`q)^2, "]"],
      Editable->False], ")"}]}]], TraditionalForm]], "Output",
 CellTags->"FAD",
 CellLabel->"Out[601]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FAD", "[", 
  RowBox[{"p", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p", "-", "q"}], ",", "m"}], "}"}]}], "]"}]], "Input",
 CellTags->"FAD",
 CellLabel->"In[602]:="],

Cell[BoxData[
 FormBox[
  FractionBox["1", 
   RowBox[{
    RowBox[{"(", 
     InterpretationBox[
      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
       SuperscriptBox["p", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
      SequenceForm["[", $CellContext`p^2, "]"],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"p", "-", "q"}], ")"}], "2"], 
       "\[InvisibleSpace]", "\<\"-\"\>", "\[InvisibleSpace]", 
       SuperscriptBox["m", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
      SequenceForm[
      "[", ($CellContext`p - $CellContext`q)^2, "-", $CellContext`m^2, "]"],
      Editable->False], ")"}]}]], TraditionalForm]], "Output",
 CellTags->"FAD",
 CellLabel->"Out[602]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"FAD", "[", 
     RowBox[{"q", ",", 
      RowBox[{"p", "-", "q"}]}], "]"}], "//", "FCI"}], "//", "FCE"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"FAD",
 CellLabel->"In[603]:="],

Cell[BoxData[
 RowBox[{"FAD", "[", 
  RowBox[{
   RowBox[{"p", "-", "q"}], ",", "q"}], "]"}]], "Output",
 CellTags->"FAD",
 CellLabel->"Out[603]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FAD", "[", 
    RowBox[{"q", ",", 
     RowBox[{"p", "-", "q"}]}], "]"}], "//", "FCI"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"FAD",
 CellLabel->"In[604]:="],

Cell[BoxData[
 RowBox[{"FeynAmpDenominator", "[", 
  RowBox[{
   RowBox[{"PropagatorDenominator", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Momentum", "[", 
       RowBox[{"p", ",", "D"}], "]"}], "-", 
      RowBox[{"Momentum", "[", 
       RowBox[{"q", ",", "D"}], "]"}]}], ",", "0"}], "]"}], ",", 
   RowBox[{"PropagatorDenominator", "[", 
    RowBox[{
     RowBox[{"Momentum", "[", 
      RowBox[{"q", ",", "D"}], "]"}], ",", "0"}], "]"}]}], "]"}]], "Output",
 CellTags->"FAD",
 CellLabel->"Out[604]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"FAD", "[", "p", "]"}], " ", 
    RowBox[{"FAD", "[", 
     RowBox[{"p", "-", "q"}], "]"}]}], " ", "//", " ", 
   "FeynAmpDenominatorCombine"}], "//", "StandardForm"}]], "Input",
 CellTags->"FAD",
 CellLabel->"In[605]:="],

Cell[BoxData[
 RowBox[{"FeynAmpDenominator", "[", 
  RowBox[{
   RowBox[{"PropagatorDenominator", "[", 
    RowBox[{
     RowBox[{"Momentum", "[", 
      RowBox[{"p", ",", "D"}], "]"}], ",", "0"}], "]"}], ",", 
   RowBox[{"PropagatorDenominator", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Momentum", "[", 
       RowBox[{"p", ",", "D"}], "]"}], "-", 
      RowBox[{"Momentum", "[", 
       RowBox[{"q", ",", "D"}], "]"}]}], ",", "0"}], "]"}]}], "]"}]], "Output",\

 CellTags->"FAD",
 CellLabel->"Out[605]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["FC", "ObjectName",
 CellTags->"FC"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FC"],

Cell["\<\
FC changes the output format to FeynCalcForm. To change to InputForm use FI.\
\>", "Text",
 CellTags->"FC"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynCalcForm",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalcForm",
  ButtonNote->"FeynCalcForm"],
 ", ",
 ButtonBox["FI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FI",
  ButtonNote->"FI"],
 ", ",
 ButtonBox["FeynCalcExternal",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalcExternal",
  ButtonNote->"FeynCalcExternal"],
 ", ",
 ButtonBox["FeynCalcInternal",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalcInternal",
  ButtonNote->"FeynCalcInternal"],
 "."
}], "Text",
 CellTags->"FC"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FC"],

Cell[BoxData["FI"], "Input",
 CellTags->"FC",
 CellLabel->"In[606]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"DiracGamma", "[", "5", "]"}], ",", 
   RowBox[{"DiracGamma", "[", 
    RowBox[{"Momentum", "[", "p", "]"}], "]"}]}], "}"}]], "Input",
 CellTags->"FC",
 CellLabel->"In[607]:="],

Cell["{DiracGamma[5], DiracGamma[Momentum[p]]}", "Output",
 CellTags->"FC",
 CellLabel->"Out[607]="]
}, Open  ]],

Cell[BoxData["FC"], "Input",
 CellTags->"FC",
 CellLabel->"In[608]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"DiracGamma", "[", "5", "]"}], ",", 
   RowBox[{"DiracGamma", "[", 
    RowBox[{"Momentum", "[", "p", "]"}], "]"}]}], "}"}]], "Input",
 CellTags->"FC",
 CellLabel->"In[609]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    SuperscriptBox["\[Gamma]", "5"], ",", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["p",
      TraditionalForm]}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"FC",
 CellLabel->"Out[609]="]
}, Open  ]]
}, Open  ]],

Cell["FCE", "ObjectName",
 CellTags->"FCE"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FCE"],

Cell["\<\
FCE[exp] translates exp from the internal FeynCalc representation to a short \
form.\
\>", "Text",
 CellTags->"FCE"],

Cell["FCE is equivalent to FeynCalcExternal.", "Text",
 CellTags->"FCE"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynCalcExternal",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalcExternal",
  ButtonNote->"FeynCalcExternal"],
 ", ",
 ButtonBox["FCI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCI",
  ButtonNote->"FCI"],
 ", ",
 ButtonBox["FeynCalcInternal",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalcInternal",
  ButtonNote->"FeynCalcInternal"],
 "."
}], "Text",
 CellTags->"FCE"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FCE"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FCE", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"DiracGamma", "[", "5", "]"}], ",", 
    RowBox[{"DiracGamma", "[", 
     RowBox[{"Momentum", "[", "p", "]"}], "]"}]}], "}"}], "]"}]], "Input",
 CellTags->"FCE",
 CellLabel->"In[610]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    SuperscriptBox["\[Gamma]", "5"], ",", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "p"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"FCE",
 CellLabel->"Out[610]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"FCE",
 CellLabel->"In[611]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"GA", "[", "5", "]"}], ",", 
   RowBox[{"GS", "[", "p", "]"}]}], "}"}]], "Output",
 CellTags->"FCE",
 CellLabel->"Out[611]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
   RowBox[{"GS", "[", "p", "]"}], ",", 
   RowBox[{"SP", "[", 
    RowBox[{"p", ",", "q"}], "]"}], ",", 
   RowBox[{"MT", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
   RowBox[{"FV", "[", 
    RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Input",
 CellTags->"FCE",
 CellLabel->"In[612]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    SuperscriptBox["\[Gamma]", "\[Mu]"], ",", 
    SuperscriptBox["\[Gamma]", "\[Rho]"], ",", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], ",", 
    FormBox[
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}],
     TraditionalForm], ",", 
    SuperscriptBox["g", 
     RowBox[{"\[Alpha]", "\[Beta]"}]], ",", 
    SuperscriptBox["p", "\[Mu]"]}], "}"}], TraditionalForm]], "Output",
 CellTags->"FCE",
 CellLabel->"Out[612]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"FCE",
 CellLabel->"In[613]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
   RowBox[{"GS", "[", "p", "]"}], ",", 
   RowBox[{"SP", "[", 
    RowBox[{"p", ",", "q"}], "]"}], ",", 
   RowBox[{"MT", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
   RowBox[{"FV", "[", 
    RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Output",
 CellTags->"FCE",
 CellLabel->"Out[613]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "FCI"}]], "Input",
 CellTags->"FCE",
 CellLabel->"In[614]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], ",", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm]], ",", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["p",
      TraditionalForm]}], ",", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}], ",", 
    SuperscriptBox["g", 
     RowBox[{"\[Alpha]", "\[Beta]"}]], ",", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]]}], "}"}], TraditionalForm]], "Output",
 CellTags->"FCE",
 CellLabel->"Out[614]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"FCE",
 CellLabel->"In[615]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"DiracGamma", "[", 
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ",", 
   RowBox[{"DiracGamma", "[", 
    RowBox[{
     RowBox[{"LorentzIndex", "[", 
      RowBox[{"\[Rho]", ",", "D"}], "]"}], ",", "D"}], "]"}], ",", 
   RowBox[{"DiracGamma", "[", 
    RowBox[{"Momentum", "[", "p", "]"}], "]"}], ",", 
   RowBox[{"Pair", "[", 
    RowBox[{
     RowBox[{"Momentum", "[", "p", "]"}], ",", 
     RowBox[{"Momentum", "[", "q", "]"}]}], "]"}], ",", 
   RowBox[{"Pair", "[", 
    RowBox[{
     RowBox[{"LorentzIndex", "[", "\[Alpha]", "]"}], ",", 
     RowBox[{"LorentzIndex", "[", "\[Beta]", "]"}]}], "]"}], ",", 
   RowBox[{"Pair", "[", 
    RowBox[{
     RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
     RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]}], "}"}]], "Output",
 CellTags->"FCE",
 CellLabel->"Out[615]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FCE", "[", "%", "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"FCE",
 CellLabel->"In[616]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
   RowBox[{"GS", "[", "p", "]"}], ",", 
   RowBox[{"SP", "[", 
    RowBox[{"p", ",", "q"}], "]"}], ",", 
   RowBox[{"MT", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
   RowBox[{"FV", "[", 
    RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Output",
 CellTags->"FCE",
 CellLabel->"Out[616]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["FCI", "ObjectName",
 CellTags->"FCI"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FCI"],

Cell["\<\
FCI[exp] translates exp into the internal FeynCalc \
(datatype-)representation.FCI is equivalent to FeynCalcInternal.\
\>", "Text",
 CellTags->"FCI"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynCalcExternal",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalcExternal",
  ButtonNote->"FeynCalcExternal"],
 ", ",
 ButtonBox["FeynCalcInternal",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalcInternal",
  ButtonNote->"FeynCalcInternal"],
 ", ",
 ButtonBox["FCE",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCE",
  ButtonNote->"FCE"],
 "."
}], "Text",
 CellTags->"FCI"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FCI"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
   RowBox[{"GS", "[", "p", "]"}], ",", 
   RowBox[{"SP", "[", 
    RowBox[{"p", ",", "q"}], "]"}], ",", 
   RowBox[{"MT", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
   RowBox[{"FV", "[", 
    RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Input",
 CellTags->"FCI",
 CellLabel->"In[617]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    SuperscriptBox["\[Gamma]", "\[Mu]"], ",", 
    SuperscriptBox["\[Gamma]", "\[Rho]"], ",", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], ",", 
    FormBox[
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}],
     TraditionalForm], ",", 
    SuperscriptBox["g", 
     RowBox[{"\[Alpha]", "\[Beta]"}]], ",", 
    SuperscriptBox["p", "\[Mu]"]}], "}"}], TraditionalForm]], "Output",
 CellTags->"FCI",
 CellLabel->"Out[617]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"FCI",
 CellLabel->"In[618]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
   RowBox[{"GS", "[", "p", "]"}], ",", 
   RowBox[{"SP", "[", 
    RowBox[{"p", ",", "q"}], "]"}], ",", 
   RowBox[{"MT", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
   RowBox[{"FV", "[", 
    RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Output",
 CellTags->"FCI",
 CellLabel->"Out[618]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "FCI"}]], "Input",
 CellTags->"FCI",
 CellLabel->"In[619]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], ",", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm]], ",", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["p",
      TraditionalForm]}], ",", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}], ",", 
    SuperscriptBox["g", 
     RowBox[{"\[Alpha]", "\[Beta]"}]], ",", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]]}], "}"}], TraditionalForm]], "Output",
 CellTags->"FCI",
 CellLabel->"Out[619]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"FCI",
 CellLabel->"In[620]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"DiracGamma", "[", 
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ",", 
   RowBox[{"DiracGamma", "[", 
    RowBox[{
     RowBox[{"LorentzIndex", "[", 
      RowBox[{"\[Rho]", ",", "D"}], "]"}], ",", "D"}], "]"}], ",", 
   RowBox[{"DiracGamma", "[", 
    RowBox[{"Momentum", "[", "p", "]"}], "]"}], ",", 
   RowBox[{"Pair", "[", 
    RowBox[{
     RowBox[{"Momentum", "[", "p", "]"}], ",", 
     RowBox[{"Momentum", "[", "q", "]"}]}], "]"}], ",", 
   RowBox[{"Pair", "[", 
    RowBox[{
     RowBox[{"LorentzIndex", "[", "\[Alpha]", "]"}], ",", 
     RowBox[{"LorentzIndex", "[", "\[Beta]", "]"}]}], "]"}], ",", 
   RowBox[{"Pair", "[", 
    RowBox[{
     RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
     RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]}], "}"}]], "Output",
 CellTags->"FCI",
 CellLabel->"Out[620]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FCE", "[", "%", "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"FCI",
 CellLabel->"In[621]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
   RowBox[{"GS", "[", "p", "]"}], ",", 
   RowBox[{"SP", "[", 
    RowBox[{"p", ",", "q"}], "]"}], ",", 
   RowBox[{"MT", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
   RowBox[{"FV", "[", 
    RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Output",
 CellTags->"FCI",
 CellLabel->"Out[621]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["FCIntegral", "ObjectName",
 CellTags->"FCIntegral"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FCIntegral"],

Cell["\<\
FCIntegral is the head of integrals in a setting of the option IntegralTable \
of FeynAmpDenominatorSimplify. Currently implemented only for 2-loop \
integrals.\
\>", "Text",
 CellTags->"FCIntegral"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["IntegralTable",
  BaseStyle->"AddOnsLink",
  ButtonData:>"IntegralTable",
  ButtonNote->"IntegralTable"],
 ", ",
 ButtonBox["FeynAmpDenominatorSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynAmpDenominatorSimplify",
  ButtonNote->"FeynAmpDenominatorSimplify"],
 "."
}], "Text",
 CellTags->"FCIntegral"]
}, Open  ]],

Cell["FCIntegrate", "ObjectName",
 CellTags->"FCIntegrate"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FCIntegrate"],

Cell["\<\
FCIntegrate is an option of certain Feynman integral related functions. It \
determines which integration function is used to evaluate analytic integrals. \
Possible settings include Integrate, NIntegrate, (Dot[Integratedx@@#2, #1] &).\
\>", "Text",
 CellTags->"FCIntegrate"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FCNIntegrate",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCNIntegrate",
  ButtonNote->"FCNIntegrate"],
 "."
}], "Text",
 CellTags->"FCIntegrate"]
}, Open  ]],

Cell["FCNIntegrate", "ObjectName",
 CellTags->"FCNIntegrate"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FCNIntegrate"],

Cell["\<\
FCNIntegrate is an option of certain Feynman integral related functions which \
may return output containing both integrals that can be evaluated and \
integrals that can only be evaluated numerically. It then determines which \
integration function is used to evaluate numeric integrals. Possible settings \
include NIntegrate, (0*#1)&, (Dot[Integratedx@@#2, #1] &).\
\>", "Text",
 CellTags->"FCNIntegrate"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FCIntegrate",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCIntegrate",
  ButtonNote->"FCIntegrate"],
 "."
}], "Text",
 CellTags->"FCNIntegrate"]
}, Open  ]],

Cell["FC2RHI ", "ObjectName",
 CellTags->"FC2RHI"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FC2RHI"],

Cell["\<\
FC2RHI[exp, k1, k2] transforms all 2-loop OPE-integrals in FeynAmpDenominator \
form to the RHI-integrals.  FC2RHI[exp] is equivalent to FC2RHI[exp,q1,q2]. \
The option IncludePair governs the inclusion  of scalar products p.k1, p.k2 \
and k1.k2 (setting True).\
\>", "Text",
 CellTags->"FC2RHI"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "FC2RHI", "]"}]], "Input",
 CellTags->"FC2RHI",
 CellLabel->"In[622]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"IncludePair", "\[Rule]", "True"}], ",", 
    RowBox[{"Do", "\[Rule]", "True"}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"FC2RHI",
 CellLabel->"Out[622]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"FAD", "[", 
     RowBox[{"q1", ",", 
      RowBox[{"q1", "-", "q2"}], ",", 
      RowBox[{"q2", "-", "p"}]}], "]"}], " ", 
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"q1", ",", "OPEDelta"}], "]"}], "^", "OPEm"}]}], "//", 
   "FCI"}]}]], "Input",
 CellLabel->"In[623]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FormBox["\[CapitalDelta]",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q1",
       TraditionalForm]}], ")"}], "m"], 
   RowBox[{
    SuperscriptBox["q1", "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q1", "-", "q2"}], ")"}], "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q2", "-", "p"}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellLabel->"Out[623]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FC2RHI", "[", 
  RowBox[{"t", ",", "q1", ",", "q2"}], "]"}]], "Input",
 CellLabel->"In[624]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox[
   StyleBox["T",
    FontFamily->"Times",
    FontWeight->"Bold"], 
   StyleBox[
    RowBox[{"1", "0", "0", "1", "1"}],
    FontColor->RGBColor[0, 0, 1]], 
   RowBox[{
    FormBox["m",
     TraditionalForm], 
    FormBox["0",
     TraditionalForm], 
    FormBox["0",
     TraditionalForm], 
    FormBox["0",
     TraditionalForm], 
    FormBox["0",
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellLabel->"Out[624]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "InputForm"}]], "Input",
 CellLabel->"In[625]:="],

Cell["RHI[{0, 0, OPEm, 0, 0}, {0, 1, 1, 0, 1}]", "Output",
 CellLabel->"Out[625]//InputForm="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["RHI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RHI",
  ButtonNote->"RHI"],
 "."
}], "Text",
 CellTags->"FC2RHI"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FC2RHI"],

Cell[BoxData[""], "Input",
 CellTags->"FC2RHI",
 CellLabel->"In[626]:="]
}, Open  ]],

Cell["FC2TLI ", "ObjectName",
 CellTags->"FC2TLI"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FC2TLI"],

Cell["\<\
FC2TLI[exp, k1, k2] transforms all 2-loop OPE-integrals in FeynAmpDenominator \
form to the TLI-integrals.  The option IncludePair governs the inclusion  of \
scalar products p.k1, p.k2 and k1.k2 (setting True).\
\>", "Text",
 CellTags->"FC2TLI"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "FC2TLI", "]"}]], "Input",
 CellTags->"FC2TLI",
 CellLabel->"In[627]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"IncludePair", "\[Rule]", "True"}], ",", 
    RowBox[{"Do", "\[Rule]", "True"}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"FC2TLI",
 CellLabel->"Out[627]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "FAD"}]], "Input",
 CellLabel->"In[628]:="],

Cell[BoxData[
 StyleBox["\<\"FAD[q, q-p, ...] denotes 1/(q^2 (q-p)^2 ...).\\nFAD[{q1,m}, \
{q1-p,m}, q2, ...] is\\n1/( (q1^2 - m^2) ( (q1-p)^2 - m^2 ) q2^2 ... \
).\\n(Translation into FeynCalc internal form is performed \
by\\nFeynCalcInternal.)\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->"Info3522790263-4590919"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{
   RowBox[{"FAD", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"q1", ",", "m1"}], "}"}], ",", 
     RowBox[{"q2", "-", "q1"}], ",", 
     RowBox[{"q2", "-", "p"}]}], "]"}], " ", 
   RowBox[{
    RowBox[{"SP", "[", 
     RowBox[{"q1", ",", "OPEDelta"}], "]"}], "^", "OPEm"}]}]}]], "Input",
 CellLabel->"In[629]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     FormBox[
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q1",
        TraditionalForm]}],
      TraditionalForm], ")"}], "m"], " ", 
   FormBox[
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"q2", "-", "p"}], ")"}], "2"], 
         "\[InvisibleSpace]", "\<\"]\"\>"}],
        SequenceForm["[", (-$CellContext`p + $CellContext`q2)^2, "]"],
        Editable->False], ")"}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"q2", "-", "q1"}], ")"}], "2"], 
         "\[InvisibleSpace]", "\<\"]\"\>"}],
        SequenceForm["[", (-$CellContext`q1 + $CellContext`q2)^2, "]"],
        Editable->False], ")"}], " ", 
      RowBox[{"(", 
       InterpretationBox[
        RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
         SuperscriptBox["q1", "2"], "\[InvisibleSpace]", "\<\"-\"\>", 
         "\[InvisibleSpace]", 
         SuperscriptBox["m1", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
        SequenceForm["[", $CellContext`q1^2, "-", $CellContext`m1^2, "]"],
        Editable->False], ")"}]}]],
    TraditionalForm]}], TraditionalForm]], "Output",
 CellLabel->"Out[629]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FC2TLI", "[", 
  RowBox[{"t", ",", "q1", ",", "q2"}], "]"}]], "Input",
 CellLabel->"In[630]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox[
   StyleBox["T",
    FontFamily->"Times",
    FontWeight->"Bold"], 
   RowBox[{
    StyleBox["1",
     FontWeight->"Bold",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["0",
     FontColor->RGBColor[0, 0, 1]], 
    StyleBox["0",
     FontColor->RGBColor[0, 0, 1]], 
    StyleBox["1",
     FontColor->RGBColor[0, 0, 1]], 
    StyleBox["1",
     FontColor->RGBColor[0, 0, 1]]}], 
   RowBox[{
    FormBox["m",
     TraditionalForm], 
    FormBox["0",
     TraditionalForm], 
    FormBox["0",
     TraditionalForm], 
    FormBox["0",
     TraditionalForm], 
    FormBox["0",
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellLabel->"Out[630]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "InputForm"}]], "Input",
 CellLabel->"In[631]:="],

Cell["TLI[{OPEm, 0, 0, 0, 0}, {{1, m1}, 0, 0, 1, 1}]", "Output",
 CellLabel->"Out[631]//InputForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TLI2FC", "[", "%", "]"}]], "Input",
 CellLabel->"In[632]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FormBox["\[CapitalDelta]",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q1",
       TraditionalForm]}], ")"}], "m"], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["m1", "2"]}], ")"}], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q1", "-", "q2"}], ")"}], "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q2", "-", "p"}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellLabel->"Out[632]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["TLI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TLI",
  ButtonNote->"TLI"],
 "."
}], "Text",
 CellTags->"FC2TLI"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FC2TLI"],

Cell[BoxData[""], "Input",
 CellTags->"FC2TLI",
 CellLabel->"In[633]:="]
}, Open  ]],

Cell["FDS", "ObjectName",
 CellTags->"FDS"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FDS"],

Cell["FDS is shorthand for FeynAmpDenominatorSimplify.", "Text",
 CellTags->"FDS"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynAmpDenominatorSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynAmpDenominatorSimplify",
  ButtonNote->"FeynAmpDenominatorSimplify"],
 "."
}], "Text",
 CellTags->"FDS"]
}, Open  ]],

Cell["FermionSpinSum", "ObjectName",
 CellTags->"FermionSpinSum"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FermionSpinSum"],

Cell["\<\
FermionSpinSum[x] constructs the Traces out of squared ampliudes.\
\>", "Text",
 CellTags->"FermionSpinSum"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "FermionSpinSum", "]"}]], "Input",
 CellTags->"FermionSpinSum",
 CellLabel->"In[634]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"SpinPolarizationSum", "\[Rule]", "Identity"}], ",", 
    RowBox[{"SpinorCollect", "\[Rule]", "False"}], ",", 
    RowBox[{"ExtraFactor", "\[Rule]", "1"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"FermionSpinSum",
 CellLabel->"Out[634]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Spinor",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Spinor",
  ButtonNote->"Spinor"],
 ", ",
 ButtonBox["ComplexConjugate",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ComplexConjugate",
  ButtonNote->"ComplexConjugate"],
 ", ",
 ButtonBox["DiracTrace",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrace",
  ButtonNote->"DiracTrace"],
 ", ",
 ButtonBox["Tr",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Tr",
  ButtonNote->"Tr"],
 "."
}], "Text",
 CellTags->"FermionSpinSum"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FermionSpinSum"],

Cell[TextData[{
 "Spinors of fermions of mass ",
 StyleBox["m",
  FontSlant->"Italic"],
 " are normalized to have square 2 ",
 StyleBox["m",
  FontSlant->"Italic"],
 " or -2 ",
 StyleBox["m",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellTags->"FermionSpinSum"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SpinorUBar", "[", 
   RowBox[{
    RowBox[{"Momentum", "[", "p", "]"}], ",", "m"}], "]"}], ".", 
  RowBox[{"SpinorU", "[", 
   RowBox[{
    RowBox[{"Momentum", "[", "p", "]"}], ",", "m"}], "]"}]}]], "Input",
 CellTags->"FermionSpinSum",
 CellLabel->"In[635]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FormBox[
     OverscriptBox["\<\"u\"\>", "_"],
     TraditionalForm], "(", 
    FormBox["p",
     TraditionalForm], ",", "m", ")"}], ".", 
   RowBox[{"u", "(", 
    FormBox["p",
     TraditionalForm], ",", "m", ")"}]}], TraditionalForm]], "Output",
 CellTags->"FermionSpinSum",
 CellLabel->"Out[635]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"%", "//", "FCI"}], "//", "FermionSpinSum"}]], "Input",
 CellTags->"FermionSpinSum",
 CellLabel->"In[636]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"tr", "(", 
   FormBox[
    RowBox[{"m", "+", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["p",
       TraditionalForm]}]}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"FermionSpinSum",
 CellLabel->"Out[636]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"DiracTrace", "\[Rule]", "TR"}]}]], "Input",
 CellTags->"FermionSpinSum",
 CellLabel->"In[637]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"4", " ", "m"}], TraditionalForm]], "Output",
 CellTags->"FermionSpinSum",
 CellLabel->"Out[637]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SpinorVBar", "[", 
   RowBox[{
    RowBox[{"Momentum", "[", "p", "]"}], ",", "m"}], "]"}], ".", 
  RowBox[{"SpinorV", "[", 
   RowBox[{
    RowBox[{"Momentum", "[", "p", "]"}], ",", "m"}], "]"}]}]], "Input",
 CellTags->"FermionSpinSum",
 CellLabel->"In[638]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FormBox[
     OverscriptBox["\<\"v\"\>", "_"],
     TraditionalForm], "(", 
    FormBox["p",
     TraditionalForm], ",", "m", ")"}], ".", 
   RowBox[{"v", "(", 
    FormBox["p",
     TraditionalForm], ",", "m", ")"}]}], TraditionalForm]], "Output",
 CellTags->"FermionSpinSum",
 CellLabel->"Out[638]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"%", "//", "FCI"}], "//", "FermionSpinSum"}]], "Input",
 CellTags->"FermionSpinSum",
 CellLabel->"In[639]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"tr", "(", 
   FormBox[
    RowBox[{
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["p",
       TraditionalForm]}], "-", "m"}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"FermionSpinSum",
 CellLabel->"Out[639]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"DiracTrace", "\[Rule]", "TR"}]}]], "Input",
 CellTags->"FermionSpinSum",
 CellLabel->"In[640]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "4"}], " ", "m"}], TraditionalForm]], "Output",
 CellTags->"FermionSpinSum",
 CellLabel->"Out[640]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{
   RowBox[{"Spinor", "[", 
    RowBox[{"k1", ",", "m"}], "]"}], ".", 
   RowBox[{"DiracSlash", "[", "p", "]"}], ".", 
   RowBox[{"GA", "[", "5", "]"}], ".", 
   RowBox[{"Spinor", "[", 
    RowBox[{"p1", ",", "m"}], "]"}]}]}]], "Input",
 CellTags->"FermionSpinSum",
 CellLabel->"In[641]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[CurlyPhi]", "(", 
    FormBox["k1",
     TraditionalForm], ",", "m", ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["p",
      TraditionalForm]}], ")"}], ".", 
   SuperscriptBox["\[Gamma]", "5"], ".", 
   RowBox[{"\[CurlyPhi]", "(", 
    FormBox["p1",
     TraditionalForm], ",", "m", ")"}]}], TraditionalForm]], "Output",
 CellTags->"FermionSpinSum",
 CellLabel->"Out[641]="]
}, Open  ]],

Cell["\<\
Notice that SpinorUBar and SpinorU are only input functions. Internally they \
are converted to Spinor objects.\
\>", "Text",
 CellTags->"FermionSpinSum"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ct", "=", 
  RowBox[{"ComplexConjugate", "[", "t", "]"}]}]], "Input",
 CellTags->"FermionSpinSum",
 CellLabel->"In[642]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   RowBox[{
    RowBox[{"\[CurlyPhi]", "(", 
     FormBox["p1",
      TraditionalForm], ",", "m", ")"}], ".", 
    SuperscriptBox["\[Gamma]", "5"], ".", 
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["p",
       TraditionalForm]}], ")"}], ".", 
    RowBox[{"\[CurlyPhi]", "(", 
     FormBox["k1",
      TraditionalForm], ",", "m", ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"FermionSpinSum",
 CellLabel->"Out[642]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FermionSpinSum", "[", 
  RowBox[{"t", " ", "ct"}], "]"}]], "Input",
 CellTags->"FermionSpinSum",
 CellLabel->"In[643]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   RowBox[{"tr", "(", 
    FormBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox["\<\"\[Gamma]\"\>",
          TraditionalForm], "\[CenterDot]", 
         FormBox["k1",
          TraditionalForm]}], "+", "m"}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{
        FormBox["\<\"\[Gamma]\"\>",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}], ")"}], ".", 
      SuperscriptBox["\[Gamma]", "5"], ".", 
      RowBox[{"(", 
       RowBox[{"m", "+", 
        RowBox[{
         FormBox["\<\"\[Gamma]\"\>",
          TraditionalForm], "\[CenterDot]", 
         FormBox["p1",
          TraditionalForm]}]}], ")"}], ".", 
      SuperscriptBox["\[Gamma]", "5"], ".", 
      RowBox[{"(", 
       RowBox[{
        FormBox["\<\"\[Gamma]\"\>",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}], ")"}]}],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellTags->"FermionSpinSum",
 CellLabel->"Out[643]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", " ", "/.", 
  RowBox[{"DiracTrace", "\[Rule]", "TR"}]}]], "Input",
 CellTags->"FermionSpinSum",
 CellLabel->"In[644]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "4"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"], " ", 
      RowBox[{
       FormBox["k1",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p1",
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       FormBox["k1",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p1",
        TraditionalForm]}]}], "+", 
     RowBox[{
      SuperscriptBox["m", "2"], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"FermionSpinSum",
 CellLabel->"Out[644]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"t", ",", " ", "ct"}], "]"}]], "Input",
 CellTags->"FermionSpinSum",
 CellLabel->"In[645]:="]
}, Open  ]],

Cell["FeynAmp", "ObjectName",
 CellTags->"FeynAmp"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FeynAmp"],

Cell["\<\
FeynAmp[q, amp] is the head of a Feynman amplitude. amp denotes the \
analytical expression for the amplitude and q is the integration variable. \
FeynAmp[q1, q2, amp] denotes a two-loop amplitude.\
\>", "Text",
 CellTags->"FeynAmp"],

Cell["\<\
FeynAmp has no functional properties and serves just as a head. There are \
however special typesetting rules attached.\
\>", "Text",
 CellTags->"FeynAmp"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Amplitude",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Amplitude",
  ButtonNote->"Amplitude"],
 "."
}], "Text",
 CellTags->"FeynAmp"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FeynAmp"],

Cell["\<\
This is a 1-loop gluon self-energy amplitude (ignoring factors of (2 \[Pi])).\
\
\>", "Text",
 CellTags->"FeynAmp"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FeynAmp", "[", 
  RowBox[{"q", ",", 
   RowBox[{
    RowBox[{"GV", "[", 
     RowBox[{"p", ",", "\[Mu]", ",", "a", ",", " ", 
      RowBox[{"q", "-", "p"}], ",", "\[Alpha]", ",", "c", ",", " ", 
      RowBox[{"-", "q"}], ",", "\[Beta]", ",", "e"}], "]"}], " ", 
    RowBox[{"GP", "[", 
     RowBox[{
      RowBox[{"p", "-", "q"}], ",", " ", "\[Alpha]", ",", "c", ",", " ", 
      "\[Rho]", ",", "d"}], "]"}], 
    RowBox[{"GV", "[", 
     RowBox[{
      RowBox[{"-", "p"}], ",", "\[Nu]", ",", "b", ",", " ", 
      RowBox[{"p", "-", "q"}], ",", "\[Rho]", ",", "d", ",", " ", "q", ",", 
      "\[Sigma]", ",", "f"}], "]"}], " ", 
    RowBox[{"GP", "[", 
     RowBox[{
     "q", ",", " ", "\[Beta]", ",", "e", ",", " ", "\[Sigma]", ",", "f"}], 
     "]"}]}]}], "]"}]], "Input",
 CellTags->"FeynAmp",
 CellLabel->"In[646]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[Integral]", 
   StyleBox[
    RowBox[{
     SuperscriptBox["\[DifferentialD]", "D"], "Global`q"}],
    ZeroWidthTimes->True], "(", 
   FormBox[
    RowBox[{
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     RowBox[{
      SubsuperscriptBox["\[CapitalPi]", 
       RowBox[{"e", "f"}], 
       RowBox[{"\[Beta]", "\[Sigma]"}]], "(", "q", ")"}], " ", 
     RowBox[{
      SuperscriptBox["V", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Alpha]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Beta]",
          TraditionalForm],
         TraditionalForm]}]], "(", 
      RowBox[{
       FormBox["p",
        TraditionalForm], 
       RowBox[{",", " "}], 
       FormBox[
        RowBox[{"q", "-", "p"}],
        TraditionalForm], 
       RowBox[{",", " "}], 
       FormBox[
        RowBox[{"-", "q"}],
        TraditionalForm]}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["V", 
       RowBox[{
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]}]], "(", 
      RowBox[{
       FormBox[
        RowBox[{"-", "p"}],
        TraditionalForm], 
       RowBox[{",", " "}], 
       FormBox[
        RowBox[{"p", "-", "q"}],
        TraditionalForm], 
       RowBox[{",", " "}], 
       FormBox["q",
        TraditionalForm]}], ")"}], " ", 
     RowBox[{
      SubsuperscriptBox["\[CapitalPi]", 
       RowBox[{"c", "d"}], 
       RowBox[{"\[Alpha]", "\[Rho]"}]], "(", 
      FormBox[
       RowBox[{"p", "-", "q"}],
       TraditionalForm], ")"}]}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"FeynAmp",
 CellLabel->"Out[646]="]
}, Open  ]],

Cell["This is a generic 2-loop amplitude.", "Text",
 CellTags->"FeynAmp"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FeynAmp", "[", 
  RowBox[{
   SubscriptBox["q", "1"], ",", 
   SubscriptBox["q", "2"], ",", "anyexpression"}], "]"}]], "Input",
 CellTags->"FeynAmp",
 CellLabel->"In[647]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[Integral]", 
   RowBox[{
    StyleBox[
     RowBox[{
      SuperscriptBox["\[DifferentialD]", "D"], 
      SubscriptBox["q", "1"]}],
     ZeroWidthTimes->True], "\[Integral]", 
    RowBox[{
     SuperscriptBox["\[DifferentialD]", "D"], 
     SubscriptBox["q", "2"]}]}], "(", "anyexpression", ")"}], 
  TraditionalForm]], "Output",
 CellTags->"FeynAmp",
 CellLabel->"Out[647]="]
}, Open  ]]
}, Open  ]],

Cell["FeynAmpDenominator", "ObjectName",
 CellTags->"FeynAmpDenominator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FeynAmpDenominator"],

Cell["\<\
FeynAmpDenominator[ PropagatorDenominator[ ... ], PropagatorDenominator[ ... \
], ...] is the head of the denominators of the propagators, i.e., \
FeynAmpDenominator[x] is the representation of 1/x .\
\>", "Text",
 CellTags->"FeynAmpDenominator"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FAD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FAD",
  ButtonNote->"FAD"],
 ", ",
 ButtonBox["FeynAmpDenominatorSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynAmpDenominatorSimplify",
  ButtonNote->"FeynAmpDenominatorSimplify"],
 "."
}], "Text",
 CellTags->"FeynAmpDenominator"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FeynAmpDenominator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FeynAmpDenominator", "[", 
  RowBox[{"PropagatorDenominator", "[", 
   RowBox[{"p", ",", "m"}], "]"}], "]"}]], "Input",
 CellTags->"FeynAmpDenominator",
 CellLabel->"In[648]:="],

Cell[BoxData[
 FormBox[
  FractionBox["1", 
   RowBox[{
    SuperscriptBox["p", "2"], "-", 
    SuperscriptBox["m", "2"]}]], TraditionalForm]], "Output",
 CellTags->"FeynAmpDenominator",
 CellLabel->"Out[648]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FeynAmpDenominator", "[", 
  RowBox[{
   RowBox[{"PropagatorDenominator", "[", 
    RowBox[{"p", ",", "m"}], "]"}], ",", 
   RowBox[{"PropagatorDenominator", "[", 
    RowBox[{
     RowBox[{"p", "-", "q"}], ",", "m"}], "]"}]}], "]"}]], "Input",
 CellTags->"FeynAmpDenominator",
 CellLabel->"In[649]:="],

Cell[BoxData[
 FormBox[
  FractionBox["1", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["p", "2"], "-", 
      SuperscriptBox["m", "2"]}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"p", "-", "q"}], ")"}], "2"], "-", 
      SuperscriptBox["m", "2"]}], ")"}]}]], TraditionalForm]], "Output",
 CellTags->"FeynAmpDenominator",
 CellLabel->"Out[649]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"t", "=", 
   RowBox[{"FeynAmpDenominator", "[", 
    RowBox[{"PropagatorDenominator", "[", 
     RowBox[{"p", ",", "m"}], "]"}], "]"}]}], ";"}]], "Input",
 CellTags->"FeynAmpDenominator",
 CellLabel->"In[650]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"t", "//", "FCI"}], "]"}]], "Input",
 CellTags->"FeynAmpDenominator",
 CellLabel->"In[651]:="],

Cell[BoxData[
 RowBox[{"FeynAmpDenominator", "[", 
  RowBox[{"PropagatorDenominator", "[", 
   RowBox[{
    RowBox[{"Momentum", "[", 
     RowBox[{"p", ",", "D"}], "]"}], ",", "m"}], "]"}], "]"}]], "Output",
 CellTags->"FeynAmpDenominator",
 CellLabel->"Out[651]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"t", "//", "FCE"}], "]"}]], "Input",
 CellTags->"FeynAmpDenominator",
 CellLabel->"In[652]:="],

Cell[BoxData[
 RowBox[{"FAD", "[", 
  RowBox[{"{", 
   RowBox[{"p", ",", "m"}], "}"}], "]"}]], "Output",
 CellTags->"FeynAmpDenominator",
 CellLabel->"Out[652]//StandardForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "t", "]"}], ";"}]], "Input",
 CellTags->"FeynAmpDenominator",
 CellLabel->"In[653]:="]
}, Open  ]],

Cell["FeynAmpDenominatorCombine", "ObjectName",
 CellTags->"FeynAmpDenominatorCombine"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FeynAmpDenominatorCombine"],

Cell["\<\
FeynAmpDenominatorCombine[expr] expands expr with respect to \
FeynAmpDenominator and combines products of FeynAmpDenominator in expr into \
one FeynAmpDenominator.\
\>", "Text",
 CellTags->"FeynAmpDenominatorCombine"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynAmpDenominatorSplit",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynAmpDenominatorSplit",
  ButtonNote->"FeynAmpDenominatorSplit"],
 "."
}], "Text",
 CellTags->"FeynAmpDenominatorCombine"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FeynAmpDenominatorCombine"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", " ", "=", " ", 
  RowBox[{
   RowBox[{"FAD", "[", "q", "]"}], " ", 
   RowBox[{"FAD", "[", 
    RowBox[{"q", "-", "p"}], "]"}]}]}]], "Input",
 CellTags->"FeynAmpDenominatorCombine",
 CellLabel->"In[654]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    FractionBox["1", 
     InterpretationBox[
      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
       SuperscriptBox["q", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
      SequenceForm["[", $CellContext`q^2, "]"],
      Editable->False]],
    TraditionalForm], " ", 
   FormBox[
    FractionBox["1", 
     InterpretationBox[
      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"q", "-", "p"}], ")"}], "2"], 
       "\[InvisibleSpace]", "\<\"]\"\>"}],
      SequenceForm["[", (-$CellContext`p + $CellContext`q)^2, "]"],
      Editable->False]],
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"FeynAmpDenominatorCombine",
 CellLabel->"Out[654]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FeynAmpDenominatorCombine", "[", "%", "]"}], "//", "FCE"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"FeynAmpDenominatorCombine",
 CellLabel->"In[655]:="],

Cell[BoxData[
 RowBox[{"FAD", "[", 
  RowBox[{"q", ",", 
   RowBox[{
    RowBox[{"-", "p"}], "+", "q"}]}], "]"}]], "Output",
 CellTags->"FeynAmpDenominatorCombine",
 CellLabel->"Out[655]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FeynAmpDenominatorSplit", "[", "%", "]"}], "//", "FCE"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"FeynAmpDenominatorCombine",
 CellLabel->"In[656]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"FAD", "[", "q", "]"}], " ", 
  RowBox[{"FAD", "[", 
   RowBox[{
    RowBox[{"-", "p"}], "+", "q"}], "]"}]}]], "Output",
 CellTags->"FeynAmpDenominatorCombine",
 CellLabel->"Out[656]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["FeynAmpDenominatorSimplify", "ObjectName",
 CellTags->"FeynAmpDenominatorSimplify"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FeynAmpDenominatorSimplify"],

Cell["\<\
FeynAmpDenominatorSimplify[exp] tries to simplify each PropagatorDenominator \
in a canonical way. FeynAmpDenominatorSimplify[exp, q1] simplifies all \
FeynAmpDenominator's in exp in a canonical way, including some translation of \
momenta. FeynAmpDenominatorSimplify[exp, q1, q2] additionally removes \
integrals with no mass scale.\
\>", "Text",
 CellTags->"FeynAmpDenominatorSimplify"],

Cell["FDS can be used as an alias.", "Text",
 CellTags->"FeynAmpDenominatorSimplify"],

Cell[CellGroupData[{

Cell[BoxData["FDS"], "Input",
 CellTags->"FeynAmpDenominatorSimplify",
 CellLabel->"In[657]:="],

Cell[BoxData[
 FormBox["FeynAmpDenominatorSimplify", TraditionalForm]], "Output",
 CellTags->"FeynAmpDenominatorSimplify",
 CellLabel->"Out[657]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OneLoopSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoopSimplify",
  ButtonNote->"OneLoopSimplify"],
 "."
}], "Text",
 CellTags->"FeynAmpDenominatorSimplify"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FeynAmpDenominatorSimplify"],

Cell[TextData[{
 "The cornerstone of dimensional regularization is that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Integral]", 
     RowBox[{
      SuperscriptBox["d", "n"], "k", " ", 
      RowBox[{
       RowBox[{"f", "(", "k", ")"}], "/", 
       SuperscriptBox["k", 
        RowBox[{"2", "m"}]]}]}]}], "=", " ", 
    RowBox[{"0", " ", "."}]}], TraditionalForm]]]
}], "Text",
 CellTags->"FeynAmpDenominatorSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FeynAmpDenominatorSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "k", "]"}], " ", 
    RowBox[{"FAD", "[", 
     RowBox[{"k", ",", "k"}], "]"}]}], ",", "k"}], "]"}]], "Input",
 CellTags->"FeynAmpDenominatorSimplify",
 CellLabel->"In[658]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"FeynAmpDenominatorSimplify",
 CellLabel->"Out[658]="]
}, Open  ]],

Cell[TextData[{
 "This brings ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "/", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SubscriptBox["p", "1"]}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SubscriptBox["p", "2"]}], ")"}], "2"]}], ")"}]}], 
   TraditionalForm]]],
 " into a standard form."
}], "Text",
 CellTags->"FeynAmpDenominatorSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FeynAmpDenominatorSimplify", "[", 
  RowBox[{
   RowBox[{"FAD", "[", 
    RowBox[{
     RowBox[{"k", "-", 
      SubscriptBox["p", "1"]}], ",", 
     RowBox[{"k", "-", 
      SubscriptBox["p", "2"]}]}], "]"}], ",", "k"}], "]"}]], "Input",
 CellTags->"FeynAmpDenominatorSimplify",
 CellLabel->"In[659]:="],

Cell[BoxData[
 FormBox[
  FractionBox["1", 
   RowBox[{
    SuperscriptBox["k", "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", 
       SubscriptBox["p", "1"], "+", 
       SubscriptBox["p", "2"]}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellTags->"FeynAmpDenominatorSimplify",
 CellLabel->"Out[659]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FeynAmpDenominatorSimplify", "[", 
  RowBox[{
   RowBox[{"FAD", "[", 
    RowBox[{"k", ",", "k", ",", 
     RowBox[{"k", "-", "q"}]}], "]"}], ",", "k"}], "]"}]], "Input",
 CellTags->"FeynAmpDenominatorSimplify",
 CellLabel->"In[660]:="],

Cell[BoxData[
 FormBox[
  FractionBox["1", 
   RowBox[{
    SuperscriptBox["k", "2"], ".", 
    SuperscriptBox["k", "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", "q"}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellTags->"FeynAmpDenominatorSimplify",
 CellLabel->"Out[660]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FeynAmpDenominatorSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "k", "]"}], 
    RowBox[{"FAD", "[", 
     RowBox[{"k", ",", 
      RowBox[{"k", "-", "q"}], ",", 
      RowBox[{"k", "-", "q"}]}], "]"}]}], ",", "k"}], "]"}]], "Input",
 CellTags->"FeynAmpDenominatorSimplify",
 CellLabel->"In[661]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"f", "(", 
    RowBox[{"q", "-", "k"}], ")"}], 
   RowBox[{
    SuperscriptBox["k", "2"], ".", 
    SuperscriptBox["k", "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", "q"}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellTags->"FeynAmpDenominatorSimplify",
 CellLabel->"Out[661]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{"FeynAmpDenominatorSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"FAD", "[", 
      RowBox[{
       RowBox[{"k", "-", 
        SubscriptBox["p", "1"]}], ",", 
       RowBox[{"k", "-", 
        SubscriptBox["p", "2"]}]}], "]"}], " ", 
     RowBox[{"SPD", "[", 
      RowBox[{"k", ",", "k"}], "]"}]}], ",", "k"}], "]"}]}]], "Input",
 CellTags->"FeynAmpDenominatorSimplify",
 CellLabel->"In[662]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    SuperscriptBox[
     FormBox["k",
      TraditionalForm], "2"], 
    RowBox[{
     SuperscriptBox["k", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"k", "-", 
        SubscriptBox["p", "1"], "+", 
        SubscriptBox["p", "2"]}], ")"}], "2"]}]], "+", 
   FractionBox[
    SubsuperscriptBox["p", "1", "2"], 
    RowBox[{
     SuperscriptBox["k", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"k", "-", 
        SubscriptBox["p", "1"], "+", 
        SubscriptBox["p", "2"]}], ")"}], "2"]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["p", "1"],
       TraditionalForm]}]}], 
    RowBox[{
     SuperscriptBox["k", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"k", "-", 
        SubscriptBox["p", "1"], "+", 
        SubscriptBox["p", "2"]}], ")"}], "2"]}]]}], 
  TraditionalForm]], "Output",
 CellTags->"FeynAmpDenominatorSimplify",
 CellLabel->"Out[662]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"r", "=", 
  RowBox[{"SPC", "[", 
   RowBox[{"t", ",", "k", ",", 
    RowBox[{"FDS", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellTags->"FeynAmpDenominatorSimplify",
 CellLabel->"In[663]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["p", "2"],
       TraditionalForm]}]}], 
    RowBox[{
     SuperscriptBox["k", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"k", "+", 
        SubscriptBox["p", "1"], "-", 
        SubscriptBox["p", "2"]}], ")"}], "2"]}]], "-", 
   FractionBox[
    RowBox[{
     SubsuperscriptBox["p", "1", "2"], "+", 
     SubsuperscriptBox["p", "2", "2"], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm]}]}]}], 
    RowBox[{
     SuperscriptBox["k", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"k", "+", 
        SubscriptBox["p", "1"], "-", 
        SubscriptBox["p", "2"]}], ")"}], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     SubsuperscriptBox["p", "1", "2"], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["p", "2", "2"]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["p", "2", "2"], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}]}], ")"}]}]}], 
    RowBox[{
     SuperscriptBox["k", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"k", "-", 
        SubscriptBox["p", "1"], "+", 
        SubscriptBox["p", "2"]}], ")"}], "2"]}]]}], 
  TraditionalForm]], "Output",
 CellTags->"FeynAmpDenominatorSimplify",
 CellLabel->"Out[663]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OneLoopSimplify", "[", 
  RowBox[{"r", ",", "k"}], "]"}]], "Input",
 CellTags->"FeynAmpDenominatorSimplify",
 CellLabel->"In[664]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    FormBox[
     SubscriptBox["p", "1"],
     TraditionalForm], "\[CenterDot]", 
    FormBox[
     SubscriptBox["p", "2"],
     TraditionalForm]}], 
   RowBox[{
    SuperscriptBox["k", "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", 
       SubscriptBox["p", "1"], "+", 
       SubscriptBox["p", "2"]}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellTags->"FeynAmpDenominatorSimplify",
 CellLabel->"Out[664]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FDS", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"FAD", "[", 
     RowBox[{
      RowBox[{"k", "-", "p1"}], ",", 
      RowBox[{"k", "-", "p2"}]}], "]"}], 
    RowBox[{
     RowBox[{"SPD", "[", 
      RowBox[{"k", ",", "OPEDelta"}], "]"}], "^", "2"}]}], ",", "k"}], 
  "]"}]], "Input",
 CellTags->"FeynAmpDenominatorSimplify",
 CellLabel->"In[665]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["k",
        TraditionalForm], "\[CenterDot]", 
       FormBox["\[CapitalDelta]",
        TraditionalForm]}],
      TraditionalForm], "2"], 
    RowBox[{
     SuperscriptBox["k", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"k", "-", "p1", "+", "p2"}], ")"}], "2"]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox["\[CapitalDelta]",
       TraditionalForm], "\[CenterDot]", 
      FormBox["p1",
       TraditionalForm]}]}], 
    RowBox[{
     SuperscriptBox["k", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"k", "-", "p1", "+", "p2"}], ")"}], "2"]}]], "+", 
   FractionBox[
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p1",
        TraditionalForm]}],
      TraditionalForm], "2"], 
    RowBox[{
     SuperscriptBox["k", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"k", "-", "p1", "+", "p2"}], ")"}], "2"]}]]}], 
  TraditionalForm]], "Output",
 CellTags->"FeynAmpDenominatorSimplify",
 CellLabel->"Out[665]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"t", ",", "r"}], "]"}]], "Input",
 CellTags->"FeynAmpDenominatorSimplify",
 CellLabel->"In[666]:="]
}, Open  ]],

Cell["FeynAmpDenominatorSplit", "ObjectName",
 CellTags->"FeynAmpDenominatorSplit"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FeynAmpDenominatorSplit"],

Cell["\<\
FeynAmpDenominatorSplit[expr] splits all FeynAmpDenominator[a,b, ...] in expr \
into FeynAmpDenominator[a]*FeynAmpDenominator[b] ... . \
FeynAmpDenominatorSplit[expr, q1] splits all FeynAmpDenominator in expr into \
a product of two, one containing q1 and other momenta, the second without q1.\
\
\>", "Text",
 CellTags->"FeynAmpDenominatorSplit"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynAmpDenominatorCombine",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynAmpDenominatorCombine",
  ButtonNote->"FeynAmpDenominatorCombine"],
 "."
}], "Text",
 CellTags->"FeynAmpDenominatorSplit"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FeynAmpDenominatorSplit"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{
   RowBox[{"FAD", "[", 
    RowBox[{"q1", ",", 
     RowBox[{"q1", "-", "p"}], ",", 
     RowBox[{"q1", "-", "q2"}], ",", "q2", ",", 
     RowBox[{"q2", "-", "p"}]}], "]"}], "//", "FCI"}]}]], "Input",
 CellTags->"FeynAmpDenominatorSplit",
 CellLabel->"In[667]:="],

Cell[BoxData[
 FormBox[
  FractionBox["1", 
   RowBox[{
    SuperscriptBox["q1", "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q1", "-", "p"}], ")"}], "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q1", "-", "q2"}], ")"}], "2"], ".", 
    SuperscriptBox["q2", "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q2", "-", "p"}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellTags->"FeynAmpDenominatorSplit",
 CellLabel->"Out[667]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "//", "Head"}]], "Input",
 CellTags->"FeynAmpDenominatorSplit",
 CellLabel->"In[668]:="],

Cell[BoxData[
 FormBox["FeynAmpDenominator", TraditionalForm]], "Output",
 CellTags->"FeynAmpDenominatorSplit",
 CellLabel->"Out[668]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FeynAmpDenominatorSplit", "[", "t", "]"}]], "Input",
 CellTags->"FeynAmpDenominatorSplit",
 CellLabel->"In[669]:="],

Cell[BoxData[
 FormBox[
  FractionBox["1", 
   RowBox[{
    SuperscriptBox["q1", "2"], " ", 
    SuperscriptBox["q2", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q1", "-", "p"}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q2", "-", "p"}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q1", "-", "q2"}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellTags->"FeynAmpDenominatorSplit",
 CellLabel->"Out[669]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"%", "//", "FCE"}], "//", "StandardForm"}]], "Input",
 CellTags->"FeynAmpDenominatorSplit",
 CellLabel->"In[670]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"FAD", "[", "q1", "]"}], " ", 
  RowBox[{"FAD", "[", 
   RowBox[{
    RowBox[{"-", "p"}], "+", "q1"}], "]"}], " ", 
  RowBox[{"FAD", "[", 
   RowBox[{"q1", "-", "q2"}], "]"}], " ", 
  RowBox[{"FAD", "[", "q2", "]"}], " ", 
  RowBox[{"FAD", "[", 
   RowBox[{
    RowBox[{"-", "p"}], "+", "q2"}], "]"}]}]], "Output",
 CellTags->"FeynAmpDenominatorSplit",
 CellLabel->"Out[670]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FeynAmpDenominatorSplit", "[", 
    RowBox[{"t", ",", "q1"}], "]"}], "//", "FCE"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"FeynAmpDenominatorSplit",
 CellLabel->"In[671]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"FAD", "[", 
   RowBox[{"q2", ",", 
    RowBox[{
     RowBox[{"-", "p"}], "+", "q2"}]}], "]"}], " ", 
  RowBox[{"FAD", "[", 
   RowBox[{"q1", ",", 
    RowBox[{
     RowBox[{"-", "p"}], "+", "q1"}], ",", 
    RowBox[{"q1", "-", "q2"}]}], "]"}]}]], "Output",
 CellTags->"FeynAmpDenominatorSplit",
 CellLabel->"Out[671]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FeynAmpDenominatorCombine", "[", "%", "]"}], "//", "FCE"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"FeynAmpDenominatorSplit",
 CellLabel->"In[672]:="],

Cell[BoxData[
 RowBox[{"FAD", "[", 
  RowBox[{"q1", ",", 
   RowBox[{
    RowBox[{"-", "p"}], "+", "q1"}], ",", 
   RowBox[{"q1", "-", "q2"}], ",", "q2", ",", 
   RowBox[{
    RowBox[{"-", "p"}], "+", "q2"}]}], "]"}]], "Output",
 CellTags->"FeynAmpDenominatorSplit",
 CellLabel->"Out[672]//StandardForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "t", "]"}]], "Input",
 CellTags->"FeynAmpDenominatorSplit",
 CellLabel->"In[673]:="]
}, Open  ]],

Cell["FeynAmpList", "ObjectName",
 CellTags->"FeynAmpList"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FeynAmpList"],

Cell["\<\
FeynAmpList[info][FeynAmp[...], FeynAmp[...], ...] is a head of a list of \
Feynman amplitudes.\
\>", "Text",
 CellTags->"FeynAmpList"],

Cell["\<\
FeynAmpList has no functional properties and serves just as a head.\
\>", "Text",
 CellTags->"FeynAmpList"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynAmp",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynAmp",
  ButtonNote->"FeynAmp"],
 "."
}], "Text",
 CellTags->"FeynAmpList"]
}, Open  ]],

Cell["FeynCalc", "ObjectName",
 CellTags->"FeynCalc"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FeynCalc"],

Cell["FeynCalc is simply a symbol with a usage definition.", "Text",
 CellTags->"FeynCalc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "FeynCalc"}]], "Input",
 CellTags->"FeynCalc",
 CellLabel->"In[674]:="],

Cell[BoxData[
 StyleBox["\<\"For installation notes visit www.feyncalc.org\\n\\nFor a list \
of availabe objects type $FeynCalcStuff, which contains a list of all \
functions and options in StringForm. You can get on-line information by \
?function, e.g. ?Contract.\\n\\nThere are several useful functions for short \
input, type $FCS for a list of short commands. Then type, e.g., \
?GA.\\n\\n\\nTo enable/disable start-up messages, put the \
line\\n\\n$FeynCalcStartupMessages = \
True;\\n\\nor\\n\\n$FeynCalcStartupMessages = False;\\n\\n into your \
\\\"init.m\\\" file or into your \\\"FCConfig.m\\\" file.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellTags->{"FeynCalc", "Info3522790274-4590919"}]
}, Open  ]]
}, Open  ]],

Cell["FeynCalcExternal", "ObjectName",
 CellTags->"FeynCalcExternal"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FeynCalcExternal"],

Cell["\<\
FeynCalcExternal[exp] translates exp from the internal FeynCalc \
representation to a shorthand form.\
\>", "Text",
 CellTags->"FeynCalcExternal"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynCalcInternal",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalcInternal",
  ButtonNote->"FeynCalcInternal"],
 "."
}], "Text",
 CellTags->"FeynCalcExternal"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FeynCalcExternal"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FeynCalcExternal", "[", 
  RowBox[{"DiracGamma", "[", "5", "]"}], "]"}]], "Input",
 CellTags->"FeynCalcExternal",
 CellLabel->"In[675]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Gamma]", "5"], TraditionalForm]], "Output",
 CellTags->"FeynCalcExternal",
 CellLabel->"Out[675]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"FeynCalcExternal",
 CellLabel->"In[676]:="],

Cell[BoxData[
 RowBox[{"GA", "[", "5", "]"}]], "Output",
 CellTags->"FeynCalcExternal",
 CellLabel->"Out[676]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
   RowBox[{"GS", "[", "p", "]"}], ",", 
   RowBox[{"SP", "[", 
    RowBox[{"p", ",", "q"}], "]"}], ",", 
   RowBox[{"MT", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
   RowBox[{"FV", "[", 
    RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Input",
 CellTags->"FeynCalcExternal",
 CellLabel->"In[677]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    SuperscriptBox["\[Gamma]", "\[Mu]"], ",", 
    SuperscriptBox["\[Gamma]", "\[Rho]"], ",", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], ",", 
    FormBox[
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}],
     TraditionalForm], ",", 
    SuperscriptBox["g", 
     RowBox[{"\[Alpha]", "\[Beta]"}]], ",", 
    SuperscriptBox["p", "\[Mu]"]}], "}"}], TraditionalForm]], "Output",
 CellTags->"FeynCalcExternal",
 CellLabel->"Out[677]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"FeynCalcExternal",
 CellLabel->"In[678]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
   RowBox[{"GS", "[", "p", "]"}], ",", 
   RowBox[{"SP", "[", 
    RowBox[{"p", ",", "q"}], "]"}], ",", 
   RowBox[{"MT", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
   RowBox[{"FV", "[", 
    RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Output",
 CellTags->"FeynCalcExternal",
 CellLabel->"Out[678]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "FeynCalcInternal"}]], "Input",
 CellTags->"FeynCalcExternal",
 CellLabel->"In[679]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], ",", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm]], ",", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["p",
      TraditionalForm]}], ",", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}], ",", 
    SuperscriptBox["g", 
     RowBox[{"\[Alpha]", "\[Beta]"}]], ",", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]]}], "}"}], TraditionalForm]], "Output",
 CellTags->"FeynCalcExternal",
 CellLabel->"Out[679]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"FeynCalcExternal",
 CellLabel->"In[680]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"DiracGamma", "[", 
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ",", 
   RowBox[{"DiracGamma", "[", 
    RowBox[{
     RowBox[{"LorentzIndex", "[", 
      RowBox[{"\[Rho]", ",", "D"}], "]"}], ",", "D"}], "]"}], ",", 
   RowBox[{"DiracGamma", "[", 
    RowBox[{"Momentum", "[", "p", "]"}], "]"}], ",", 
   RowBox[{"Pair", "[", 
    RowBox[{
     RowBox[{"Momentum", "[", "p", "]"}], ",", 
     RowBox[{"Momentum", "[", "q", "]"}]}], "]"}], ",", 
   RowBox[{"Pair", "[", 
    RowBox[{
     RowBox[{"LorentzIndex", "[", "\[Alpha]", "]"}], ",", 
     RowBox[{"LorentzIndex", "[", "\[Beta]", "]"}]}], "]"}], ",", 
   RowBox[{"Pair", "[", 
    RowBox[{
     RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
     RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]}], "}"}]], "Output",
 CellTags->"FeynCalcExternal",
 CellLabel->"Out[680]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FeynCalcExternal", "[", "%", "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"FeynCalcExternal",
 CellLabel->"In[681]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
   RowBox[{"GS", "[", "p", "]"}], ",", 
   RowBox[{"SP", "[", 
    RowBox[{"p", ",", "q"}], "]"}], ",", 
   RowBox[{"MT", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
   RowBox[{"FV", "[", 
    RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Output",
 CellTags->"FeynCalcExternal",
 CellLabel->"Out[681]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["FeynCalcForm", "ObjectName",
 CellTags->"FeynCalcForm"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FeynCalcForm"],

Cell[TextData[{
 "FeynCalcForm[expr] changes the printed output to a an easy-to-read form. It \
allows a readable output also when running a terminal based ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " session. Whether the result of FeynCalcForm[expr] is displayed or not, \
depends on the setting of $PrePrint. $PrePrint = FeynCalcForm forces \
displaying everything after applying FeynCalcForm. In order to change to the \
normal (internal) Mathematica OutputForm, do: ($PrePrint=.)."
}], "Text",
 CellTags->"FeynCalcForm"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FC",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FC",
  ButtonNote->"FC"],
 ", ",
 ButtonBox["FeynCalcExternal",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalcExternal",
  ButtonNote->"FeynCalcExternal"],
 ", ",
 ButtonBox["FeynCalcInternal",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalcInternal",
  ButtonNote->"FeynCalcInternal"],
 "."
}], "Text",
 CellTags->"FeynCalcForm"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FeynCalcForm"],

Cell["This is the normal notebook display:", "Text",
 CellTags->"FeynCalcForm"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNTrace", "[", 
  RowBox[{
   RowBox[{"SUNT", "[", "a", "]"}], ".", 
   RowBox[{"SUNT", "[", "b", "]"}], ".", 
   RowBox[{"SUNT", "[", "c", "]"}]}], "]"}]], "Input",
 CellTags->"FeynCalcForm",
 CellLabel->"In[682]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"tr", "(", 
   FormBox[
    RowBox[{
     SubscriptBox["T", 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]]}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"FeynCalcForm",
 CellLabel->"Out[682]="]
}, Open  ]],

Cell["\<\
This is the shorthand (terminal) display (easy-to-read form):\
\>", "Text",
 CellTags->"FeynCalcForm"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$PrePrint", " ", "=", " ", "FeynCalcForm"}], ";"}]], "Input",
 CellTags->"FeynCalcForm",
 CellLabel->"In[683]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"$FrontEnd", ",", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Options", "[", 
         RowBox[{"$FrontEnd", ",", "\"\<CommonDefaultFormatTypes\>\""}], 
         "]"}], "/.", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\"\<Output\>\"", "\[Rule]", "_"}], ")"}], "\[Rule]", 
         RowBox[{"(", 
          RowBox[{"\"\<Output\>\"", "\[Rule]", "OutputForm"}], ")"}]}]}], 
       ")"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], ";"}]], "Input",
 CellTags->"FeynCalcForm",
 CellLabel->"In[684]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNTrace", "[", 
  RowBox[{
   RowBox[{"SUNT", "[", "a", "]"}], ".", 
   RowBox[{"SUNT", "[", "b", "]"}], ".", 
   RowBox[{"SUNT", "[", "c", "]"}]}], "]"}]], "Input",
 CellTags->"FeynCalcForm",
 CellLabel->"In[685]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\<\"tr\"\>", "(", 
   FormBox[
    InterpretationBox[
     RowBox[{
      RowBox[{"\<\"T\"\>", "(", "a", ")"}], "\<\" \"\>", 
      RowBox[{"\<\"T\"\>", "(", "b", ")"}], "\<\" \"\>", 
      RowBox[{"\<\"T\"\>", "(", "c", ")"}]}],
     Infix[
      HighEnergyPhysics`FeynCalc`FeynCalcForm`Private`fcdot2[
       "T"[$CellContext`a], 
       "T"[$CellContext`b], 
       "T"[$CellContext`c]], " "],
     Editable->False],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"FeynCalcForm",
 CellLabel->"Out[685]="]
}, Open  ]],

Cell["Reset to normal notebook display:", "Text",
 CellTags->"FeynCalcForm"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$PrePrint", "=."}], ";"}]], "Input",
 CellTags->"FeynCalcForm",
 CellLabel->"In[686]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"$FrontEnd", ",", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Options", "[", 
         RowBox[{"$FrontEnd", ",", "\"\<CommonDefaultFormatTypes\>\""}], 
         "]"}], "/.", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\"\<Output\>\"", "\[Rule]", "_"}], ")"}], "\[Rule]", 
         RowBox[{"(", 
          RowBox[{"\"\<Output\>\"", "\[Rule]", "TraditionalForm"}], ")"}]}]}],
        ")"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], ";"}]], "Input",
 CellTags->"FeynCalcForm",
 CellLabel->"In[687]:="]
}, Open  ]],

Cell["FeynCalcInternal", "ObjectName",
 CellTags->"FeynCalcInternal"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FeynCalcInternal"],

Cell["\<\
FeynCalcInternal[exp] translates exp into the internal FeynCalc (abstract \
data-type) representation.\
\>", "Text",
 CellTags->"FeynCalcInternal"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynCalcExternal",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalcExternal",
  ButtonNote->"FeynCalcExternal"],
 ", ",
 ButtonBox["FCI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCI",
  ButtonNote->"FCI"],
 ", ",
 ButtonBox["FCE",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCE",
  ButtonNote->"FCE"],
 "."
}], "Text",
 CellTags->"FeynCalcInternal"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FeynCalcInternal"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
   RowBox[{"GS", "[", "p", "]"}], ",", 
   RowBox[{"SP", "[", 
    RowBox[{"p", ",", "q"}], "]"}], ",", 
   RowBox[{"MT", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
   RowBox[{"FV", "[", 
    RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Input",
 CellTags->"FeynCalcInternal",
 CellLabel->"In[688]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    SuperscriptBox["\[Gamma]", "\[Mu]"], ",", 
    SuperscriptBox["\[Gamma]", "\[Rho]"], ",", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], ",", 
    FormBox[
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}],
     TraditionalForm], ",", 
    SuperscriptBox["g", 
     RowBox[{"\[Alpha]", "\[Beta]"}]], ",", 
    SuperscriptBox["p", "\[Mu]"]}], "}"}], TraditionalForm]], "Output",
 CellTags->"FeynCalcInternal",
 CellLabel->"Out[688]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"FeynCalcInternal",
 CellLabel->"In[689]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
   RowBox[{"GS", "[", "p", "]"}], ",", 
   RowBox[{"SP", "[", 
    RowBox[{"p", ",", "q"}], "]"}], ",", 
   RowBox[{"MT", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
   RowBox[{"FV", "[", 
    RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Output",
 CellTags->"FeynCalcInternal",
 CellLabel->"Out[689]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "FeynCalcInternal"}]], "Input",
 CellTags->"FeynCalcInternal",
 CellLabel->"In[690]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], ",", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm]], ",", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["p",
      TraditionalForm]}], ",", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}], ",", 
    SuperscriptBox["g", 
     RowBox[{"\[Alpha]", "\[Beta]"}]], ",", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]]}], "}"}], TraditionalForm]], "Output",
 CellTags->"FeynCalcInternal",
 CellLabel->"Out[690]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"FeynCalcInternal",
 CellLabel->"In[691]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"DiracGamma", "[", 
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ",", 
   RowBox[{"DiracGamma", "[", 
    RowBox[{
     RowBox[{"LorentzIndex", "[", 
      RowBox[{"\[Rho]", ",", "D"}], "]"}], ",", "D"}], "]"}], ",", 
   RowBox[{"DiracGamma", "[", 
    RowBox[{"Momentum", "[", "p", "]"}], "]"}], ",", 
   RowBox[{"Pair", "[", 
    RowBox[{
     RowBox[{"Momentum", "[", "p", "]"}], ",", 
     RowBox[{"Momentum", "[", "q", "]"}]}], "]"}], ",", 
   RowBox[{"Pair", "[", 
    RowBox[{
     RowBox[{"LorentzIndex", "[", "\[Alpha]", "]"}], ",", 
     RowBox[{"LorentzIndex", "[", "\[Beta]", "]"}]}], "]"}], ",", 
   RowBox[{"Pair", "[", 
    RowBox[{
     RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
     RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]}], "}"}]], "Output",
 CellTags->"FeynCalcInternal",
 CellLabel->"Out[691]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FeynCalcExternal", "[", "%", "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"FeynCalcInternal",
 CellLabel->"In[692]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"GA", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"GAD", "[", "\[Rho]", "]"}], ",", 
   RowBox[{"GS", "[", "p", "]"}], ",", 
   RowBox[{"SP", "[", 
    RowBox[{"p", ",", "q"}], "]"}], ",", 
   RowBox[{"MT", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
   RowBox[{"FV", "[", 
    RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "}"}]], "Output",
 CellTags->"FeynCalcInternal",
 CellLabel->"Out[692]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FCI", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"SD", "[", 
     RowBox[{"a", ",", "b"}], "]"}], ",", 
    RowBox[{"SUND", "[", 
     RowBox[{"a", ",", "b", ",", "c"}], "]"}], ",", 
    RowBox[{"SUNF", "[", 
     RowBox[{"a", ",", "b", ",", "c"}], "]"}], ",", 
    RowBox[{"FAD", "[", "q", "]"}], ",", 
    RowBox[{"LC", "[", 
     RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], "]"}]}],
    "}"}], "]"}]], "Input",
 CellTags->"FeynCalcInternal",
 CellLabel->"In[693]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]}]], ",", 
    SubscriptBox["d", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]}]], ",", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]}]], ",", 
    FractionBox["1", 
     SuperscriptBox["q", "2"]], ",", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]}]]}], "}"}], TraditionalForm]], "Output",
 CellTags->"FeynCalcInternal",
 CellLabel->"Out[693]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"FeynCalcInternal",
 CellLabel->"In[694]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"SUNDelta", "[", 
    RowBox[{
     RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
     RowBox[{"SUNIndex", "[", "b", "]"}]}], "]"}], ",", 
   RowBox[{"SUND", "[", 
    RowBox[{
     RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
     RowBox[{"SUNIndex", "[", "b", "]"}], ",", 
     RowBox[{"SUNIndex", "[", "c", "]"}]}], "]"}], ",", 
   RowBox[{"SUNF", "[", 
    RowBox[{
     RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
     RowBox[{"SUNIndex", "[", "b", "]"}], ",", 
     RowBox[{"SUNIndex", "[", "c", "]"}]}], "]"}], ",", 
   RowBox[{"FeynAmpDenominator", "[", 
    RowBox[{"PropagatorDenominator", "[", 
     RowBox[{
      RowBox[{"Momentum", "[", 
       RowBox[{"q", ",", "D"}], "]"}], ",", "0"}], "]"}], "]"}], ",", 
   RowBox[{"Eps", "[", 
    RowBox[{
     RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
     RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], ",", 
     RowBox[{"LorentzIndex", "[", "\[Rho]", "]"}], ",", 
     RowBox[{"LorentzIndex", "[", "\[Sigma]", "]"}]}], "]"}]}], 
  "}"}]], "Output",
 CellTags->"FeynCalcInternal",
 CellLabel->"Out[694]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["FeynCalc2FORM", "ObjectName",
 CellTags->"FeynCalc2FORM"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FeynCalc2FORM"],

Cell["\<\
FeynCalc2FORM[expr] displays expr in FORM syntax. FeynCalc2FORM[file, x] \
writes x in FORM syntax to a file. FeynCalc2FORM[file, x==y] writes x=y to a \
file in FORM syntax.\
\>", "Text",
 CellTags->"FeynCalc2FORM"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FORM2FeynCalc",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FORM2FeynCalc",
  ButtonNote->"FORM2FeynCalc"],
 "."
}], "Text",
 CellTags->"FeynCalc2FORM"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "FeynCalc2FORM", "]"}]], "Input",
 CellTags->"FeynCalc2FORM",
 CellLabel->"In[695]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"EpsDiscard", "\[Rule]", "False"}], ",", 
    RowBox[{"FORMEpilog", "\[Rule]", "\<\"\"\>"}], ",", 
    RowBox[{"FORMProlog", "\[Rule]", "\<\"write statistics;\"\>"}], ",", 
    RowBox[{"Replace", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\<\"\\\\[Alpha]\"\>", "\[Rule]", "\<\"al\"\>"}], ",", 
       RowBox[{"\<\"\\\\[Beta]\"\>", "\[Rule]", "\<\"be\"\>"}], ",", 
       RowBox[{"\<\"\\\\[Gamma]\"\>", "\[Rule]", "\<\"ga\"\>"}], ",", 
       RowBox[{"\<\"\\\\[Delta]\"\>", "\[Rule]", "\<\"de\"\>"}], ",", 
       RowBox[{"\<\"\\\\[Mu]\"\>", "\[Rule]", "\<\"mu\"\>"}], ",", 
       RowBox[{"\<\"\\\\[Nu]\"\>", "\[Rule]", "\<\"nu\"\>"}], ",", 
       RowBox[{"\<\"\\\\[Rho]\"\>", "\[Rule]", "\<\"ro\"\>"}], ",", 
       RowBox[{"\<\"\\\\[Sigma]\"\>", "\[Rule]", "\<\"si\"\>"}]}], "}"}]}], 
    ",", 
    RowBox[{"TraceDimension", "\[Rule]", "4"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"FeynCalc2FORM",
 CellLabel->"Out[695]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FeynCalc2FORM"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MT", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
  RowBox[{"FV", "[", 
   RowBox[{"p", ",", "\[Rho]"}], "]"}], " ", 
  RowBox[{
   RowBox[{"y", "^", "2"}], "/", "d"}]}]], "Input",
 CellTags->"FeynCalc2FORM",
 CellLabel->"In[696]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["y", "2"], " ", 
    SuperscriptBox["p", "\[Rho]"], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]]}], "d"], TraditionalForm]], "Output",
 CellTags->"FeynCalc2FORM",
 CellLabel->"Out[696]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FeynCalc2FORM", "[", "%", "]"}], ";"}]], "Input",
 CellTags->"FeynCalc2FORM",
 CellLabel->"In[697]:="],

Cell["(y^2*d_(mu,nu)*p(ro))/d", "Print",
 CellTags->"FeynCalc2FORM"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"LC", "[", 
   RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Delta]", ",", "\[Rho]"}], 
   "]"}]}]], "Input",
 CellTags->"FeynCalc2FORM",
 CellLabel->"In[698]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{"\[Alpha]", "\[Beta]", "\[Delta]", "\[Rho]"}]], 
  TraditionalForm]], "Output",
 CellTags->"FeynCalc2FORM",
 CellLabel->"Out[698]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FeynCalc2FORM", "[", "%", "]"}], ";"}]], "Input",
 CellTags->"FeynCalc2FORM",
 CellLabel->"In[699]:="],

Cell["(-i_)*e_(al,be,de,ro)", "Print",
 CellTags->"FeynCalc2FORM"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracTrace", "[", 
  RowBox[{"GA", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], "]"}], 
  "]"}]], "Input",
 CellTags->"FeynCalc2FORM",
 CellLabel->"In[700]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"tr", "(", 
   FormBox[
    RowBox[{
     SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
     SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
     SuperscriptBox["\[Gamma]", "\[Rho]"], ".", 
     SuperscriptBox["\[Gamma]", "\[Sigma]"]}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"FeynCalc2FORM",
 CellLabel->"Out[700]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FeynCalc2FORM", "[", "%", "]"}], ";"}]], "Input",
 CellTags->"FeynCalc2FORM",
 CellLabel->"In[701]:="],

Cell["\<\
g_(0,mu)*g_(0,nu)*g_(0,ro)*g_(0,si)\
\>", "Print",
 CellTags->"FeynCalc2FORM"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracTrace", "[", 
   RowBox[{"GA", "[", 
    RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "]"}], 
  RowBox[{"DiracTrace", "[", 
   RowBox[{"GA", "[", 
    RowBox[{"\[Mu]", ",", "\[Rho]"}], "]"}], "]"}]}]], "Input",
 CellTags->"FeynCalc2FORM",
 CellLabel->"In[702]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"tr", "(", 
    FormBox[
     RowBox[{
      SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
      SuperscriptBox["\[Gamma]", "\[Nu]"]}],
     TraditionalForm], ")"}], " ", 
   RowBox[{"tr", "(", 
    FormBox[
     RowBox[{
      SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
      SuperscriptBox["\[Gamma]", "\[Rho]"]}],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellTags->"FeynCalc2FORM",
 CellLabel->"Out[702]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FeynCalc2FORM", "[", "%", "]"}], ";"}]], "Input",
 CellTags->"FeynCalc2FORM",
 CellLabel->"In[703]:="],

Cell["\<\
g_(0,mu)*g_(0,nu)*g_(1,mu)*g_(1,ro)\
\>", "Print",
 CellTags->"FeynCalc2FORM"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"FeynCalc2FORM", "[", 
   RowBox[{"\"\<fc2ftest.f\>\"", ",", 
    RowBox[{
     RowBox[{"MT", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
     RowBox[{"FV", "[", 
      RowBox[{"p", ",", "\[Mu]"}], "]"}]}]}], "]"}], ";"}]], "Input",
 CellTags->"FeynCalc2FORM",
 CellLabel->"In[704]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ReadList", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", "\"\<:\>\"", 
      ",", "\"\<\>\""}], "]"}], "<>", "\"\<fc2ftest.f\>\""}], ",", "String"}],
   "]"}]], "Input",
 CellTags->"FeynCalc2FORM",
 CellLabel->"In[705]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", "\<\"d_(mu,nu)*p(mu)\"\>", "}"}], TraditionalForm]], "Output",
 CellTags->"FeynCalc2FORM",
 CellLabel->"Out[705]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{"TR", "[", 
   RowBox[{
    RowBox[{"GA", "[", 
     RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], "]"}], 
    ".", 
    RowBox[{"GS", "[", 
     RowBox[{"p", ",", "q"}], "]"}]}], "]"}]}]], "Input",
 CellTags->"FeynCalc2FORM",
 CellLabel->"In[706]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Rho]", "\[Sigma]"}]]}], "-", 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Rho]", "\[Sigma]"}]]}], "-", 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Sigma]"}]]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Sigma]"}]]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Sigma]"}]]}], "-", 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Sigma]"}]]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Rho]"}]]}], "-", 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Rho]"}]]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]]}], "-", 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Rho]"}]]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Rho]"}]]}], "-", 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Rho]", "\[Sigma]"}]], " ", 
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Sigma]"}]], " ", 
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"FeynCalc2FORM",
 CellLabel->"Out[706]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"FeynCalc2FORM", "[", 
   RowBox[{"\"\<fc2ftest.f\>\"", ",", 
    RowBox[{"L", " ", "==", "t"}]}], "]"}], ";"}]], "Input",
 CellTags->"FeynCalc2FORM",
 CellLabel->"In[707]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"ReadList", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", "\"\<:\>\"",
        ",", "\"\<\>\""}], "]"}], "<>", "\"\<fc2ftest.f\>\""}], ",", 
    "String"}], "]"}], "]"}]], "Input",
 CellTags->"FeynCalc2FORM",
 CellLabel->"In[708]:="],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {"\<\"Indices \\\\[Mu],\\\\[Nu],\\\\[Rho],\\\\[Sigma];\"\>"},
      {"\<\"Vectors p,q;\"\>"},
      {"\<\"write statistics;\"\>"},
      {"\<\"Local L = ( \"\>"},
      {"\<\"4*(d_(mu,si)*d_(nu,ro)*q.p-d_(mu,ro)*d_(nu,si)*q.p+d_(mu,nu)*d_(\
ro,si)*q.p+\"\>"},
      {"\<\"d_(ro,si)*p(nu)*q(mu)-d_(nu,si)*p(ro)*q(mu)+d_(nu,ro)*p(si)*q(mu)-\
\"\>"},
      {"\<\"d_(ro,si)*p(mu)*q(nu)+d_(mu,si)*p(ro)*q(nu)-d_(mu,ro)*p(si)*q(nu)+\
\"\>"},
      {"\<\"d_(nu,si)*p(mu)*q(ro)-d_(mu,si)*p(nu)*q(ro)+d_(mu,nu)*p(si)*q(ro)-\
\"\>"},
      {"\<\"d_(nu,ro)*p(mu)*q(si)+d_(mu,ro)*p(nu)*q(si)-d_(mu,nu)*p(ro)*q(si))\
 ); \"\>"},
      {"\<\"   \"\>"},
      {"\<\"Print; \"\>"},
      {"\<\".end\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellTags->"FeynCalc2FORM",
 CellLabel->"Out[708]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"FileNames", "[", "\"\<fc2ftest.f\>\"", "]"}], "=!=", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"DeleteFile", "[", "\"\<fc2ftest.f\>\"", "]"}]}], "]"}], 
  ";"}]], "Input",
 CellTags->"FeynCalc2FORM",
 CellLabel->"In[709]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "t", "]"}], ";"}]], "Input",
 CellTags->"FeynCalc2FORM",
 CellLabel->"In[710]:="]
}, Open  ]],

Cell["FeynCalcToLaTeX", "ObjectName",
 CellTags->"FeynCalcToLaTeX"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FeynCalcToLaTeX"],

Cell["\<\
FeynCalcToLaTeX[expr] generates LaTeX with line-breaking  for expr. 
FeynCalcToLaTeX[expr, 500] generates LaTeX for expr where 500 is the Window \
width  setting for the Mathematica frontend. Increasing its value will \
generate less line breaks.\
\>", "Text",
 CellTags->"FeynCalcToLaTeX"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GluonPropagator", "[", 
   RowBox[{"p", ",", "1", ",", "2"}], "]"}], "//", "Explicit"}]], "Input",
 CellLabel->"In[711]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["ci1",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["ci2",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"li1", "li2"}]]}], 
    SuperscriptBox["p", "2"]]}], TraditionalForm]], "Output",
 CellLabel->"Out[711]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FeynCalcToLaTeX", "[", "%", "]"}]], "Input",
 CellLabel->"In[712]:="],

Cell[BoxData[
 FormBox["\<\"%% AMS-LaTeX Created by Wolfram Mathematica 8.0 : \
www.wolfram.com\\\\documentclass{article}\\n\\\\usepackage{amsmath, amssymb, \
graphics, \
setspace}\\\\newcommand{\\\\mathsym}[1]{{}}\\n\\\\newcommand{\\\\unicode}[1]{{\
}}\\\\newcounter{mathematicapage}\\n\\\\begin{document}\\\\begin{doublespace}\
\\n\\\\noindent\\\\(-\\\\frac{i \\\\delta _{\\\\text{ci1}\\\\text{ci2}} g^{\\\
\\text{li1}\\\\text{li2}}}{p^2}\\\\)\\n\\\\end{doublespace}\"\>", 
  TraditionalForm]], "Output",
 CellLabel->"Out[712]="]
}, Open  ]]
}, Open  ]],

Cell["FeynmanParameterNames", "ObjectName",
 CellTags->"FeynmanParameterNames"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FeynmanParameterNames"],

Cell["\<\
FeynmanParameterNames is an option for FeynmanParametrize and \
FeynmanParametrize.\
\>", "Text",
 CellTags->"FeynmanParameterNames"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynmanParametrize",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynmanParametrize",
  ButtonNote->"FeynmanParametrize"],
 ", ",
 ButtonBox["FeynmanParametrize",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynmanParametrize",
  ButtonNote->"FeynmanParametrize"],
 "."
}], "Text",
 CellTags->"FeynmanParameterNames"]
}, Open  ]],

Cell["FeynmanParametrize ***unfinished***", "ObjectName",
 CellTags->"FeynmanParametrize"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FeynmanParametrize"],

Cell["\<\
FeynmanParametrize[exp,k] introduces feynman parameters for all one-loop \
integrals in exp (k = integration momentum).\
\>", "Text",
 CellTags->"FeynmanParametrize"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "FeynmanParametrize", "]"}]], "Input",
 CellTags->"FeynmanParametrize",
 CellLabel->"In[713]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"FeynmanParameterNames", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"FeynmanParametrize",
 CellLabel->"Out[713]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FeynmanParametrize"],

Cell[BoxData[""], "Input",
 CellTags->"FeynmanParametrize",
 CellLabel->"In[714]:="]
}, Open  ]],

Cell["FeynRule", "ObjectName",
 CellTags->"FeynRule"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FeynRule"],

Cell["\<\
FeynRule[lag, {fields}] derives the Feynman rule corresponding to the field \
configuration fields of the lagrangian lag.\
\>", "Text",
 CellTags->"FeynRule"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "FeynRule", "]"}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[715]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Anti5", "\[Rule]", 
     RowBox[{"-", "\[Infinity]"}]}], ",", 
    RowBox[{"Contract", "\[Rule]", "False"}], ",", 
    RowBox[{"Factor1", "\[Rule]", "False"}], ",", 
    RowBox[{"FinalSubstitutions", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"PartialD", "\[Rule]", "RightPartialD"}], ",", 
    RowBox[{"Schouten", "\[Rule]", "False"}], ",", 
    RowBox[{"ZeroMomentumInsertion", "\[Rule]", "True"}], ",", 
    RowBox[{"InitialFunction", "\[Rule]", "Identity"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[715]="]
}, Open  ]],

Cell["FeynRule does not calculate propagator Feynman rules.", "Text",
 CellTags->"FeynRule"],

Cell["\<\
The option ZeroMomentumInsertion can be used for twist-2 and higher twist \
operators.\
\>", "Text",
 CellTags->"FeynRule"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Lagrangian",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Lagrangian",
  ButtonNote->"Lagrangian"],
 "."
}], "Text",
 CellTags->"FeynRule"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FeynRule"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gou", "=", 
  RowBox[{"Lagrangian", "[", "\"\<ogu\>\"", "]"}]}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[716]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["\[ImaginaryI]", 
    RowBox[{"m", "-", "1"}]], " ", 
   RowBox[{
    SubsuperscriptBox["F", 
     RowBox[{"\[Alpha]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], "a"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      SubsuperscriptBox["D", 
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       RowBox[{"a", "b"}]], ")"}], 
     RowBox[{"m", "-", "2"}]], ".", 
    SubsuperscriptBox["F", 
     RowBox[{"\[Alpha]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], "b"]}]}], TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[716]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gop", "=", 
  RowBox[{"Lagrangian", "[", "\"\<ogp\>\"", "]"}]}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[717]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["\[ImaginaryI]", "m"], " ", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Alpha]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Beta]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Gamma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}]], ".", 
    SubsuperscriptBox["F", 
     RowBox[{"\[Beta]", "\[Gamma]"}], "a"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      SubsuperscriptBox["D", 
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       RowBox[{"a", "b"}]], ")"}], 
     RowBox[{"m", "-", "2"}]], ".", 
    SubsuperscriptBox["F", 
     RowBox[{"\[Alpha]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], "b"]}]}], TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[717]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Explicit", "[", "gop", "]"}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[718]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["\[ImaginaryI]", "m"], " ", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Alpha]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Beta]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Gamma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}]], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Beta]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox[
        FormBox["A",
         TraditionalForm], 
        FormBox[
         FormBox["\[Gamma]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Gamma]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox[
        FormBox["A",
         TraditionalForm], 
        FormBox[
         FormBox["\[Beta]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       SubscriptBox["g", "s"], " ", 
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["b30",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["c31",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       RowBox[{
        SubsuperscriptBox[
         FormBox["A",
          TraditionalForm], 
         FormBox[
          FormBox["\[Beta]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["b30",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubsuperscriptBox[
         FormBox["A",
          TraditionalForm], 
         FormBox[
          FormBox["\[Gamma]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["c31",
           TraditionalForm],
          TraditionalForm]]}]}]}], ")"}], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      SubsuperscriptBox["D", 
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       RowBox[{"a", "b"}]], ")"}], 
     RowBox[{"m", "-", "2"}]], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["\[PartialD]", 
         FormBox[
          FormBox["\[Alpha]",
           TraditionalForm],
          TraditionalForm]],
        TraditionalForm], 
       SubsuperscriptBox[
        FormBox["A",
         TraditionalForm], 
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox["\[CapitalDelta]",
         TraditionalForm]], 
       SubsuperscriptBox[
        FormBox["A",
         TraditionalForm], 
        FormBox[
         FormBox["\[Alpha]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       SubscriptBox["g", "s"], " ", 
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["b32",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["c33",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       RowBox[{
        SubsuperscriptBox[
         FormBox["A",
          TraditionalForm], 
         FormBox[
          FormBox["\[Alpha]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["b32",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubsuperscriptBox[
         FormBox["A",
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["c33",
           TraditionalForm],
          TraditionalForm]]}]}]}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[718]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Cases2", "[", 
  RowBox[{"%", ",", "QuantumField"}], "]"}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[719]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    SubsuperscriptBox[
     FormBox["A",
      TraditionalForm], 
     FormBox[
      FormBox["\[Alpha]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b32",
       TraditionalForm],
      TraditionalForm]], ",", 
    SubsuperscriptBox[
     FormBox["A",
      TraditionalForm], 
     FormBox[
      FormBox["\[Beta]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b30",
       TraditionalForm],
      TraditionalForm]], ",", 
    SubsuperscriptBox[
     FormBox["A",
      TraditionalForm], 
     FormBox[
      FormBox["\[Gamma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c31",
       TraditionalForm],
      TraditionalForm]], ",", 
    SubsuperscriptBox[
     FormBox["A",
      TraditionalForm], 
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["c33",
       TraditionalForm],
      TraditionalForm]], ",", 
    RowBox[{
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Alpha]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm], 
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox["\[CapitalDelta]",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}], ",", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Beta]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Gamma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]]}], ",", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Gamma]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Beta]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]]}], ",", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]], 
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Alpha]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[719]="]
}, Open  ]],

Cell["2-gluon Feynman rules (unpolarized)", "Text",
 CellTags->"FeynRule"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fi", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"QuantumField", "[", 
      RowBox[{"GaugeField", ",", 
       RowBox[{"{", "\[Mu]", "}"}], ",", 
       RowBox[{"{", "a", "}"}]}], "]"}], "[", "p", "]"}], ",", 
    RowBox[{
     RowBox[{"QuantumField", "[", 
      RowBox[{"GaugeField", ",", 
       RowBox[{"{", "\[Nu]", "}"}], ",", 
       RowBox[{"{", "b", "}"}]}], "]"}], "[", "q", "]"}]}], "}"}]}]], "Input",\

 CellTags->"FeynRule",
 CellLabel->"In[720]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], "(", "p", ")"}], ",", 
    RowBox[{
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], "(", "q", ")"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[720]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f2u", "=", 
  RowBox[{"FullSimplify", "/@", 
   RowBox[{"Factor2", "[", 
    RowBox[{"FeynRule", "[", 
     RowBox[{"gou", ",", "fi", ",", 
      RowBox[{"ZeroMomentumInsertion", "\[Rule]", "False"}]}], "]"}], 
    "]"}]}]}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[721]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], "\[CenterDot]", 
          FormBox["p",
           TraditionalForm]}], ")"}], "m"]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], "\[CenterDot]", 
          FormBox["p",
           TraditionalForm]}],
         TraditionalForm], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}], ")"}], "m"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["p",
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], 
           FormBox[
            FormBox["\[Nu]",
             TraditionalForm],
            TraditionalForm]], " ", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}]}], "-", 
         RowBox[{
          SuperscriptBox[
           FormBox["\[CapitalDelta]",
            TraditionalForm], 
           FormBox[
            FormBox["\[Nu]",
             TraditionalForm],
            TraditionalForm]], " ", 
          RowBox[{
           FormBox["p",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}]}]}], ")"}]}]}], ")"}]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}],
      TraditionalForm], "2"], " ", 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]}]], TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[721]="]
}, Open  ]],

Cell["2-gluon Feynman rules (polarized)", "Text",
 CellTags->"FeynRule"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fi", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"QuantumField", "[", 
      RowBox[{"GaugeField", ",", 
       RowBox[{"{", "\[Mu]", "}"}], ",", 
       RowBox[{"{", "a", "}"}]}], "]"}], "[", "p", "]"}], ",", 
    RowBox[{
     RowBox[{"QuantumField", "[", 
      RowBox[{"GaugeField", ",", 
       RowBox[{"{", "\[Nu]", "}"}], ",", 
       RowBox[{"{", "b", "}"}]}], "]"}], "[", "q", "]"}]}], "}"}]}]], "Input",\

 CellTags->"FeynRule",
 CellLabel->"In[722]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], "(", "p", ")"}], ",", 
    RowBox[{
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], "(", "q", ")"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[722]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f2p", "=", 
  RowBox[{"FullSimplify", "/@", 
   RowBox[{"Factor2", "[", 
    RowBox[{"FeynRule", "[", 
     RowBox[{"gop", ",", "fi", ",", 
      RowBox[{"ZeroMomentumInsertion", "\[Rule]", "False"}]}], "]"}], 
    "]"}]}]}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[723]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], ")"}], "m"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            FormBox["\[CapitalDelta]",
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["\[Epsilon]", 
            RowBox[{
             FormBox[
              FormBox["\[Nu]",
               TraditionalForm],
              TraditionalForm], 
             FormBox["p",
              TraditionalForm], 
             FormBox["q",
              TraditionalForm], 
             FormBox["\[CapitalDelta]",
              TraditionalForm]}]]}], "+", 
          RowBox[{
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["p",
             TraditionalForm]}], " ", 
           SuperscriptBox["\[Epsilon]", 
            RowBox[{
             FormBox[
              FormBox["\[Mu]",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]",
               TraditionalForm],
              TraditionalForm], 
             FormBox["q",
              TraditionalForm], 
             FormBox["\[CapitalDelta]",
              TraditionalForm]}]]}]}], ")"}]}], "-", 
       RowBox[{
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}], ")"}], "m"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            FormBox["\[CapitalDelta]",
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["\[Epsilon]", 
            RowBox[{
             FormBox[
              FormBox["\[Mu]",
               TraditionalForm],
              TraditionalForm], 
             FormBox["p",
              TraditionalForm], 
             FormBox["q",
              TraditionalForm], 
             FormBox["\[CapitalDelta]",
              TraditionalForm]}]]}], "+", 
          RowBox[{
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q",
             TraditionalForm]}], " ", 
           SuperscriptBox["\[Epsilon]", 
            RowBox[{
             FormBox[
              FormBox["\[Mu]",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]",
               TraditionalForm],
              TraditionalForm], 
             FormBox["p",
              TraditionalForm], 
             FormBox["\[CapitalDelta]",
              TraditionalForm]}]]}]}], ")"}]}]}], ")"}]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}],
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]]}], TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[723]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor2", "[", 
  RowBox[{"Calc", "[", 
   RowBox[{"f2p", "/.", 
    RowBox[{"p", "\[Rule]", 
     RowBox[{"-", "q"}]}]}], "]"}], "]"}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[724]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FormBox["\[CapitalDelta]",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}], ")"}], 
    RowBox[{"m", "-", "1"}]], " ", 
   SuperscriptBox["\[Epsilon]", 
    RowBox[{
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox["q",
      TraditionalForm], 
     FormBox["\[CapitalDelta]",
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[724]="]
}, Open  ]],

Cell["\<\
Compare with the Feynman rule tabulated in Twist2GluonOperator.\
\>", "Text",
 CellTags->"FeynRule"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{"q", ",", 
   RowBox[{"{", 
    RowBox[{"\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[725]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FormBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "m"],
      TraditionalForm]}], ")"}], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   FormBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}], ")"}], 
     RowBox[{"m", "-", "1"}]],
    TraditionalForm], " ", 
   SuperscriptBox["\[Epsilon]", 
    RowBox[{
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox["q",
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[725]="]
}, Open  ]],

Cell["quark-quark Feynman rule (unpolarized)", "Text",
 CellTags->"FeynRule"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"qo", "=", 
  RowBox[{"Lagrangian", "[", "\"\<oqu\>\"", "]"}]}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[726]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[ImaginaryI]", "m"], " ", 
   RowBox[{
    FormBox[
     OverscriptBox["\[Psi]", "_"],
     TraditionalForm], ".", 
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], ")"}], ".", 
    SuperscriptBox[
     SubscriptBox["D", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]], 
     RowBox[{"m", "-", "1"}]], ".", 
    FormBox["\[Psi]",
     TraditionalForm]}]}], TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[726]="]
}, Open  ]],

Cell["quark-quark -gluon-gluon Feynman rule (unpolarized)", "Text",
 CellTags->"FeynRule"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"qo", "=", 
  RowBox[{"Lagrangian", "[", "\"\<oqu\>\"", "]"}]}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[727]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[ImaginaryI]", "m"], " ", 
   RowBox[{
    FormBox[
     OverscriptBox["\[Psi]", "_"],
     TraditionalForm], ".", 
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], ")"}], ".", 
    SuperscriptBox[
     SubscriptBox["D", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]], 
     RowBox[{"m", "-", "1"}]], ".", 
    FormBox["\[Psi]",
     TraditionalForm]}]}], TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[727]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"qggf", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"QuantumField", "[", "QuarkField", "]"}], "[", "p", "]"}], ",", 
    RowBox[{
     RowBox[{"QuantumField", "[", "AntiQuarkField", "]"}], "[", "q", "]"}], 
    ",", 
    RowBox[{
     RowBox[{"QuantumField", "[", 
      RowBox[{"GaugeField", ",", 
       RowBox[{"{", "\[Mu]", "}"}], ",", 
       RowBox[{"{", "a", "}"}]}], "]"}], "[", "r", "]"}], ",", 
    RowBox[{
     RowBox[{"QuantumField", "[", 
      RowBox[{"GaugeField", ",", 
       RowBox[{"{", "\[Nu]", "}"}], ",", 
       RowBox[{"{", "b", "}"}]}], "]"}], "[", "s", "]"}]}], "}"}]}]], "Input",\

 CellTags->"FeynRule",
 CellLabel->"In[728]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     FormBox["\[Psi]",
      TraditionalForm], "(", "p", ")"}], ",", 
    RowBox[{
     FormBox[
      OverscriptBox["\[Psi]", "_"],
      TraditionalForm], "(", "q", ")"}], ",", 
    RowBox[{
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], "(", "r", ")"}], ",", 
    RowBox[{
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], "(", "s", ")"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[728]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"n4", "=", 
  RowBox[{"FeynRule", "[", 
   RowBox[{"qo", ",", "qggf", ",", 
    RowBox[{"ZeroMomentumInsertion", "\[Rule]", "True"}]}], "]"}]}]], "Input",\

 CellTags->"FeynRule",
 CellLabel->"In[729]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["g", "s", "2"], " ", 
    RowBox[{
     SubscriptBox["T", 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], ".", 
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["\[CapitalDelta]",
        TraditionalForm]}], ")"}]}], " ", 
    RowBox[{"(", 
     RowBox[{
      FormBox[
       TagBox[
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "0"}], 
          RowBox[{
           RowBox[{"-", "3"}], "+", "m"}]], "\<\"\"\>"}],
        HoldForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"\<\"\"\>", " ", 
        RowBox[{"(", 
         RowBox[{"j", "+", "1"}], ")"}]}],
       TraditionalForm], 
      FormBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "j"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}], ")"}], "i"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], ")"}], 
         RowBox[{
          RowBox[{"-", "j"}], "+", "m", "-", "3"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q",
             TraditionalForm]}], "+", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["s",
             TraditionalForm]}]}], ")"}], 
         RowBox[{"j", "-", "i"}]]}],
       TraditionalForm]}], ")"}]}], "-", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "m"], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["g", "s", "2"], " ", 
    RowBox[{
     SubscriptBox["T", 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], ".", 
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["\[CapitalDelta]",
        TraditionalForm]}], ")"}]}], " ", 
    RowBox[{"(", 
     RowBox[{
      FormBox[
       TagBox[
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "0"}], 
          RowBox[{
           RowBox[{"-", "3"}], "+", "m"}]], "\<\"\"\>"}],
        HoldForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"\<\"\"\>", " ", 
        RowBox[{"(", 
         RowBox[{"j", "+", "1"}], ")"}]}],
       TraditionalForm], 
      FormBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "j"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], ")"}], "i"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}], ")"}], 
         RowBox[{
          RowBox[{"-", "j"}], "+", "m", "-", "3"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["p",
             TraditionalForm]}], "+", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["s",
             TraditionalForm]}]}], ")"}], 
         RowBox[{"j", "-", "i"}]]}],
       TraditionalForm]}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[729]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t4", "=", 
  RowBox[{"Twist2QuarkOperator", "[", 
   RowBox[{
    RowBox[{"{", "p", "}"}], ",", 
    RowBox[{"{", "q", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
    RowBox[{"Polarization", "\[Rule]", "0"}]}], "]"}]}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[730]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "m"]}], " ", 
   SuperscriptBox[
    FormBox["\[CapitalDelta]",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox[
    FormBox["\[CapitalDelta]",
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["g", "s", "2"], " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["T", 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], " ", 
       RowBox[{"(", 
        RowBox[{
         FormBox[
          TagBox[
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"i", "=", "0"}], 
             RowBox[{
              RowBox[{"-", "3"}], "+", "m"}]], "\<\"\"\>"}],
           HoldForm],
          TraditionalForm], 
         FormBox[
          RowBox[{"\<\"\"\>", " ", 
           RowBox[{"(", 
            RowBox[{"i", "+", "1"}], ")"}]}],
          TraditionalForm], 
         FormBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], ")"}], "j"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                FormBox["\[CapitalDelta]",
                 TraditionalForm], "\[CenterDot]", 
                FormBox["p",
                 TraditionalForm]}], ")"}]}], ")"}], 
            RowBox[{
             RowBox[{"-", "i"}], "+", "m", "-", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["q",
                TraditionalForm]}], "+", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["r",
                TraditionalForm]}]}], ")"}], 
            RowBox[{"i", "-", "j"}]]}],
          TraditionalForm]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SubscriptBox["T", 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]]}], " ", 
       RowBox[{"(", 
        RowBox[{
         FormBox[
          TagBox[
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"i", "=", "0"}], 
             RowBox[{
              RowBox[{"-", "3"}], "+", "m"}]], "\<\"\"\>"}],
           HoldForm],
          TraditionalForm], 
         FormBox[
          RowBox[{"\<\"\"\>", " ", 
           RowBox[{"(", 
            RowBox[{"i", "+", "1"}], ")"}]}],
          TraditionalForm], 
         FormBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], ")"}], "j"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                FormBox["\[CapitalDelta]",
                 TraditionalForm], "\[CenterDot]", 
                FormBox["p",
                 TraditionalForm]}], ")"}]}], ")"}], 
            RowBox[{
             RowBox[{"-", "i"}], "+", "m", "-", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["q",
                TraditionalForm]}], "+", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["s",
                TraditionalForm]}]}], ")"}], 
            RowBox[{"i", "-", "j"}]]}],
          TraditionalForm]}], ")"}]}]}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[730]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"n4", "-", "t4"}], "/.", 
     RowBox[{"OPEm", "\[Rule]", "5"}]}], "/.", 
    RowBox[{"s", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "p"}], "-", "q", "-", "r"}]}]}], "/.", 
   RowBox[{"D", "\[Rule]", "4"}]}], "]"}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[731]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[731]="]
}, Open  ]],

Cell["\<\
 In general equality can be shown by Timing[Factor2[ \
FCE[Calc[ChangeDimension[FCE[OPESumExplicit[n4-t4]],4]/.s\[Rule]-p-q-r]]]] \
but it is a little bit slow ...\
\>", "Text",
 CellTags->"FeynRule"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"qggf", ",", "n2", ",", "n4"}], "]"}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[732]:="],

Cell["QCD vertices", "Text",
 CellTags->"FeynRule"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fii", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"QuantumField", "[", 
      RowBox[{"GaugeField", ",", 
       RowBox[{"{", "\[Mu]", "}"}], ",", 
       RowBox[{"{", "a", "}"}]}], "]"}], "[", "p", "]"}], ",", 
    RowBox[{
     RowBox[{"QuantumField", "[", 
      RowBox[{"GaugeField", ",", 
       RowBox[{"{", "\[Nu]", "}"}], ",", 
       RowBox[{"{", "b", "}"}]}], "]"}], "[", "q", "]"}], ",", 
    RowBox[{
     RowBox[{"QuantumField", "[", 
      RowBox[{"GaugeField", ",", 
       RowBox[{"{", "\[Rho]", "}"}], ",", 
       RowBox[{"{", "c", "}"}]}], "]"}], "[", "r", "]"}]}], "}"}]}]], "Input",\

 CellTags->"FeynRule",
 CellLabel->"In[733]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], "(", "p", ")"}], ",", 
    RowBox[{
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], "(", "q", ")"}], ",", 
    RowBox[{
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], "(", "r", ")"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[733]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g3", "=", 
  RowBox[{"FeynRule", "[", 
   RowBox[{
    RowBox[{"Lagrangian", "[", "\"\<QCD\>\"", "]"}], ",", "fii"}], 
   "]"}]}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[734]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["g", "s"], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm]], "-", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]], "-", 
        SuperscriptBox[
         FormBox["r",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]], "-", 
        SuperscriptBox[
         FormBox["r",
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 CellTags->"FeynRule",
 CellLabel->"Out[734]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GluonVertex", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[735]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["g", "s"], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FormBox[
         RowBox[{"p", "-", "q"}],
         TraditionalForm], ")"}], 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FormBox[
         RowBox[{"r", "-", "p"}],
         TraditionalForm], ")"}], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FormBox[
         RowBox[{"q", "-", "r"}],
         TraditionalForm], ")"}], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[735]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", 
  RowBox[{"g3", "-", 
   RowBox[{"ChangeDimension", "[", 
    RowBox[{"%", ",", "4"}], "]"}]}], "]"}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[736]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[736]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fi4", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"QuantumField", "[", 
      RowBox[{"GaugeField", ",", 
       RowBox[{"{", "\[Mu]", "}"}], ",", 
       RowBox[{"{", "a", "}"}]}], "]"}], "[", "p", "]"}], ",", 
    RowBox[{
     RowBox[{"QuantumField", "[", 
      RowBox[{"GaugeField", ",", 
       RowBox[{"{", "\[Nu]", "}"}], ",", 
       RowBox[{"{", "b", "}"}]}], "]"}], "[", "q", "]"}], ",", 
    RowBox[{
     RowBox[{"QuantumField", "[", 
      RowBox[{"GaugeField", ",", 
       RowBox[{"{", "\[Rho]", "}"}], ",", 
       RowBox[{"{", "c", "}"}]}], "]"}], "[", "r", "]"}], ",", 
    RowBox[{
     RowBox[{"QuantumField", "[", 
      RowBox[{"GaugeField", ",", 
       RowBox[{"{", "\[Sigma]", "}"}], ",", 
       RowBox[{"{", "d", "}"}]}], "]"}], "[", "s", "]"}]}], "}"}]}]], "Input",\

 CellTags->"FeynRule",
 CellLabel->"In[737]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], "(", "p", ")"}], ",", 
    RowBox[{
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], "(", "q", ")"}], ",", 
    RowBox[{
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], "(", "r", ")"}], ",", 
    RowBox[{
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], "(", "s", ")"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[737]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g4", "=", 
  RowBox[{"FeynRule", "[", 
   RowBox[{
    RowBox[{"Lagrangian", "[", "\"\<QCD\>\"", "]"}], ",", "fi4"}], 
   "]"}]}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[738]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["g", "s", "2"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["si39",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["si39",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"\[Nu]", "\[Sigma]"}]]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"\[Rho]", "\[Sigma]"}]]}]}], ")"}]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["g", "s", "2"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["si39",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["si39",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"\[Nu]", "\[Rho]"}]]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"\[Rho]", "\[Sigma]"}]]}]}], ")"}]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["g", "s", "2"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["si39",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["si39",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"\[Nu]", "\[Rho]"}]]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"\[Nu]", "\[Sigma]"}]]}]}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[738]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GluonVertex", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "\[Sigma]", ",", "d"}], "}"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[739]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   SubsuperscriptBox["g", "s", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u97",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u97",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Rho]", "\[Sigma]"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Nu]", "\[Sigma]"}]]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u97",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u97",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Rho]", "\[Sigma]"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Nu]", "\[Rho]"}]]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u97",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u97",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Nu]", "\[Sigma]"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Nu]", "\[Rho]"}]]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[739]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", 
  RowBox[{"g4", "-", 
   RowBox[{"ChangeDimension", "[", 
    RowBox[{"%", ",", "4"}], "]"}]}], "]"}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[740]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"FeynRule",
 CellLabel->"Out[740]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "f2p", ",", "f2u", ",", "f3", ",", "f32", ",", "fi", ",", "fi4", ",", "fii",
    ",", "g3", ",", "g4", ",", "gop", ",", "gou", ",", "n3", ",", "nf3", ",", 
   "n4", ",", "np2", ",", "npf3", ",", "p33", ",", "pf3", ",", "pn3", ",", 
   "pqo", ",", "qf", ",", "qp", ",", "qgf", ",", "qo", ",", "t4"}], 
  "]"}]], "Input",
 CellTags->"FeynRule",
 CellLabel->"In[741]:="]
}, Open  ]],

Cell["FI", "ObjectName",
 CellTags->"FI"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FI"],

Cell["\<\
FI changes the output format to InputForm. This is useful to see the internal \
representation of FeynCalc objects. To change back to FeynCalcForm use FC.\
\>", "Text",
 CellTags->"FI"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynCalcForm",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalcForm",
  ButtonNote->"FeynCalcForm"],
 ", ",
 ButtonBox["FC",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FC",
  ButtonNote->"FC"],
 ", ",
 ButtonBox["FeynCalcExternal",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalcExternal",
  ButtonNote->"FeynCalcExternal"],
 ", ",
 ButtonBox["FeynCalcInternal",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalcInternal",
  ButtonNote->"FeynCalcInternal"],
 "."
}], "Text",
 CellTags->"FI"]
}, Open  ]],

Cell["FieldDerivative", "ObjectName",
 CellTags->"FieldDerivative"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FieldDerivative"],

Cell["\<\
FieldDerivative[f[x],x,li1,li2,...] is the derivative of f[x] with respect to \
space-time variables x and with Lorentz indices li1, li2, ..., where li1, \
li2, ... have head LorentzIndex. FieldDerivative[f[x],x,li1,li2,...] can be \
given as FieldDerivative[f[x],x,{l1,l2,...}], where l1 is li1 without the \
head, ... FieldDerivative is defined only for objects with head \
QuantumField[...]. If the space-time derivative of other objects is wanted, \
the corresponding rule must be specified.\
\>", "Text",
 CellTags->"FieldDerivative"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["PartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PartialD",
  ButtonNote->"PartialD"],
 ", ",
 ButtonBox["ExpandPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExpandPartialD",
  ButtonNote->"ExpandPartialD"],
 "."
}], "Text",
 CellTags->"FieldDerivative"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FieldDerivative"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"QuantumField", "[", 
    RowBox[{"A", ",", 
     RowBox[{"{", "\[Mu]", "}"}]}], "]"}], "[", "x", "]"}], ".", 
  RowBox[{
   RowBox[{"QuantumField", "[", 
    RowBox[{"B", ",", 
     RowBox[{"{", "\[Nu]", "}"}]}], "]"}], "[", "y", "]"}], ".", 
  RowBox[{
   RowBox[{"QuantumField", "[", 
    RowBox[{"C", ",", 
     RowBox[{"{", "\[Rho]", "}"}]}], "]"}], "[", "x", "]"}], ".", 
  RowBox[{
   RowBox[{"QuantumField", "[", 
    RowBox[{"D", ",", 
     RowBox[{"{", "\[Sigma]", "}"}]}], "]"}], "[", "y", "]"}]}]], "Input",
 CellTags->"FieldDerivative",
 CellLabel->"In[742]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["A", "\[Mu]"], "(", "x", ")"}], ".", 
   RowBox[{
    SubscriptBox["B", "\[Nu]"], "(", "y", ")"}], ".", 
   RowBox[{
    SubscriptBox[
     FormBox["C",
      TraditionalForm], "\[Rho]"], "(", "x", ")"}], ".", 
   RowBox[{
    SubscriptBox[
     FormBox["D",
      TraditionalForm], "\[Sigma]"], "(", "y", ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"FieldDerivative",
 CellLabel->"Out[742]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FieldDerivative", "[", 
   RowBox[{"%", ",", "x", ",", 
    RowBox[{"{", "\[Mu]", "}"}]}], "]"}], "//", "DotExpand"}]], "Input",
 CellTags->"FieldDerivative",
 CellLabel->"In[743]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["A", "\[Mu]"], "(", "x", ")"}], ".", 
    RowBox[{
     SubscriptBox["B", "\[Nu]"], "(", "y", ")"}], ".", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox[
        FormBox["C",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], "\[Null]"]}], ")"}], "\[InvisibleApplication]", 
     RowBox[{"(", "x", ")"}]}], ".", 
    RowBox[{
     SubscriptBox[
      FormBox["D",
       TraditionalForm], "\[Sigma]"], "(", "y", ")"}]}], "+", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["A", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], "\[Null]"]}], ")"}], "\[InvisibleApplication]", 
     RowBox[{"(", "x", ")"}]}], ".", 
    RowBox[{
     SubscriptBox["B", "\[Nu]"], "(", "y", ")"}], ".", 
    RowBox[{
     SubscriptBox[
      FormBox["C",
       TraditionalForm], "\[Rho]"], "(", "x", ")"}], ".", 
    RowBox[{
     SubscriptBox[
      FormBox["D",
       TraditionalForm], "\[Sigma]"], "(", "y", ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"FieldDerivative",
 CellLabel->"Out[743]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FieldDerivative", "[", 
   RowBox[{"%", ",", "y", ",", 
    RowBox[{"{", "\[Nu]", "}"}]}], "]"}], "//", "DotExpand"}]], "Input",
 CellTags->"FieldDerivative",
 CellLabel->"In[744]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["A", "\[Mu]"], "(", "x", ")"}], ".", 
    RowBox[{
     SubscriptBox["B", "\[Nu]"], "(", "y", ")"}], ".", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox[
        FormBox["C",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], "\[Null]"]}], ")"}], "\[InvisibleApplication]", 
     RowBox[{"(", "x", ")"}]}], ".", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox[
        FormBox["D",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm], "\[Null]"]}], ")"}], "\[InvisibleApplication]", 
     RowBox[{"(", "y", ")"}]}]}], "+", 
   RowBox[{
    RowBox[{
     SubscriptBox["A", "\[Mu]"], "(", "x", ")"}], ".", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["B", 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], "\[Null]"]}], ")"}], "\[InvisibleApplication]", 
     RowBox[{"(", "y", ")"}]}], ".", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox[
        FormBox["C",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], "\[Null]"]}], ")"}], "\[InvisibleApplication]", 
     RowBox[{"(", "x", ")"}]}], ".", 
    RowBox[{
     SubscriptBox[
      FormBox["D",
       TraditionalForm], "\[Sigma]"], "(", "y", ")"}]}], "+", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["A", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], "\[Null]"]}], ")"}], "\[InvisibleApplication]", 
     RowBox[{"(", "x", ")"}]}], ".", 
    RowBox[{
     SubscriptBox["B", "\[Nu]"], "(", "y", ")"}], ".", 
    RowBox[{
     SubscriptBox[
      FormBox["C",
       TraditionalForm], "\[Rho]"], "(", "x", ")"}], ".", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox[
        FormBox["D",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm], "\[Null]"]}], ")"}], "\[InvisibleApplication]", 
     RowBox[{"(", "y", ")"}]}]}], "+", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["A", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], "\[Null]"]}], ")"}], "\[InvisibleApplication]", 
     RowBox[{"(", "x", ")"}]}], ".", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["B", 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], "\[Null]"]}], ")"}], "\[InvisibleApplication]", 
     RowBox[{"(", "y", ")"}]}], ".", 
    RowBox[{
     SubscriptBox[
      FormBox["C",
       TraditionalForm], "\[Rho]"], "(", "x", ")"}], ".", 
    RowBox[{
     SubscriptBox[
      FormBox["D",
       TraditionalForm], "\[Sigma]"], "(", "y", ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"FieldDerivative",
 CellLabel->"Out[744]="]
}, Open  ]]
}, Open  ]],

Cell["FieldStrength", "ObjectName",
 CellTags->"FieldStrength"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FieldStrength"],

Cell[TextData[{
 "FieldStrength[\[Mu], \[Nu], a] is the field strength tensor ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "\[Mu]"], 
     SubsuperscriptBox["A", "\[Nu]", "a"]}], "-", 
    RowBox[{
     SubscriptBox["\[PartialD]", "\[Nu]"], 
     SubsuperscriptBox["A", "\[Mu]", "a"]}], "+", 
    RowBox[{
     SubscriptBox["g", "s"], " ", 
     SubsuperscriptBox["A", "\[Mu]", "b1"], 
     SubsuperscriptBox["A", "\[Nu]", "c1"]}]}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox["f", 
     RowBox[{"a", " ", "b1", " ", "c1"}]]}], TraditionalForm]]],
 ". FieldStrength[\[Mu], \[Nu]] is the field strength tensor ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "\[Mu]"], 
     SubsuperscriptBox["A", "\[Nu]", "\[Null]"]}], "-", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "\[Nu]"], 
      SubsuperscriptBox["A", "\[Mu]", "\[Null]"]}], "."}]}], 
   TraditionalForm]]],
 " The name of the field (A) and the coupling constant (g) can be set through \
the options or by additional arguments. The first two indices are interpreted \
as type LorentzIndex, except OPEDelta, which is converted to \
Momentum[OPEDelta]."
}], "Text",
 CellTags->"FieldStrength"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "FieldStrength", "]"}]], "Input",
 CellTags->"FieldStrength",
 CellLabel->"In[745]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}], ",", 
    RowBox[{"Explicit", "\[Rule]", "False"}], ",", 
    RowBox[{
    "HighEnergyPhysics`fctools`IndexPosition`IndexPosition", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], ",", 
    RowBox[{"Symbol", "\[Rule]", "\<\"F\"\>"}], ",", 
    RowBox[{"QuantumField", "\[Rule]", "A"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"FieldStrength",
 CellLabel->"Out[745]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["QuantumField",
  BaseStyle->"AddOnsLink",
  ButtonData:>"QuantumField",
  ButtonNote->"QuantumField"],
 "."
}], "Text",
 CellTags->"FieldStrength"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FieldStrength"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FieldStrength", "[", 
  RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]], "Input",
 CellTags->"FieldStrength",
 CellLabel->"In[746]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox["F", 
   RowBox[{"\[Mu]", "\[Nu]"}], "\[Null]"], TraditionalForm]], "Output",
 CellTags->"FieldStrength",
 CellLabel->"Out[746]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FieldStrength", "[", 
  RowBox[{"\[Mu]", ",", "\[Nu]", ",", "a"}], "]"}]], "Input",
 CellTags->"FieldStrength",
 CellLabel->"In[747]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox["F", 
   RowBox[{"\[Mu]", "\[Nu]"}], "a"], TraditionalForm]], "Output",
 CellTags->"FieldStrength",
 CellLabel->"Out[747]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FieldStrength", "[", 
  RowBox[{"\[Mu]", ",", "\[Nu]", ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"FieldStrength",
 CellLabel->"In[748]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], 
    SubsuperscriptBox[
     FormBox["A",
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], "\[Null]"]}], "-", 
   RowBox[{
    SubscriptBox["\[PartialD]", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], 
    SubsuperscriptBox[
     FormBox["A",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], "\[Null]"]}]}], TraditionalForm]], "Output",
 CellTags->"FieldStrength",
 CellLabel->"Out[748]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FieldStrength", "[", 
  RowBox[{"\[Mu]", ",", "\[Nu]", ",", "a", ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"FieldStrength",
 CellLabel->"In[749]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["g", "s"], " ", 
    SubscriptBox["f", 
     RowBox[{"a", "b106", "c107"}]], " ", 
    RowBox[{
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b106",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c107",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    SubscriptBox["\[PartialD]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], 
    SubsuperscriptBox[
     FormBox["A",
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    SubscriptBox["\[PartialD]", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], 
    SubsuperscriptBox[
     FormBox["A",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"FieldStrength",
 CellLabel->"Out[749]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"FieldStrength", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", 
    RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}], "]"}]], "Input",
 CellTags->"FieldStrength",
 CellLabel->"In[750]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"QuantumField", "[", 
   RowBox[{
    RowBox[{"PartialD", "[", 
     RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ",", "GaugeField", 
    ",", 
    RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], "]"}], "-", 
  RowBox[{"QuantumField", "[", 
   RowBox[{
    RowBox[{"PartialD", "[", 
     RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], "]"}], ",", "GaugeField", 
    ",", 
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}]}]], "Output",
 CellTags->"FieldStrength",
 CellLabel->"Out[750]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"FieldStrength", "[", 
   RowBox[{"\[Mu]", ",", "OPEDelta", ",", 
    RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}], "]"}]], "Input",
 CellTags->"FieldStrength",
 CellLabel->"In[751]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"QuantumField", "[", 
   RowBox[{
    RowBox[{"PartialD", "[", 
     RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ",", "GaugeField", 
    ",", 
    RowBox[{"Momentum", "[", "OPEDelta", "]"}]}], "]"}], "-", 
  RowBox[{"QuantumField", "[", 
   RowBox[{
    RowBox[{"PartialD", "[", 
     RowBox[{"Momentum", "[", "OPEDelta", "]"}], "]"}], ",", "GaugeField", 
    ",", 
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}]}]], "Output",
 CellTags->"FieldStrength",
 CellLabel->"Out[751]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FieldStrength", "[", 
  RowBox[{"\[Mu]", ",", "\[Nu]", ",", "a", ",", 
   RowBox[{"CouplingConstant", "\[Rule]", 
    RowBox[{"-", "Gstrong"}]}], ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"FieldStrength",
 CellLabel->"In[752]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SubscriptBox["g", "s"], " ", 
     SubscriptBox["f", 
      RowBox[{"a", "b108", "c109"}]], " ", 
     RowBox[{
      SubsuperscriptBox[
       FormBox["A",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b108",
         TraditionalForm],
        TraditionalForm]], ".", 
      SubsuperscriptBox[
       FormBox["A",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["c109",
         TraditionalForm],
        TraditionalForm]]}]}]}], "+", 
   RowBox[{
    SubscriptBox["\[PartialD]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], 
    SubsuperscriptBox[
     FormBox["A",
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    SubscriptBox["\[PartialD]", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], 
    SubsuperscriptBox[
     FormBox["A",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"FieldStrength",
 CellLabel->"Out[752]="]
}, Open  ]]
}, Open  ]],

Cell["FinalFunction", "ObjectName",
 CellTags->"FinalFunction"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FinalFunction"],

Cell["FinalFunction is an option for OneLoopSum.", "Text",
 CellTags->"FinalFunction"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OneLoopSum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoopSum",
  ButtonNote->"OneLoopSum"],
 "."
}], "Text",
 CellTags->"FinalFunction"]
}, Open  ]],

Cell["FinalSubstitutions", "ObjectName",
 CellTags->"FinalSubstitutions"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FinalSubstitutions"],

Cell["\<\
FinalSubstitutions is an option for OneLoop and OneLoopSum and Write2. All \
substitutions indicated hereby are done at the end of the calculation.\
\>", "Text",
 CellTags->"FinalSubstitutions"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OneLoop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoop",
  ButtonNote->"OneLoop"],
 ", ",
 ButtonBox["OneLoopSum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoopSum",
  ButtonNote->"OneLoopSum"],
 ", ",
 ButtonBox["Write2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Write2",
  ButtonNote->"Write2"],
 "."
}], "Text",
 CellTags->"FinalSubstitutions"]
}, Open  ]],

Cell["FORM", "ObjectName",
 CellTags->"FORM"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FORM"],

Cell["\<\
FORM is an option for RHI. If set to True a FORM file is generated and run \
from Mathematica (provided R. Hamberg's FORM-program is installed correctly \
... ).\
\>", "Text",
 CellTags->"FORM"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["RHI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RHI",
  ButtonNote->"RHI"],
 ", ",
 ButtonBox["FeynCalc2FORM",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalc2FORM",
  ButtonNote->"FeynCalc2FORM"],
 "."
}], "Text",
 CellTags->"FORM"]
}, Open  ]],

Cell["FORMEpilog", "ObjectName",
 CellTags->"FORMEpilog"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FORMEpilog"],

Cell["\<\
FORMEpilog is an option for FeynCalc2FORM. It may be set to a string which is \
put at the end of the FORM-file.\
\>", "Text",
 CellTags->"FORMEpilog"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynCalc2FORM",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalc2FORM",
  ButtonNote->"FeynCalc2FORM"],
 ", ",
 ButtonBox["FORMProlog",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FORMProlog",
  ButtonNote->"FORMProlog"],
 "."
}], "Text",
 CellTags->"FORMEpilog"]
}, Open  ]],

Cell["FORMProlog", "ObjectName",
 CellTags->"FORMProlog"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FORMProlog"],

Cell["\<\
FORMProlog is an option for FeynCalc2FORM. It may be set to a string which is \
put after the type declarations of the FORM-file.\
\>", "Text",
 CellTags->"FORMProlog"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynCalc2FORM",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalc2FORM",
  ButtonNote->"FeynCalc2FORM"],
 ", ",
 ButtonBox["FORMEpilog",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FORMEpilog",
  ButtonNote->"FORMEpilog"],
 "."
}], "Text",
 CellTags->"FORMProlog"]
}, Open  ]],

Cell["FORM2FeynCalc", "ObjectName",
 CellTags->"FORM2FeynCalc"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FORM2FeynCalc"],

Cell["\<\
FORM2FeynCalc[expr] translates the FORM expr into FeynCalc notation. \
FORM2FeynCalc[file] translates the FORM expresssions in file into \
FeynCalcnotation. FORM2FeynCalc[file, x1, x2, ...] reads in a file in \
FORM-format and translates the assignments for the variables a, b, ... into \
FeynCalc syntax. If the option Set is True, the variables x1, x2 are assigned \
to the right hand sides defined in the FORM-file.\
\>", "Text",
 CellTags->"FORM2FeynCalc"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynCalc2FORM",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalc2FORM",
  ButtonNote->"FeynCalc2FORM"],
 "."
}], "Text",
 CellTags->"FORM2FeynCalc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "FORM2FeynCalc", "]"}]], "Input",
 CellTags->"FORM2FeynCalc",
 CellLabel->"In[753]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Dimension", "\[Rule]", "4"}], ",", 
    RowBox[{"FinalSubstitutions", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"Dot", "\[Rule]", "Dot"}], ",", 
    RowBox[{"HoldForm", "\[Rule]", "True"}], ",", 
    RowBox[{"LorentzIndex", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"mu", ",", "nu", ",", "al", ",", "be"}], "}"}]}], ",", 
    RowBox[{"Set", "\[Rule]", "False"}], ",", 
    RowBox[{"Replace", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"Vectors", "\[Rule]", "Automatic"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"FORM2FeynCalc",
 CellLabel->"Out[753]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FORM2FeynCalc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FORM2FeynCalc", "[", "\"\<p.q + 2*x m^2\>\"", "]"}]], "Input",
 CellTags->"FORM2FeynCalc",
 CellLabel->"In[754]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{"x", ".", 
     SuperscriptBox["m", "2"]}]}], "+", 
   FormBox[
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}],
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"FORM2FeynCalc",
 CellLabel->"Out[754]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"FORM2FeynCalc",
 CellLabel->"In[755]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   RowBox[{"x", ".", 
    SuperscriptBox["m", "2"]}]}], "+", 
  RowBox[{"SP", "[", 
   RowBox[{"p", ",", "q"}], "]"}]}]], "Output",
 CellTags->"FORM2FeynCalc",
 CellLabel->"Out[755]//StandardForm="]
}, Open  ]],

Cell["\<\
Functions are automatically converted right, but bracketed expressions need \
to be substituted explicitly.\
\>", "Text",
 CellTags->"FORM2FeynCalc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FORM2FeynCalc", "[", 
  RowBox[{"\"\<x +f(z)+ log(x)^2+[li2(1-x)]\>\"", ",", 
   RowBox[{"Replace", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<[li2(1-x)]\>\"", "\[Rule]", "\"\<PolyLog[2,1-x]\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellTags->"FORM2FeynCalc",
 CellLabel->"In[756]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"f", "(", "z", ")"}], "+", 
   TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
    "PolyLog"], "+", "x", "+", 
   RowBox[{
    SuperscriptBox["log", "2"], "(", "x", ")"}]}], TraditionalForm]], "Output",\

 CellTags->"FORM2FeynCalc",
 CellLabel->"Out[756]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"FORM2FeynCalc",
 CellLabel->"In[757]:="],

Cell[BoxData[
 RowBox[{"x", "+", 
  RowBox[{"f", "[", "z", "]"}], "+", 
  SuperscriptBox[
   RowBox[{"Log", "[", "x", "]"}], "2"], "+", 
  RowBox[{"PolyLog", "[", 
   RowBox[{"2", ",", 
    RowBox[{"1", "-", "x"}]}], "]"}]}]], "Output",
 CellTags->"FORM2FeynCalc",
 CellLabel->"Out[757]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FORM2FeynCalc", "[", "\"\<x + [(1)]*y -[(-1)^m]\>\"", 
  "]"}]], "Input",
 CellTags->"FORM2FeynCalc",
 CellLabel->"In[758]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"Hold", "[", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], "]"}]}], "+", 
   RowBox[{
    RowBox[{"Hold", "[", "1", "]"}], ".", "y"}], "+", "x"}], 
  TraditionalForm]], "Output",
 CellTags->"FORM2FeynCalc",
 CellLabel->"Out[758]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ReleaseHold", "[", "%", "]"}]], "Input",
 CellTags->"FORM2FeynCalc",
 CellLabel->"In[759]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "m"]}], "+", "x", "+", 
   RowBox[{"1", ".", "y"}]}], TraditionalForm]], "Output",
 CellTags->"FORM2FeynCalc",
 CellLabel->"Out[759]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FORM2FeynCalc", "[", "\"\<p(mu)*q(nu)+d_(mu,nu)\>\"", 
  "]"}]], "Input",
 CellTags->"FORM2FeynCalc",
 CellLabel->"In[760]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["g", 
    RowBox[{"mu", "nu"}]], "+", 
   RowBox[{
    SuperscriptBox["p", "mu"], ".", 
    SuperscriptBox["q", "nu"]}]}], TraditionalForm]], "Output",
 CellTags->"FORM2FeynCalc",
 CellLabel->"Out[760]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"FORM2FeynCalc",
 CellLabel->"In[761]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FV", "[", 
    RowBox[{"p", ",", "mu"}], "]"}], ".", 
   RowBox[{"FV", "[", 
    RowBox[{"q", ",", "nu"}], "]"}]}], "+", 
  RowBox[{"MT", "[", 
   RowBox[{"mu", ",", "nu"}], "]"}]}]], "Output",
 CellTags->"FORM2FeynCalc",
 CellLabel->"Out[761]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FORM2FeynCalc", "[", 
  RowBox[{"\"\<p(mu)*q(nu)+d_(mu,nu)\>\"", ",", 
   RowBox[{"Replace", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mu", "\[Rule]", "\[Mu]"}], ",", 
      RowBox[{"nu", "\[Rule]", "\[Nu]"}]}], "}"}]}]}], "]"}]], "Input",
 CellTags->"FORM2FeynCalc",
 CellLabel->"In[762]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["g", 
    RowBox[{"\[Mu]", "\[Nu]"}]], "+", 
   RowBox[{
    SuperscriptBox["p", "\[Mu]"], ".", 
    SuperscriptBox["q", "\[Nu]"]}]}], TraditionalForm]], "Output",
 CellTags->"FORM2FeynCalc",
 CellLabel->"Out[762]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FORM2FeynCalc", "[", 
  "\"\<i_*az*bz*aM^2*D1*[(1)]*b_G1 * ( 4*eperp(mu,nu)*avec.bvec*blam )\>\"", 
  "]"}]], "Input",
 CellTags->"FORM2FeynCalc",
 CellLabel->"In[763]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"4", " ", "\[ImaginaryI]"}], ")"}], ".", "az", ".", "bz", ".", 
   SuperscriptBox["aM", "2"], ".", 
   RowBox[{"(", 
    TagBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["q", "\[Mu]"], ".", 
       SuperscriptBox["p", "\[Nu]"], ".", 
       SuperscriptBox["g", 
        RowBox[{"\[Rho]", "\[Sigma]"}]]}], "-", 
      RowBox[{
       SuperscriptBox["p", "\[Mu]"], ".", 
       SuperscriptBox["q", "\[Nu]"], ".", 
       SuperscriptBox["g", 
        RowBox[{"\[Rho]", "\[Sigma]"}]]}], "-", 
      RowBox[{
       SuperscriptBox["q", "\[Mu]"], ".", 
       SuperscriptBox["g", 
        RowBox[{"\[Nu]", "\[Sigma]"}]], ".", 
       SuperscriptBox["p", "\[Rho]"]}], "+", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Sigma]"}]], ".", 
       SuperscriptBox["q", "\[Nu]"], ".", 
       SuperscriptBox["p", "\[Rho]"]}], "+", 
      RowBox[{
       SuperscriptBox["p", "\[Mu]"], ".", 
       SuperscriptBox["g", 
        RowBox[{"\[Nu]", "\[Sigma]"}]], ".", 
       SuperscriptBox["q", "\[Rho]"]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Sigma]"}]], ".", 
       SuperscriptBox["p", "\[Nu]"], ".", 
       SuperscriptBox["q", "\[Rho]"]}], "+", 
      RowBox[{
       SuperscriptBox["q", "\[Mu]"], ".", 
       SuperscriptBox["g", 
        RowBox[{"\[Nu]", "\[Rho]"}]], ".", 
       SuperscriptBox["p", "\[Sigma]"]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Rho]"}]], ".", 
       SuperscriptBox["q", "\[Nu]"], ".", 
       SuperscriptBox["p", "\[Sigma]"]}], "+", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Nu]"}]], ".", 
       SuperscriptBox["q", "\[Rho]"], ".", 
       SuperscriptBox["p", "\[Sigma]"]}], "-", 
      RowBox[{
       SuperscriptBox["p", "\[Mu]"], ".", 
       SuperscriptBox["g", 
        RowBox[{"\[Nu]", "\[Rho]"}]], ".", 
       SuperscriptBox["q", "\[Sigma]"]}], "+", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Rho]"}]], ".", 
       SuperscriptBox["p", "\[Nu]"], ".", 
       SuperscriptBox["q", "\[Sigma]"]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Nu]"}]], ".", 
       SuperscriptBox["p", "\[Rho]"], ".", 
       SuperscriptBox["q", "\[Sigma]"]}], "+", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Sigma]"}]], ".", 
       SuperscriptBox["g", 
        RowBox[{"\[Nu]", "\[Rho]"}]], ".", 
       RowBox[{"(", 
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Rho]"}]], ".", 
       SuperscriptBox["g", 
        RowBox[{"\[Nu]", "\[Sigma]"}]], ".", 
       RowBox[{"(", 
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Nu]"}]], ".", 
       SuperscriptBox["g", 
        RowBox[{"\[Rho]", "\[Sigma]"}]], ".", 
       RowBox[{"(", 
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], ")"}]}]}],
     HoldForm], ")"}], ".", 
   RowBox[{"Hold", "[", "1", "]"}], ".", "b$G1", ".", 
   RowBox[{"eperp", "(", 
    RowBox[{"mu", ",", "nu"}], ")"}], ".", 
   RowBox[{"(", 
    FormBox[
     RowBox[{
      FormBox["avec",
       TraditionalForm], "\[CenterDot]", 
      FormBox["bvec",
       TraditionalForm]}],
     TraditionalForm], ")"}], ".", "blam"}], TraditionalForm]], "Output",
 CellTags->"FORM2FeynCalc",
 CellLabel->"Out[763]="]
}, Open  ]]
}, Open  ]],

Cell["FourDivergence", "ObjectName",
 CellTags->"FourDivergence"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FourDivergence"],

Cell["\<\
FourDivergence[exp, FourVector[p, mu]] calculates the partial derivative of \
exp w.r.t. p(mu). FourDivergence[exp, FourVector[p, mu], FourVector[p,nu], \
...]gives the multiple derivative.\
\>", "Text",
 CellTags->"FourDivergence"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["RussianTrick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RussianTrick",
  ButtonNote->"RussianTrick"],
 "."
}], "Text",
 CellTags->"FourDivergence"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FourDivergence"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{"ScalarProduct", "[", 
   RowBox[{"p", ",", "q"}], "]"}]}]], "Input",
 CellTags->"FourDivergence",
 CellLabel->"In[764]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["p",
    TraditionalForm], "\[CenterDot]", 
   FormBox["q",
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"FourDivergence",
 CellLabel->"Out[764]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FourDivergence", "[", 
  RowBox[{"t", ",", 
   RowBox[{"FourVector", "[", 
    RowBox[{"q", ",", "\[Mu]"}], "]"}]}], "]"}]], "Input",
 CellTags->"FourDivergence",
 CellLabel->"In[765]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   FormBox["p",
    TraditionalForm], 
   FormBox[
    FormBox["\[Mu]",
     TraditionalForm],
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"FourDivergence",
 CellLabel->"Out[765]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{"ScalarProduct", "[", 
   RowBox[{
    RowBox[{"p", "-", "k"}], ",", "q"}], "]"}]}]], "Input",
 CellTags->"FourDivergence",
 CellLabel->"In[766]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"(", 
   FormBox[
    RowBox[{"p", "-", "k"}],
    TraditionalForm], ")", "\[CenterDot]", 
   FormBox["q",
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"FourDivergence",
 CellLabel->"Out[766]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FourDivergence", "[", 
  RowBox[{"t", ",", 
   RowBox[{"FourVector", "[", 
    RowBox[{
     RowBox[{"k", "-", "p"}], ",", "\[Mu]"}], "]"}]}], "]"}]], "Input",
 CellTags->"FourDivergence",
 CellLabel->"In[767]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"FourDivergence",
 CellLabel->"Out[767]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "t", "]"}]], "Input",
 CellTags->"FourDivergence",
 CellLabel->"In[768]:="]
}, Open  ]],

Cell["FourLaplacian", "ObjectName",
 CellTags->"FourLaplacian"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FourLaplacian"],

Cell[TextData[{
 "FourLaplacian[exp, p, q] is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[PartialD]", 
    RowBox[{"/", 
     RowBox[{"\[PartialD]", 
      SubscriptBox["p", "\[Mu]"]}]}], " "}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"\[PartialD]", 
    RowBox[{"/", 
     RowBox[{"\[PartialD]", 
      SubscriptBox["q", "\[Mu]"]}]}], " "}], TraditionalForm]]],
 "exp."
}], "Text",
 CellTags->"FourLaplacian"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "FourLaplacian", "]"}]], "Input",
 CellTags->"FourLaplacian",
 CellLabel->"In[769]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"Dimension", "\[Rule]", "D"}], "}"}], TraditionalForm]], "Output",
 CellTags->"FourLaplacian",
 CellLabel->"Out[769]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FourDivergence",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FourDivergence",
  ButtonNote->"FourDivergence"],
 ", ",
 ButtonBox["RussianTrick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RussianTrick",
  ButtonNote->"RussianTrick"],
 "."
}], "Text",
 CellTags->"FourLaplacian"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FourLaplacian"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SP", "[", 
  RowBox[{"q", ",", "q"}], "]"}]], "Input",
 CellTags->"FourLaplacian",
 CellLabel->"In[770]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   FormBox["q",
    TraditionalForm], "2"], TraditionalForm]], "Output",
 CellTags->"FourLaplacian",
 CellLabel->"Out[770]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FourLaplacian", "[", 
  RowBox[{"%", ",", "q", ",", "q"}], "]"}]], "Input",
 CellTags->"FourLaplacian",
 CellLabel->"In[771]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "D"}], TraditionalForm]], "Output",
 CellTags->"FourLaplacian",
 CellLabel->"Out[771]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SOD", "[", "q", "]"}], "^", "OPEm"}], 
   RowBox[{"FAD", "[", 
    RowBox[{"q", ",", 
     RowBox[{"q", "-", "p"}]}], "]"}]}], "//", "FCI"}]], "Input",
 CellTags->"FourLaplacian",
 CellLabel->"In[772]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FormBox["\[CapitalDelta]",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}], ")"}], "m"], 
   RowBox[{
    SuperscriptBox["q", "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q", "-", "p"}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellTags->"FourLaplacian",
 CellLabel->"Out[772]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FourLaplacian", "[", 
  RowBox[{"%", ",", "q", ",", " ", "q"}], "]"}]], "Input",
 CellTags->"FourLaplacian",
 CellLabel->"In[773]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", "D", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}], ")"}], "m"]}], 
     RowBox[{
      SuperscriptBox["q", "2"], ".", 
      SuperscriptBox["q", "2"], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"q", "-", "p"}], ")"}], "2"]}]]}], "-", 
   FractionBox[
    RowBox[{"2", " ", "D", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}], ")"}], "m"]}], 
    RowBox[{
     SuperscriptBox["q", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q", "-", "p"}], ")"}], "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "-", 
   FractionBox[
    RowBox[{"4", " ", "m", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}], ")"}], 
      RowBox[{"m", "-", "1"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}], "-", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}]}], ")"}]}], 
    RowBox[{
     SuperscriptBox["q", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q", "-", "p"}], ")"}], "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "-", 
   FractionBox[
    RowBox[{"4", " ", "m", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}], ")"}], "m"]}], 
    RowBox[{
     SuperscriptBox["q", "2"], ".", 
     SuperscriptBox["q", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "+", 
   FractionBox[
    RowBox[{"12", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}], ")"}], "m"]}], 
    RowBox[{
     SuperscriptBox["q", "2"], ".", 
     SuperscriptBox["q", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "+", 
   FractionBox[
    RowBox[{"12", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}], ")"}], "m"]}], 
    RowBox[{
     SuperscriptBox["q", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q", "-", "p"}], ")"}], "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "-", 
   FractionBox[
    RowBox[{"4", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}], ")"}], "m"]}], 
    RowBox[{
     SuperscriptBox["q", "2"], ".", 
     SuperscriptBox["q", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q", "-", "p"}], ")"}], "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q", "-", "p"}], ")"}], "2"]}]]}], TraditionalForm]], "Output",\

 CellTags->"FourLaplacian",
 CellLabel->"Out[773]="]
}, Open  ]]
}, Open  ]],

Cell["FourVector", "ObjectName",
 CellTags->"FourVector"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FourVector"],

Cell[TextData[{
 "FourVector[p, ",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "] is the four-dimensional vector p with Lorentz index ",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 ". A vector with space-time Dimension D is obtained by supplying the option \
Dimension \[Rule] D."
}], "Text",
 CellTags->"FourVector"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FV",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FV",
  ButtonNote->"FV"],
 ", ",
 ButtonBox["FVD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FVD",
  ButtonNote->"FVD"],
 ", ",
 ButtonBox["Pair",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Pair",
  ButtonNote->"Pair"],
 "."
}], "Text",
 CellTags->"FourVector"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FourVector"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FourVector", "[", 
  RowBox[{"p", ",", "\[Mu]"}], "]"}]], "Input",
 CellTags->"FourVector",
 CellLabel->"In[774]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["p", "\[Mu]"], TraditionalForm]], "Output",
 CellTags->"FourVector",
 CellLabel->"Out[774]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FourVector", "[", 
  RowBox[{
   RowBox[{"p", "-", "q"}], ",", "\[Mu]"}], "]"}]], "Input",
 CellTags->"FourVector",
 CellLabel->"In[775]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox[
   RowBox[{"(", 
    FormBox[
     TagBox[
      RowBox[{"p", "-", "q"}],
      HoldForm],
     TraditionalForm], ")"}], "\[Mu]"], TraditionalForm]], "Output",
 CellTags->"FourVector",
 CellLabel->"Out[775]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"FourVector", "[", 
   RowBox[{"p", ",", "\[Mu]"}], "]"}], "]"}]], "Input",
 CellTags->"FourVector",
 CellLabel->"In[776]:="],

Cell[BoxData[
 RowBox[{"FourVector", "[", 
  RowBox[{"p", ",", "\[Mu]"}], "]"}]], "Output",
 CellTags->"FourVector",
 CellLabel->"Out[776]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"FourVector", "[", 
   RowBox[{"p", ",", "\[Mu]", ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], "]"}]], "Input",
 CellTags->"FourVector",
 CellLabel->"In[777]:="],

Cell[BoxData[
 RowBox[{"FourVector", "[", 
  RowBox[{"p", ",", "\[Mu]", ",", 
   RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}]], "Output",
 CellTags->"FourVector",
 CellLabel->"Out[777]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"FCE", "[", 
   RowBox[{"FourVector", "[", 
    RowBox[{"p", ",", "\[Mu]"}], "]"}], "]"}], "]"}]], "Input",
 CellTags->"FourVector",
 CellLabel->"In[778]:="],

Cell[BoxData[
 RowBox[{"FourVector", "[", 
  RowBox[{"p", ",", "\[Mu]"}], "]"}]], "Output",
 CellTags->"FourVector",
 CellLabel->"Out[778]//StandardForm="]
}, Open  ]],

Cell["\<\
There is no special function to expand momenta in FourVector. Since \
FourVector is turned into Pair internally ExpandScalarProduct may be used.\
\>", "Text",
 CellTags->"FourVector"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandScalarProduct", "[", 
  RowBox[{"FourVector", "[", 
   RowBox[{
    RowBox[{"p", "-", "q"}], ",", "\[Mu]"}], "]"}], "]"}]], "Input",
 CellTags->"FourVector",
 CellLabel->"In[779]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], "-", 
   SuperscriptBox[
    FormBox["q",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"FourVector",
 CellLabel->"Out[779]="]
}, Open  ]]
}, Open  ]],

Cell["FreeIndex", "ObjectName",
 CellTags->"FreeIndex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FreeIndex"],

Cell["\<\
FreeIndex is a datatype which is recognized by Contract. Possible use: \
DataType[mu, FreeIndex] = True.\
\>", "Text",
 CellTags->"FreeIndex"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Contract",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Contract",
  ButtonNote->"Contract"],
 ", ",
 ButtonBox["DataType",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DataType",
  ButtonNote->"DataType"],
 "."
}], "Text",
 CellTags->"FreeIndex"]
}, Open  ]],

Cell["FreeQ2", "ObjectName",
 CellTags->"FreeQ2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FreeQ2"],

Cell["\<\
FreeQ2[expr, {form1, form2, ...}] yields True if expr does not contain any \
occurence of form1, form2, ... and False otherwise. FreeQ2[expr, form] is the \
same as FreeQ[expr, form].\
\>", "Text",
 CellTags->"FreeQ2"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["SelectFree",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SelectFree",
  ButtonNote->"SelectFree"],
 ", ",
 ButtonBox["SelectNotFree",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SelectNotFree",
  ButtonNote->"SelectNotFree"],
 "."
}], "Text",
 CellTags->"FreeQ2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FreeQ2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FreeQ2", "[", 
  RowBox[{
   RowBox[{"x", "+", 
    RowBox[{"f", "[", "x", "]"}], "+", "y"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"a", ",", "x"}], "}"}]}], "]"}]], "Input",
 CellTags->"FreeQ2",
 CellLabel->"In[780]:="],

Cell[BoxData[
 FormBox["False", TraditionalForm]], "Output",
 CellTags->"FreeQ2",
 CellLabel->"Out[780]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FreeQ2", "[", 
  RowBox[{
   RowBox[{"x", "+", 
    RowBox[{"f", "[", "x", "]"}], "+", "y"}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b"}], "}"}]}], "]"}]], "Input",
 CellTags->"FreeQ2",
 CellLabel->"In[781]:="],

Cell[BoxData[
 FormBox["True", TraditionalForm]], "Output",
 CellTags->"FreeQ2",
 CellLabel->"Out[781]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FreeQ2", "[", 
  RowBox[{"x", ",", " ", "y"}], "]"}]], "Input",
 CellTags->"FreeQ2",
 CellLabel->"In[782]:="],

Cell[BoxData[
 FormBox["True", TraditionalForm]], "Output",
 CellTags->"FreeQ2",
 CellLabel->"Out[782]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FreeQ2", "[", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], ",", " ", "f"}], "]"}]], "Input",
 CellTags->"FreeQ2",
 CellLabel->"In[783]:="],

Cell[BoxData[
 FormBox["False", TraditionalForm]], "Output",
 CellTags->"FreeQ2",
 CellLabel->"Out[783]="]
}, Open  ]]
}, Open  ]],

Cell["FRH", "ObjectName",
 CellTags->"FRH"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FRH"],

Cell["\<\
FRH[exp_] := FixedPoint[ReleaseHold, exp], i.e., FRH removes all HoldForm and \
Hold in exp.\
\>", "Text",
 CellTags->"FRH"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Isolate",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Isolate",
  ButtonNote->"Isolate"],
 "."
}], "Text",
 CellTags->"FRH"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FRH"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Hold", "[", 
  RowBox[{"1", "-", "1", " ", "-", " ", 
   RowBox[{"Hold", "[", 
    RowBox[{"2", "-", "2"}], "]"}]}], "]"}]], "Input",
 CellTags->"FRH",
 CellLabel->"In[784]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"Hold", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Hold", "[", 
      RowBox[{"2", "-", "2"}], "]"}]}], "+", "1", "-", "1"}], "]"}], 
  TraditionalForm]], "Output",
 CellTags->"FRH",
 CellLabel->"Out[784]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FRH", "[", "%", "]"}]], "Input",
 CellTags->"FRH",
 CellLabel->"In[785]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"FRH",
 CellLabel->"Out[785]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Isolate", "[", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "^", "3"}], "-", "x", "-", "1"}], "==", "0"}], "]"}], ",", 
   "x", ",", 
   RowBox[{"IsolateNames", "\[Rule]", "HH"}]}], "]"}]], "Input",
 CellTags->"FRH",
 CellLabel->"In[786]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", "\[Rule]", 
      TagBox[
       RowBox[{"HH", "(", "112", ")"}],
       HoldForm]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", "\[Rule]", 
      TagBox[
       RowBox[{"HH", "(", "115", ")"}],
       HoldForm]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", "\[Rule]", 
      TagBox[
       RowBox[{"HH", "(", "116", ")"}],
       HoldForm]}], "}"}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"FRH",
 CellLabel->"Out[786]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FRH", "[", 
  RowBox[{"HH", "[", "3", "]"}], "]"}]], "Input",
 CellTags->"FRH",
 CellLabel->"In[787]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"HH", "(", "3", ")"}], TraditionalForm]], "Output",
 CellTags->"FRH",
 CellLabel->"Out[787]="]
}, Open  ]]
}, Open  ]],

Cell["FromTFI", "ObjectName",
 CellTags->"FromTFi"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FromTFi"],

Cell["\<\
FromTFi[expr, q1, q2, p] translates the TFi notatation from the TARCER \
package to the usual FeynCalc notation. See TFi for details on the \
conventions.\
\>", "Text",
 CellTags->"FromTFi"],

Cell[TextData[{
 "See also: ",
 ButtonBox["TFI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TFI",
  ButtonNote->"TFI"],
 ", ",
 ButtonBox["ToTFI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ToTFI",
  ButtonNote->"ToTFI"],
 "."
}], "Text",
 CellTags->"FromTFI"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FromTFi"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ToTFI", "[", 
  RowBox[{
   RowBox[{"FAD", "[", 
    RowBox[{"q1", ",", 
     RowBox[{"q1", "-", "p"}], ",", 
     RowBox[{"{", 
      RowBox[{"q2", ",", "M"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q2", "-", "p"}], ",", "m"}], "}"}], ",", 
     RowBox[{"q1", "-", "q2"}]}], "]"}], ",", "q1", ",", "q2", ",", "p"}], 
  "]"}]], "Input",
 CellTags->"FromTFi",
 CellLabel->"In[788]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"TFI", "(", 
   RowBox[{"D", ",", 
    SuperscriptBox["m", "2"], ",", 
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0"},
       {"1", "M"},
       {"1", "0"},
       {"1", "m"},
       {"1", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}]}], ")"}], 
  TraditionalForm]], "Output",
 CellTags->"FromTFi",
 CellLabel->"Out[788]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FromTFI", "[", 
  RowBox[{
   RowBox[{"TFI", "[", 
    RowBox[{"D", ",", 
     RowBox[{"SPD", "[", 
      RowBox[{"p", ",", "p"}], "]"}], ",", 
     RowBox[{"SOD", "[", "p", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "M"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "m"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}], "}"}]}], "]"}], ",", "q1", ",", 
   "q2", ",", "p"}], "]"}]], "Input",
 CellTags->"FromTFi",
 CellLabel->"In[789]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"TFI", "(", 
   RowBox[{"D", ",", 
    SuperscriptBox["m", "2"], ",", 
    RowBox[{
     FormBox["\<\"\[CapitalDelta]\"\>",
      TraditionalForm], 
     FormBox["\<\"\[CenterDot]\"\>",
      TraditionalForm], 
     FormBox["p",
      TraditionalForm]}], ",", 
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0"},
       {"1", "M"},
       {"1", "0"},
       {"1", "m"},
       {"1", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}]}], ")"}], 
  TraditionalForm]], "Output",
 CellTags->"FromTFi",
 CellLabel->"Out[789]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FromTFI", "[", 
  RowBox[{
   RowBox[{"TFI", "[", 
    RowBox[{"D", ",", 
     RowBox[{"SPD", "[", 
      RowBox[{"p", ",", "p"}], "]"}], ",", 
     RowBox[{"SOD", "[", "p", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "m"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "M"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "m"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}]}], "}"}]}], "]"}], ",", "q1", ",", 
   "q2", ",", "p"}], "]"}]], "Input",
 CellTags->"FromTFi",
 CellLabel->"In[790]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"TFI", "(", 
   RowBox[{"D", ",", 
    SuperscriptBox["m", "2"], ",", 
    RowBox[{
     FormBox["\<\"\[CapitalDelta]\"\>",
      TraditionalForm], 
     FormBox["\<\"\[CenterDot]\"\>",
      TraditionalForm], 
     FormBox["p",
      TraditionalForm]}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], ",", 
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "m"},
       {"1", "M"},
       {"1", "0"},
       {"1", "m"},
       {"1", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}]}], ")"}], 
  TraditionalForm]], "Output",
 CellTags->"FromTFi",
 CellLabel->"Out[790]="]
}, Open  ]]
}, Open  ]],

Cell["FUNCTION", "ObjectName",
 CellTags->"FUNCTION"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FUNCTION"],

Cell["\<\
FUNCTION[exp, string] is a head of an expression to be declared a function \
(of type string), if used in Write2.\
\>", "Text",
 CellTags->"FUNCTION"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Write2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Write2",
  ButtonNote->"Write2"],
 "."
}], "Text",
 CellTags->"FUNCTION"]
}, Open  ]],

Cell["FunctionalD", "ObjectName",
 CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FunctionalD"],

Cell["\<\
FunctionalD[expr, {QuantumField[name, {mu}, {a}][p], ...}] calculates the \
functional derivative of expr with respect to the field list (with incoming \
momenta p, etc.) and does the fourier transform. FunctionalD[expr, \
{QuantumField[name, {mu},{a}], ...}] calculates the functional derivative and \
does partial integration but omits the x-space delta functions.\
\>", "Text",
 CellTags->"FunctionalD"],

Cell["FunctionalD is a low level function used in FeynRule.", "Text",
 CellTags->"FunctionalD"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynRule",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynRule",
  ButtonNote->"FeynRule"],
 ", ",
 ButtonBox["QuantumField",
  BaseStyle->"AddOnsLink",
  ButtonData:>"QuantumField",
  ButtonNote->"QuantumField"],
 "."
}], "Text",
 CellTags->"FunctionalD"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FunctionalD"],

Cell[TextData[{
 "Instead of the usual ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"\[Delta]\[Phi]", "(", "x", ")"}], "/", 
     RowBox[{"\[Delta]\[Phi]", "(", "y", ")"}]}], "=", 
    RowBox[{
     SuperscriptBox["\[Delta]", 
      RowBox[{"(", "D", ")"}]], "(", 
     RowBox[{"x", "-", "y"}], ")"}]}], TraditionalForm]]],
 " the arguments and the \[Delta] function are omitted, i.e., for the program \
for simplicity: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Delta]\[Phi]", "/", "\[Delta]\[Phi]"}], "=", "1"}], 
   TraditionalForm]]]
}], "Text",
 CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FunctionalD", "[", 
  RowBox[{
   RowBox[{"QuantumField", "[", "\[Phi]", "]"}], ",", 
   RowBox[{"QuantumField", "[", "\[Phi]", "]"}]}], "]"}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[791]:="],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[791]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FunctionalD", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"QuantumField", "[", "\[Phi]", "]"}], "^", "2"}], ",", 
   RowBox[{"QuantumField", "[", "\[Phi]", "]"}]}], "]"}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[792]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[Phi]"}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[792]="]
}, Open  ]],

Cell[TextData[{
 "Instead of the usual ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Delta]", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", "\[Mu]"], 
        RowBox[{"\[Phi]", "(", "x", ")"}]}]}], ")"}], "/", 
     RowBox[{"\[Delta]\[Phi]", "(", "y", ")"}]}], "=", 
    RowBox[{
     SubscriptBox["\[PartialD]", "\[Mu]"], 
     RowBox[{
      SuperscriptBox["\[Delta]", 
       RowBox[{"(", "D", ")"}]], "(", 
      RowBox[{"x", "-", "y"}], ")"}]}]}], TraditionalForm]]],
 " the arguments are omitted, and the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[PartialD]", "\[Mu]"], TraditionalForm]]],
 "operator is specified by default to be an integration by parts operator, \
i.e., the right hand side will be just ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", 
     FormBox[
      SubscriptBox["\[PartialD]", "\[Mu]"],
      TraditionalForm]}], ","}], TraditionalForm]]],
 " or, more precisely (by default) ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", 
    SubscriptBox[
     OverscriptBox["\[PartialD]", "\[RightArrow]"], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]]}], TraditionalForm]]],
 "."
}], "Text",
 ZeroWidthTimes->True,
 CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FunctionalD", "[", 
  RowBox[{
   RowBox[{"QuantumField", "[", 
    RowBox[{
     RowBox[{"PartialD", "[", "\[Mu]", "]"}], ",", "\[Phi]"}], "]"}], ",", 
   RowBox[{"QuantumField", "[", "\[Phi]", "]"}]}], "]"}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[793]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[RightArrow]"], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[793]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"S", "[", "\[Phi]", "]"}], " ", "=", 
   RowBox[{
    RowBox[{"1", "/", "2"}], 
    RowBox[{"\[Integral]", " ", 
     RowBox[{
      SuperscriptBox["d", "D"], 
      RowBox[{"x", " ", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["\[PartialD]", "\[Mu]"], 
          RowBox[{"\[Phi]", "(", "x", ")"}]}], " ", 
         RowBox[{
          SuperscriptBox["\[PartialD]", "\[Mu]"], 
          RowBox[{"\[Phi]", "(", "x", ")"}]}]}], "-", 
        RowBox[{
         SuperscriptBox["m", "2"], 
         RowBox[{"\[Phi]", "(", "x", ")"}], " ", 
         RowBox[{"\[Phi]", "(", "y", ")"}]}]}], "]"}]}]}]}]}], 
  TraditionalForm]]]], "Text",
 ZeroWidthTimes->True,
 CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"s", "[", "\[Phi]", "]"}], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"QuantumField", "[", 
       RowBox[{
        RowBox[{"PartialD", "[", "\[Mu]", "]"}], ",", "\[Phi]"}], "]"}], ".", 
      
      RowBox[{"QuantumField", "[", 
       RowBox[{
        RowBox[{"PartialD", "[", "\[Mu]", "]"}], ",", "\[Phi]"}], "]"}]}], 
     "-", 
     RowBox[{
      RowBox[{"m", "^", "2"}], " ", 
      RowBox[{
       RowBox[{"QuantumField", "[", "\[Phi]", "]"}], ".", 
       RowBox[{"QuantumField", "[", "\[Phi]", "]"}]}]}]}], ")"}], "/", 
   "2"}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[794]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["\[Phi]", "\[Null]", "\[Null]"]}], ".", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["\[Phi]", "\[Null]", "\[Null]"]}]}], "-", 
     RowBox[{
      SuperscriptBox["m", "2"], " ", 
      RowBox[{"\[Phi]", ".", "\[Phi]"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[794]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FunctionalD", "[", 
  RowBox[{
   RowBox[{"s", "[", "\[Phi]", "]"}], ",", 
   RowBox[{"QuantumField", "[", "\[Phi]", "]"}]}], "]"}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[795]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["m", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"-", "\[Phi]"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm], 
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm]}], 
    SubsuperscriptBox["\[Phi]", "\[Null]", "\[Null]"]}]}], 
  TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[795]="]
}, Open  ]],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"S", "[", "A", "]"}], " ", "=", " ", 
   RowBox[{"-", 
    RowBox[{"\[Integral]", " ", 
     RowBox[{
      SuperscriptBox["d", "D"], "x", " ", 
      FractionBox["1", "4"], " ", 
      RowBox[{
       SubsuperscriptBox["F", "a", "\[Mu]\[Nu]"], "(", "x", ")"}], " ", 
      RowBox[{
       SubscriptBox["F", "\[Mu]\[Nu]a"], "(", "x", ")"}]}]}]}]}], 
  TraditionalForm]]]], "Text",
 ZeroWidthTimes->True,
 CellTags->"FunctionalD"],

Cell[TextData[StyleBox["First approach",
 FontWeight->"Bold"]], "Text",
 CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F1", "=", 
  RowBox[{"FieldStrength", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "a", ",", 
    RowBox[{"{", 
     RowBox[{"A", ",", "b", ",", "c"}], "}"}], ",", "1", ",", 
    RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[796]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["f", 
     RowBox[{"a", "b", "c"}]], " ", 
    RowBox[{
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    SubscriptBox["\[PartialD]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    SubscriptBox["\[PartialD]", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[796]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F2", "=", 
  RowBox[{"FieldStrength", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "a", ",", 
    RowBox[{"{", 
     RowBox[{"A", ",", "d", ",", "e"}], "}"}], ",", "1", ",", 
    RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[797]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["f", 
     RowBox[{"a", "d", "e"}]], " ", 
    RowBox[{
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    SubscriptBox["\[PartialD]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    SubscriptBox["\[PartialD]", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[797]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"S", "[", "A", "]"}], "=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"1", "/", "4"}]}], 
   RowBox[{"F1", ".", "F2"}]}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[798]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "4"]}], " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", 
        RowBox[{"a", "b", "c"}]], " ", 
       RowBox[{
        SubsuperscriptBox["A", 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubsuperscriptBox["A", 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]]}]}], "+", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["A", 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["A", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]]}]}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", 
        RowBox[{"a", "d", "e"}]], " ", 
       RowBox[{
        SubsuperscriptBox["A", 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubsuperscriptBox["A", 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}]}], "+", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["A", 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["A", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]]}]}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[798]="]
}, Open  ]],

Cell[TextData[{
 "In order to derive the equation of motion the functional derivative of ",
 Cell[BoxData[
  FormBox["S", TraditionalForm]]],
 " with respect to ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["A", "\[Sigma]", "g"], TraditionalForm]]],
 "has to be set to zero. Bearing in mind that for FeynCalc we have to be \
precise as to where which operators (coming from the substitution of the \
derivative of the \[Delta] function) act:, act with the functional derivative \
operator on the first field strength:"
}], "Text",
 CellTags->"FunctionalD"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     FormBox[
      RowBox[{
       FormBox[
        RowBox[{
         FormBox[
          RowBox[{"0", " ", "=", " ", 
           RowBox[{
            FormBox[
             RowBox[{
              RowBox[{"(", "\[Delta]S", ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"\[Delta]", 
                RowBox[{
                 SubsuperscriptBox["A", "\[Sigma]", "g"], "(", "y", ")"}]}], 
               ")"}]}],
             TraditionalForm], "=", 
            RowBox[{"-", 
             RowBox[{"2", "/", "4"}]}]}]}],
          TraditionalForm], 
         RowBox[{"\[Integral]", 
          RowBox[{
           SuperscriptBox["d", "D"], "x"}]}]}],
        TraditionalForm], " ", 
       RowBox[{"(", 
        RowBox[{"\[Delta]", "/", 
         RowBox[{"(", 
          RowBox[{"\[Delta]", 
           RowBox[{
            SubsuperscriptBox["A", "\[Sigma]", "g"], "(", "y", ")"}]}], 
          ")"}]}]}]}],
      TraditionalForm], " ", 
     RowBox[{
      SubscriptBox["F", "\[Mu]\[Nu]a"], "(", "x", ")"}]}], ")"}], 
   TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     RowBox[{" ", 
      SubsuperscriptBox["F", "a", 
       RowBox[{",", "\[Mu]\[Nu]"}]]}],
     TraditionalForm], 
    RowBox[{"(", "x", ")"}]}], TraditionalForm]]]
}], "Text",
 ZeroWidthTimes->True,
 CellTags->"FunctionalD"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{"See", " ", "what", " ", "happens", " ", "with", " ", "just", 
   RowBox[{
    FormBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Delta]", 
        RowBox[{"S", "[", "A", "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"\[Delta]", 
        SubsuperscriptBox["A", "\[Sigma]", "g"]}], ")"}]}],
     TraditionalForm], "."}]}], TraditionalForm]]]], "Text",
 CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ag", "=", 
  RowBox[{"QuantumField", "[", 
   RowBox[{"A", ",", 
    RowBox[{"{", "\[Sigma]", "}"}], ",", 
    RowBox[{"{", "g", "}"}]}], "]"}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[799]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox["A", 
   FormBox[
    FormBox["\[Sigma]",
     TraditionalForm],
    TraditionalForm], 
   FormBox[
    FormBox["g",
     TraditionalForm],
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[799]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{"FunctionalD", "[", 
   RowBox[{"F1", ",", "Ag"}], "]"}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[800]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Sigma]"}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{"(", 
     RowBox[{"-", 
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Sigma]"}]]}], ")"}], " ", 
    SubscriptBox[
     OverscriptBox["\[PartialD]", "\[RightArrow]"], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
    SubscriptBox[
     OverscriptBox["\[PartialD]", "\[RightArrow]"], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[800]="]
}, Open  ]],

Cell["\<\
In order to minimize the number of dummy indices, replace b \[Rule] c.\
\>", "Text",
 CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", " ", "=", " ", 
  RowBox[{"t1", " ", "/.", " ", 
   RowBox[{"b", "\[Rule]", "c"}]}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[801]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Nu]", "\[Sigma]"}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{"(", 
     RowBox[{"-", 
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Sigma]"}]]}], ")"}], " ", 
    SubscriptBox[
     OverscriptBox["\[PartialD]", "\[RightArrow]"], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
    SubscriptBox[
     OverscriptBox["\[PartialD]", "\[RightArrow]"], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[801]="]
}, Open  ]],

Cell[TextData[{
 "Instead of inserting the definition for the second ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["F", "a", "\[Mu]\[Nu]"], TraditionalForm]]],
 ", introduce a QuantumField object with antisymmetry built into the Lorentz \
indices:"
}], "Text",
 CellTags->"FunctionalD"],

Cell[BoxData[
 RowBox[{"F", "/:", " ", 
  RowBox[{"QuantumField", "[", 
   RowBox[{
   "pard___", ",", "F", ",", "\[Beta]_", ",", "\[Alpha]_", ",", "s_"}], "]"}],
   ":=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"QuantumField", "[", 
     RowBox[{"pard", ",", "F", ",", "\[Alpha]", ",", "\[Beta]", ",", "s"}], 
     "]"}]}], "/;", 
   RowBox[{"!", 
    RowBox[{"OrderedQ", "[", 
     RowBox[{"{", 
      RowBox[{"\[Beta]", ",", "\[Alpha]"}], "}"}], "]"}]}]}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[802]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuantumField", "[", 
  RowBox[{"F", ",", 
   RowBox[{"{", 
    RowBox[{"\[Mu]", ",", "\[Nu]"}], "}"}], ",", 
   RowBox[{"{", "a", "}"}]}], "]"}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[803]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox["F", 
   RowBox[{
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]}], 
   FormBox[
    FormBox["a",
     TraditionalForm],
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[803]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Mu]", "\[RuleDelayed]", "\[Nu]"}], ",", 
    RowBox[{"\[Nu]", "\[RuleDelayed]", "\[Mu]"}]}], "}"}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[804]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   SubsuperscriptBox["F", 
    RowBox[{
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]}], 
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[804]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", "=", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{"ExpandPartialD", "[", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"1", "/", "2"}]}], " ", 
      RowBox[{"t1", ".", 
       RowBox[{"QuantumField", "[", 
        RowBox[{"F", ",", 
         RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
         RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], ",", 
         RowBox[{"SUNIndex", "[", "a", "]"}]}], "]"}]}]}], "]"}], "]"}], "/.", 
   RowBox[{"Dot", "\[Rule]", "Times"}]}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[805]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     SubsuperscriptBox["F", 
      RowBox[{
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]}], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubsuperscriptBox["F", 
     RowBox[{
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]}], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["F", 
      RowBox[{
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]}], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["F", 
      RowBox[{
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]}], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[805]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t3", " ", "=", " ", 
  RowBox[{"t2", " ", "/.", " ", 
   RowBox[{"\[Nu]", "\[Rule]", "\[Mu]"}]}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[806]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], 
    SubsuperscriptBox["F", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]}], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubsuperscriptBox["F", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]}], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[806]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t4", "=", 
  RowBox[{
   RowBox[{"FCE", "[", "t3", "]"}], "/.", " ", 
   RowBox[{
    RowBox[{"SUNF", "[", 
     RowBox[{"a", ",", "c", ",", "g"}], "]"}], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"SUNF", "[", 
      RowBox[{"g", ",", "c", ",", "a"}], "]"}]}]}]}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[807]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{"g", "c", "a"}]], " ", 
    SubsuperscriptBox["F", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]}], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    SubscriptBox["\[PartialD]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], 
    SubsuperscriptBox["F", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]}], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[807]="]
}, Open  ]],

Cell[TextData[{
 "Since the variational derivative vanishes t4 implies that 0 = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["D", "\[Mu]"], 
    SubsuperscriptBox["F", "g", "\[Mu]\[Sigma]"]}], TraditionalForm]]],
 " ."
}], "Text",
 CellTags->"FunctionalD"],

Cell[TextData[StyleBox["Second approach",
 FontWeight->"Bold"]], "Text",
 CellTags->"FunctionalD"],

Cell["\<\
It is of course also possible to do the functional deriviate on the S[A] with \
both field strength tensors inserted.\
\>", "Text",
 CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"S", "[", "A", "]"}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[808]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "4"]}], " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", 
        RowBox[{"a", "b", "c"}]], " ", 
       RowBox[{
        SubsuperscriptBox["A", 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubsuperscriptBox["A", 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]]}]}], "+", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["A", 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["A", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]]}]}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", 
        RowBox[{"a", "d", "e"}]], " ", 
       RowBox[{
        SubsuperscriptBox["A", 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubsuperscriptBox["A", 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}]}], "+", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["A", 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["A", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]]}]}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[808]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"r1", "=", 
  RowBox[{"FunctionalD", "[", 
   RowBox[{
    RowBox[{"S", "[", "A", "]"}], ",", "Ag"}], "]"}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[809]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     RowBox[{
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], ".", 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], ".", 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]]}]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], ".", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]]}]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], ".", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]]}]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], ".", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]]}]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], ".", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]]}]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]]}], ".", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]]}], ".", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]]}], ".", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]]}], ".", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], ".", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]]}]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]]}], ".", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], ".", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]]}]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]]}], ".", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], ".", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]]}], ".", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], ".", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]]}], ".", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["\[PartialD]", 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[PartialD]", 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]],
        TraditionalForm]}], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["\[PartialD]", 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[PartialD]", 
         FormBox[
          FormBox["\[Sigma]",
           TraditionalForm],
          TraditionalForm]],
        TraditionalForm]}], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["\[PartialD]", 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[PartialD]", 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]],
        TraditionalForm]}], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["\[PartialD]", 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[PartialD]", 
         FormBox[
          FormBox["\[Sigma]",
           TraditionalForm],
          TraditionalForm]],
        TraditionalForm]}], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[809]="]
}, Open  ]],

Cell["\<\
This is just funcional derivation and partial integration and simple \
contraction of indices. No attempt is made to rename dummy indices (since \
this is difficult in general).\
\>", "Text",
 CellTags->"FunctionalD"],

Cell["\<\
With a general replacement rule only valid for commuting fields the color \
indices can be canonicalized a bit more. The idea is to use the commutative \
properties of the vector fields, and canonicalize the color indices by a \
trick. This function will work on any commuting product of fields.\
\>", "Text",
 CellTags->"FunctionalD"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "symfun", "]"}], ";"}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[810]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"symfun", "[", 
   RowBox[{"z_", ",", "fieldname_Symbol"}], "]"}], ":=", 
  RowBox[{"Expand", "[", 
   RowBox[{"SUNSimplify", "[", 
    RowBox[{"FixedPoint", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Collect2", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"DotSimplify", "[", 
            RowBox[{"#1", "/.", 
             RowBox[{"Times", "\[Rule]", "Dot"}]}], "]"}], "/.", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", "qi___", ")"}], ".", 
                RowBox[{"QuantumField", "[", 
                 RowBox[{
                 "par1___", ",", "fieldname", ",", "li1_", ",", "sui1_"}], 
                 "]"}], ".", 
                RowBox[{"QuantumField", "[", 
                 RowBox[{
                 "par2___", ",", "fieldname", ",", "li2_", ",", "sui2_"}], 
                 "]"}], ".", "qf___"}], " ", ")"}], "any_"}], ")"}], 
            "\[RuleDelayed]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"qi", ".", 
                 RowBox[{"QuantumField", "[", 
                  RowBox[{"par1", ",", "A", ",", "li1", ",", "sui2"}], "]"}], 
                 ".", 
                 RowBox[{"QuantumField", "[", 
                  RowBox[{"par2", ",", "fieldname", ",", "li2", ",", "sui1"}],
                   "]"}], ".", "qf"}], " ", ")"}], 
               RowBox[{"(", 
                RowBox[{"any", "/.", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"sui1", "\[RuleDelayed]", "sui2"}], ",", 
                   RowBox[{"sui2", "\[RuleDelayed]", "sui1"}]}], "}"}]}], 
                ")"}]}], ")"}], "/;", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"!", 
                RowBox[{"(", 
                 RowBox[{"FreeQ2", "[", 
                  RowBox[{"any", ",", 
                   RowBox[{"{", 
                    RowBox[{"sui1", ",", "su2"}], "}"}]}], "]"}], ")"}]}], 
               ")"}], "&&", 
              RowBox[{"!", 
               RowBox[{"(", 
                RowBox[{"OrderedQ", "[", 
                 RowBox[{"{", 
                  RowBox[{"sui1", ",", "sui2"}], "}"}], "]"}], 
                ")"}]}]}]}]}]}], "/.", 
          RowBox[{"Dot", "\[Rule]", "Times"}]}], ",", "QuantumField"}], "]"}],
        "&"}], ",", "z", ",", "42"}], "]"}], "]"}], "]"}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[811]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"r2", " ", "=", " ", 
  RowBox[{"symfun", "[", 
   RowBox[{"r1", ",", "A"}], "]"}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[812]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]}]]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["\[PartialD]", 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[PartialD]", 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]],
        TraditionalForm]}], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["\[PartialD]", 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[PartialD]", 
         FormBox[
          FormBox["\[Sigma]",
           TraditionalForm],
          TraditionalForm]],
        TraditionalForm]}], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["\[PartialD]", 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[PartialD]", 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]],
        TraditionalForm]}], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["\[PartialD]", 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]],
        TraditionalForm], 
       FormBox[
        SubscriptBox["\[PartialD]", 
         FormBox[
          FormBox["\[Sigma]",
           TraditionalForm],
          TraditionalForm]],
        TraditionalForm]}], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[812]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"r3", "=", 
  RowBox[{"r2", "/.", 
   RowBox[{"\[Nu]", "\[Rule]", "\[Mu]"}]}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[813]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["3", "4"], " ", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]}]]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    RowBox[{
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm], 
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm]}], 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    RowBox[{
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm], 
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm]}], 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[813]="]
}, Open  ]],

Cell[TextData[{
 "Inspection reveals that still terms are the same. Gather the terms with two \
",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", " "}], TraditionalForm]]],
 "'s:"
}], "Text",
 CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"twof", "=", 
  RowBox[{"Select", "[", 
   RowBox[{"r3", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Count", "[", 
       RowBox[{"#", ",", 
        RowBox[{"SUNF", "[", "__", "]"}]}], "]"}], "===", "2"}], "&"}]}], 
   "]"}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[814]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["3", "4"], " ", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]}]]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[814]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"twofnew", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"twof", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
     "+", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"twof", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"b", "\[RuleDelayed]", "c"}], ",", 
         RowBox[{"c", "\[RuleDelayed]", "b"}]}], "}"}]}], ")"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[RuleDelayed]", "c"}], ",", 
     RowBox[{"c", "\[RuleDelayed]", "a"}]}], "}"}]}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[815]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]]}], " ", 
   SubsuperscriptBox["A", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["b",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["A", 
    FormBox[
     FormBox["\[Sigma]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["e",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[815]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"r4", " ", "=", " ", 
  RowBox[{"r3", "-", "twof", "+", "twofnew"}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[816]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]}]]}]}], "-", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    RowBox[{
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm], 
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm]}], 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    RowBox[{
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm], 
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm]}], 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[816]="]
}, Open  ]],

Cell["\<\
Check that this is now indeed the same as the t4 result from the first \
attempt.\
\>", "Text",
 CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData["t4"], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[817]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{"g", "c", "a"}]], " ", 
    SubsuperscriptBox["F", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]}], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    SubscriptBox["\[PartialD]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], 
    SubsuperscriptBox["F", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]}], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[817]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"w0", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"RightPartialD", "[", "\[Mu]", "]"}], ".", 
    RowBox[{"FieldStrength", "[", 
     RowBox[{"\[Mu]", ",", "\[Sigma]", ",", "g", ",", 
      RowBox[{"{", 
       RowBox[{"A", ",", "a", ",", "b"}], "}"}], ",", "1"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"QuantumField", "[", 
     RowBox[{"A", ",", 
      RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
      RowBox[{"SUNIndex", "[", "c", "]"}]}], "]"}], 
    RowBox[{"FieldStrength", "[", 
     RowBox[{"\[Mu]", ",", "\[Sigma]", ",", "a", ",", 
      RowBox[{"{", 
       RowBox[{"A", ",", "b", ",", "d"}], "}"}], ",", "1"}], "]"}], 
    RowBox[{"SUNF", "[", 
     RowBox[{"g", ",", "c", ",", "a"}], "]"}]}]}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[818]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{"g", "c", "a"}]], " ", 
    SubsuperscriptBox["F", 
     RowBox[{"\[Mu]", "\[Sigma]"}], 
     RowBox[{"a", 
      FormBox[
       RowBox[{"{", 
        RowBox[{"A", ",", "b", ",", "d"}], "}"}],
       TraditionalForm], 
      FormBox["1",
       TraditionalForm]}]]}], "+", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["\[PartialD]", "\[RightArrow]"], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], ".", 
    SubsuperscriptBox["F", 
     RowBox[{"\[Mu]", "\[Sigma]"}], 
     RowBox[{"g", 
      FormBox[
       RowBox[{"{", 
        RowBox[{"A", ",", "a", ",", "b"}], "}"}],
       TraditionalForm], 
      FormBox["1",
       TraditionalForm]}]]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[818]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"w1", "=", 
  RowBox[{"Explicit", "[", "w0", "]"}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[819]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox[
     OverscriptBox["\[PartialD]", "\[RightArrow]"], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       RowBox[{
        SubsuperscriptBox["A", 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubsuperscriptBox["A", 
         FormBox[
          FormBox["\[Sigma]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}]}], "+", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["A", 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["A", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}]}], ")"}]}], "-", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       RowBox[{
        SubsuperscriptBox["A", 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubsuperscriptBox["A", 
         FormBox[
          FormBox["\[Sigma]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]]}]}], "+", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["A", 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["A", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]]}]}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[819]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"w2", "=", 
  RowBox[{
   RowBox[{"ExpandPartialD", "[", "w1", "]"}], "/.", 
   RowBox[{"Dot", "\[Rule]", "Times"}]}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[820]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]}]]}]}], "+", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    RowBox[{
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm], 
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm]}], 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    RowBox[{
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm], 
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm]}], 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[820]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dif1", " ", "=", " ", 
  RowBox[{"w2", "-", "r4"}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[821]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]}]]}]}], "+", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]]}], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FormBox[
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]],
       TraditionalForm], 
      FormBox[
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]],
       TraditionalForm]}], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], ")"}], "+", 
   RowBox[{
    RowBox[{
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm], 
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm]}], 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    RowBox[{
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm], 
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm]}], 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    RowBox[{
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm], 
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm]}], 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[821]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dif2", "=", 
  RowBox[{"symfun", "[", 
   RowBox[{"dif1", ",", "A"}], "]"}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[822]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "+", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}]}], "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FormBox[
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]],
       TraditionalForm], 
      FormBox[
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]],
       TraditionalForm]}], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], ")"}], "+", 
   RowBox[{
    RowBox[{
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm], 
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm]}], 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    RowBox[{
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm], 
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm]}], 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    RowBox[{
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm], 
     FormBox[
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Sigma]",
         TraditionalForm],
        TraditionalForm]],
      TraditionalForm]}], 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[822]="]
}, Open  ]],

Cell["quod erat demonstrandum.", "Text",
 CellTags->"FunctionalD"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Unset", "[", 
   RowBox[{"s", "[", "\[Phi]", "]"}], "]"}], ";", 
  RowBox[{"Unset", "[", 
   RowBox[{"S", "[", "A", "]"}], "]"}], ";", 
  RowBox[{"Clear", "[", 
   RowBox[{
   "Ag", ",", "F1", ",", "F2", ",", "t1", ",", "t2", ",", "t3", ",", "t4", 
    ",", "F", ",", "r1", ",", "r2", ",", "r3", ",", "r4", ",", "symfun", ",", 
    "twof", ",", "twofnew", ",", "w0", ",", "w1", ",", "w2", ",", "dif1", ",",
     "dif2", ",", "dif3"}], "]"}]}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[823]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples of funcional differentiation as used in FeynRule", \
"Subsubsection",
 CellTags->"FunctionalD"],

Cell["This is a part of the QCD Lagrangian.", "Text",
 CellTags->"FunctionalD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Gstrong", "*", 
    RowBox[{
     RowBox[{"QuantumField", "[", 
      RowBox[{"GaugeField", ",", " ", 
       RowBox[{"LorentzIndex", "[", "li1", "]"}], ",", "  ", 
       RowBox[{"SUNIndex", "[", "si2", "]"}]}], "]"}], ".", "  ", 
     RowBox[{"QuantumField", "[", 
      RowBox[{"GaugeField", ",", " ", 
       RowBox[{"LorentzIndex", "[", "li2", "]"}], ",", "   ", 
       RowBox[{"SUNIndex", "[", "si4", "]"}]}], "]"}], " ", ".", "  ", 
     RowBox[{"QuantumField", "[", 
      RowBox[{
       RowBox[{"PartialD", "[", 
        RowBox[{"LorentzIndex", "[", "li1", "]"}], "]"}], ",", " ", 
       "GaugeField", ",", "   ", 
       RowBox[{"LorentzIndex", "[", "li2", "]"}], ",", " ", 
       RowBox[{"SUNIndex", "[", "si1", "]"}]}], "]"}]}], "*", "  ", 
    RowBox[{"SUNF", "[", 
     RowBox[{
      RowBox[{"SUNIndex", "[", "si1", "]"}], ",", " ", 
      RowBox[{"SUNIndex", "[", "si2", "]"}], ",", " ", 
      RowBox[{"SUNIndex", "[", "si4", "]"}]}], "]"}]}], ")"}], "/", 
  "4"}]], "Input",
 CellLabel->"In[824]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "4"], " ", 
   SubscriptBox["g", "s"], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["si1",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["si2",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["si4",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{
    SubsuperscriptBox[
     FormBox["A",
      TraditionalForm], 
     FormBox[
      FormBox["li1",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["si2",
       TraditionalForm],
      TraditionalForm]], ".", 
    SubsuperscriptBox[
     FormBox["A",
      TraditionalForm], 
     FormBox[
      FormBox["li2",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["si4",
       TraditionalForm],
      TraditionalForm]], ".", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["li1",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox[
      FormBox["A",
       TraditionalForm], 
      FormBox[
       FormBox["li2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["si1",
        TraditionalForm],
       TraditionalForm]]}]}]}], TraditionalForm]], "Output",
 CellLabel->"Out[824]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FunctionalD", "[", 
  RowBox[{"%", ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"QuantumField", "[", 
       RowBox[{"GaugeField", ",", 
        RowBox[{"{", "\[Mu]", "}"}], ",", 
        RowBox[{"{", "a", "}"}]}], "]"}], "[", "p", "]"}], ",", " ", 
     RowBox[{
      RowBox[{"QuantumField", "[", 
       RowBox[{"GaugeField", ",", 
        RowBox[{"{", "\[Nu]", "}"}], ",", 
        RowBox[{"{", "b", "}"}]}], "]"}], "[", "q", "]"}], ",", " ", 
     RowBox[{
      RowBox[{"QuantumField", "[", 
       RowBox[{"GaugeField", ",", 
        RowBox[{"{", "\[Rho]", "}"}], ",", 
        RowBox[{"{", "c", "}"}]}], "]"}], "[", "r", "]"}]}], "}"}]}], 
  "]"}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[825]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "4"], " ", 
   SubscriptBox["g", "s"], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["si1",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["si2",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["si4",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["si2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"li1", "\[Nu]"}]]}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["c",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["si4",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"li2", "\[Rho]"}]]}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["li1",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["a",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["si1",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"li2", "\[Mu]"}]]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["c",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["si2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"li1", "\[Rho]"}]]}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["si4",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"li2", "\[Nu]"}]]}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["li1",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["a",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["si1",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"li2", "\[Mu]"}]]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["a",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["si2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"li1", "\[Mu]"}]]}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["c",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["si4",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"li2", "\[Rho]"}]]}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["li1",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["si1",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"li2", "\[Nu]"}]]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["c",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["si2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"li1", "\[Rho]"}]]}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["a",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["si4",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"li2", "\[Mu]"}]]}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["li1",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["si1",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"li2", "\[Nu]"}]]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["a",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["si2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"li1", "\[Mu]"}]]}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["si4",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"li2", "\[Nu]"}]]}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SuperscriptBox[
         FormBox["r",
          TraditionalForm], 
         FormBox[
          FormBox["li1",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["c",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["si1",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"li2", "\[Rho]"}]]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["si2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"li1", "\[Nu]"}]]}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["a",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["si4",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"li2", "\[Mu]"}]]}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SuperscriptBox[
         FormBox["r",
          TraditionalForm], 
         FormBox[
          FormBox["li1",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["c",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["si1",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"li2", "\[Rho]"}]]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"FunctionalD",
 CellLabel->"Out[825]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Calc", "[", 
   RowBox[{"%", "//", "Calc"}], "]"}], "//", "Factor"}]], "Input",
 CellTags->"FunctionalD",
 CellLabel->"In[826]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
   SubscriptBox["g", "s"], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Rho]"}]]}]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Rho]"}]]}], "-", 
     RowBox[{
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]]}], "-", 
     RowBox[{
      SuperscriptBox[
       FormBox["r",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Rho]"}]]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["r",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Rho]"}]]}]}], ")"}]}], TraditionalForm]], "Output",\

 CellTags->"FunctionalD",
 CellLabel->"Out[826]="]
}, Open  ]]
}, Open  ]],

Cell["FV", "ObjectName",
 CellTags->"FV"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FV"],

Cell[TextData[{
 "FV[",
 StyleBox["p",
  FontSlant->"Italic"],
 ", ",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "] is the four-dimensional vector ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["p", "\[Mu]"], TraditionalForm]]],
 ". "
}], "Text",
 CellTags->"FV"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FCE",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCE",
  ButtonNote->"FCE"],
 ", ",
 ButtonBox["FCI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCI",
  ButtonNote->"FCI"],
 ", ",
 ButtonBox["FVD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FVD",
  ButtonNote->"FVD"],
 ", ",
 ButtonBox["FourVector",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FourVector",
  ButtonNote->"FourVector"],
 ", ",
 ButtonBox["Pair",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Pair",
  ButtonNote->"Pair"],
 "."
}], "Text",
 CellTags->"FV"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FV"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FV", "[", 
  RowBox[{"p", ",", "\[Mu]"}], "]"}]], "Input",
 CellTags->"FV",
 CellLabel->"In[827]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["p", "\[Mu]"], TraditionalForm]], "Output",
 CellTags->"FV",
 CellLabel->"Out[827]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FV", "[", 
  RowBox[{
   RowBox[{"p", "-", "q"}], ",", "\[Mu]"}], "]"}]], "Input",
 CellTags->"FV",
 CellLabel->"In[828]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   FormBox[
    RowBox[{"p", "-", "q"}],
    TraditionalForm], "\[Mu]"], TraditionalForm]], "Output",
 CellTags->"FV",
 CellLabel->"Out[828]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FV", "[", 
   RowBox[{"p", ",", "\[Mu]"}], "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"FV",
 CellLabel->"In[829]:="],

Cell[BoxData[
 RowBox[{"FV", "[", 
  RowBox[{"p", ",", "\[Mu]"}], "]"}]], "Output",
 CellTags->"FV",
 CellLabel->"Out[829]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FCI", "[", 
   RowBox[{"FV", "[", 
    RowBox[{"p", ",", "\[Mu]"}], "]"}], "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"FV",
 CellLabel->"In[830]:="],

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]], "Output",
 CellTags->"FV",
 CellLabel->"Out[830]//StandardForm="]
}, Open  ]],

Cell["\<\
There is no special function to expand momenta in FV; ExpandScalarProduct \
does the job.\
\>", "Text",
 CellTags->"FV"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandScalarProduct", "[", 
  RowBox[{"FV", "[", 
   RowBox[{
    RowBox[{"p", "-", "q"}], ",", "\[Mu]"}], "]"}], "]"}]], "Input",
 CellTags->"FV",
 CellLabel->"In[831]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], "-", 
   SuperscriptBox[
    FormBox["q",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"FV",
 CellLabel->"Out[831]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
 CellTags->"FV",
 CellLabel->"In[832]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pair", "[", 
   RowBox[{
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
    RowBox[{"Momentum", "[", "p", "]"}]}], "]"}], "-", 
  RowBox[{"Pair", "[", 
   RowBox[{
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
    RowBox[{"Momentum", "[", "q", "]"}]}], "]"}]}]], "Output",
 CellTags->"FV",
 CellLabel->"Out[832]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["FVD", "ObjectName",
 CellTags->"FVD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FVD"],

Cell[TextData[{
 "FVD[",
 StyleBox["p",
  FontSlant->"Italic"],
 ", ",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "] is the D-dimensional vector ",
 StyleBox["p",
  FontSlant->"Italic"],
 " with Lorentz index ",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "."
}], "Text",
 CellTags->"FVD"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FCE",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCE",
  ButtonNote->"FCE"],
 ", ",
 ButtonBox["FCI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCI",
  ButtonNote->"FCI"],
 ", ",
 ButtonBox["FV",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FV",
  ButtonNote->"FV"],
 ", ",
 ButtonBox["FourVector",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FourVector",
  ButtonNote->"FourVector"],
 ", ",
 ButtonBox["Pair",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Pair",
  ButtonNote->"Pair"],
 "."
}], "Text",
 CellTags->"FVD"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FVD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FVD", "[", 
  RowBox[{"p", ",", "\[Mu]"}], "]"}]], "Input",
 CellTags->"FVD",
 CellLabel->"In[833]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["p", "\[Mu]"], TraditionalForm]], "Output",
 CellTags->"FVD",
 CellLabel->"Out[833]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FVD", "[", 
  RowBox[{
   RowBox[{"p", "-", "q"}], ",", "\[Mu]"}], "]"}]], "Input",
 CellTags->"FVD",
 CellLabel->"In[834]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   FormBox[
    RowBox[{"p", "-", "q"}],
    TraditionalForm], "\[Mu]"], TraditionalForm]], "Output",
 CellTags->"FVD",
 CellLabel->"Out[834]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FVD", "[", 
   RowBox[{"p", ",", "\[Mu]"}], "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"FVD",
 CellLabel->"In[835]:="],

Cell[BoxData[
 RowBox[{"FVD", "[", 
  RowBox[{"p", ",", "\[Mu]"}], "]"}]], "Output",
 CellTags->"FVD",
 CellLabel->"Out[835]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FCI", "[", 
   RowBox[{"FVD", "[", 
    RowBox[{"p", ",", "\[Mu]"}], "]"}], "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"FVD",
 CellLabel->"In[836]:="],

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
   RowBox[{"Momentum", "[", 
    RowBox[{"p", ",", "D"}], "]"}]}], "]"}]], "Output",
 CellTags->"FVD",
 CellLabel->"Out[836]//StandardForm="]
}, Open  ]],

Cell["There is no special function to expand momenta in FVD.", "Text",
 CellTags->"FVD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandScalarProduct", "[", 
  RowBox[{"FVD", "[", 
   RowBox[{
    RowBox[{"p", "-", "q"}], ",", "\[Mu]"}], "]"}], "]"}]], "Input",
 CellTags->"FVD",
 CellLabel->"In[837]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], "-", 
   SuperscriptBox[
    FormBox["q",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"FVD",
 CellLabel->"Out[837]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
 CellTags->"FVD",
 CellLabel->"In[838]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pair", "[", 
   RowBox[{
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
    RowBox[{"Momentum", "[", 
     RowBox[{"p", ",", "D"}], "]"}]}], "]"}], "-", 
  RowBox[{"Pair", "[", 
   RowBox[{
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
    RowBox[{"Momentum", "[", 
     RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]], "Output",
 CellTags->"FVD",
 CellLabel->"Out[838]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["GA", "ObjectName",
 CellTags->"GA"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GA"],

Cell[TextData[{
 "GA[",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "] can be used as input for a 4-dimensional ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", 
    RowBox[{"\[Mu]", " "}]], TraditionalForm]]],
 "and is transformed into DiracGamma[LorentzIndex[",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "]] by FeynCalcInternal (=FCI).GA[",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Mu]", ",", "\[Nu]", ","}], TraditionalForm]]],
 " ...] is a short form for GA[",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "].GA[",
 Cell[BoxData[
  FormBox["\[Nu]", TraditionalForm]]],
 "]. ... ."
}], "Text",
 CellTags->"GA"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracMatrix",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracMatrix",
  ButtonNote->"DiracMatrix"],
 ", ",
 ButtonBox["GAD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GAD",
  ButtonNote->"GAD"],
 ", ",
 ButtonBox["GS",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GS",
  ButtonNote->"GS"],
 "."
}], "Text",
 CellTags->"GA"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"GA"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GA", "[", "\[Mu]", "]"}]], "Input",
 CellTags->"GA",
 CellLabel->"In[839]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Gamma]", "\[Mu]"], TraditionalForm]], "Output",
 CellTags->"GA",
 CellLabel->"Out[839]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GA", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "-", 
  RowBox[{"GA", "[", 
   RowBox[{"\[Nu]", ",", "\[Mu]"}], "]"}]}]], "Input",
 CellTags->"GA",
 CellLabel->"In[840]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
    SuperscriptBox["\[Gamma]", "\[Nu]"]}], "-", 
   RowBox[{
    SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
    SuperscriptBox["\[Gamma]", "\[Mu]"]}]}], TraditionalForm]], "Output",
 CellTags->"GA",
 CellLabel->"Out[840]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"FCI", "[", 
   RowBox[{"GA", "[", "\[Mu]", "]"}], "]"}], "]"}]], "Input",
 CellTags->"GA",
 CellLabel->"In[841]:="],

Cell[BoxData[
 RowBox[{"DiracGamma", "[", 
  RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}]], "Output",
 CellTags->"GA",
 CellLabel->"Out[841]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GA", "[", 
  RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
  "]"}]], "Input",
 CellTags->"GA",
 CellLabel->"In[842]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Rho]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Sigma]"]}], TraditionalForm]], "Output",
 CellTags->"GA",
 CellLabel->"Out[842]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"GA", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], "]"}], 
  "]"}]], "Input",
 CellTags->"GA",
 CellLabel->"In[843]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"GA", "[", "\[Mu]", "]"}], ".", 
  RowBox[{"GA", "[", "\[Nu]", "]"}], ".", 
  RowBox[{"GA", "[", "\[Rho]", "]"}], ".", 
  RowBox[{"GA", "[", "\[Sigma]", "]"}]}]], "Output",
 CellTags->"GA",
 CellLabel->"Out[843]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GA", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"GS", "[", "p", "]"}], "+", "m"}], ")"}], ".", 
  RowBox[{"GA", "[", "\[Beta]", "]"}]}]], "Input",
 CellTags->"GA",
 CellLabel->"In[844]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Alpha]"], ".", 
   RowBox[{"(", 
    RowBox[{"m", "+", 
     RowBox[{"\[Gamma]", "\[CenterDot]", "p"}]}], ")"}], ".", 
   SuperscriptBox["\[Gamma]", "\[Beta]"]}], TraditionalForm]], "Output",
 CellTags->"GA",
 CellLabel->"Out[844]="]
}, Open  ]]
}, Open  ]],

Cell["GAD", "ObjectName",
 CellTags->"GAD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GAD"],

Cell[TextData[{
 "GAD[",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "] can be used as input for a D-dimensional ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", 
    RowBox[{"\[Mu]", " "}]], TraditionalForm]]],
 "and is transformed into DiracGamma[LorentzIndex[",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 ",D],D] by FeynCalcInternal (=FCI).GAD[",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", " ", "..."}], TraditionalForm]]],
 "] is a short form for GAD[",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "].GAD[",
 Cell[BoxData[
  FormBox["\[Nu]", TraditionalForm]]],
 "]. ... ."
}], "Text",
 CellTags->"GAD"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracMatrix",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracMatrix",
  ButtonNote->"DiracMatrix"],
 ", ",
 ButtonBox["GA",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GA",
  ButtonNote->"GA"],
 ", ",
 ButtonBox["GS",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GS",
  ButtonNote->"GS"],
 "."
}], "Text",
 CellTags->"GAD"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"GAD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GAD", "[", "\[Mu]", "]"}]], "Input",
 CellTags->"GAD",
 CellLabel->"In[845]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Gamma]", "\[Mu]"], TraditionalForm]], "Output",
 CellTags->"GAD",
 CellLabel->"Out[845]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GAD", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "-", 
  RowBox[{"GAD", "[", 
   RowBox[{"\[Nu]", ",", "\[Mu]"}], "]"}]}]], "Input",
 CellTags->"GAD",
 CellLabel->"In[846]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
    SuperscriptBox["\[Gamma]", "\[Nu]"]}], "-", 
   RowBox[{
    SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
    SuperscriptBox["\[Gamma]", "\[Mu]"]}]}], TraditionalForm]], "Output",
 CellTags->"GAD",
 CellLabel->"Out[846]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"FCI", "[", 
   RowBox[{"GAD", "[", "\[Mu]", "]"}], "]"}], "]"}]], "Input",
 CellTags->"GAD",
 CellLabel->"In[847]:="],

Cell[BoxData[
 RowBox[{"DiracGamma", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", "D"}], "]"}]], "Output",
 CellTags->"GAD",
 CellLabel->"Out[847]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GAD", "[", 
  RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
  "]"}]], "Input",
 CellTags->"GAD",
 CellLabel->"In[848]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Rho]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Sigma]"]}], TraditionalForm]], "Output",
 CellTags->"GAD",
 CellLabel->"Out[848]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"GAD", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], "]"}], 
  "]"}]], "Input",
 CellTags->"GAD",
 CellLabel->"In[849]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"GAD", "[", "\[Mu]", "]"}], ".", 
  RowBox[{"GAD", "[", "\[Nu]", "]"}], ".", 
  RowBox[{"GAD", "[", "\[Rho]", "]"}], ".", 
  RowBox[{"GAD", "[", "\[Sigma]", "]"}]}]], "Output",
 CellTags->"GAD",
 CellLabel->"Out[849]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GAD", "[", "\[Alpha]", "]"}], ".", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"GSD", "[", "p", "]"}], "+", "m"}], ")"}], ".", 
  RowBox[{"GAD", "[", "\[Beta]", "]"}]}]], "Input",
 CellTags->"GAD",
 CellLabel->"In[850]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Alpha]"], ".", 
   RowBox[{"(", 
    RowBox[{"m", "+", 
     RowBox[{"\[Gamma]", "\[CenterDot]", "p"}]}], ")"}], ".", 
   SuperscriptBox["\[Gamma]", "\[Beta]"]}], TraditionalForm]], "Output",
 CellTags->"GAD",
 CellLabel->"Out[850]="]
}, Open  ]]
}, Open  ]],

Cell["GammaEpsilon", "ObjectName",
 CellTags->"GammaEpsilon"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GammaEpsilon"],

Cell["\<\
GammaEpsilon[exp] gives a series expansion of Gamma[exp] in Epsilon up to \
order 6 (where EulerGamma is neglected).\
\>", "Text",
 CellTags->"GammaEpsilon"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["GammaExpand",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GammaExpand",
  ButtonNote->"GammaExpand"],
 ", ",
 ButtonBox["Series2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Series2",
  ButtonNote->"Series2"],
 "."
}], "Text",
 CellTags->"GammaEpsilon"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"GammaEpsilon"],

Cell["\<\
If the argument is of the form (1+a Epsilon) the result is not calculated but \
tabulated.\
\>", "Text",
 CellTags->"GammaEpsilon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GammaEpsilon", "[", 
  RowBox[{"1", "+", 
   RowBox[{"a", " ", "Epsilon"}]}], "]"}]], "Input",
 CellTags->"GammaEpsilon",
 CellLabel->"In[851]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "5"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         TemplateBox[{"5"},
          "Zeta"]}], "5"]}], "-", 
      RowBox[{
       FractionBox["1", "36"], " ", 
       SuperscriptBox["\[Pi]", "2"], " ", 
       SuperscriptBox["a", "5"], " ", 
       TemplateBox[{"3"},
        "Zeta"]}]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "160"], " ", 
    SuperscriptBox["\[Pi]", "4"], " ", 
    SuperscriptBox["a", "4"], " ", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "4"]}], "-", 
   RowBox[{
    FractionBox["1", "3"], " ", 
    SuperscriptBox["a", "3"], " ", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "3"], " ", 
    TemplateBox[{"3"},
     "Zeta"]}], "+", 
   RowBox[{
    FractionBox["1", "12"], " ", 
    SuperscriptBox["\[Pi]", "2"], " ", 
    SuperscriptBox["a", "2"], " ", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "2"]}], "+", 
   RowBox[{"C$7747", " ", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "6"]}], "+", "1"}], TraditionalForm]], "Output",
 CellTags->"GammaEpsilon",
 CellLabel->"Out[851]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GammaEpsilon", "[", 
  RowBox[{"1", "-", 
   RowBox[{"Epsilon", "/", "2"}]}], "]"}]], "Input",
 CellTags->"GammaEpsilon",
 CellLabel->"In[852]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"C$7767", " ", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "6"]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[Pi]", "4"], " ", 
     SuperscriptBox[
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], "4"]}], "2560"], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[Pi]", "2"], " ", 
     SuperscriptBox[
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], "2"]}], "48"], "+", 
   RowBox[{
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "5"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Pi]", "2"], " ", 
        TemplateBox[{"3"},
         "Zeta"]}], "1152"], "+", 
      FractionBox[
       TemplateBox[{"5"},
        "Zeta"], "160"]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], "3"], " ", 
     TemplateBox[{"3"},
      "Zeta"]}], "24"], "+", "1"}], TraditionalForm]], "Output",
 CellTags->"GammaEpsilon",
 CellLabel->"Out[852]="]
}, Open  ]],

Cell["For other arguments the expansion is calculated.", "Text",
 CellTags->"GammaEpsilon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GammaEpsilon", "[", "Epsilon", "]"}]], "Input",
 CellTags->"GammaEpsilon",
 CellLabel->"In[853]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"C$8861", " ", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "6"]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[Pi]", "4"], " ", 
     SuperscriptBox[
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], "3"]}], "160"], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[Pi]", "2"], " ", 
     TagBox["\[CurlyEpsilon]",
      TraditionalForm]}], "12"], "+", 
   FractionBox["1", 
    FormBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm],
     TraditionalForm]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"61", " ", 
        SuperscriptBox["\[Pi]", "6"]}], "+", 
       RowBox[{"1680", " ", 
        SuperscriptBox[
         TemplateBox[{"2","1"},
          "PolyGamma2"], "2"]}]}], ")"}]}], "120960"], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], "2"], " ", 
     TemplateBox[{"2","1"},
      "PolyGamma2"]}], "6"], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2016"}], " ", 
        SuperscriptBox["\[Pi]", "2"], " ", 
        TemplateBox[{"5"},
         "Zeta"]}], "+", 
       RowBox[{"126", " ", 
        SuperscriptBox["\[Pi]", "4"], " ", 
        TemplateBox[{"2","1"},
         "PolyGamma2"]}], "+", 
       RowBox[{"24", " ", 
        TemplateBox[{"6","1"},
         "PolyGamma2"]}]}], ")"}]}], "120960"], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"20", " ", 
        SuperscriptBox["\[Pi]", "2"], " ", 
        TemplateBox[{"2","1"},
         "PolyGamma2"]}], "-", 
       RowBox[{"288", " ", 
        TemplateBox[{"5"},
         "Zeta"]}]}], ")"}]}], "1440"]}], TraditionalForm]], "Output",
 CellTags->"GammaEpsilon",
 CellLabel->"Out[853]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GammaEpsilon", "[", "x", "]"}]], "Input",
 CellTags->"GammaEpsilon",
 CellLabel->"In[854]:="],

Cell[BoxData[
 FormBox[
  TemplateBox[{"x"},
   "Gamma"], TraditionalForm]], "Output",
 CellTags->"GammaEpsilon",
 CellLabel->"Out[854]="]
}, Open  ]]
}, Open  ]],

Cell["GammaExpand", "ObjectName",
 CellTags->"GammaExpand"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GammaExpand"],

Cell["\<\
GammaExpand[exp] rewrites Gamma[n + m] in exp (where n has Head Integer).\
\>", "Text",
 CellTags->"GammaExpand"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["GammaEpsilon",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GammaEpsilon",
  ButtonNote->"GammaEpsilon"],
 "."
}], "Text",
 CellTags->"GammaExpand"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"GammaExpand"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GammaExpand", "[", 
  RowBox[{"Gamma", "[", 
   RowBox[{"2", " ", "+", " ", "Epsilon"}], "]"}], "]"}]], "Input",
 CellTags->"GammaExpand",
 CellLabel->"In[855]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "+", "1"}], ")"}], " ", 
   TemplateBox[{RowBox[{
       TagBox["\[CurlyEpsilon]", TraditionalForm], "+", "1"}]},
    "Gamma"]}], TraditionalForm]], "Output",
 CellTags->"GammaExpand",
 CellLabel->"Out[855]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GammaExpand", "[", 
  RowBox[{"Gamma", "[", 
   RowBox[{
    RowBox[{"-", "3"}], "+", "Epsilon"}], "]"}], "]"}]], "Input",
 CellTags->"GammaExpand",
 CellLabel->"In[856]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   TemplateBox[{RowBox[{
       TagBox["\[CurlyEpsilon]", TraditionalForm], "+", "1"}]},
    "Gamma"], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], "-", "3"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], "-", "2"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], "-", "1"}], ")"}], " ", 
    TagBox["\[CurlyEpsilon]",
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"GammaExpand",
 CellLabel->"Out[856]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GammaExpand", "[", 
  RowBox[{"Gamma", "[", 
   RowBox[{"1", " ", "+", " ", "Epsilon"}], "]"}], "]"}]], "Input",
 CellTags->"GammaExpand",
 CellLabel->"In[857]:="],

Cell[BoxData[
 FormBox[
  TemplateBox[{RowBox[{
      TagBox["\[CurlyEpsilon]", TraditionalForm], "+", "1"}]},
   "Gamma"], TraditionalForm]], "Output",
 CellTags->"GammaExpand",
 CellLabel->"Out[857]="]
}, Open  ]]
}, Open  ]],

Cell["Gamma1", "ObjectName",
 CellTags->"Gamma1"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Gamma1"],

Cell["\<\
Gamma1[al,ga, be,de] is a special product of Gamma functions expanded up to \
order Epsilon^2.\
\>", "Text",
 CellTags->"Gamma1"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Gamma2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Gamma2",
  ButtonNote->"Gamma2"],
 ", ",
 ButtonBox["Gamma3",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Gamma3",
  ButtonNote->"Gamma3"],
 "."
}], "Text",
 CellTags->"Gamma1"]
}, Open  ]],

Cell["Gamma2", "ObjectName",
 CellTags->"Gamma2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Gamma2"],

Cell["\<\
Gamma2[x,y] is a special product of Gamma functions expanded up to order \
Epsilon^3 when positive integer arguments are given.\
\>", "Text",
 CellTags->"Gamma2"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Gamma1",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Gamma1",
  ButtonNote->"Gamma1"],
 ", ",
 ButtonBox["Gamma3",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Gamma3",
  ButtonNote->"Gamma3"],
 "."
}], "Text",
 CellTags->"Gamma2"]
}, Open  ]],

Cell["Gamma3", "ObjectName",
 CellTags->"Gamma3"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Gamma3"],

Cell["\<\
Gamma3[al,be,ga,ep] is a special product of Gamma functions expanded up to \
order Epsilon^n when positive integer arguments are given (the order n is \
determined by the option EpsilonOrder).\
\>", "Text",
 CellTags->"Gamma3"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Gamma1",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Gamma1",
  ButtonNote->"Gamma1"],
 ", ",
 ButtonBox["Gamma2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Gamma2",
  ButtonNote->"Gamma2"],
 "."
}], "Text",
 CellTags->"Gamma3"]
}, Open  ]],

Cell["Gauge", "ObjectName",
 CellTags->"Gauge"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Gauge"],

Cell["\<\
Gauge is an option for GluonProgagator. If set to 1 the 't Hooft Feynman \
gauge is used.\
\>", "Text",
 CellTags->"Gauge"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["$Gauge",
  BaseStyle->"AddOnsLink",
  ButtonData:>"$Gauge",
  ButtonNote->"$Gauge"],
 ", ",
 ButtonBox["GluonProgagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonProgagator",
  ButtonNote->"GluonProgagator"],
 "."
}], "Text",
 CellTags->"Gauge"]
}, Open  ]],

Cell["GaugeField", "ObjectName",
 CellTags->"GaugeField"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GaugeField"],

Cell["\<\
GaugeField is just a name. No functional properties are associated with it. \
GaugeField is used as default setting for the option QuantumField of \
FieldStrength.\
\>", "Text",
 CellTags->"GaugeField"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FieldStrength",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FieldStrength",
  ButtonNote->"FieldStrength"],
 ", ",
 ButtonBox["QuantumField",
  BaseStyle->"AddOnsLink",
  ButtonData:>"QuantumField",
  ButtonNote->"QuantumField"],
 "."
}], "Text",
 CellTags->"GaugeField"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"GaugeField"],

Cell[CellGroupData[{

Cell[BoxData["GaugeField"], "Input",
 CellTags->"GaugeField",
 CellLabel->"In[858]:="],

Cell[BoxData[
 FormBox["A", TraditionalForm]], "Output",
 CellTags->"GaugeField",
 CellLabel->"Out[858]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuantumField", "[", 
  RowBox[{"GaugeField", ",", 
   RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"SUNIndex", "[", "a", "]"}]}], "]"}]], "Input",
 CellTags->"GaugeField",
 CellLabel->"In[859]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox[
   FormBox["A",
    TraditionalForm], 
   FormBox[
    FormBox["\[Mu]",
     TraditionalForm],
    TraditionalForm], 
   FormBox[
    FormBox["a",
     TraditionalForm],
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"GaugeField",
 CellLabel->"Out[859]="]
}, Open  ]]
}, Open  ]],

Cell["GaugeXi", "ObjectName",
 CellTags->"GaugeXi"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GaugeXi"],

Cell["GaugeXi is a head for gauge parameters.", "Text",
 CellTags->"GaugeXi"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Gauge",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Gauge",
  ButtonNote->"Gauge"],
 ", ",
 ButtonBox["GaugeField",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GaugeField",
  ButtonNote->"GaugeField"],
 "."
}], "Text",
 CellTags->"GaugeXi"]
}, Open  ]],

Cell["GA5", "ObjectName",
 CellTags->"GA5"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GA5"],

Cell["GA5 is equivalent to DiracGamma[5] and denotes gamma5.", "Text",
 CellTags->"GA5"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracGamma",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGamma",
  ButtonNote->"DiracGamma"],
 ", ",
 ButtonBox["GA",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GA",
  ButtonNote->"GA"],
 ", ",
 ButtonBox["GS",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GS",
  ButtonNote->"GS"],
 "."
}], "Text",
 CellTags->"GA5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"GA5"],

Cell[CellGroupData[{

Cell[BoxData["GA5"], "Input",
 CellTags->"GA5",
 CellLabel->"In[860]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Gamma]", "5"], TraditionalForm]], "Output",
 CellTags->"GA5",
 CellLabel->"Out[860]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "Tr"}]], "Input",
 CellTags->"GA5",
 CellLabel->"In[861]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"GA5",
 CellLabel->"Out[861]="]
}, Open  ]]
}, Open  ]],

Cell["GGV", "ObjectName",
 CellTags->"GGV"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GGV"],

Cell["GGV is equivalent to GluonGhostVertex.", "Text",
 CellTags->"GGV"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["GluonGhostVertex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonGhostVertex",
  ButtonNote->"GluonGhostVertex"],
 "."
}], "Text",
 CellTags->"GGV"]
}, Open  ]],

Cell["GhostPropagator", "ObjectName",
 CellTags->"GhostPropagator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GhostPropagator"],

Cell[TextData[{
 "GhostPropagator[p, a, b] gives the ghost propagator where \"a\" and \"b\" \
are the color indices. GhostPropagator[p] omits the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Delta]", 
     RowBox[{"a", "\[NoBreak]", "b"}]], "."}], TraditionalForm]]]
}], "Text",
 CellTags->"GhostPropagator"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["GHP",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GHP",
  ButtonNote->"GHP"],
 ", ",
 ButtonBox["GluonPropagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonPropagator",
  ButtonNote->"GluonPropagator"],
 ", ",
 ButtonBox["GluonGhostVertex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonGhostVertex",
  ButtonNote->"GluonGhostVertex"],
 "."
}], "Text",
 CellTags->"GhostPropagator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "GhostPropagator", "]"}]], "Input",
 CellLabel->"In[862]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"Explicit", "\[Rule]", "False"}], "}"}], 
  TraditionalForm]], "Output",
 CellLabel->"Out[862]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"GhostPropagator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GhostPropagator", "[", 
  RowBox[{"p", ",", "a", ",", "b"}], "]"}]], "Input",
 CellTags->"GhostPropagator",
 CellLabel->"In[863]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[CapitalPi]", 
    RowBox[{"a", "b"}]], "(", "p", ")"}], TraditionalForm]], "Output",
 CellTags->"GhostPropagator",
 CellLabel->"Out[863]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GhostPropagator", "[", 
  RowBox[{"p", ",", "a", ",", "b", ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"GhostPropagator",
 CellLabel->"In[864]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]}]]}], 
   SuperscriptBox["p", "2"]], TraditionalForm]], "Output",
 CellTags->"GhostPropagator",
 CellLabel->"Out[864]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GhostPropagator", "[", "p", "]"}]], "Input",
 CellTags->"GhostPropagator",
 CellLabel->"In[865]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[CapitalPi]", "u"], "(", "p", ")"}], 
  TraditionalForm]], "Output",
 CellTags->"GhostPropagator",
 CellLabel->"Out[865]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GhostPropagator", "[", 
   RowBox[{"p", ",", "1", ",", "2"}], "]"}], "//", "Explicit"}]], "Input",
 CellTags->"GhostPropagator",
 CellLabel->"In[866]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["ci1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ci2",
        TraditionalForm],
       TraditionalForm]}]]}], 
   SuperscriptBox["p", "2"]], TraditionalForm]], "Output",
 CellTags->"GhostPropagator",
 CellLabel->"Out[866]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GhostPropagator", "[", 
     RowBox[{
      RowBox[{"-", "k"}], ",", "3", ",", "4"}], "]"}], "//", "Explicit"}], "//",
    " ", "FCE"}], "//", "StandardForm"}]], "Input",
 CellTags->"GhostPropagator",
 CellLabel->"In[867]:="],

Cell[BoxData[
 RowBox[{"\[ImaginaryI]", " ", 
  RowBox[{"FAD", "[", "k", "]"}], " ", 
  RowBox[{"SD", "[", 
   RowBox[{"ci3", ",", "ci4"}], "]"}]}]], "Output",
 CellTags->"GhostPropagator",
 CellLabel->"Out[867]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["GHP", "ObjectName",
 CellTags->"GHP"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GHP"],

Cell[TextData[{
 "GHP[p, a, b] gives the ghost propagator where \"a\" and \"b\" are the color \
indices. GHP[p] omits the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Delta]", 
     RowBox[{"a", "\[NoBreak]", "b"}]], "."}], TraditionalForm]]]
}], "Text",
 CellTags->"GHP"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["GhostPropagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GhostPropagator",
  ButtonNote->"GhostPropagator"],
 ", ",
 ButtonBox["GluonPropagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonPropagator",
  ButtonNote->"GluonPropagator"],
 ", ",
 ButtonBox["GluonGhostVertex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonGhostVertex",
  ButtonNote->"GluonGhostVertex"],
 "."
}], "Text",
 CellTags->"GHP"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"GHP"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GHP", "[", 
  RowBox[{"p", ",", "a", ",", "b"}], "]"}]], "Input",
 CellTags->"GHP",
 CellLabel->"In[868]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[CapitalPi]", 
    RowBox[{"a", "b"}]], "(", "p", ")"}], TraditionalForm]], "Output",
 CellTags->"GHP",
 CellLabel->"Out[868]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GHP", "[", "p", "]"}], "//", "Explicit"}]], "Input",
 CellTags->"GHP",
 CellLabel->"In[869]:="],

Cell[BoxData[
 FormBox[
  FractionBox["\[ImaginaryI]", 
   SuperscriptBox["p", "2"]], TraditionalForm]], "Output",
 CellTags->"GHP",
 CellLabel->"Out[869]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GHP", "[", 
  RowBox[{"p", ",", "1", ",", "2"}], "]"}]], "Input",
 CellTags->"GHP",
 CellLabel->"In[870]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[CapitalPi]", 
    RowBox[{"ci1", "ci2"}]], "(", "p", ")"}], TraditionalForm]], "Output",
 CellTags->"GHP",
 CellLabel->"Out[870]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"FCE", "[", 
   RowBox[{
    RowBox[{"GHP", "[", 
     RowBox[{
      RowBox[{"-", "k"}], ",", "3", ",", "4"}], "]"}], "//", "Explicit"}], 
   "]"}], "]"}]], "Input",
 CellTags->"GHP",
 CellLabel->"In[871]:="],

Cell[BoxData[
 RowBox[{"\[ImaginaryI]", " ", 
  RowBox[{"FAD", "[", "k", "]"}], " ", 
  RowBox[{"SD", "[", 
   RowBox[{"ci3", ",", "ci4"}], "]"}]}]], "Output",
 CellTags->"GHP",
 CellLabel->"Out[871]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["GluonField", "ObjectName",
 CellTags->"GluonField"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GluonField"],

Cell["GluonField is a name of a gauge field.", "Text",
 CellTags->"GluonField"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["GaugeField",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GaugeField",
  ButtonNote->"GaugeField"],
 "."
}], "Text",
 CellTags->"GluonField"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"GluonField"],

Cell[CellGroupData[{

Cell[BoxData["GluonField"], "Input",
 CellTags->"GluonField",
 CellLabel->"In[872]:="],

Cell[BoxData[
 FormBox["A", TraditionalForm]], "Output",
 CellTags->"GluonField",
 CellLabel->"Out[872]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuantumField", "[", 
  RowBox[{"GluonField", ",", 
   RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"SUNIndex", "[", "a", "]"}]}], "]"}]], "Input",
 CellTags->"GluonField",
 CellLabel->"In[873]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox[
   FormBox["A",
    TraditionalForm], 
   FormBox[
    FormBox["\[Mu]",
     TraditionalForm],
    TraditionalForm], 
   FormBox[
    FormBox["a",
     TraditionalForm],
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"GluonField",
 CellLabel->"Out[873]="]
}, Open  ]]
}, Open  ]],

Cell["GluonGhostVertex", "ObjectName",
 CellTags->"GluonGhostVertex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GluonGhostVertex"],

Cell["\<\
GluonGhostVertex[{p,mu,a}, {q,nu,b}, {k,rho,c}] or GluonGhostVertex[ p,mu,a , \
q,nu,b , k,rho,c ] yields the Gluon-Ghost vertex. The first argument \
represents the gluon and the third argument the outgoing ghost field (but \
incoming four-momentum). The dimension and the name of the coupling constant \
are determined by the options Dimension and CouplingConstant.\
\>", "Text",
 CellTags->"GluonGhostVertex"],

Cell[TextData[{
 "See also: ",
 ButtonBox["GluonPropagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonPropagator",
  ButtonNote->"GluonPropagator"],
 ", ",
 ButtonBox["GluonSelfEnergy",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonSelfEnergy",
  ButtonNote->"GluonSelfEnergy"],
 ", ",
 ButtonBox["GhostPropagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GhostPropagator",
  ButtonNote->"GhostPropagator"],
 ", ",
 ButtonBox["GluonVertex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonVertex",
  ButtonNote->"GluonVertex"],
 "."
}], "Text",
 CellTags->"GluonGhostVertex"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "GluonGhostVertex", "]"}]], "Input",
 CellTags->"GluonGhostVertex",
 CellLabel->"In[874]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Explicit", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"GluonGhostVertex",
 CellLabel->"Out[874]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"GluonGhostVertex"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GluonGhostVertex", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "\[Rho]", ",", "c"}], "}"}]}], "]"}]], "Input",
 CellTags->"GluonGhostVertex",
 CellLabel->"In[875]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     OverscriptBox["\[CapitalLambda]", "~"], "\[Mu]"], "(", "k", ")"}], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"GluonGhostVertex",
 CellLabel->"Out[875]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Explicit", "[", "%", "]"}]], "Input",
 CellLabel->"In[876]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    SubscriptBox["g", "s"]}], " ", 
   SuperscriptBox[
    FormBox["k",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellLabel->"Out[876]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GluonGhostVertex", "[", 
  RowBox[{"k", ",", "\[Mu]"}], "]"}]], "Input",
 CellLabel->"In[877]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    OverscriptBox["\[CapitalLambda]", "~"], "\[Mu]"], "(", "k", ")"}], 
  TraditionalForm]], "Output",
 CellLabel->"Out[877]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Explicit", "[", "%", "]"}]], "Input",
 CellLabel->"In[878]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    SubscriptBox["g", "s"]}], " ", 
   SuperscriptBox[
    FormBox["k",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellLabel->"Out[878]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"%", "//", "Explicit"}], "//", "StandardForm"}]], "Input",
 CellTags->"GluonGhostVertex",
 CellLabel->"In[879]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "Gstrong"}], " ", 
  RowBox[{"Pair", "[", 
   RowBox[{
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
    RowBox[{"Momentum", "[", 
     RowBox[{"k", ",", "D"}], "]"}]}], "]"}]}]], "Output",
 CellTags->"GluonGhostVertex",
 CellLabel->"Out[879]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GluonGhostVertex", "[", 
  RowBox[{"p", ",", "1", ",", "q", ",", "2", ",", "k", ",", "3"}], 
  "]"}]], "Input",
 CellTags->"GluonGhostVertex",
 CellLabel->"In[880]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     OverscriptBox["\[CapitalLambda]", "~"], "li1"], "(", "k", ")"}], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["ci1",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["ci2",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["ci3",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"GluonGhostVertex",
 CellLabel->"Out[880]="]
}, Open  ]]
}, Open  ]],

Cell["GluonPropagator", "ObjectName",
 CellTags->"GluonPropagator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GluonPropagator"],

Cell[TextData[{
 "GluonPropagator[p, {mu, a}, {nu, b}] or GluonPropagator[p, mu, a , nu, b ] \
yields the gluon propagator. GluonPropagator[p, {mu}, {nu}] or \
GluonPropagator[p, mu, nu] omits the SUNDelta. The gauge and the dimension is \
determined by the option Gauge and Dimension. The following settings of Gauge \
are possible: 1 for the Feynman gauge; ",
 Cell[BoxData[
  FormBox["\[Alpha]", TraditionalForm]]],
 " for the general covariant gauge; {Momentum[n] ,1} for the axial gauge."
}], "Text",
 CellTags->"GluonPropagator"],

Cell["GP can be used as an abbreviation of GluonPropagator.", "Text",
 CellTags->"GluonPropagator"],

Cell[CellGroupData[{

Cell[BoxData["GP"], "Input",
 CellTags->"GluonPropagator",
 CellLabel->"In[881]:="],

Cell[BoxData[
 FormBox["GluonPropagator", TraditionalForm]], "Output",
 CellTags->"GluonPropagator",
 CellLabel->"Out[881]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "GluonPropagator", "]"}]], "Input",
 CellTags->"GluonPropagator",
 CellLabel->"In[882]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"CounterTerm", "\[Rule]", "False"}], ",", 
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Explicit", "\[Rule]", "False"}], ",", 
    RowBox[{"Gauge", "\[Rule]", "1"}], ",", 
    RowBox[{"\[CapitalOmega]", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"GluonPropagator",
 CellLabel->"Out[882]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["GluonSelfEnergy",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonSelfEnergy",
  ButtonNote->"GluonSelfEnergy"],
 ", ",
 ButtonBox["GluonVertex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonVertex",
  ButtonNote->"GluonVertex"],
 ", ",
 ButtonBox["GhostPropagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GhostPropagator",
  ButtonNote->"GhostPropagator"],
 ", ",
 ButtonBox["GluonGhostVertex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonGhostVertex",
  ButtonNote->"GluonGhostVertex"],
 "."
}], "Text",
 CellTags->"GluonPropagator"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Examples"], "Subsubsection",
 CellTags->"GluonPropagator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GluonPropagator", "[", 
  RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b"}], 
  "]"}]], "Input",
 CellTags->"GluonPropagator",
 CellLabel->"In[883]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubsuperscriptBox["\[CapitalPi]", 
    RowBox[{"a", "b"}], 
    RowBox[{"\[Mu]", "\[Nu]"}]], "(", "p", ")"}], TraditionalForm]], "Output",\

 CellTags->"GluonPropagator",
 CellLabel->"Out[883]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GluonPropagator", "[", 
   RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b"}], "]"}], "//",
   "Explicit"}]], "Input",
 CellLabel->"In[884]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"\[Mu]", "\[Nu]"}]]}], 
    SuperscriptBox["p", "2"]]}], TraditionalForm]], "Output",
 CellLabel->"Out[884]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GluonPropagator", "[", 
   RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b", ",", 
    RowBox[{"Gauge", "\[Rule]", "\[Alpha]"}]}], "]"}], "//", 
  "Explicit"}]], "Input",
 CellTags->"GluonPropagator",
 CellLabel->"In[885]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox["p", "2"]], "-", 
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]]}], ")"}]}], 
   SuperscriptBox["p", "2"]], TraditionalForm]], "Output",
 CellTags->"GluonPropagator",
 CellLabel->"Out[885]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GluonPropagator", "[", 
   RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b", ",", 
    RowBox[{"Gauge", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Momentum", "[", "n", "]"}], ",", "1"}], "}"}]}]}], "]"}], "//",
   "Explicit"}]], "Input",
 CellTags->"GluonPropagator",
 CellLabel->"In[886]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Nu]"}]]}], "-", 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox[
          FormBox["n",
           TraditionalForm], "2"], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]]}], "-", 
        RowBox[{
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"], " ", 
         SuperscriptBox[
          FormBox["n",
           TraditionalForm], 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["n",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]]}]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["n",
           TraditionalForm], "\[CenterDot]", 
          FormBox["p",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox[
          FormBox["n",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        RowBox[{
         SuperscriptBox[
          FormBox["n",
           TraditionalForm], 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]]}]}], 
       RowBox[{
        FormBox["n",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}]]}], ")"}]}], 
   SuperscriptBox["p", "2"]], TraditionalForm]], "Output",
 CellTags->"GluonPropagator",
 CellLabel->"Out[886]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GluonPropagator", "[", 
   RowBox[{"p", ",", "\[Mu]", ",", "\[Nu]"}], "]"}], "//", 
  "Explicit"}]], "Input",
 CellTags->"GluonPropagator",
 CellLabel->"In[887]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"\[Mu]", "\[Nu]"}]]}], 
    SuperscriptBox["p", "2"]]}], TraditionalForm]], "Output",
 CellTags->"GluonPropagator",
 CellLabel->"Out[887]="]
}, Open  ]],

Cell["\<\
This is a convenient way to enter amplitudes by hand (GP is an abbreviation \
GluonPropagator).\
\>", "Text",
 CellTags->"GluonPropagator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Explicit", "[", 
  RowBox[{
   RowBox[{"GP", "[", 
    RowBox[{"p", ",", "1", ",", "2"}], "]"}], ",", 
   RowBox[{"Gauge", "\[Rule]", "\[Xi]"}]}], "]"}]], "Input",
 CellTags->"GluonPropagator",
 CellLabel->"In[888]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["ci1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ci2",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Xi]"}], ")"}], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["li1",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["li2",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox["p", "2"]], "-", 
      SuperscriptBox["g", 
       RowBox[{"li1", "li2"}]]}], ")"}]}], 
   SuperscriptBox["p", "2"]], TraditionalForm]], "Output",
 CellTags->"GluonPropagator",
 CellLabel->"Out[888]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GP", "[", 
     RowBox[{
      RowBox[{"-", "k"}], ",", "3", ",", "4"}], "]"}], "//", "Explicit"}], "//",
    "FCE"}], "//", "StandardForm"}]], "Input",
 CellTags->"GluonPropagator",
 CellLabel->"In[889]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "\[ImaginaryI]"}], " ", 
  RowBox[{"FAD", "[", "k", "]"}], " ", 
  RowBox[{"MTD", "[", 
   RowBox[{"li3", ",", "li4"}], "]"}], " ", 
  RowBox[{"SD", "[", 
   RowBox[{"ci3", ",", "ci4"}], "]"}]}]], "Output",
 CellTags->"GluonPropagator",
 CellLabel->"Out[889]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GluonPropagator", "[", 
   RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b", ",", 
    RowBox[{"CounterTerm", "\[Rule]", " ", "1"}]}], "]"}], "//", 
  "Explicit"}]], "Input",
 CellTags->"GluonPropagator",
 CellLabel->"In[890]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["C", "A"], " ", 
     SubsuperscriptBox["g", "s", "2"], " ", 
     SubscriptBox["S", "n"], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"11", " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]]}], "3"], "-", 
       RowBox[{
        FractionBox["19", "6"], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        SuperscriptBox["g", 
         RowBox[{"\[Mu]", "\[Nu]"}]]}]}], ")"}]}], 
    TagBox["\[CurlyEpsilon]",
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"GluonPropagator",
 CellLabel->"Out[890]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GluonPropagator", "[", 
   RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b", ",", 
    RowBox[{"CounterTerm", "\[Rule]", " ", "2"}]}], "]"}], "//", 
  "Explicit"}]], "Input",
 CellTags->"GluonPropagator",
 CellLabel->"In[891]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["C", "A"], " ", 
     SubsuperscriptBox["g", "s", "2"], " ", 
     SubscriptBox["S", "n"], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         FractionBox["1", "6"], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Nu]"}]]}]}], "-", 
       RowBox[{
        FractionBox["1", "3"], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]]}]}], ")"}]}], 
    TagBox["\[CurlyEpsilon]",
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"GluonPropagator",
 CellLabel->"Out[891]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GluonPropagator", "[", 
   RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b", ",", 
    RowBox[{"CounterTerm", "\[Rule]", " ", "3"}]}], "]"}], "//", 
  "Explicit"}]], "Input",
 CellTags->"GluonPropagator",
 CellLabel->"In[892]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SubscriptBox["T", "f"], " ", 
     SubsuperscriptBox["g", "s", "2"], " ", 
     SubscriptBox["S", "n"], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["4", "3"], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        SuperscriptBox["g", 
         RowBox[{"\[Mu]", "\[Nu]"}]]}], "-", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]]}], "3"]}], ")"}]}], 
    TagBox["\[CurlyEpsilon]",
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"GluonPropagator",
 CellLabel->"Out[892]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GluonPropagator", "[", 
   RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b", ",", 
    RowBox[{"CounterTerm", "\[Rule]", " ", "4"}]}], "]"}], "//", 
  "Explicit"}]], "Input",
 CellTags->"GluonPropagator",
 CellLabel->"In[893]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["C", "A"], " ", 
     SubsuperscriptBox["g", "s", "2"], " ", 
     SubscriptBox["S", "n"], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"10", " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]]}], "3"], "-", 
       RowBox[{
        FractionBox["10", "3"], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        SuperscriptBox["g", 
         RowBox[{"\[Mu]", "\[Nu]"}]]}]}], ")"}]}], 
    TagBox["\[CurlyEpsilon]",
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"GluonPropagator",
 CellLabel->"Out[893]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GluonPropagator", "[", 
   RowBox[{"p", ",", "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b", ",", 
    RowBox[{"CounterTerm", "\[Rule]", " ", "5"}]}], "]"}], "//", 
  "Explicit"}]], "Input",
 CellTags->"GluonPropagator",
 CellLabel->"In[894]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["C", "A"], " ", 
     SubsuperscriptBox["g", "s", "2"], " ", 
     SubscriptBox["S", "n"], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"10", " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]]}], "3"], "-", 
       RowBox[{
        FractionBox["10", "3"], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        SuperscriptBox["g", 
         RowBox[{"\[Mu]", "\[Nu]"}]]}]}], ")"}]}], 
    TagBox["\[CurlyEpsilon]",
     TraditionalForm]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubscriptBox["T", "f"], " ", 
     SubsuperscriptBox["g", "s", "2"], " ", 
     SubscriptBox["S", "n"], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["4", "3"], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        SuperscriptBox["g", 
         RowBox[{"\[Mu]", "\[Nu]"}]]}], "-", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]]}], "3"]}], ")"}]}], 
    TagBox["\[CurlyEpsilon]",
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"GluonPropagator",
 CellLabel->"Out[894]="]
}, Open  ]]
}, Open  ]],

Cell["GluonSelfEnergy", "ObjectName",
 CellTags->"GluonSelfEnergy"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GluonSelfEnergy"],

Cell["\<\
GluonSelfEnergy[{mu, a}, {nu,b}] yields the 1-loop Gluon selfenergy.\
\>", "Text",
 CellTags->"GluonSelfEnergy"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "GluonSelfEnergy", "]"}]], "Input",
 CellTags->"GluonSelfEnergy",
 CellLabel->"In[895]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}], ",", 
    RowBox[{"FinalSubstitutions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"log", "(", 
         RowBox[{"_", " ", 
          SuperscriptBox["\[Mu]", "2"]}], ")"}], "\[RuleDelayed]", "0"}], ",", 
       RowBox[{
        TagBox["\[DoubledGamma]",
         Function[{}, EulerGamma]], "\[RuleDelayed]", 
        RowBox[{"log", "(", 
         RowBox[{"4", " ", "\[Pi]"}], ")"}]}]}], "}"}]}], ",", 
    RowBox[{"Gauge", "\[Rule]", "1"}], ",", 
    RowBox[{"Momentum", "\[Rule]", "p"}]}], "}"}], TraditionalForm]], "Output",\

 CellTags->"GluonSelfEnergy",
 CellLabel->"Out[895]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["GluonPropagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonPropagator",
  ButtonNote->"GluonPropagator"],
 ", ",
 ButtonBox["GluonVertex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonVertex",
  ButtonNote->"GluonVertex"],
 ", ",
 ButtonBox["GhostPropagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GhostPropagator",
  ButtonNote->"GhostPropagator"],
 ", ",
 ButtonBox["GluonGhostVertex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonGhostVertex",
  ButtonNote->"GluonGhostVertex"],
 "."
}], "Text",
 CellTags->"GluonSelfEnergy"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Examples"], "Subsubsection",
 CellTags->"GluonSelfEnergy"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GluonSelfEnergy", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Nu]", ",", "b"}], "}"}]}], "]"}]], "Input",
 CellTags->"GluonSelfEnergy",
 CellLabel->"In[896]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["20", 
       RowBox[{"3", " ", 
        TagBox["\[CurlyEpsilon]",
         TraditionalForm]}]], "-", 
      FractionBox["62", "9"]}], ")"}], " ", 
    SubscriptBox["C", "A"], " ", 
    SubsuperscriptBox["g", "s", "2"], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"], " ", 
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Nu]"}]]}]}], ")"}]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["20", "9"], "-", 
      FractionBox["8", 
       RowBox[{"3", " ", 
        TagBox["\[CurlyEpsilon]",
         TraditionalForm]}]]}], ")"}], " ", 
    SubscriptBox["T", "f"], " ", 
    SubsuperscriptBox["g", "s", "2"], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"], " ", 
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Nu]"}]]}]}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"GluonSelfEnergy",
 CellLabel->"Out[896]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GluonSelfEnergy", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"Gauge", "\[Rule]", "\[Xi]"}]}], "]"}]], "Input",
 CellTags->"GluonSelfEnergy",
 CellLabel->"In[897]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubscriptBox["C", "A"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          FractionBox["13", "3"], "-", "\[Xi]"}], ")"}]}], 
       TagBox["\[CurlyEpsilon]",
        TraditionalForm]], "-", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Xi]"}], ")"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Xi]"}], ")"}]}], "-", 
      FractionBox["62", "9"]}], ")"}], " ", 
    SubsuperscriptBox["g", "s", "2"], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"], " ", 
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Nu]"}]]}]}], ")"}]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["20", "9"], "-", 
      FractionBox["8", 
       RowBox[{"3", " ", 
        TagBox["\[CurlyEpsilon]",
         TraditionalForm]}]]}], ")"}], " ", 
    SubscriptBox["T", "f"], " ", 
    SubsuperscriptBox["g", "s", "2"], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"], " ", 
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Nu]"}]]}]}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"GluonSelfEnergy",
 CellLabel->"Out[897]="]
}, Open  ]]
}, Open  ]],

Cell["GluonVertex", "ObjectName",
 CellTags->"GluonVertex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GluonVertex"],

Cell["Note: All momenta are flowing into the vertex.", "Text",
 CellTags->"GluonVertex"],

Cell["\<\
GluonVertex[{p,mu,a}, {q,nu,b}, {k,la,c}] or GluonVertex[p,mu,a , q,nu,b , \
k,la,c ] yields the 3-gluon vertex. GluonVertex[{p,mu}, {q,nu}, {k,la}] \
yields the 3-gluon vertex without color structure and the coupling constant. \
GluonVertex[{p,mu,a}, {q,nu,b}, {k,la,c}, {s,si,d}] or GluonVertex[{mu,a}, \
{nu,b}, {la,c}, {si,d}] or GluonVertex[p,mu,a , q,nu,b , k,la,c , s,si,d] or \
GluonVertex[ mu,a , nu,b , la,c , si,d ] yields the 4-gluon vertex. The \
dimension and the name of the coupling constant are determined by the options \
Dimension and CouplingConstant.\
\>", "Text",
 CellTags->"GluonVertex"],

Cell["GV can be used as an abbreviation of GluonVertex.", "Text",
 CellTags->"GluonVertex"],

Cell[CellGroupData[{

Cell[BoxData["GV"], "Input",
 CellTags->"GluonVertex",
 CellLabel->"In[898]:="],

Cell[BoxData[
 FormBox["GluonVertex", TraditionalForm]], "Output",
 CellTags->"GluonVertex",
 CellLabel->"Out[898]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "GluonVertex", "]"}]], "Input",
 CellTags->"GluonVertex",
 CellLabel->"In[899]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Explicit", "\[Rule]", "False"}], ",", 
    RowBox[{"\[CapitalOmega]", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"GluonVertex",
 CellLabel->"Out[899]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["GluonGhostVertex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonGhostVertex",
  ButtonNote->"GluonGhostVertex"],
 ", ",
 ButtonBox["GluonPropagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonPropagator",
  ButtonNote->"GluonPropagator"],
 "."
}], "Text",
 CellTags->"GluonVertex"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"GluonVertex"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GluonVertex", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}]}], "]"}]], "Input",
 CellTags->"GluonVertex",
 CellLabel->"In[900]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{
    SuperscriptBox["V", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm]}]], "(", 
    RowBox[{
     FormBox["p",
      TraditionalForm], 
     RowBox[{",", " "}], 
     FormBox["q",
      TraditionalForm], 
     RowBox[{",", " "}], 
     FormBox["r",
      TraditionalForm]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"GluonVertex",
 CellLabel->"Out[900]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GluonVertex", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}]}], "]"}], "//", 
  "Explicit"}]], "Input",
 CellTags->"GluonVertex",
 CellLabel->"In[901]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["g", "s"], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm]], "-", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         FormBox["r",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]], "-", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]], "-", 
        SuperscriptBox[
         FormBox["r",
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 CellTags->"GluonVertex",
 CellLabel->"Out[901]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GluonVertex", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]"}], "}"}]}], "]"}]], "Input",
 CellTags->"GluonVertex",
 CellLabel->"In[902]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["V", 
    RowBox[{"\[Mu]", "\[Nu]", "\[Rho]"}]], "(", 
   RowBox[{"p", 
    RowBox[{",", " "}], "q", 
    RowBox[{",", " "}], "r"}], ")"}], TraditionalForm]], "Output",
 CellTags->"GluonVertex",
 CellLabel->"Out[902]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GluonVertex", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Rho]"}], "}"}]}], "]"}], "//", 
  "Explicit"}]], "Input",
 CellTags->"GluonVertex",
 CellLabel->"In[903]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["g", "s"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm]], "-", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         FormBox["r",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]], "-", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]], "-", 
        SuperscriptBox[
         FormBox["r",
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 CellTags->"GluonVertex",
 CellLabel->"Out[903]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GluonVertex", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "\[Sigma]", ",", "d"}], "}"}]}], "]"}]], "Input",
 CellTags->"GluonVertex",
 CellLabel->"In[904]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubsuperscriptBox["V", 
    RowBox[{"a", "b", "c", "d"}], 
    RowBox[{"\[Mu]", "\[Nu]", "\[Rho]", "\[Sigma]"}]], "(", 
   RowBox[{"p", 
    RowBox[{",", " "}], "q", 
    RowBox[{",", " "}], "r", 
    RowBox[{",", " "}], "s"}], ")"}], TraditionalForm]], "Output",
 CellTags->"GluonVertex",
 CellLabel->"Out[904]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GluonVertex", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "\[Sigma]", ",", "d"}], "}"}]}], "]"}], "//", 
  "Explicit"}]], "Input",
 CellLabel->"In[905]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   SubsuperscriptBox["g", "s", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u125",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u125",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Rho]", "\[Sigma]"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Nu]", "\[Sigma]"}]]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u125",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u125",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Rho]", "\[Sigma]"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Nu]", "\[Rho]"}]]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u125",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u125",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Nu]", "\[Sigma]"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Nu]", "\[Rho]"}]]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellLabel->"Out[905]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GluonVertex", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Rho]", ",", "c"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Sigma]", ",", "d"}], "}"}]}], "]"}]], "Input",
 CellTags->"GluonVertex",
 CellLabel->"In[906]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["W", 
   RowBox[{"a", "b", "c", "d"}]], TraditionalForm]], "Output",
 CellTags->"GluonVertex",
 CellLabel->"Out[906]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GluonVertex", "[", 
   RowBox[{
   "\[Mu]", ",", "a", ",", "\[Nu]", ",", "b", ",", "\[Rho]", ",", "c", ",", 
    "\[Sigma]", ",", "d"}], "]"}], "//", "Explicit"}]], "Input",
 CellTags->"GluonVertex",
 CellLabel->"In[907]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   SubsuperscriptBox["g", "s", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u126",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u126",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Rho]", "\[Sigma]"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Nu]", "\[Sigma]"}]]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u126",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u126",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Rho]", "\[Sigma]"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Nu]", "\[Rho]"}]]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u126",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u126",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Nu]", "\[Sigma]"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"\[Nu]", "\[Rho]"}]]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"GluonVertex",
 CellLabel->"Out[907]="]
}, Open  ]],

Cell["\<\
A very convenient way to enter diagrams by hand is to label each line hitting \
a vertex by a number and put this number after the inflowing momentum.\
\>", "Text",
 CellTags->"GluonVertex"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GV", "[", 
  RowBox[{"p", ",", "1", ",", "q", ",", "2", ",", "r", ",", "3"}], 
  "]"}]], "Input",
 CellTags->"GluonVertex",
 CellLabel->"In[908]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["ci1",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["ci2",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["ci3",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{
    SuperscriptBox["V", 
     RowBox[{
      FormBox[
       FormBox["li1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["li2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["li3",
        TraditionalForm],
       TraditionalForm]}]], "(", 
    RowBox[{
     FormBox["p",
      TraditionalForm], 
     RowBox[{",", " "}], 
     FormBox["q",
      TraditionalForm], 
     RowBox[{",", " "}], 
     FormBox["r",
      TraditionalForm]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"GluonVertex",
 CellLabel->"Out[908]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GV", "[", 
   RowBox[{
   "p", ",", "1", ",", "q", ",", "2", ",", "r", ",", "3", ",", "s", ",", 
    "4"}], "]"}], "//", "Explicit"}]], "Input",
 CellTags->"GluonVertex",
 CellLabel->"In[909]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   SubsuperscriptBox["g", "s", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["ci1",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["ci4",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u127",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["ci2",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["ci3",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u127",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"li1", "li2"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"li3", "li4"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"li1", "li3"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"li2", "li4"}]]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["ci1",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["ci3",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u127",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["ci2",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["ci4",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u127",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"li1", "li2"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"li3", "li4"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"li1", "li4"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"li2", "li3"}]]}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["ci1",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["ci2",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u127",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["ci3",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["ci4",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["u127",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"li1", "li3"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"li2", "li4"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"li1", "li4"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"li2", "li3"}]]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"GluonVertex",
 CellLabel->"Out[909]="]
}, Open  ]]
}, Open  ]],

Cell["GO", "ObjectName",
 CellTags->"GO"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GO"],

Cell["GO is equivalent to Twist2GluonOperator.", "Text",
 CellTags->"GO"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Twist2GluonOperator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Twist2GluonOperator",
  ButtonNote->"Twist2GluonOperator"],
 "."
}], "Text",
 CellTags->"GO"]
}, Open  ]],

Cell["GP", "ObjectName",
 CellTags->"GP"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GP"],

Cell["GP is equivalent to GluonPropagator.", "Text",
 CellTags->"GP"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["GluonPropagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonPropagator",
  ButtonNote->"GluonPropagator"],
 "."
}], "Text",
 CellTags->"GP"]
}, Open  ]],

Cell["GrassmannParity", "ObjectName",
 CellTags->"GrassmannParity"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GrassmannParity"],

Cell["\<\
GrassmannParity is a data type. E.g. DataType[F, GrassmannParity] = 1 \
declares F to be of bosonic type and DataType[F, GrassmannParity] = -1 of \
fermionic one.\
\>", "Text",
 CellTags->"GrassmannParity"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DataType",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DataType",
  ButtonNote->"DataType"],
 "."
}], "Text",
 CellTags->"GrassmannParity"]
}, Open  ]],

Cell["GS", "ObjectName",
 CellTags->"GS"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GS"],

Cell[TextData[{
 "GS[p] can be used as input for a 4-dimensional ",
 Cell[BoxData[
  FormBox[
   RowBox[{
   "p", " \[NegativeMediumSpace]", 
    "\[NegativeMediumSpace]\[NegativeMediumSpace]", "\[NegativeMediumSpace]", 
    "/", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"=", 
       RowBox[{"\[Gamma]", ".", "p"}]}], " ", "=", " ", 
      RowBox[{
       SubscriptBox["\[Gamma]", "\[Mu]"], 
       SuperscriptBox["p", "\[Mu]"]}]}], ")"}]}], TraditionalForm]]],
 " and is transformed into DiracGamma[Momentum[p]] by FeynCalcInternal \
(=FCI). GS[p,q, ...] is a short form for GS[p].GS[q]. ... ."
}], "Text",
 CellTags->"GS"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracGamma",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGamma",
  ButtonNote->"DiracGamma"],
 ", ",
 ButtonBox["DiracSlash",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSlash",
  ButtonNote->"DiracSlash"],
 ", ",
 ButtonBox["GA",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GA",
  ButtonNote->"GA"],
 ", ",
 ButtonBox["GAD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GAD",
  ButtonNote->"GAD"],
 "."
}], "Text",
 CellTags->"GS"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"GS"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GS", "[", "p", "]"}]], "Input",
 CellTags->"GS",
 CellLabel->"In[910]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], TraditionalForm]], "Output",
 CellTags->"GS",
 CellLabel->"Out[910]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GS", "[", "p", "]"}], "//", "FCI"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"GS",
 CellLabel->"In[911]:="],

Cell[BoxData[
 RowBox[{"DiracGamma", "[", 
  RowBox[{"Momentum", "[", "p", "]"}], "]"}]], "Output",
 CellTags->"GS",
 CellLabel->"Out[911]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GS", "[", 
  RowBox[{"p", ",", "q", ",", "r", ",", "s"}], "]"}]], "Input",
 CellTags->"GS",
 CellLabel->"In[912]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "q"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "r"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "s"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"GS",
 CellLabel->"Out[912]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GS", "[", 
   RowBox[{"p", ",", "q", ",", "r", ",", "s"}], "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"GS",
 CellLabel->"In[913]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"GS", "[", "p", "]"}], ".", 
  RowBox[{"GS", "[", "q", "]"}], ".", 
  RowBox[{"GS", "[", "r", "]"}], ".", 
  RowBox[{"GS", "[", "s", "]"}]}]], "Output",
 CellTags->"GS",
 CellLabel->"Out[913]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GS", "[", "q", "]"}], ".", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"GS", "[", "p", "]"}], "+", "m"}], ")"}], ".", 
  RowBox[{"GS", "[", "q", "]"}]}]], "Input",
 CellTags->"GS",
 CellLabel->"In[914]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "q"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"m", "+", 
     RowBox[{"\[Gamma]", "\[CenterDot]", "p"}]}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "q"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"GS",
 CellLabel->"Out[914]="]
}, Open  ]]
}, Open  ]],

Cell["GSD", "ObjectName",
 CellTags->"GSD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GSD"],

Cell[TextData[{
 "GSD[p] can be used as input for a D-dimensional ",
 Cell[BoxData[
  FormBox[
   RowBox[{
   "p", " \[NegativeMediumSpace]", 
    "\[NegativeMediumSpace]\[NegativeMediumSpace]", "\[NegativeMediumSpace]", 
    "/", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"=", 
       RowBox[{"\[Gamma]", ".", "p"}]}], " ", "=", " ", 
      RowBox[{
       SubscriptBox["\[Gamma]", "\[Mu]"], 
       SuperscriptBox["p", "\[Mu]"]}]}], ")"}]}], TraditionalForm]]],
 " and is transformed into DiracGamma[Momentum[p,D],D] by FeynCalcInternal \
(=FCI). GSD[p,q, ...] is a short form for GSD[p].GSD[q]. ... ."
}], "Text",
 CellTags->"GSD"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracGamma",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGamma",
  ButtonNote->"DiracGamma"],
 ", ",
 ButtonBox["DiracSlash",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSlash",
  ButtonNote->"DiracSlash"],
 ", ",
 ButtonBox["GA",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GA",
  ButtonNote->"GA"],
 ", ",
 ButtonBox["GAD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GAD",
  ButtonNote->"GAD"],
 "."
}], "Text",
 CellTags->"GSD"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"GSD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GSD", "[", "p", "]"}]], "Input",
 CellTags->"GSD",
 CellLabel->"In[915]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], TraditionalForm]], "Output",
 CellTags->"GSD",
 CellLabel->"Out[915]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GSD", "[", "p", "]"}], "//", "FCI"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"GSD",
 CellLabel->"In[916]:="],

Cell[BoxData[
 RowBox[{"DiracGamma", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", 
    RowBox[{"p", ",", "D"}], "]"}], ",", "D"}], "]"}]], "Output",
 CellTags->"GSD",
 CellLabel->"Out[916]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GSD", "[", 
  RowBox[{"p", ",", "q", ",", "r", ",", "s"}], "]"}]], "Input",
 CellTags->"GSD",
 CellLabel->"In[917]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "p"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "q"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "r"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "s"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"GSD",
 CellLabel->"Out[917]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GSD", "[", 
   RowBox[{"p", ",", "q", ",", "r", ",", "s"}], "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"GSD",
 CellLabel->"In[918]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"GSD", "[", "p", "]"}], ".", 
  RowBox[{"GSD", "[", "q", "]"}], ".", 
  RowBox[{"GSD", "[", "r", "]"}], ".", 
  RowBox[{"GSD", "[", "s", "]"}]}]], "Output",
 CellTags->"GSD",
 CellLabel->"Out[918]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GSD", "[", "q", "]"}], ".", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"GSD", "[", "p", "]"}], "+", "m"}], ")"}], ".", 
  RowBox[{"GSD", "[", "q", "]"}]}]], "Input",
 CellTags->"GSD",
 CellLabel->"In[919]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "q"}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"m", "+", 
     RowBox[{"\[Gamma]", "\[CenterDot]", "p"}]}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"\[Gamma]", "\[CenterDot]", "q"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"GSD",
 CellLabel->"Out[919]="]
}, Open  ]]
}, Open  ]],

Cell["Gstrong", "ObjectName",
 CellTags->"Gstrong"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Gstrong"],

Cell["Gstrong denotes the strong coupling constant.", "Text",
 CellTags->"Gstrong"],

Cell[TextData[{
 "See also: ",
 ButtonBox["CovariantD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CovariantD"],
 ", ",
 ButtonBox["FieldStrength",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FieldStrength"],
 ", ",
 ButtonBox["GluonVertex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonVertex"],
 "."
}], "Text",
 CellTags->"Gstrong"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Gstrong"],

Cell["\<\
Gstrong has no functional properties. Only a typesetting rule is defined.\
\>", "Text",
 CellTags->"Gstrong"],

Cell[CellGroupData[{

Cell[BoxData["Gstrong"], "Input",
 CellTags->"Gstrong",
 CellLabel->"In[920]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["g", "s"], TraditionalForm]], "Output",
 CellTags->"Gstrong",
 CellLabel->"Out[920]="]
}, Open  ]]
}, Open  ]],

Cell["GTI", "ObjectName",
 CellTags->"GTI"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GTI"],

Cell["GTI is like RHI, but with no functional properties.", "Text",
 CellTags->"GTI"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["RHI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RHI",
  ButtonNote->"RHI"],
 "."
}], "Text",
 CellTags->"GTI"]
}, Open  ]],

Cell["GV", "ObjectName",
 CellTags->"GV"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"GV"],

Cell["GV is equivalent to GluonVertex.", "Text",
 CellTags->"GV"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["GluonVertex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonVertex",
  ButtonNote->"GluonVertex"],
 "."
}], "Text",
 CellTags->"GV"]
}, Open  ]],

Cell["Hill", "ObjectName",
 CellTags->"Hill"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Hill"],

Cell["\<\
Hill[x, y] gives the Hill identity with arguments x and y. The returned \
object is 0.\
\>", "Text",
 CellTags->"Hill"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["SimplifyPolyLog",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SimplifyPolyLog",
  ButtonNote->"SimplifyPolyLog"],
 "."
}], "Text",
 CellTags->"Hill"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Hill"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Hill", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Input",
 CellTags->"Hill",
 CellLabel->"In[921]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"2",FractionBox[
      RowBox[{"1", "-", "a"}], 
      RowBox[{"1", "-", "b"}]]},
    "PolyLog"], "+", 
   TemplateBox[{"2",FractionBox["b", "a"]},
    "PolyLog"], "-", 
   TemplateBox[{"2",FractionBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"1", "-", "a"}], ")"}], " ", "b"}], 
      RowBox[{"a", " ", 
        RowBox[{"(", 
          RowBox[{"1", "-", "b"}], ")"}]}]]},
    "PolyLog"], "+", 
   RowBox[{
    RowBox[{"log", "(", "a", ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"log", "(", 
       RowBox[{"1", "-", "a"}], ")"}], "-", 
      RowBox[{"log", "(", 
       RowBox[{"1", "-", "b"}], ")"}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"log", "(", 
     FractionBox[
      RowBox[{"1", "-", "a"}], 
      RowBox[{"1", "-", "b"}]], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"log", "(", 
        FractionBox[
         RowBox[{"a", "-", "b"}], "a"], ")"}]}], "+", 
      RowBox[{"log", "(", 
       FractionBox[
        RowBox[{"a", "-", "b"}], 
        RowBox[{"1", "-", "b"}]], ")"}], "-", 
      RowBox[{"log", "(", "a", ")"}], "+", 
      RowBox[{"log", "(", 
       RowBox[{"1", "-", "b"}], ")"}]}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"log", "(", 
        FractionBox[
         RowBox[{"a", "-", "b"}], "a"], ")"}]}], "+", 
      RowBox[{"log", "(", 
       FractionBox[
        RowBox[{"a", "-", "b"}], 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "b"}], ")"}]}]], ")"}], "+", 
      RowBox[{"log", "(", 
       RowBox[{"1", "-", "b"}], ")"}]}], ")"}], " ", 
    RowBox[{"log", "(", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "a"}], ")"}], " ", "b"}], 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "b"}], ")"}]}]], ")"}]}], "+", 
   TemplateBox[{"2","a"},
    "PolyLog"], "-", 
   TemplateBox[{"2","b"},
    "PolyLog"], "-", 
   FractionBox[
    SuperscriptBox["\[Pi]", "2"], "6"]}], TraditionalForm]], "Output",
 CellTags->"Hill",
 CellLabel->"Out[921]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"%", " ", "/.", " ", 
    RowBox[{"a", "\[RuleDelayed]", " ", ".123"}]}], " ", "/.", " ", 
   RowBox[{"b", "\[RuleDelayed]", " ", ".656"}]}], " ", "//", " ", 
  "Chop"}]], "Input",
 CellTags->"Hill",
 CellLabel->"In[922]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"Hill",
 CellLabel->"Out[922]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Hill", "[", 
     RowBox[{"x", ",", 
      RowBox[{"x", " ", "y"}]}], "]"}], "//", "PowerExpand"}], "//", 
   "SimplifyPolyLog"}], "//", "Expand"}]], "Input",
 CellTags->"Hill",
 CellLabel->"In[923]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[Zeta]", "(", "2", ")"}], "-", 
   TemplateBox[{"2",RowBox[{"x", " ", "y"}]},
    "PolyLog"], "+", 
   TemplateBox[{"2",FractionBox[
      RowBox[{"1", "-", "x"}], 
      RowBox[{"1", "-", 
        RowBox[{"x", " ", "y"}]}]]},
    "PolyLog"], "-", 
   TemplateBox[{"2",FractionBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"1", "-", "x"}], ")"}], " ", "y"}], 
      RowBox[{"1", "-", 
        RowBox[{"x", " ", "y"}]}]]},
    "PolyLog"], "-", 
   TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
    "PolyLog"], "-", 
   TemplateBox[{"2",RowBox[{"1", "-", "y"}]},
    "PolyLog"], "-", 
   RowBox[{
    RowBox[{"log", "(", "x", ")"}], " ", 
    RowBox[{"log", "(", 
     RowBox[{"1", "-", 
      RowBox[{"x", " ", "y"}]}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "y"}], ")"}], " ", 
    RowBox[{"log", "(", "y", ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Hill",
 CellLabel->"Out[923]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"%", " ", "/.", " ", 
     RowBox[{"x", "\[RuleDelayed]", " ", ".34"}]}], "/.", " ", 
    RowBox[{"y", "\[Rule]", " ", ".6"}]}], "//", "N"}], "//", 
  "Chop"}]], "Input",
 CellTags->"Hill",
 CellLabel->"In[924]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"Hill",
 CellLabel->"Out[924]="]
}, Open  ]]
}, Open  ]],

Cell["HypergeometricAC", "ObjectName",
 CellTags->"HypergeometricAC"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"HypergeometricAC"],

Cell["\<\
HypergeometricAC[n][exp] analytically continues Hypergeometric2F1 functions \
in exp. The second argument n refers to the equation number (n) in chapter \
2.10 of \"Higher Transcendental Functions\" by Ergelyi, Magnus, \
Oberhettinger, Tricomi. In case of eq. (6) (p.109) the last line is returned \
for HypergeometricAC[6][exp], while the first equality is given by \
HypergeometricAC[61][exp]. ((2.10.1) is identical to eq. (9.5.7) of \"Special \
Functions & their Applications\" by N.N.Lebedev).\
\>", "Text",
 CellTags->"HypergeometricAC"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "HypergeometricAC", "]"}]], "Input",
 CellTags->"HypergeometricAC",
 CellLabel->"In[925]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"Collect2", "\[Rule]", "True"}], "}"}], TraditionalForm]], "Output",\

 CellTags->"HypergeometricAC",
 CellLabel->"Out[925]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["HypExplicit",
  BaseStyle->"AddOnsLink",
  ButtonData:>"HypExplicit",
  ButtonNote->"HypExplicit"],
 ", ",
 ButtonBox["HypergeometricIR",
  BaseStyle->"AddOnsLink",
  ButtonData:>"HypergeometricIR",
  ButtonNote->"HypergeometricIR"],
 ", ",
 ButtonBox["HypergeometricSE",
  BaseStyle->"AddOnsLink",
  ButtonData:>"HypergeometricSE",
  ButtonNote->"HypergeometricSE"],
 ", ",
 ButtonBox["ToHypergeometric",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ToHypergeometric",
  ButtonNote->"ToHypergeometric"],
 "."
}], "Text",
 CellTags->"HypergeometricAC"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"HypergeometricAC"],

Cell["These are all transformation rules currently built in.", "Text",
 CellTags->"HypergeometricAC"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"HypergeometricAC", "[", "1", "]"}], "[", 
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "z"}], "]"}], 
  "]"}]], "Input",
 CellTags->"HypergeometricAC",
 CellLabel->"In[926]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     TemplateBox[{"\[Gamma]"},
      "Gamma"], " ", 
     TemplateBox[{RowBox[{"\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]"}]},
      "Gamma"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "z"}], ")"}], 
      RowBox[{
       RowBox[{"-", "\[Alpha]"}], "-", "\[Beta]", "+", "\[Gamma]"}]], " ", 
     TemplateBox[{
      RowBox[{"\[Gamma]", "-", "\[Alpha]"}],
       RowBox[{"\[Gamma]", "-", "\[Beta]"}],RowBox[{
         RowBox[{"-", "\[Alpha]"}], "-", "\[Beta]", "+", "\[Gamma]", "+", 
         "1"}],RowBox[{"1", "-", "z"}]},
      "Hypergeometric2F1"]}], 
    RowBox[{
     TemplateBox[{"\[Alpha]"},
      "Gamma"], " ", 
     TemplateBox[{"\[Beta]"},
      "Gamma"]}]], "+", 
   FractionBox[
    RowBox[{
     TemplateBox[{"\[Gamma]"},
      "Gamma"], " ", 
     TemplateBox[{RowBox[{
         RowBox[{"-", "\[Alpha]"}], "-", "\[Beta]", "+", "\[Gamma]"}]},
      "Gamma"], " ", 
     TemplateBox[{
      "\[Alpha]","\[Beta]",
       RowBox[{"\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "+", "1"}],
       RowBox[{"1", "-", "z"}]},
      "Hypergeometric2F1"]}], 
    RowBox[{
     TemplateBox[{RowBox[{"\[Gamma]", "-", "\[Alpha]"}]},
      "Gamma"], " ", 
     TemplateBox[{RowBox[{"\[Gamma]", "-", "\[Beta]"}]},
      "Gamma"]}]]}], TraditionalForm]], "Output",
 CellTags->"HypergeometricAC",
 CellLabel->"Out[926]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"HypergeometricAC", "[", "2", "]"}], "[", 
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "z"}], "]"}], 
  "]"}]], "Input",
 CellTags->"HypergeometricAC",
 CellLabel->"In[927]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     TemplateBox[{"\[Gamma]"},
      "Gamma"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "z"}], ")"}], 
      RowBox[{"-", "\[Alpha]"}]], " ", 
     TemplateBox[{RowBox[{"\[Beta]", "-", "\[Alpha]"}]},
      "Gamma"], " ", 
     TemplateBox[{
      "\[Alpha]",RowBox[{"\[Alpha]", "-", "\[Gamma]", "+", "1"}],
       RowBox[{"\[Alpha]", "-", "\[Beta]", "+", "1"}],FractionBox["1", "z"]},
      "Hypergeometric2F1"]}], 
    RowBox[{
     TemplateBox[{"\[Beta]"},
      "Gamma"], " ", 
     TemplateBox[{RowBox[{"\[Gamma]", "-", "\[Alpha]"}]},
      "Gamma"]}]], "+", 
   FractionBox[
    RowBox[{
     TemplateBox[{"\[Gamma]"},
      "Gamma"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "z"}], ")"}], 
      RowBox[{"-", "\[Beta]"}]], " ", 
     TemplateBox[{RowBox[{"\[Alpha]", "-", "\[Beta]"}]},
      "Gamma"], " ", 
     TemplateBox[{
      "\[Beta]",RowBox[{"\[Beta]", "-", "\[Gamma]", "+", "1"}],RowBox[{
         RowBox[{"-", "\[Alpha]"}], "+", "\[Beta]", "+", "1"}],FractionBox[
       "1", "z"]},
      "Hypergeometric2F1"]}], 
    RowBox[{
     TemplateBox[{"\[Alpha]"},
      "Gamma"], " ", 
     TemplateBox[{RowBox[{"\[Gamma]", "-", "\[Beta]"}]},
      "Gamma"]}]]}], TraditionalForm]], "Output",
 CellTags->"HypergeometricAC",
 CellLabel->"Out[927]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"HypergeometricAC", "[", "3", "]"}], "[", 
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "z"}], "]"}], 
  "]"}]], "Input",
 CellTags->"HypergeometricAC",
 CellLabel->"In[928]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     TemplateBox[{"\[Gamma]"},
      "Gamma"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "z"}], ")"}], 
      RowBox[{"-", "\[Alpha]"}]], " ", 
     TemplateBox[{RowBox[{"\[Beta]", "-", "\[Alpha]"}]},
      "Gamma"], " ", 
     TemplateBox[{
      "\[Alpha]",RowBox[{"\[Gamma]", "-", "\[Beta]"}],
       RowBox[{"\[Alpha]", "-", "\[Beta]", "+", "1"}],FractionBox["1", 
        RowBox[{"1", "-", "z"}]]},
      "Hypergeometric2F1"]}], 
    RowBox[{
     TemplateBox[{"\[Beta]"},
      "Gamma"], " ", 
     TemplateBox[{RowBox[{"\[Gamma]", "-", "\[Alpha]"}]},
      "Gamma"]}]], "+", 
   FractionBox[
    RowBox[{
     TemplateBox[{"\[Gamma]"},
      "Gamma"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "z"}], ")"}], 
      RowBox[{"-", "\[Beta]"}]], " ", 
     TemplateBox[{RowBox[{"\[Alpha]", "-", "\[Beta]"}]},
      "Gamma"], " ", 
     TemplateBox[{"\[Beta]",RowBox[{"\[Gamma]", "-", "\[Alpha]"}],RowBox[{
         RowBox[{"-", "\[Alpha]"}], "+", "\[Beta]", "+", "1"}],FractionBox[
       "1", 
        RowBox[{"1", "-", "z"}]]},
      "Hypergeometric2F1"]}], 
    RowBox[{
     TemplateBox[{"\[Alpha]"},
      "Gamma"], " ", 
     TemplateBox[{RowBox[{"\[Gamma]", "-", "\[Beta]"}]},
      "Gamma"]}]]}], TraditionalForm]], "Output",
 CellTags->"HypergeometricAC",
 CellLabel->"Out[928]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"HypergeometricAC", "[", "4", "]"}], "[", 
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "z"}], "]"}], 
  "]"}]], "Input",
 CellTags->"HypergeometricAC",
 CellLabel->"In[929]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     TemplateBox[{"\[Gamma]"},
      "Gamma"], " ", 
     SuperscriptBox["z", 
      RowBox[{"-", "\[Alpha]"}]], " ", 
     TemplateBox[{RowBox[{
         RowBox[{"-", "\[Alpha]"}], "-", "\[Beta]", "+", "\[Gamma]"}]},
      "Gamma"], " ", 
     TemplateBox[{
      "\[Alpha]",RowBox[{"\[Alpha]", "-", "\[Gamma]", "+", "1"}],
       RowBox[{"\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]", "+", "1"}],
       RowBox[{"-", 
         FractionBox[
          RowBox[{"1", "-", "z"}], "z"]}]},
      "Hypergeometric2F1"]}], 
    RowBox[{
     TemplateBox[{RowBox[{"\[Gamma]", "-", "\[Alpha]"}]},
      "Gamma"], " ", 
     TemplateBox[{RowBox[{"\[Gamma]", "-", "\[Beta]"}]},
      "Gamma"]}]], "+", 
   FractionBox[
    RowBox[{
     TemplateBox[{"\[Gamma]"},
      "Gamma"], " ", 
     SuperscriptBox["z", 
      RowBox[{"\[Alpha]", "-", "\[Gamma]"}]], " ", 
     TemplateBox[{RowBox[{"\[Alpha]", "+", "\[Beta]", "-", "\[Gamma]"}]},
      "Gamma"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "z"}], ")"}], 
      RowBox[{
       RowBox[{"-", "\[Alpha]"}], "-", "\[Beta]", "+", "\[Gamma]"}]], " ", 
     TemplateBox[{
      RowBox[{"1", "-", "\[Alpha]"}],RowBox[{"\[Gamma]", "-", "\[Alpha]"}],
       RowBox[{
         RowBox[{"-", "\[Alpha]"}], "-", "\[Beta]", "+", "\[Gamma]", "+", 
         "1"}],RowBox[{"-", 
         FractionBox[
          RowBox[{"1", "-", "z"}], "z"]}]},
      "Hypergeometric2F1"]}], 
    RowBox[{
     TemplateBox[{"\[Alpha]"},
      "Gamma"], " ", 
     TemplateBox[{"\[Beta]"},
      "Gamma"]}]]}], TraditionalForm]], "Output",
 CellTags->"HypergeometricAC",
 CellLabel->"Out[929]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"HypergeometricAC", "[", "6", "]"}], "[", 
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "z"}], "]"}], 
  "]"}]], "Input",
 CellTags->"HypergeometricAC",
 CellLabel->"In[930]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", "z"}], ")"}], 
    RowBox[{"-", "\[Beta]"}]], " ", 
   TemplateBox[{
    "\[Beta]",RowBox[{"\[Gamma]", "-", "\[Alpha]"}],"\[Gamma]",RowBox[{"-", 
       FractionBox["z", 
        RowBox[{"1", "-", "z"}]]}]},
    "Hypergeometric2F1"]}], TraditionalForm]], "Output",
 CellTags->"HypergeometricAC",
 CellLabel->"Out[930]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"HypergeometricAC", "[", "61", "]"}], "[", 
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "z"}], "]"}], 
  "]"}]], "Input",
 CellTags->"HypergeometricAC",
 CellLabel->"In[931]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", "z"}], ")"}], 
    RowBox[{"-", "\[Alpha]"}]], " ", 
   TemplateBox[{
    "\[Alpha]",RowBox[{"\[Gamma]", "-", "\[Beta]"}],"\[Gamma]",RowBox[{"-", 
       FractionBox["z", 
        RowBox[{"1", "-", "z"}]]}]},
    "Hypergeometric2F1"]}], TraditionalForm]], "Output",
 CellTags->"HypergeometricAC",
 CellLabel->"Out[931]="]
}, Open  ]]
}, Open  ]],

Cell["HypergeometricIR", "ObjectName",
 CellTags->"HypergeometricIR"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"HypergeometricIR"],

Cell["\<\
HypergeometricIR[exp, t] substitutes for all Hypergeometric2F1[a,b,c,z] in \
exp by its Euler integral reprentation. The factor Integratedx[t, 0, 1] can \
be omitted by setting the option Integratedx \[Rule] False.\
\>", "Text",
 CellTags->"HypergeometricIR"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["HypergeometricAC",
  BaseStyle->"AddOnsLink",
  ButtonData:>"HypergeometricAC",
  ButtonNote->"HypergeometricAC"],
 ", ",
 ButtonBox["HypergeometricSE",
  BaseStyle->"AddOnsLink",
  ButtonData:>"HypergeometricSE",
  ButtonNote->"HypergeometricSE"],
 ", ",
 ButtonBox["ToHypergeometric",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ToHypergeometric",
  ButtonNote->"ToHypergeometric"],
 "."
}], "Text",
 CellTags->"HypergeometricIR"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "HypergeometricIR", "]"}]], "Input",
 CellTags->"HypergeometricIR",
 CellLabel->"In[932]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"Integratedx", "\[Rule]", "False"}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"HypergeometricIR",
 CellLabel->"Out[932]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"HypergeometricIR"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HypergeometricIR", "[", 
  RowBox[{
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], ",", "t"}], 
  "]"}]], "Input",
 CellTags->"HypergeometricIR",
 CellLabel->"In[933]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["t", 
     RowBox[{"b", "-", "1"}]], " ", 
    TemplateBox[{"c"},
     "Gamma"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"t", " ", "z"}]}], ")"}], 
     RowBox[{"-", "a"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "t"}], ")"}], 
     RowBox[{
      RowBox[{"-", "b"}], "+", "c", "-", "1"}]]}], 
   RowBox[{
    TemplateBox[{"b"},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"c", "-", "b"}]},
     "Gamma"]}]], TraditionalForm]], "Output",
 CellTags->"HypergeometricIR",
 CellLabel->"Out[933]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ToHypergeometric", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"t", "^", "b"}], " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "t"}], ")"}], "^", "c"}], " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"t", " ", "z"}]}], ")"}], "^", "a"}]}], ",", "t"}], 
  "]"}]], "Input",
 CellTags->"HypergeometricIR",
 CellLabel->"In[934]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    TemplateBox[{RowBox[{"b", "+", "1"}]},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"c", "+", "1"}]},
     "Gamma"], " ", 
    TemplateBox[{
     RowBox[{"-", "a"}],RowBox[{"b", "+", "1"}],
      RowBox[{"b", "+", "c", "+", "2"}],RowBox[{"-", "z"}]},
     "Hypergeometric2F1"]}], 
   TemplateBox[{RowBox[{"b", "+", "c", "+", "2"}]},
    "Gamma"]], TraditionalForm]], "Output",
 CellTags->"HypergeometricIR",
 CellLabel->"Out[934]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HypergeometricIR", "[", 
  RowBox[{"%", ",", "t"}], "]"}]], "Input",
 CellTags->"HypergeometricIR",
 CellLabel->"In[935]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["t", "b"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", "t"}], ")"}], "c"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t", " ", "z"}], "+", "1"}], ")"}], "a"]}], 
  TraditionalForm]], "Output",
 CellTags->"HypergeometricIR",
 CellLabel->"Out[935]="]
}, Open  ]]
}, Open  ]],

Cell["HypergeometricSE", "ObjectName",
 CellTags->"HypergeometricSE"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"HypergeometricSE"],

Cell[TextData[{
 "HypergeometricSE[exp, ",
 Cell[BoxData[
  FormBox["\[Nu]", TraditionalForm]]],
 "] expresses Hypergeometric functions by their series expansion in terms of \
a sum (the Sum is omitted and ",
 Cell[BoxData[
  FormBox["\[Nu]", TraditionalForm]]],
 ", running from 0 to ",
 Cell[BoxData[
  FormBox["\[Infinity]", TraditionalForm]]],
 ", is the summation index)."
}], "Text",
 CellTags->"HypergeometricSE"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "HypergeometricSE", "]"}]], "Input",
 CellTags->"HypergeometricSE",
 CellLabel->"In[936]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"Simplify", "\[Rule]", "FullSimplify"}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"HypergeometricSE",
 CellLabel->"Out[936]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["HypergeometricIR",
  BaseStyle->"AddOnsLink",
  ButtonData:>"HypergeometricIR",
  ButtonNote->"HypergeometricIR"],
 "."
}], "Text",
 CellTags->"HypergeometricSE"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"HypergeometricSE"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HypergeometricSE", "[", 
  RowBox[{
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], ",", "\[Nu]"}], 
  "]"}]], "Input",
 CellTags->"HypergeometricSE",
 CellLabel->"In[937]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    TemplateBox[{"c"},
     "Gamma"], " ", 
    SuperscriptBox["z", "\[Nu]"], " ", 
    TemplateBox[{RowBox[{"a", "+", "\[Nu]"}]},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"b", "+", "\[Nu]"}]},
     "Gamma"]}], 
   RowBox[{
    TemplateBox[{"a"},
     "Gamma"], " ", 
    TemplateBox[{"b"},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"\[Nu]", "+", "1"}]},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"c", "+", "\[Nu]"}]},
     "Gamma"]}]], TraditionalForm]], "Output",
 CellTags->"HypergeometricSE",
 CellLabel->"Out[937]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HypergeometricSE", "[", 
  RowBox[{
   RowBox[{"HypergeometricPFQ", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"d", ",", "e"}], "}"}], ",", "z"}], "]"}], ",", "\[Nu]"}], 
  "]"}]], "Input",
 CellTags->"HypergeometricSE",
 CellLabel->"In[938]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    TemplateBox[{"d"},
     "Gamma"], " ", 
    TemplateBox[{"e"},
     "Gamma"], " ", 
    SuperscriptBox["z", "\[Nu]"], " ", 
    TemplateBox[{RowBox[{"a", "+", "\[Nu]"}]},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"b", "+", "\[Nu]"}]},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"c", "+", "\[Nu]"}]},
     "Gamma"]}], 
   RowBox[{
    TemplateBox[{"a"},
     "Gamma"], " ", 
    TemplateBox[{"b"},
     "Gamma"], " ", 
    TemplateBox[{"c"},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"\[Nu]", "+", "1"}]},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"d", "+", "\[Nu]"}]},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"e", "+", "\[Nu]"}]},
     "Gamma"]}]], TraditionalForm]], "Output",
 CellTags->"HypergeometricSE",
 CellLabel->"Out[938]="]
}, Open  ]]
}, Open  ]],

Cell["HypExplicit", "ObjectName",
 CellTags->"HypExplicit"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"HypExplicit"],

Cell[TextData[{
 "HypExplicit[exp, ",
 Cell[BoxData[
  FormBox["\[Nu]", TraditionalForm]]],
 "] expresses Hypergeometric functions in exp by their definition in terms of \
a sum (the Sum is omitted and ",
 Cell[BoxData[
  FormBox["\[Nu]", TraditionalForm]]],
 " is the summation index)."
}], "Text",
 CellTags->"HypExplicit"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["HypergeometricIR",
  BaseStyle->"AddOnsLink",
  ButtonData:>"HypergeometricIR",
  ButtonNote->"HypergeometricIR"],
 "."
}], "Text",
 CellTags->"HypExplicit"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"HypExplicit"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Hypergeometric2F1", "[", 
  RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}]], "Input",
 CellTags->"HypExplicit",
 CellLabel->"In[939]:="],

Cell[BoxData[
 FormBox[
  TemplateBox[{"a","b","c","z"},
   "Hypergeometric2F1"], TraditionalForm]], "Output",
 CellTags->"HypExplicit",
 CellLabel->"Out[939]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HypExplicit", "[", 
  RowBox[{"%", ",", "\[Nu]"}], "]"}]], "Input",
 CellTags->"HypExplicit",
 CellLabel->"In[940]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    TemplateBox[{"c"},
     "Gamma"], " ", 
    SuperscriptBox["z", "\[Nu]"], " ", 
    TemplateBox[{RowBox[{"a", "+", "\[Nu]"}]},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"b", "+", "\[Nu]"}]},
     "Gamma"]}], 
   RowBox[{
    TemplateBox[{"a"},
     "Gamma"], " ", 
    TemplateBox[{"b"},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"\[Nu]", "+", "1"}]},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"c", "+", "\[Nu]"}]},
     "Gamma"]}]], TraditionalForm]], "Output",
 CellTags->"HypExplicit",
 CellLabel->"Out[940]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HypergeometricPFQ", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"d", ",", "e"}], "}"}], ",", "z"}], "]"}]], "Input",
 CellTags->"HypExplicit",
 CellLabel->"In[941]:="],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[
    RowBox[{
     RowBox[{
      SubscriptBox["\[InvisiblePrefixScriptBase]", "3"], 
      SubscriptBox["F", "2"]}], "\[InvisibleApplication]", 
     RowBox[{"(", 
      RowBox[{
       TagBox[
        TagBox[
         RowBox[{
          TagBox["a",
           HypergeometricPFQ,
           Editable->True,
           Selectable->True], ",", 
          TagBox["b",
           HypergeometricPFQ,
           Editable->True,
           Selectable->True], ",", 
          TagBox["c",
           HypergeometricPFQ,
           Editable->True,
           Selectable->True]}],
         InterpretTemplate[{
           SlotSequence[1]}& ]],
        HypergeometricPFQ,
        Editable->False,
        Selectable->False], ";", 
       TagBox[
        TagBox[
         RowBox[{
          TagBox["d",
           HypergeometricPFQ,
           Editable->True,
           Selectable->True], ",", 
          TagBox["e",
           HypergeometricPFQ,
           Editable->True,
           Selectable->True]}],
         InterpretTemplate[{
           SlotSequence[1]}& ]],
        HypergeometricPFQ,
        Editable->False,
        Selectable->False], ";", 
       TagBox["z",
        HypergeometricPFQ,
        Editable->True,
        Selectable->True]}], ")"}]}],
    InterpretTemplate[HypergeometricPFQ[#, #2, #3]& ],
    Editable->False,
    Selectable->False],
   HypergeometricPFQ], TraditionalForm]], "Output",
 CellTags->"HypExplicit",
 CellLabel->"Out[941]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HypExplicit", "[", 
  RowBox[{"%", ",", "\[Nu]"}], "]"}]], "Input",
 CellTags->"HypExplicit",
 CellLabel->"In[942]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    TemplateBox[{"d"},
     "Gamma"], " ", 
    TemplateBox[{"e"},
     "Gamma"], " ", 
    SuperscriptBox["z", "\[Nu]"], " ", 
    TemplateBox[{RowBox[{"a", "+", "\[Nu]"}]},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"b", "+", "\[Nu]"}]},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"c", "+", "\[Nu]"}]},
     "Gamma"]}], 
   RowBox[{
    TemplateBox[{"a"},
     "Gamma"], " ", 
    TemplateBox[{"b"},
     "Gamma"], " ", 
    TemplateBox[{"c"},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"\[Nu]", "+", "1"}]},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"d", "+", "\[Nu]"}]},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"e", "+", "\[Nu]"}]},
     "Gamma"]}]], TraditionalForm]], "Output",
 CellTags->"HypExplicit",
 CellLabel->"Out[942]="]
}, Open  ]]
}, Open  ]],

Cell["HypInt", "ObjectName",
 CellTags->"HypInt"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"HypInt"],

Cell["\<\
HypInt[exp, t]  substitutes for all  Hypergeometric2F1[a,b,c,z] in exp \
Gamma[c]/(Gamma[b] Gamma[c-b]) Integratedx[t,0,1]  t^(b-1) (1-t)^(c-b-1) (1-t \
z)^(-a).\
\>", "Text",
 CellTags->"HypInt"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"HypInt"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Hypergeometric2F1", "[", 
  RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}]], "Input",
 CellTags->"HypInt",
 CellLabel->"In[943]:="],

Cell[BoxData[
 FormBox[
  TemplateBox[{"a","b","c","z"},
   "Hypergeometric2F1"], TraditionalForm]], "Output",
 CellTags->"HypInt",
 CellLabel->"Out[943]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HypInt", "[", 
  RowBox[{"%", ",", "t"}], "]"}]], "Input",
 CellTags->"HypInt",
 CellLabel->"In[944]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["t", 
     RowBox[{"b", "-", "1"}]], " ", 
    TemplateBox[{"c"},
     "Gamma"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"t", " ", "z"}]}], ")"}], 
     RowBox[{"-", "a"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "t"}], ")"}], 
     RowBox[{
      RowBox[{"-", "b"}], "+", "c", "-", "1"}]], " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      FormBox["0",
       TraditionalForm], 
      FormBox["1",
       TraditionalForm]], 
     RowBox[{"\[DifferentialD]", 
      TagBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm,
       Editable->True], "\[VeryThinSpace]"}]}]}], 
   RowBox[{
    TemplateBox[{"b"},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"c", "-", "b"}]},
     "Gamma"]}]], TraditionalForm]], "Output",
 CellTags->"HypInt",
 CellLabel->"Out[944]="]
}, Open  ]]
}, Open  ]],

Cell["IFPD", "ObjectName",
 CellTags->"IFPD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"IFPD"],

Cell["IFPD[p, m] denotes (p^2 - m^2).", "Text",
 CellTags->"IFPD"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["PropagatorDenominator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PropagatorDenominator",
  ButtonNote->"PropagatorDenominator"],
 "."
}], "Text",
 CellTags->"IFPD"]
}, Open  ]],

Cell["IFPDOff", "ObjectName",
 CellTags->"IFPDOff"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"IFPDOff"],

Cell["\<\
IFPDOff[exp_,q1_, q2_, ...] changes from IFPD representation to \
FeynAmpDenominator[ ...]. The q1, q2, ... are the integration momenta.\
\>", "Text",
 CellTags->"IFPDOff"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["IFPD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"IFPD",
  ButtonNote->"IFPD"],
 ", ",
 ButtonBox["IFPDOn",
  BaseStyle->"AddOnsLink",
  ButtonData:>"IFPDOn",
  ButtonNote->"IFPDOn"],
 "."
}], "Text",
 CellTags->"IFPDOff"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"IFPDOff"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IFPD", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", "p", "]"}], ",", "m"}], "]"}]], "Input",
 CellTags->"IFPDOff",
 CellLabel->"In[945]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["\<\"(\"\>",
    TraditionalForm], 
   FormBox[
    SuperscriptBox["p", "2"],
    TraditionalForm], 
   FormBox["\<\" - \"\>",
    TraditionalForm], 
   FormBox[
    SuperscriptBox["m", "2"],
    TraditionalForm], 
   FormBox["\<\")\"\>",
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"IFPDOff",
 CellLabel->"Out[945]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"IFPDOff",
 CellLabel->"In[946]:="],

Cell[BoxData[
 RowBox[{"IFPD", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", "p", "]"}], ",", "m"}], "]"}]], "Output",
 CellTags->"IFPDOff",
 CellLabel->"Out[946]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IFPDOff", "[", 
  RowBox[{"%", ",", "p"}], "]"}]], "Input",
 CellTags->"IFPDOff",
 CellLabel->"In[947]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], "2"], "-", 
   SuperscriptBox["m", "2"]}], TraditionalForm]], "Output",
 CellTags->"IFPDOff",
 CellLabel->"Out[947]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"IFPDOff",
 CellLabel->"In[948]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox["m", "2"]}], "+", 
  RowBox[{"Pair", "[", 
   RowBox[{
    RowBox[{"Momentum", "[", "p", "]"}], ",", 
    RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]}]], "Output",
 CellTags->"IFPDOff",
 CellLabel->"Out[948]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["IFPDOn", "ObjectName",
 CellTags->"IFPDOn"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"IFPDOn"],

Cell["\<\
IFPDOn[exp_,q1_, q2_, ...] changes from FeynAmpDenominator[ ...] \
representation to the IFPD one (Inverse Feynman Propagator Denominator). \
I.e., FeynAmpDenominator[PropagatorDenominator[a,b]] is replaced by \
1/IFPD[a,b] and The q1, q2, ... are the integration momenta.\
\>", "Text",
 CellTags->"IFPDOn"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["IFPD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"IFPD",
  ButtonNote->"IFPD"],
 ", ",
 ButtonBox["IFPDOff",
  BaseStyle->"AddOnsLink",
  ButtonData:>"IFPDOff",
  ButtonNote->"IFPDOff"],
 "."
}], "Text",
 CellTags->"IFPDOn"]
}, Open  ]],

Cell["IncludePair", "ObjectName",
 CellTags->"IncludePair"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"IncludePair"],

Cell["\<\
IncludePair is an option for FC2RHI. Possible settings are True and False.\
\>", "Text",
 CellTags->"IncludePair"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FC2RHI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FC2RHI",
  ButtonNote->"FC2RHI"],
 "."
}], "Text",
 CellTags->"IncludePair"]
}, Open  ]],

Cell["IndexPosition", "ObjectName",
 CellTags->"IndexPosition"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"IndexPosition"],

Cell["IndexPosition is an option for FieldStrength.", "Text",
 CellTags->"IndexPosition"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FieldStrength",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FieldStrength",
  ButtonNote->"FieldStrength"],
 "."
}], "Text",
 CellTags->"IndexPosition"]
}, Open  ]],

Cell["Indices", "ObjectName",
 CellTags->"Indices"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Indices"],

Cell["\<\
Indices is an option for FORM2FeynCalc. Its default setting is Automatic. It \
may be set to a list, if the FORM-file does not contain a I(ndices) statement.\
\>", "Text",
 CellTags->"Indices"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FORM2FeynCalc",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FORM2FeynCalc",
  ButtonNote->"FORM2FeynCalc"],
 "."
}], "Text",
 CellTags->"Indices"]
}, Open  ]],

Cell["InitialFunction", "ObjectName",
 CellTags->"InitialFunction"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"InitialFunction"],

Cell["\<\
InitialFunction is an option of FeynRule the setting of which is applied to \
the first argument of FeynRule before anything else\
\>", "Text",
 CellTags->"InitialFunction"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynRule",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynRule",
  ButtonNote->"FeynRule"],
 "."
}], "Text",
 CellTags->"InitialFunction"]
}, Open  ]],

Cell["InitialSubstitutions", "ObjectName",
 CellTags->"InitialSubstitutions"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"InitialSubstitutions"],

Cell["\<\
InitialSubstitutions is an option for OneLoop and OneLoopSum and Write2. All \
substitutions indicated hereby are done at the end of the calculation.\
\>", "Text",
 CellTags->"InitialSubstitutions"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OneLoop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoop",
  ButtonNote->"OneLoop"],
 ", ",
 ButtonBox["OneLoopSum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoopSum",
  ButtonNote->"OneLoopSum"],
 ", ",
 ButtonBox["Write2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Write2",
  ButtonNote->"Write2"],
 "."
}], "Text",
 CellTags->"InitialSubstitutions"]
}, Open  ]],

Cell["InsideDiracTrace", "ObjectName",
 CellTags->"InsideDiracTrace"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"InsideDiracTrace"],

Cell["\<\
InsideDiracTrace is and option of DiracSimplify. If set to True, \
DiracSimplify assumes to operate inside a DiracTrace, i.e., products of an \
odd number of Dirac matrices are discarded. Furthermore simple traces are \
calculated (but divided by a factor 4, i.e. :  \
DiracSimplify[DiracMatrix[a,b], InsideDiracTrace\[Rule]True]  yields \
ScalarProduct[a,b]) Traces involving more than four DiracGamma's and \
DiracGamma[5] are not performed.\
\>", "Text",
 CellTags->"InsideDiracTrace"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 ", ",
 ButtonBox["DiracTrace",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrace",
  ButtonNote->"DiracTrace"],
 "."
}], "Text",
 CellTags->"InsideDiracTrace"]
}, Open  ]],

Cell["IntegralTable", "ObjectName",
 CellTags->"IntegralTable"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"IntegralTable"],

Cell["\<\
IntegralTable is an option of OneLoopSimplify, TwoLoopSimplify and \
FeynAmpDenominatorSimplify. It may be set to a list of the form : \
{FCIntegral[ ... ] \[RuleDelayed] bla, ...}.\
\>", "Text",
 CellTags->"IntegralTable"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OneLoopSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoopSimplify",
  ButtonNote->"OneLoopSimplify"],
 ", ",
 ButtonBox["TwoLoopSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TwoLoopSimplify",
  ButtonNote->"TwoLoopSimplify"],
 ", ",
 ButtonBox["FeynAmpDenominatorSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynAmpDenominatorSimplify",
  ButtonNote->"FeynAmpDenominatorSimplify"],
 "."
}], "Text",
 CellTags->"IntegralTable"]
}, Open  ]],

Cell["IntegrateByParts", "ObjectName",
 CellTags->"IntegrateByParts"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"IntegrateByParts"],

Cell["\<\
IntegrateByParts[(1-t)^(a Epsilon -1) g[t], deriv, t] does an integration by \
parts of the definite integral over t from 0 to 1.\
\>", "Text",
 CellTags->"IntegrateByParts"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "IntegrateByParts", "]"}]], "Input",
 CellTags->"IntegrateByParts",
 CellLabel->"In[949]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"Hold", "\[Rule]", "False"}], "}"}], TraditionalForm]], "Output",
 CellTags->"IntegrateByParts",
 CellLabel->"Out[949]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"IntegrateByParts"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IntegrateByParts", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "t"}], ")"}], "^", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a", " ", "Epsilon"}], "-", "1"}], ")"}]}], " ", 
    RowBox[{"g", "[", "t", "]"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "t"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "Epsilon"}], "-", "1"}], ")"}]}], ",", "t"}], 
  "]"}]], "Input",
 CellTags->"IntegrateByParts",
 CellLabel->"In[950]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "t"}], ")"}], 
      RowBox[{"a", " ", 
       TagBox["\[CurlyEpsilon]",
        TraditionalForm]}]], " ", 
     RowBox[{
      SuperscriptBox["g", "\[Prime]",
       MultilineFunction->None], "(", "t", ")"}]}], 
    RowBox[{"a", " ", 
     TagBox["\[CurlyEpsilon]",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"g", "(", "0", ")"}], 
    RowBox[{"a", " ", 
     TagBox["\[CurlyEpsilon]",
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"IntegrateByParts",
 CellLabel->"Out[950]="]
}, Open  ]]
}, Open  ]],

Cell["Integratedx", "ObjectName",
 CellTags->"Integratedx"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Integratedx"],

Cell["\<\
Integratedx[x, low, up] is a variable representing the integration operator \
Integrate[#, {x,low,up}]&.\
\>", "Text",
 CellTags->"Integratedx"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynmanParametrize",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynmanParametrize",
  ButtonNote->"FeynmanParametrize"],
 ", ",
 ButtonBox["CalculateCounterTerm",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CalculateCounterTerm",
  ButtonNote->"CalculateCounterTerm"],
 ", ",
 ButtonBox["TimedIntegrate",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TimedIntegrate",
  ButtonNote->"TimedIntegrate"],
 ", ",
 ButtonBox["HypergeometricIR",
  BaseStyle->"AddOnsLink",
  ButtonData:>"HypergeometricIR",
  ButtonNote->"HypergeometricIR"],
 ", ",
 ButtonBox["HypInt",
  BaseStyle->"AddOnsLink",
  ButtonData:>"HypInt",
  ButtonNote->"HypInt"],
 ", ",
 ButtonBox["TimedIntegrate",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TimedIntegrate",
  ButtonNote->"TimedIntegrate"],
 "."
}], "Text",
 CellTags->"Integratedx"]
}, Open  ]],

Cell["Integrate2", "ObjectName",
 CellTags->"Integrate2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Integrate2"],

Cell[TextData[{
 "Integrate2 is like Integrate, but : Integrate2[a_Plus, b__] := \
Map[Integrate2[#, b]&, a] ( more linear algebra and partial fraction \
decomposition is done) Integrate2[f[x] DeltaFunction[x], x] \[Rule] f[0] \
Integrate2[f[x] DeltaFunction[x0-x], x] \[Rule] f[x0]. Integrate2[f[x] \
DeltaFunction[a + b x], x] \[Rule] Integrate[f[x] (1/Abs[b]) \
DeltaFunction[a/b + x], x], where abs[b] \[Rule] b, if b is a Symbol, and if \
b = -c, then abs[-c] \[Rule] c, i.e., the variable contained in b is supposed \
to be positive. ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox["\[Pi]", "2"]}], TraditionalForm]]],
 " is replaced by 6 Zeta2. Integrate2[1/(1-y),{y,x,1}] is intepreted as \
distribution, i.e. as Integrate2[-1/(1-y)],{y, 0, x}] \[Rule] Log[1-y]. \
Integrate2[1/(1-x),{x,0,1}] \[Rule] 0."
}], "Text",
 CellTags->"Integrate2"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DeltaFunction",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DeltaFunction",
  ButtonNote->"DeltaFunction"],
 ", ",
 ButtonBox["Integrate3",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Integrate3",
  ButtonNote->"Integrate3"],
 ", ",
 ButtonBox["SumS",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SumS",
  ButtonNote->"SumS"],
 ", ",
 ButtonBox["SumT",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SumT",
  ButtonNote->"SumT"],
 "."
}], "Text",
 CellTags->"Integrate2"],

Cell["\<\
NOTE: Since Integrate2 does do a reordering and partial fraction \
decomposition before calling the integral table of Integrate3 it will in \
general be slower compared to Integrate3 for sums of integrals. I.e., if the \
integrand has already an expanded form and if partial fraction decomposition \
is not necessary it is more effective to use Integrate3.\
\>", "Text",
 CellTags->"Integrate2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Integrate2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Integrate2", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Log", "[", 
      RowBox[{"1", "+", "x"}], "]"}], 
     RowBox[{
      RowBox[{"Log", "[", "x", "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "x"}], ")"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
  "Timing"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[951]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0.047000000000011255`", ",", 
    RowBox[{
     TemplateBox[{"3"},
      "Zeta"], "-", 
     RowBox[{
      FractionBox["3", "2"], " ", 
      RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
      RowBox[{"log", "(", "2", ")"}]}]}]}], "}"}], TraditionalForm]], "Output",\

 CellTags->"Integrate2",
 CellLabel->"Out[951]="]
}, Open  ]],

Cell[TextData[{
 "Since Integrate2 uses table-look-up methods it is much faster than ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s Integrate."
}], "Text",
 CellTags->"Integrate2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{"PolyLog", "[", 
    RowBox[{"2", ",", 
     RowBox[{"x", "^", "2"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[952]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[Zeta]", "(", "2", ")"}], "-", "4", "+", 
   RowBox[{"4", " ", 
    RowBox[{"log", "(", "2", ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[952]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{"PolyLog", "[", 
    RowBox[{"3", ",", 
     RowBox[{"-", "x"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[953]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"\[Zeta]", "(", "2", ")"}], "2"], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     TemplateBox[{"3"},
      "Zeta"]}], "4"], "+", "1", "-", 
   RowBox[{"2", " ", 
    RowBox[{"log", "(", "2", ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[953]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{"PolyLog", "[", 
    RowBox[{"3", ",", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", "x"}], ")"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[954]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"-", 
      RowBox[{"log", "(", "2", ")"}]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{"3", " ", 
     TemplateBox[{"3"},
      "Zeta"]}], "4"], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["log", "3"], "(", "2", ")"}], "3"], "-", 
   RowBox[{
    SuperscriptBox["log", "2"], "(", "2", ")"}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"log", "(", "2", ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[954]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"DeltaFunction", "[", 
     RowBox[{"1", "-", "x"}], "]"}], " ", 
    RowBox[{"f", "[", "x", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[955]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"f", "(", "1", ")"}], TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[955]="]
}, Open  ]],

Cell[TextData[{
 "Integrate2 does integration in a Hadamard sense, i.e., ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], 
    RowBox[{
     RowBox[{"f", "(", "x", ")"}], 
     RowBox[{"\[DifferentialD]", "x"}]}], " "}], TraditionalForm]]],
 " means acutally expanding the result of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[Integral]", "\[Delta]", 
     RowBox[{"1", "-", "\[Delta]"}]], 
    RowBox[{
     RowBox[{"f", "(", "x", ")"}], 
     RowBox[{"\[DifferentialD]", "x"}]}], " "}], TraditionalForm]]],
 "up do ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", "\[Delta]", ")"}], TraditionalForm]]],
 " and neglecting all ",
 Cell[BoxData[
  FormBox["\[Delta]", TraditionalForm]]],
 "-dependent terms. E.g. ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "\[Delta]", 
      RowBox[{"1", "-", "\[Delta]"}]], 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", "x"}], ")"}]}], 
      RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "log"}], 
       RowBox[{"(", 
        RowBox[{"1", "-", "x"}], ")"}]}], 
      SubsuperscriptBox["\[VerticalSeparator]", "\[Delta]", 
       RowBox[{"1", "-", "\[Delta]"}]]}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"log", "(", "\[Delta]", ")"}]}], "+", 
       RowBox[{"log", "(", "1", ")"}]}], "\[Implies]", "0."}]}], " "}], 
   TraditionalForm]]]
}], "Text",
 ZeroWidthTimes->False,
 CellTags->"Integrate2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{"1", "/", 
    RowBox[{"(", 
     RowBox[{"1", "-", "x"}], ")"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[956]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[956]="]
}, Open  ]],

Cell[TextData[{
 "In the physics literature sometimes the \"+\" notation is used. In FeynCalc \
the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{"1", "-", "x"}]], ")"}], "+"], TraditionalForm]]],
 " is represented by ",
 Cell[BoxData[
  FormBox[
   RowBox[{"PlusDistribution", "[", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "]"}], TraditionalForm]]],
 " or just ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "/", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "x"}], ")"}], " ", "."}]}], TraditionalForm]]]
}], "Text",
 CellTags->"Integrate2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{"PlusDistribution", "[", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[957]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[957]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PolyLog", "[", 
     RowBox[{"2", ",", 
      RowBox[{"1", "-", "x"}]}], "]"}], "/", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "x"}], ")"}], "^", "2"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[958]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"2", "-", 
   RowBox[{"\[Zeta]", "(", "2", ")"}]}], TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[958]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Log", "[", "x", "]"}], " ", 
      RowBox[{"Log", "[", 
       RowBox[{"1", "+", "x"}], "]"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", "x"}], ")"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[959]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    TemplateBox[{"3"},
     "Zeta"], "8"]}], TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[959]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Log", "[", "x", "]"}], "^", "2"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "-", "x"}], ")"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[960]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", 
   TemplateBox[{"3"},
    "Zeta"]}], TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[960]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PolyLog", "[", 
     RowBox[{"2", ",", 
      RowBox[{"-", "x"}]}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", "x"}], ")"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[961]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    TemplateBox[{"3"},
     "Zeta"], "4"], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
    RowBox[{"log", "(", "2", ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[961]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Log", "[", "x", "]"}], " ", 
    RowBox[{"PolyLog", "[", 
     RowBox[{"2", ",", "x"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[962]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"3", "-", 
   RowBox[{"2", " ", 
    RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[962]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{"x", " ", 
    RowBox[{"PolyLog", "[", 
     RowBox[{"3", ",", "x"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[963]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"\[Zeta]", "(", "2", ")"}], "4"]}], "+", 
   FractionBox[
    TemplateBox[{"3"},
     "Zeta"], "2"], "+", 
   FractionBox["3", "16"]}], TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[963]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Log", "[", "x", "]"}], "^", "2"}], " ", 
      RowBox[{"Log", "[", 
       RowBox[{"1", "-", "x"}], "]"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", "x"}], ")"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[964]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
    RowBox[{
     SuperscriptBox["log", "2"], "(", "2", ")"}]}], "-", 
   RowBox[{"4", " ", 
    TemplateBox[{"4",FractionBox["1", "2"]},
     "PolyLog"]}], "+", 
   FractionBox[
    SuperscriptBox["\[Pi]", "4"], "90"], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["log", "4"], "(", "2", ")"}], "6"]}], 
  TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[964]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PolyLog", "[", 
     RowBox[{"2", ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"x", " ", 
            RowBox[{"(", 
             RowBox[{"1", "-", "z"}], ")"}]}], "+", "z"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "x", "+", 
           RowBox[{"x", " ", "z"}]}], ")"}]}], ")"}], "/", "z"}]}], "]"}], 
    "/", 
    RowBox[{"(", 
     RowBox[{"1", "-", "x", "+", 
      RowBox[{"x", " ", "z"}]}], ")"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[965]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]", " ", 
     TemplateBox[{"2",RowBox[{"-", "z"}]},
      "PolyLog"]}], 
    RowBox[{"1", "-", "z"}]], "+", 
   FractionBox[
    RowBox[{"4", " ", 
     TemplateBox[{"3",RowBox[{"1", "-", "z"}]},
      "PolyLog"]}], 
    RowBox[{"1", "-", "z"}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     TemplateBox[{"3",RowBox[{"-", "z"}]},
      "PolyLog"]}], 
    RowBox[{"1", "-", "z"}]], "+", 
   FractionBox[
    RowBox[{"4", " ", 
     TemplateBox[{"3",FractionBox["1", 
        RowBox[{"z", "+", "1"}]]},
      "PolyLog"]}], 
    RowBox[{"1", "-", "z"}]], "+", 
   FractionBox[
    RowBox[{"4", " ", 
     TemplateBox[{"3",RowBox[{"-", 
         FractionBox[
          RowBox[{"1", "-", "z"}], 
          RowBox[{"z", "+", "1"}]]}]},
      "PolyLog"]}], 
    RowBox[{"1", "-", "z"}]], "-", 
   FractionBox[
    RowBox[{"4", " ", 
     TemplateBox[{"3",FractionBox[
        RowBox[{"1", "-", "z"}], 
        RowBox[{"z", "+", "1"}]]},
      "PolyLog"]}], 
    RowBox[{"1", "-", "z"}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     TemplateBox[{"2",RowBox[{"1", "-", "z"}]},
      "PolyLog"], " ", 
     RowBox[{"log", "(", "z", ")"}]}], 
    RowBox[{"1", "-", "z"}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     TemplateBox[{"2",RowBox[{"-", "z"}]},
      "PolyLog"], " ", 
     RowBox[{"log", "(", "z", ")"}]}], 
    RowBox[{"1", "-", "z"}]], "+", 
   FractionBox[
    RowBox[{"4", " ", 
     TemplateBox[{"2",RowBox[{"-", "z"}]},
      "PolyLog"], " ", 
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "z"}], ")"}]}], 
    RowBox[{"1", "-", "z"}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{
      SubscriptBox["S", 
       RowBox[{
        FormBox["1",
         TraditionalForm], 
        FormBox["2",
         TraditionalForm]}]], "(", 
      FormBox[
       RowBox[{"1", "-", "z"}],
       TraditionalForm], ")"}]}], 
    RowBox[{"1", "-", "z"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", 
     RowBox[{"\[Zeta]", "(", "2", ")"}]}], 
    RowBox[{"1", "-", "z"}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
     RowBox[{"log", "(", "z", ")"}]}], 
    RowBox[{"1", "-", "z"}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "z"}], ")"}]}], 
    RowBox[{"1", "-", "z"}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
     RowBox[{"log", "(", 
      RowBox[{"z", "+", "1"}], ")"}]}], 
    RowBox[{"1", "-", "z"}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     TemplateBox[{"3"},
      "Zeta"]}], 
    RowBox[{"1", "-", "z"}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["log", "3"], "(", "z", ")"}], 
    RowBox[{"6", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["log", "3"], "(", 
      RowBox[{"z", "+", "1"}], ")"}]}], 
    RowBox[{"3", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "z"}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["log", "2"], "(", "z", ")"}]}], 
    RowBox[{"1", "-", "z"}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"log", "(", 
      RowBox[{"z", "+", "1"}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["log", "2"], "(", "z", ")"}]}], 
    RowBox[{"1", "-", "z"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", 
     RowBox[{
      SuperscriptBox["log", "2"], "(", "z", ")"}]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{"4", " ", 
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "z"}], ")"}], " ", 
     RowBox[{"log", "(", 
      RowBox[{"z", "+", "1"}], ")"}], " ", 
     RowBox[{"log", "(", "z", ")"}]}], 
    RowBox[{"1", "-", "z"}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]", " ", 
     RowBox[{"log", "(", 
      RowBox[{"z", "+", "1"}], ")"}], " ", 
     RowBox[{"log", "(", "z", ")"}]}], 
    RowBox[{"1", "-", "z"}]]}], TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[965]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Apart", "[", 
  RowBox[{
   RowBox[{"Integrate2", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "^", 
       RowBox[{"(", 
        RowBox[{"OPEm", "-", "1"}], ")"}]}], " ", 
      RowBox[{"PolyLog", "[", 
       RowBox[{"3", ",", 
        RowBox[{"1", "-", "x"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], ",", "OPEm"}], 
  "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[966]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"\[Zeta]", "(", "2", ")"}], 
     SuperscriptBox["m", "2"]]}], "-", 
   FractionBox[
    RowBox[{"\[Zeta]", "(", "2", ")"}], 
    RowBox[{"m", "-", "1"}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Zeta]", "(", "2", ")"}], "+", 
     RowBox[{
      RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"-", 
        RowBox[{
         SubscriptBox["S", "1"], "(", 
         FormBox[
          RowBox[{"m", "-", "2"}],
          TraditionalForm], ")"}]}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["S", "12"], "(", 
      FormBox["m",
       TraditionalForm], ")"}], "+", 
     TemplateBox[{"3"},
      "Zeta"]}], "m"]}], TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[966]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Integrate2", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "^", 
      RowBox[{"(", 
       RowBox[{"OPEm", "-", "1"}], ")"}]}], " ", 
     RowBox[{"Log", "[", 
      RowBox[{"1", "-", "x"}], "]"}], " ", 
     RowBox[{"Log", "[", "x", "]"}], " ", 
     FractionBox[
      RowBox[{"Log", "[", 
       RowBox[{"1", "+", "x"}], "]"}], 
      RowBox[{"1", "+", "x"}]]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
  "Simplify"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[967]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "360"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "m"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"450", " ", 
      RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
      RowBox[{
       SuperscriptBox["log", "2"], "(", "2", ")"}]}], "+", 
     RowBox[{"90", " ", 
      RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
      RowBox[{
       SubsuperscriptBox["S", 
        RowBox[{"-", "1"}], "2"], "(", 
       FormBox[
        RowBox[{"m", "-", "1"}],
        TraditionalForm], ")"}]}], "+", 
     RowBox[{"270", " ", 
      RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
      RowBox[{
       SubscriptBox["S", "2"], "(", 
       FormBox[
        RowBox[{"m", "-", "1"}],
        TraditionalForm], ")"}]}], "-", 
     RowBox[{"360", " ", 
      RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
      RowBox[{
       SubscriptBox["S", 
        RowBox[{"1", "-", "1"}]], "(", 
       FormBox[
        RowBox[{"m", "-", "1"}],
        TraditionalForm], ")"}]}], "-", 
     RowBox[{"180", " ", 
      RowBox[{
       SubscriptBox["S", 
        RowBox[{"-", "2"}]], "(", 
       FormBox[
        RowBox[{"m", "-", "1"}],
        TraditionalForm], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Zeta]", "(", "2", ")"}], "-", 
        RowBox[{
         RowBox[{"log", "(", "4", ")"}], " ", 
         RowBox[{
          SubscriptBox["S", 
           RowBox[{"-", "1"}]], "(", 
          FormBox[
           RowBox[{"m", "-", "1"}],
           TraditionalForm], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["log", "2"], "(", "2", ")"}]}], ")"}]}], "-", 
     RowBox[{"540", " ", 
      RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
      RowBox[{"log", "(", "2", ")"}], " ", 
      RowBox[{
       SubscriptBox["S", "1"], "(", 
       FormBox[
        RowBox[{"m", "-", "1"}],
        TraditionalForm], ")"}]}], "+", 
     RowBox[{"180", " ", 
      RowBox[{
       SubscriptBox["S", 
        RowBox[{"-", "1"}]], "(", 
       FormBox[
        RowBox[{"m", "-", "1"}],
        TraditionalForm], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
         RowBox[{"log", "(", "8", ")"}]}], "-", 
        RowBox[{"2", " ", 
         TemplateBox[{"3"},
          "Zeta"]}]}], ")"}]}], "+", 
     RowBox[{"585", " ", 
      TemplateBox[{"3"},
       "Zeta"], " ", 
      RowBox[{
       SubscriptBox["S", "1"], "(", 
       FormBox[
        RowBox[{"m", "-", "1"}],
        TraditionalForm], ")"}]}], "+", 
     RowBox[{"360", " ", 
      RowBox[{
       SubscriptBox["S", 
        RowBox[{
         RowBox[{"-", "2"}], "-", "1", "-", "1"}]], "(", 
       FormBox[
        RowBox[{"m", "-", "1"}],
        TraditionalForm], ")"}]}], "+", 
     RowBox[{"360", " ", 
      RowBox[{
       SubscriptBox["S", 
        RowBox[{
         RowBox[{"-", "1"}], "-", "2", "-", "1"}]], "(", 
       FormBox[
        RowBox[{"m", "-", "1"}],
        TraditionalForm], ")"}]}], "+", 
     RowBox[{"360", " ", 
      RowBox[{
       SubscriptBox["S", 
        RowBox[{
         RowBox[{"-", "1"}], "-", "1", "-", "2"}]], "(", 
       FormBox[
        RowBox[{"m", "-", "1"}],
        TraditionalForm], ")"}]}], "+", 
     RowBox[{"360", " ", 
      RowBox[{
       SubscriptBox["S", 
        RowBox[{"1", "-", "21"}]], "(", 
       FormBox[
        RowBox[{"m", "-", "1"}],
        TraditionalForm], ")"}]}], "+", 
     RowBox[{"360", " ", 
      RowBox[{
       SubscriptBox["S", 
        RowBox[{"1", "-", "12"}]], "(", 
       FormBox[
        RowBox[{"m", "-", "1"}],
        TraditionalForm], ")"}]}], "+", 
     RowBox[{"360", " ", 
      RowBox[{
       SubscriptBox["S", 
        RowBox[{"2", "-", "11"}]], "(", 
       FormBox[
        RowBox[{"m", "-", "1"}],
        TraditionalForm], ")"}]}], "-", 
     RowBox[{"180", " ", 
      RowBox[{
       SuperscriptBox["log", "2"], "(", "2", ")"}], " ", 
      RowBox[{
       SubscriptBox["S", "2"], "(", 
       FormBox[
        RowBox[{"m", "-", "1"}],
        TraditionalForm], ")"}]}], "+", 
     RowBox[{"360", " ", 
      RowBox[{"log", "(", "2", ")"}], " ", 
      RowBox[{
       SubscriptBox["S", "3"], "(", 
       FormBox[
        RowBox[{"m", "-", "1"}],
        TraditionalForm], ")"}]}], "-", 
     RowBox[{"360", " ", 
      RowBox[{"log", "(", "2", ")"}], " ", 
      RowBox[{
       SubscriptBox["S", 
        RowBox[{"-", "21"}]], "(", 
       FormBox[
        RowBox[{"m", "-", "1"}],
        TraditionalForm], ")"}]}], "-", 
     RowBox[{"360", " ", 
      RowBox[{"log", "(", "2", ")"}], " ", 
      RowBox[{
       SubscriptBox["S", 
        RowBox[{"-", "12"}]], "(", 
       FormBox[
        RowBox[{"m", "-", "1"}],
        TraditionalForm], ")"}]}], "-", 
     RowBox[{"720", " ", 
      TemplateBox[{"4",FractionBox["1", "2"]},
       "PolyLog"]}], "-", 
     RowBox[{"945", " ", 
      TemplateBox[{"3"},
       "Zeta"], " ", 
      RowBox[{"log", "(", "2", ")"}]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["\[Pi]", "4"]}], "-", 
     RowBox[{"30", " ", 
      RowBox[{
       SuperscriptBox["log", "4"], "(", "2", ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[967]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", " ", "/.", " ", 
  RowBox[{"OPEm", "\[Rule]", "2"}]}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[968]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "360"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"720", " ", 
      RowBox[{"\[Zeta]", "(", "2", ")"}]}], "+", 
     RowBox[{"450", " ", 
      RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
      RowBox[{
       SuperscriptBox["log", "2"], "(", "2", ")"}]}], "+", 
     RowBox[{"180", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Zeta]", "(", "2", ")"}], "-", 
        RowBox[{
         SuperscriptBox["log", "2"], "(", "2", ")"}], "+", 
        RowBox[{"log", "(", "4", ")"}]}], ")"}]}], "-", 
     RowBox[{"540", " ", 
      RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
      RowBox[{"log", "(", "2", ")"}]}], "-", 
     RowBox[{"720", " ", 
      TemplateBox[{"4",FractionBox["1", "2"]},
       "PolyLog"]}], "-", 
     RowBox[{"180", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
         RowBox[{"log", "(", "8", ")"}]}], "-", 
        RowBox[{"2", " ", 
         TemplateBox[{"3"},
          "Zeta"]}]}], ")"}]}], "+", 
     RowBox[{"585", " ", 
      TemplateBox[{"3"},
       "Zeta"]}], "-", 
     RowBox[{"945", " ", 
      TemplateBox[{"3"},
       "Zeta"], " ", 
      RowBox[{"log", "(", "2", ")"}]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["\[Pi]", "4"]}], "-", "2160", "-", 
     RowBox[{"30", " ", 
      RowBox[{
       SuperscriptBox["log", "4"], "(", "2", ")"}]}], "-", 
     RowBox[{"180", " ", 
      RowBox[{
       SuperscriptBox["log", "2"], "(", "2", ")"}]}], "+", 
     RowBox[{"1080", " ", 
      RowBox[{"log", "(", "2", ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 CellTags->"Integrate2",
 CellLabel->"Out[968]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[969]:="],

Cell[BoxData[
 FormBox["0.05051383540274483`", TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[969]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NIntegrate", "[", " ", 
  RowBox[{
   RowBox[{"x", " ", 
    RowBox[{"Log", "[", 
     RowBox[{"1", "-", "x"}], "]"}], " ", 
    RowBox[{"Log", "[", "x", "]"}], " ", 
    FractionBox[
     RowBox[{"Log", "[", 
      RowBox[{"1", "+", "x"}], "]"}], 
     RowBox[{"1", "+", "x"}]]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[970]:="],

Cell[BoxData[
 FormBox["0.050513835399059064`", TraditionalForm]], "Output",
 CellLabel->"Out[970]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "^", 
     RowBox[{"(", 
      RowBox[{"OPEm", "-", "1"}], ")"}]}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"PolyLog", "[", 
       RowBox[{"3", ",", 
        FractionBox[
         RowBox[{"1", "-", "x"}], 
         RowBox[{"1", "+", "x"}]]}], "]"}], "-", 
      RowBox[{"PolyLog", "[", 
       RowBox[{"3", ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"1", "-", "x"}], 
          RowBox[{"1", "+", "x"}]]}]}], "]"}]}], ")"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[971]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], " ", 
     RowBox[{"log", "(", "2", ")"}]}], 
    RowBox[{"2", " ", "m"}]], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
     RowBox[{"log", "(", "2", ")"}]}], 
    RowBox[{"2", " ", "m"}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], " ", 
     RowBox[{
      SubscriptBox["S", 
       RowBox[{"-", "1"}]], "(", 
      FormBox["m",
       TraditionalForm], ")"}]}], "m"], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
     RowBox[{
      SubscriptBox["S", 
       RowBox[{"-", "1"}]], "(", 
      FormBox["m",
       TraditionalForm], ")"}]}], 
    RowBox[{"2", " ", "m"}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], " ", 
     RowBox[{
      SubscriptBox["S", "1"], "(", 
      FormBox["m",
       TraditionalForm], ")"}]}], 
    RowBox[{"2", " ", "m"}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
     RowBox[{
      SubscriptBox["S", "1"], "(", 
      FormBox["m",
       TraditionalForm], ")"}]}], "m"], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], " ", 
     RowBox[{
      SubscriptBox["S", 
       RowBox[{"-", "3"}]], "(", 
      FormBox["m",
       TraditionalForm], ")"}]}], "m"], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], " ", 
     RowBox[{
      SubscriptBox["S", 
       RowBox[{"-", "2"}]], "(", 
      FormBox["m",
       TraditionalForm], ")"}], " ", 
     RowBox[{
      SubscriptBox["S", "1"], "(", 
      FormBox["m",
       TraditionalForm], ")"}]}], "m"], "+", 
   FractionBox[
    RowBox[{
     RowBox[{
      SubscriptBox["S", "1"], "(", 
      FormBox["m",
       TraditionalForm], ")"}], " ", 
     RowBox[{
      SubscriptBox["S", "2"], "(", 
      FormBox["m",
       TraditionalForm], ")"}]}], "m"], "+", 
   FractionBox[
    RowBox[{
     SubscriptBox["S", "3"], "(", 
     FormBox["m",
      TraditionalForm], ")"}], "m"], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], " ", 
     RowBox[{
      SubscriptBox["S", 
       RowBox[{"-", "21"}]], "(", 
      FormBox["m",
       TraditionalForm], ")"}]}], "m"], "-", 
   FractionBox[
    RowBox[{
     SubscriptBox["S", 
      RowBox[{
       RowBox[{"-", "1"}], "-", "2"}]], "(", 
     FormBox["m",
      TraditionalForm], ")"}], "m"], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], " ", 
     RowBox[{
      SubscriptBox["S", 
       RowBox[{"-", "12"}]], "(", 
      FormBox["m",
       TraditionalForm], ")"}]}], "m"], "-", 
   FractionBox[
    RowBox[{
     SubscriptBox["S", "21"], "(", 
     FormBox["m",
      TraditionalForm], ")"}], "m"], "-", 
   FractionBox[
    RowBox[{"7", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], " ", 
     TemplateBox[{"3"},
      "Zeta"]}], 
    RowBox[{"8", " ", "m"}]], "+", 
   FractionBox[
    RowBox[{"21", " ", 
     TemplateBox[{"3"},
      "Zeta"]}], 
    RowBox[{"8", " ", "m"}]]}], TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[971]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"OPEm", "\[Rule]", "3"}]}]], "Input",
 CellLabel->"In[972]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"\[Zeta]", "(", "2", ")"}], "2"]}], "+", 
   RowBox[{
    RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"-", 
      RowBox[{"log", "(", "2", ")"}]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{"7", " ", 
     TemplateBox[{"3"},
      "Zeta"]}], "6"], "+", 
   FractionBox["2", "3"]}], TraditionalForm]], "Output",
 CellLabel->"Out[972]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input",
 CellLabel->"In[973]:="],

Cell[BoxData[
 FormBox["0.10641794295256102`", TraditionalForm]], "Output",
 CellLabel->"Out[973]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "^", 
     RowBox[{"(", 
      RowBox[{"3", "-", "1"}], ")"}]}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"PolyLog", "[", 
       RowBox[{"3", ",", 
        FractionBox[
         RowBox[{"1", "-", "x"}], 
         RowBox[{"1", "+", "x"}]]}], "]"}], "-", 
      RowBox[{"PolyLog", "[", 
       RowBox[{"3", ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"1", "-", "x"}], 
          RowBox[{"1", "+", "x"}]]}]}], "]"}]}], ")"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[974]:="],

Cell[BoxData[
 FormBox["0.10641794295771256`", TraditionalForm]], "Output",
 CellLabel->"Out[974]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DataType", "[", 
  RowBox[{"OPEm", ",", "PositiveInteger"}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[975]:="],

Cell[BoxData[
 FormBox["True", TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[975]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "^", 
     RowBox[{"(", 
      RowBox[{"OPEm", "-", "1"}], ")"}]}], " ", 
    RowBox[{"DeltaFunction", "[", 
     RowBox[{"1", "-", "x"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[976]:="],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[976]="]
}, Open  ]],

Cell["\<\
This is the polarized non-singlet spin splitting function whose first moment \
vanishes.\
\>", "Text",
 CellTags->"Integrate2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{"SplittingFunction", "[", "PQQNS", "]"}]}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[977]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "8"}], " ", 
    SubscriptBox["C", "F"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["C", "F"], "-", 
      FractionBox[
       SubscriptBox["C", "A"], "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", "1"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"2", " ", 
            RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], "-", 
          RowBox[{"4", " ", 
           TemplateBox[{"2",RowBox[{"-", "x"}]},
            "PolyLog"]}], "+", 
          RowBox[{
           SuperscriptBox["log", "2"], "(", "x", ")"}], "-", 
          RowBox[{"4", " ", 
           RowBox[{"log", "(", 
            RowBox[{"x", "+", "1"}], ")"}], " ", 
           RowBox[{"log", "(", "x", ")"}]}]}], ")"}]}], 
       RowBox[{"x", "+", "1"}]], "+", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "x"}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"x", "+", "1"}], ")"}], " ", 
       RowBox[{"log", "(", "x", ")"}]}]}], ")"}]}], "+", 
   RowBox[{
    SubscriptBox["C", "A"], " ", 
    SubscriptBox["C", "F"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", "1"}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["log", "2"], "(", "x", ")"}]}], 
       RowBox[{"1", "-", "x"}]], "+", 
      RowBox[{"8", " ", 
       RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"x", "+", "1"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["536", "9"], "-", 
         RowBox[{"16", " ", 
          RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], ")"}], " ", 
       SubscriptBox[
        RowBox[{"(", 
         FractionBox["1", 
          RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "+", 
      RowBox[{
       RowBox[{"\[Delta]", "(", 
        FormBox[
         RowBox[{"1", "-", "x"}],
         TraditionalForm], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"88", " ", 
           RowBox[{"\[Zeta]", "(", "2", ")"}]}], "3"], "-", 
         RowBox[{"24", " ", 
          TemplateBox[{"3"},
           "Zeta"]}], "+", 
         FractionBox["17", "3"]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["4", "9"], " ", 
       RowBox[{"(", 
        RowBox[{"53", "-", 
         RowBox[{"187", " ", "x"}]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["4", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"5", " ", "x"}], "-", 
         FractionBox["22", 
          RowBox[{"1", "-", "x"}]], "+", "5"}], ")"}], " ", 
       RowBox[{"log", "(", "x", ")"}]}]}], ")"}]}], "+", 
   RowBox[{
    SubscriptBox["C", "F"], " ", 
    SubscriptBox["N", "f"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", "1"}], ")"}], " ", 
         RowBox[{"log", "(", "x", ")"}]}], 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "x"}], ")"}]}]]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", 
            RowBox[{"\[Zeta]", "(", "2", ")"}]}], "3"]}], "-", 
         FractionBox["2", "3"]}], ")"}], " ", 
       RowBox[{"\[Delta]", "(", 
        FormBox[
         RowBox[{"1", "-", "x"}],
         TraditionalForm], ")"}]}], "+", 
      FractionBox[
       RowBox[{"88", " ", "x"}], "9"], "-", 
      RowBox[{
       FractionBox["80", "9"], " ", 
       SubscriptBox[
        RowBox[{"(", 
         FractionBox["1", 
          RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "-", 
      FractionBox["8", "9"]}], ")"}]}], "+", 
   RowBox[{
    SubsuperscriptBox["C", "F", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"16", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", "1"}], ")"}], " ", 
         RowBox[{"log", "(", 
          RowBox[{"1", "-", "x"}], ")"}], " ", 
         RowBox[{"log", "(", "x", ")"}]}], 
        RowBox[{"1", "-", "x"}]]}], "+", 
      RowBox[{
       RowBox[{"\[Delta]", "(", 
        FormBox[
         RowBox[{"1", "-", "x"}],
         TraditionalForm], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"24", " ", 
           RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], "+", 
         RowBox[{"48", " ", 
          TemplateBox[{"3"},
           "Zeta"]}], "+", "3"}], ")"}]}], "-", 
      RowBox[{"40", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "x"}], ")"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"x", "+", "1"}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["log", "2"], "(", "x", ")"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "x"}], "+", 
         FractionBox["3", 
          RowBox[{"1", "-", "x"}]]}], ")"}], " ", 
       RowBox[{"log", "(", "x", ")"}]}]}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[977]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Integrate2", "[", 
   RowBox[{"t", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
  "Timing"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[978]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0.17199999999999704`", ",", "0"}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[978]="]
}, Open  ]],

Cell["\<\
Expanding t with respect to x yields a form already suitable for Integrate3 \
and therefore the following is faster:\
\>", "Text",
 CellTags->"Integrate2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Integrate3", "[", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{"t", ",", "x"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", "Expand"}], "//",
   "Timing"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[979]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0.04600000000000648`", ",", "0"}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[979]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "t", "]"}], ";"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[980]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"DeltaFunction", "[", 
     RowBox[{"1", "-", "x"}], "]"}], " ", 
    RowBox[{"f", "[", "x", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[981]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"f", "(", "1", ")"}], TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[981]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "5"], 
    RowBox[{
     RowBox[{"Log", "[", 
      RowBox[{"1", "+", "x"}], "]"}], "^", "2"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[982]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"46", " ", 
     RowBox[{"log", "(", "2", ")"}]}], "45"], "-", 
   FractionBox["6959", "10800"]}], TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[982]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "@", "%"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[983]:="],

Cell[BoxData[
 FormBox["0.06419859938720329`", TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[983]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "5"], 
    RowBox[{
     RowBox[{"Log", "[", 
      RowBox[{"1", "+", "x"}], "]"}], "^", "2"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[984]:="],

Cell[BoxData[
 FormBox["0.06419859938720252`", TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[984]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "^", 
     RowBox[{"(", 
      RowBox[{"OPEm", "-", "1"}], ")"}]}], 
    SuperscriptBox[
     RowBox[{"Log", "[", 
      RowBox[{"1", "+", "x"}], "]"}], "2"]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate2",
 CellLabel->"In[985]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "m"], " ", 
      RowBox[{
       SubsuperscriptBox["S", "1", "2"], "(", 
       FormBox["m",
        TraditionalForm], ")"}]}], "m"]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], " ", 
     RowBox[{
      SubscriptBox["S", "1"], "(", 
      FormBox[
       FractionBox[
        RowBox[{"m", "-", "1"}], "2"],
       TraditionalForm], ")"}], " ", 
     RowBox[{
      SubscriptBox["S", "1"], "(", 
      FormBox["m",
       TraditionalForm], ")"}]}], "m"], "-", 
   FractionBox[
    RowBox[{
     RowBox[{
      SubscriptBox["S", "1"], "(", 
      FormBox[
       FractionBox[
        RowBox[{"m", "-", "1"}], "2"],
       TraditionalForm], ")"}], " ", 
     RowBox[{
      SubscriptBox["S", "1"], "(", 
      FormBox["m",
       TraditionalForm], ")"}]}], "m"], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], " ", 
     RowBox[{
      SubscriptBox["S", "1"], "(", 
      FormBox[
       FractionBox["m", "2"],
       TraditionalForm], ")"}], " ", 
     RowBox[{
      SubscriptBox["S", "1"], "(", 
      FormBox["m",
       TraditionalForm], ")"}]}], "m"], "+", 
   FractionBox[
    RowBox[{
     RowBox[{
      SubscriptBox["S", "1"], "(", 
      FormBox[
       FractionBox["m", "2"],
       TraditionalForm], ")"}], " ", 
     RowBox[{
      SubscriptBox["S", "1"], "(", 
      FormBox["m",
       TraditionalForm], ")"}]}], "m"], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], " ", 
     RowBox[{
      SubscriptBox["S", "2"], "(", 
      FormBox[
       FractionBox[
        RowBox[{"m", "-", "1"}], "2"],
       TraditionalForm], ")"}]}], 
    RowBox[{"2", " ", "m"}]], "-", 
   FractionBox[
    RowBox[{
     SubscriptBox["S", "2"], "(", 
     FormBox[
      FractionBox[
       RowBox[{"m", "-", "1"}], "2"],
      TraditionalForm], ")"}], 
    RowBox[{"2", " ", "m"}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], " ", 
     RowBox[{
      SubscriptBox["S", "2"], "(", 
      FormBox[
       FractionBox["m", "2"],
       TraditionalForm], ")"}]}], 
    RowBox[{"2", " ", "m"}]], "+", 
   FractionBox[
    RowBox[{
     SubscriptBox["S", "2"], "(", 
     FormBox[
      FractionBox["m", "2"],
      TraditionalForm], ")"}], 
    RowBox[{"2", " ", "m"}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], " ", 
     RowBox[{
      SubscriptBox["S", "2"], "(", 
      FormBox["m",
       TraditionalForm], ")"}]}], "m"], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], " ", 
     RowBox[{
      SubscriptBox["S", 
       RowBox[{"-", "11"}]], "(", 
      FormBox["m",
       TraditionalForm], ")"}]}], "m"], "+", 
   FractionBox[
    RowBox[{"4", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], " ", 
     RowBox[{"log", "(", "2", ")"}], " ", 
     RowBox[{
      SubscriptBox["S", "1"], "(", 
      FormBox["m",
       TraditionalForm], ")"}]}], "m"], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], " ", 
     RowBox[{"log", "(", "2", ")"}], " ", 
     RowBox[{
      SubscriptBox["S", "1"], "(", 
      FormBox[
       FractionBox[
        RowBox[{"m", "-", "1"}], "2"],
       TraditionalForm], ")"}]}], "m"], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"log", "(", "2", ")"}], " ", 
     RowBox[{
      SubscriptBox["S", "1"], "(", 
      FormBox[
       FractionBox[
        RowBox[{"m", "-", "1"}], "2"],
       TraditionalForm], ")"}]}], "m"], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], " ", 
     RowBox[{"log", "(", "2", ")"}], " ", 
     RowBox[{
      SubscriptBox["S", "1"], "(", 
      FormBox[
       FractionBox["m", "2"],
       TraditionalForm], ")"}]}], "m"], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"log", "(", "2", ")"}], " ", 
     RowBox[{
      SubscriptBox["S", "1"], "(", 
      FormBox[
       FractionBox["m", "2"],
       TraditionalForm], ")"}]}], "m"], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], " ", 
     RowBox[{
      SuperscriptBox["log", "2"], "(", "2", ")"}]}], "m"], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["log", "2"], "(", "2", ")"}], "m"]}], 
  TraditionalForm]], "Output",
 CellTags->"Integrate2",
 CellLabel->"Out[985]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"OPEm", "\[Rule]", "4"}]}]], "Input",
 CellLabel->"In[986]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"4", " ", 
     RowBox[{"log", "(", "2", ")"}]}], "3"], "-", 
   FractionBox["241", "288"]}], TraditionalForm]], "Output",
 CellLabel->"Out[986]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input",
 CellLabel->"In[987]:="],

Cell[BoxData[
 FormBox["0.0873906851910381`", TraditionalForm]], "Output",
 CellLabel->"Out[987]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "^", 
     RowBox[{"(", 
      RowBox[{"4", "-", "1"}], ")"}]}], 
    SuperscriptBox[
     RowBox[{"Log", "[", 
      RowBox[{"1", "+", "x"}], "]"}], "2"]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[988]:="],

Cell[BoxData[
 FormBox["0.0873906851910375`", TraditionalForm]], "Output",
 CellLabel->"Out[988]="]
}, Open  ]]
}, Open  ]],

Cell["Integrate3", "ObjectName",
 CellTags->"Integrate3"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Integrate3"],

Cell["\<\
Integrate3 contains the integral table used by Integrate2. Integration is \
performed in a distributional sense. Integrate3 works more effectively on a \
sum of expressions if they are expanded or collected with respect to the \
integration variable. See the examples in Integrate2.\
\>", "Text",
 CellTags->"Integrate3"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Integrate2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Integrate2",
  ButtonNote->"Integrate2"],
 "."
}], "Text",
 CellTags->"Integrate3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Integrate3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate3", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "OPEm"], " ", 
    RowBox[{"Log", "[", "x", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate3",
 CellLabel->"In[989]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"m", "+", "1"}], ")"}], "2"]]}], TraditionalForm]], "Output",
 CellTags->"Integrate3",
 CellLabel->"Out[989]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate3", "[", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "OPEm"], " ", 
     RowBox[{"Log", "[", "x", "]"}], " ", 
     RowBox[{"Log", "[", 
      RowBox[{"1", "-", "x"}], "]"}]}], 
    RowBox[{"1", "-", "x"}]], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate3",
 CellLabel->"In[990]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
    RowBox[{
     SubscriptBox["S", "1"], "(", 
     FormBox["m",
      TraditionalForm], ")"}]}], "-", 
   RowBox[{
    SubscriptBox["S", "12"], "(", 
    FormBox["m",
     TraditionalForm], ")"}], "-", 
   RowBox[{
    SubscriptBox["S", "21"], "(", 
    FormBox["m",
     TraditionalForm], ")"}], "+", 
   TemplateBox[{"3"},
    "Zeta"]}], TraditionalForm]], "Output",
 CellTags->"Integrate3",
 CellLabel->"Out[990]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate3", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"a", 
     FractionBox[
      RowBox[{
       SuperscriptBox["x", "OPEm"], " ", 
       RowBox[{"Log", "[", "x", "]"}], " ", 
       RowBox[{"Log", "[", 
        RowBox[{"1", "-", "x"}], "]"}]}], 
      RowBox[{"1", "-", "x"}]]}], "+", 
    RowBox[{"b", 
     FractionBox[
      RowBox[{
       SuperscriptBox["x", "OPEm"], 
       RowBox[{"PolyLog", "[", 
        RowBox[{"3", ",", 
         RowBox[{"-", "x"}]}], "]"}]}], 
      RowBox[{"1", "+", "x"}]]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate3",
 CellLabel->"In[991]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
       RowBox[{
        SubscriptBox["S", "1"], "(", 
        FormBox["m",
         TraditionalForm], ")"}]}], "-", 
      RowBox[{
       SubscriptBox["S", "12"], "(", 
       FormBox["m",
        TraditionalForm], ")"}], "-", 
      RowBox[{
       SubscriptBox["S", "21"], "(", 
       FormBox["m",
        TraditionalForm], ")"}], "+", 
      TemplateBox[{"3"},
       "Zeta"]}], ")"}]}], "+", 
   RowBox[{"b", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "m"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SuperscriptBox[
        RowBox[{"\[Zeta]", "(", "2", ")"}], "2"], "8"], "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
       RowBox[{
        SubscriptBox["S", 
         RowBox[{"-", "2"}]], "(", 
        FormBox["m",
         TraditionalForm], ")"}]}], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       TemplateBox[{"3"},
        "Zeta"], " ", 
       RowBox[{
        SubscriptBox["S", 
         RowBox[{"-", "1"}]], "(", 
        FormBox["m",
         TraditionalForm], ")"}]}], "+", 
      RowBox[{
       SubscriptBox["S", 
        RowBox[{"3", "-", "1"}]], "(", 
       FormBox["m",
        TraditionalForm], ")"}], "+", 
      RowBox[{
       RowBox[{"log", "(", "2", ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["S", "3"], "(", 
          FormBox["m",
           TraditionalForm], ")"}], "-", 
         RowBox[{
          SubscriptBox["S", 
           RowBox[{"-", "3"}]], "(", 
          FormBox["m",
           TraditionalForm], ")"}]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["3", "4"], " ", 
       TemplateBox[{"3"},
        "Zeta"], " ", 
       RowBox[{"log", "(", "2", ")"}]}]}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"Integrate3",
 CellLabel->"Out[991]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate3", "[", 
  RowBox[{
   RowBox[{"DeltaFunctionPrime", "[", 
    RowBox[{"1", "-", "x"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate3",
 CellLabel->"In[992]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"Integrate3",
 CellLabel->"Out[992]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate3", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "x", "]"}], " ", 
    RowBox[{"DeltaFunctionPrime", "[", 
     RowBox[{"1", "-", "x"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate3",
 CellLabel->"In[993]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["f", "\[Prime]",
    MultilineFunction->None], "(", "1", ")"}], TraditionalForm]], "Output",
 CellTags->"Integrate3",
 CellLabel->"Out[993]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate3", "[", 
  RowBox[{
   RowBox[{"1", "/", 
    RowBox[{"(", 
     RowBox[{"1", "-", "x"}], ")"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Integrate3",
 CellLabel->"In[994]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"Integrate3",
 CellLabel->"Out[994]="]
}, Open  ]]
}, Open  ]],

Cell["IntermediateSubstitutions", "ObjectName",
 CellTags->"IntermediateSubstitutions"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"IntermediateSubstitutions"],

Cell["\<\
IntermediateSubstitutions is an option for OneLoop. All substitutions \
indicated hereby are done at an intermediate stage of the calculation.\
\>", "Text",
 CellTags->"IntermediateSubstitutions"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OneLoop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoop",
  ButtonNote->"OneLoop"],
 "."
}], "Text",
 CellTags->"IntermediateSubstitutions"]
}, Open  ]],

Cell["InverseMellin", "ObjectName",
 CellTags->"InverseMellin"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"InverseMellin"],

Cell[TextData[{
 "InverseMellin[exp, y] performs the inverse Mellin transform of polynomials \
in OPEm. The inverse transforms are not calculated but a table-lookup is \
done. WARNING: do not \"trust\" the results for the inverse Mellin transform \
involving SumT's; there is an unresolved inconsistency here (related to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "^", "m"}], ")"}], "."}], 
   TraditionalForm]]]
}], "Text",
 CellTags->"InverseMellin"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DeltaFunction",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DeltaFunction",
  ButtonNote->"DeltaFunction"],
 ", ",
 ButtonBox["Integrate2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Integrate2",
  ButtonNote->"Integrate2"],
 ", ",
 ButtonBox["OPEm",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OPEi",
  ButtonNote->"SumS"],
 ", ",
 ButtonBox["SumS",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SumS",
  ButtonNote->"SumS"],
 ", ",
 ButtonBox["SumT",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SumT",
  ButtonNote->"SumT"],
 "."
}], "Text",
 CellTags->"InverseMellin"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"InverseMellin"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InverseMellin", "[", 
  RowBox[{
   RowBox[{"1", "/", "OPEm"}], ",", "y"}], "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[995]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["y", 
   RowBox[{"m", "-", "1"}]], TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[995]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InverseMellin", "[", 
  RowBox[{
   RowBox[{"1", "/", 
    RowBox[{"(", 
     RowBox[{"OPEm", "+", "3"}], ")"}]}], ",", "y"}], "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[996]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["y", 
   RowBox[{"m", "+", "2"}]], TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[996]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InverseMellin", "[", 
  RowBox[{"1", ",", "y"}], "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[997]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["y", 
    RowBox[{"m", "-", "1"}]], " ", 
   RowBox[{"\[Delta]", "(", 
    FormBox[
     RowBox[{"1", "-", "y"}],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[997]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InverseMellin", "[", 
  RowBox[{
   RowBox[{"1", "/", 
    RowBox[{"OPEm", "^", "4"}]}], ",", "y"}], "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[998]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "6"]}], " ", 
   SuperscriptBox["y", 
    RowBox[{"m", "-", "1"}]], " ", 
   RowBox[{
    SuperscriptBox["log", "3"], "(", "y", ")"}]}], TraditionalForm]], "Output",\

 CellTags->"InverseMellin",
 CellLabel->"Out[998]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InverseMellin", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"1", "/", "OPEm"}], "+", "1"}], ",", "y"}], "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[999]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["y", 
     RowBox[{"m", "-", "1"}]], " ", 
    RowBox[{"\[Delta]", "(", 
     FormBox[
      RowBox[{"1", "-", "y"}],
      TraditionalForm], ")"}]}], "+", 
   SuperscriptBox["y", 
    RowBox[{"m", "-", "1"}]]}], TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[999]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InverseMellin", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"1", "/", "i"}], "+", "1"}], ",", "y", ",", "i"}], "]"}]], "Input",\

 CellTags->"InverseMellin",
 CellLabel->"In[1000]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["y", 
     RowBox[{"i", "-", "1"}]], " ", 
    RowBox[{"\[Delta]", "(", 
     FormBox[
      RowBox[{"1", "-", "y"}],
      TraditionalForm], ")"}]}], "+", 
   SuperscriptBox["y", 
    RowBox[{"i", "-", "1"}]]}], TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[1000]="]
}, Open  ]],

Cell["\<\
The inverse operation to InverseMellin is done by Integrate2.\
\>", "Text",
 CellTags->"InverseMellin"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{"InverseMellin", "[", 
    RowBox[{
     RowBox[{"1", "/", "OPEm"}], ",", "y"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1001]:="],

Cell[BoxData[
 FormBox[
  FractionBox["1", "m"], TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[1001]="]
}, Open  ]],

Cell["\<\
Below is a list of all built-in basic inverse Mellin transforms .\
\>", "Text",
 CellTags->"InverseMellin"],

Cell[BoxData[
 RowBox[{
  RowBox[{"list", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     FractionBox["1", 
      RowBox[{"OPEm", "+", "n"}]], ",", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"-", "OPEm"}], "+", "n"}]], ",", 
     RowBox[{"PolyGamma", "[", 
      RowBox[{"0", ",", "OPEm"}], "]"}], ",", 
     RowBox[{"SumS", "[", 
      RowBox[{"1", ",", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], ",", 
     FractionBox[
      RowBox[{"SumS", "[", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], 
      RowBox[{"OPEm", "-", "1"}]], ",", 
     FractionBox[
      RowBox[{"SumS", "[", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], 
      RowBox[{"1", "-", "OPEm"}]], ",", 
     FractionBox[
      RowBox[{"SumS", "[", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], 
      RowBox[{"OPEm", "+", "1"}]], ",", 
     FractionBox[
      RowBox[{"SumS", "[", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], 
      SuperscriptBox["OPEm", "2"]], ",", 
     FractionBox[
      RowBox[{"SumS", "[", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], "OPEm"], ",", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"SumS", "[", 
        RowBox[{"1", ",", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], "2"], "OPEm"], ",", 
     RowBox[{"SumS", "[", 
      RowBox[{"2", ",", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], ",", 
     FractionBox[
      RowBox[{"SumS", "[", 
       RowBox[{"2", ",", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], "OPEm"], ",", 
     RowBox[{"SumS", "[", 
      RowBox[{"3", ",", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], ",", 
     RowBox[{"SumS", "[", 
      RowBox[{"1", ",", "1", ",", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], ",", 
     SuperscriptBox[
      RowBox[{"SumS", "[", 
       RowBox[{"1", ",", 
        RowBox[{"OPEm", "-", "1"}]}], "]"}], "2"], ",", 
     RowBox[{"SumS", "[", 
      RowBox[{"1", ",", "2", ",", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], ",", 
     RowBox[{"SumS", "[", 
      RowBox[{"2", ",", "1", ",", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], ",", 
     SuperscriptBox[
      RowBox[{"SumS", "[", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], "3"], ",", 
     RowBox[{
      RowBox[{"SumS", "[", 
       RowBox[{"1", ",", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], " ", 
      RowBox[{"SumS", "[", 
       RowBox[{"2", ",", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}]}], ",", 
     RowBox[{"SumS", "[", 
      RowBox[{"1", ",", "1", ",", "1", ",", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}]}], "}"}]}], ";"}]], "Input",\

 CellTags->"InverseMellin",
 CellLabel->"In[1002]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"im", "[", "z_", "]"}], ":=", 
  RowBox[{"z", " ", "\[LongRightArrow]", 
   RowBox[{"InverseMellin", "[", 
    RowBox[{"z", ",", "y"}], "]"}]}]}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1003]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im", "[", 
  RowBox[{"OPEm", "^", 
   RowBox[{"(", 
    RowBox[{"-", "3"}], ")"}]}], "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1004]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", 
    SuperscriptBox["m", "3"]], "\[LongRightArrow]", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox["y", 
      RowBox[{"m", "-", "1"}]], " ", 
     RowBox[{
      SuperscriptBox["log", "2"], "(", "y", ")"}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[1004]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im", "[", 
  RowBox[{"OPEm", "^", 
   RowBox[{"(", 
    RowBox[{"-", "2"}], ")"}]}], "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1005]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", 
    SuperscriptBox["m", "2"]], "\[LongRightArrow]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["y", 
       RowBox[{"m", "-", "1"}]]}], " ", 
     RowBox[{"log", "(", "y", ")"}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[1005]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im", "[", 
  RowBox[{"PolyGamma", "[", 
   RowBox[{"0", ",", "OPEm"}], "]"}], "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1006]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"0","m"},
    "PolyGamma2"], "\[LongRightArrow]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       TagBox["\[DoubledGamma]",
        Function[{}, EulerGamma]], " ", 
       SuperscriptBox["y", 
        RowBox[{"m", "-", "1"}]], " ", 
       RowBox[{"\[Delta]", "(", 
        FormBox[
         RowBox[{"1", "-", "y"}],
         TraditionalForm], ")"}]}]}], "-", 
     RowBox[{
      SubscriptBox[
       RowBox[{"(", 
        FractionBox["1", 
         RowBox[{"1", "-", "y"}]], ")"}], "+"], " ", 
      SuperscriptBox["y", 
       RowBox[{"m", "-", "1"}]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[1006]="]
}, Open  ]],

Cell[BoxData[" "], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1007]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im", "[", 
  RowBox[{"SumS", "[", 
   RowBox[{"1", ",", 
    RowBox[{"OPEm", "-", "1"}]}], "]"}], "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1008]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["S", "1"], "(", 
    FormBox[
     RowBox[{"m", "-", "1"}],
     TraditionalForm], ")"}], "\[LongRightArrow]", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      RowBox[{"(", 
       FractionBox["1", 
        RowBox[{"1", "-", "y"}]], ")"}], "+"], " ", 
     RowBox[{"(", 
      RowBox[{"-", 
       SuperscriptBox["y", 
        RowBox[{"m", "-", "1"}]]}], ")"}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[1008]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im", "[", 
  RowBox[{
   RowBox[{"SumS", "[", 
    RowBox[{"1", ",", 
     RowBox[{"OPEm", "-", "1"}]}], "]"}], "/", 
   RowBox[{"(", 
    RowBox[{"OPEm", "-", "1"}], ")"}]}], "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1009]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SubscriptBox["S", "1"], "(", 
     FormBox[
      RowBox[{"m", "-", "1"}],
      TraditionalForm], ")"}], 
    RowBox[{"m", "-", "1"}]], "\[LongRightArrow]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["y", 
       RowBox[{"m", "-", "2"}]]}], " ", 
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "y"}], ")"}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[1009]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im", "[", 
  RowBox[{
   RowBox[{"SumS", "[", 
    RowBox[{"1", ",", 
     RowBox[{"OPEm", "-", "1"}]}], "]"}], "/", 
   RowBox[{"(", 
    RowBox[{"OPEm", "+", "1"}], ")"}]}], "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1010]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SubscriptBox["S", "1"], "(", 
     FormBox[
      RowBox[{"m", "-", "1"}],
      TraditionalForm], ")"}], 
    RowBox[{"m", "+", "1"}]], "\[LongRightArrow]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["y", 
       RowBox[{"m", "-", "1"}]]}], "+", 
     SuperscriptBox["y", "m"], "-", 
     RowBox[{
      SuperscriptBox["y", "m"], " ", 
      RowBox[{"log", "(", 
       RowBox[{"1", "-", "y"}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["y", "m"], " ", 
      RowBox[{"log", "(", "y", ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 CellTags->"InverseMellin",
 CellLabel->"Out[1010]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im", "[", 
  RowBox[{
   RowBox[{"SumS", "[", 
    RowBox[{"1", ",", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], "/", 
   RowBox[{"OPEm", "^", "2"}]}], "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1011]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SubscriptBox["S", "1"], "(", 
     FormBox[
      RowBox[{"m", "-", "1"}],
      TraditionalForm], ")"}], 
    SuperscriptBox["m", "2"]], "\[LongRightArrow]", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["y", 
      RowBox[{"m", "-", "1"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Zeta]", "(", "2", ")"}], "-", 
       TemplateBox[{"2","y"},
        "PolyLog"], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{
         SuperscriptBox["log", "2"], "(", "y", ")"}]}]}], ")"}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[1011]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im", "[", 
  RowBox[{
   RowBox[{"SumS", "[", 
    RowBox[{"1", ",", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], "/", "OPEm"}], 
  "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1012]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SubscriptBox["S", "1"], "(", 
     FormBox[
      RowBox[{"m", "-", "1"}],
      TraditionalForm], ")"}], "m"], "\[LongRightArrow]", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["y", 
      RowBox[{"m", "-", "1"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"log", "(", "y", ")"}], "-", 
       RowBox[{"log", "(", 
        RowBox[{"1", "-", "y"}], ")"}]}], ")"}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[1012]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"SumS", "[", 
     RowBox[{"1", ",", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "OPEm"}]}], "]"}], "^", "2"}], "/", "OPEm"}], 
  "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1013]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SubsuperscriptBox["S", "1", "2"], "(", 
     FormBox[
      RowBox[{"m", "-", "1"}],
      TraditionalForm], ")"}], "m"], "\[LongRightArrow]", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["y", 
      RowBox[{"m", "-", "1"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"3", " ", 
         RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], "+", 
       TemplateBox[{"2",RowBox[{"1", "-", "y"}]},
        "PolyLog"], "+", 
       RowBox[{"2", " ", 
        TemplateBox[{"2","y"},
         "PolyLog"]}], "+", 
       RowBox[{
        SuperscriptBox["log", "2"], "(", 
        RowBox[{"1", "-", "y"}], ")"}], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["log", "2"], "(", "y", ")"}], "2"]}], ")"}]}], 
    ")"}]}], TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[1013]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im", "[", 
  RowBox[{"SumS", "[", 
   RowBox[{"2", ",", 
    RowBox[{"OPEm", "-", "1"}]}], "]"}], "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1014]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["S", "2"], "(", 
    FormBox[
     RowBox[{"m", "-", "1"}],
     TraditionalForm], ")"}], "\[LongRightArrow]", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["y", 
      RowBox[{"m", "-", "1"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
        RowBox[{"\[Delta]", "(", 
         FormBox[
          RowBox[{"1", "-", "y"}],
          TraditionalForm], ")"}]}], "+", 
       FractionBox[
        RowBox[{"log", "(", "y", ")"}], 
        RowBox[{"1", "-", "y"}]]}], ")"}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[1014]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im", "[", 
  RowBox[{
   RowBox[{"SumS", "[", 
    RowBox[{"2", ",", 
     RowBox[{"OPEm", "-", "1"}]}], "]"}], "/", "OPEm"}], "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1015]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SubscriptBox["S", "2"], "(", 
     FormBox[
      RowBox[{"m", "-", "1"}],
      TraditionalForm], ")"}], "m"], "\[LongRightArrow]", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["y", 
      RowBox[{"m", "-", "1"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Zeta]", "(", "2", ")"}], "-", 
       TemplateBox[{"2",RowBox[{"1", "-", "y"}]},
        "PolyLog"], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{
         SuperscriptBox["log", "2"], "(", "y", ")"}]}]}], ")"}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[1015]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im", "[", 
  RowBox[{"SumS", "[", 
   RowBox[{"3", ",", 
    RowBox[{"OPEm", "-", "1"}]}], "]"}], "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1016]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["S", "3"], "(", 
    FormBox[
     RowBox[{"m", "-", "1"}],
     TraditionalForm], ")"}], "\[LongRightArrow]", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["y", 
      RowBox[{"m", "-", "1"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        TemplateBox[{"3"},
         "Zeta"], " ", 
        RowBox[{"\[Delta]", "(", 
         FormBox[
          RowBox[{"1", "-", "y"}],
          TraditionalForm], ")"}]}], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["log", "2"], "(", "y", ")"}], 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "y"}], ")"}]}]]}], ")"}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[1016]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im", "[", 
  RowBox[{"SumS", "[", 
   RowBox[{"1", ",", "1", ",", 
    RowBox[{"OPEm", "-", "1"}]}], "]"}], "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1017]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["S", "11"], "(", 
    FormBox[
     RowBox[{"m", "-", "1"}],
     TraditionalForm], ")"}], "\[LongRightArrow]", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["y", 
      RowBox[{"m", "-", "1"}]], " ", 
     SubscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"log", "(", 
         RowBox[{"1", "-", "y"}], ")"}], 
        RowBox[{"1", "-", "y"}]], ")"}], "+"]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[1017]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"im", "[", 
   RowBox[{"SumS", "[", 
    RowBox[{"1", ",", "2", ",", 
     RowBox[{"OPEm", "-", "1"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1018]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["S", "12"], "(", 
    FormBox[
     RowBox[{"m", "-", "1"}],
     TraditionalForm], ")"}], "\[LongRightArrow]", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["y", 
      RowBox[{"m", "-", "1"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        TemplateBox[{"2",RowBox[{"1", "-", "y"}]},
         "PolyLog"], 
        RowBox[{"1", "-", "y"}]], "-", 
       RowBox[{
        RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
        SubscriptBox[
         RowBox[{"(", 
          FractionBox["1", 
           RowBox[{"1", "-", "y"}]], ")"}], "+"]}], "-", 
       RowBox[{
        TemplateBox[{"3"},
         "Zeta"], " ", 
        RowBox[{"\[Delta]", "(", 
         FormBox[
          RowBox[{"1", "-", "y"}],
          TraditionalForm], ")"}]}]}], ")"}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[1018]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"im", "[", 
   RowBox[{"SumS", "[", 
    RowBox[{"2", ",", "1", ",", 
     RowBox[{"OPEm", "-", "1"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1019]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["S", "21"], "(", 
    FormBox[
     RowBox[{"m", "-", "1"}],
     TraditionalForm], ")"}], "\[LongRightArrow]", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["y", 
      RowBox[{"m", "-", "1"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        TemplateBox[{"2","y"},
         "PolyLog"], 
        RowBox[{"1", "-", "y"}]], "-", 
       RowBox[{
        RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
        SubscriptBox[
         RowBox[{"(", 
          FractionBox["1", 
           RowBox[{"1", "-", "y"}]], ")"}], "+"]}], "+", 
       RowBox[{"2", " ", 
        TemplateBox[{"3"},
         "Zeta"], " ", 
        RowBox[{"\[Delta]", "(", 
         FormBox[
          RowBox[{"1", "-", "y"}],
          TraditionalForm], ")"}]}]}], ")"}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[1019]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"im", "[", 
  RowBox[{"SumS", "[", 
   RowBox[{"1", ",", "1", ",", "1", ",", 
    RowBox[{"OPEm", "-", "1"}]}], "]"}], "]"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1020]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["S", "111"], "(", 
    FormBox[
     RowBox[{"m", "-", "1"}],
     TraditionalForm], ")"}], "\[LongRightArrow]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", 
     SuperscriptBox["y", 
      RowBox[{"m", "-", "1"}]], " ", 
     SubscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         SuperscriptBox["log", "2"], "(", 
         RowBox[{"1", "-", "y"}], ")"}], 
        RowBox[{"1", "-", "y"}]], ")"}], "+"]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"InverseMellin",
 CellLabel->"Out[1020]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"im", ",", "list"}], "]"}], ";"}]], "Input",
 CellTags->"InverseMellin",
 CellLabel->"In[1021]:="]
}, Open  ]],

Cell["Isolate", "ObjectName",
 CellTags->"Isolate"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Isolate"],

Cell["\<\
Isolate[expr] substitutes abbreviations KK[i] for all Plus[...] (sub-sums) in \
expr. The inserted KK[i] have head HoldForm. Isolate[expr, varlist] \
substitutes KK[i] for all subsums in expr which are free of any occurence of \
a member of the list varlist. Instead of KK any other head or a list of names \
of the abbreviations may be specified with the option IsolateNames.\
\>", "Text",
 CellTags->"Isolate"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Isolate", "]"}]], "Input",
 CellTags->"Isolate",
 CellLabel->"In[1022]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"IsolateNames", "\[Rule]", "KK"}], ",", 
    RowBox[{
    "HighEnergyPhysics`FeynCalc`IsolatePrint`IsolatePrint", "\[Rule]", 
     "False"}], ",", 
    RowBox[{
    "HighEnergyPhysics`FeynCalc`IsolateSplit`IsolateSplit", "\[Rule]", 
     "\[Infinity]"}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"Isolate",
 CellLabel->"Out[1022]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Isolate"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t0", "=", 
  RowBox[{"Isolate", "[", 
   RowBox[{"a", "+", "b"}], "]"}]}]], "Input",
 CellTags->"Isolate",
 CellLabel->"In[1023]:="],

Cell[BoxData[
 FormBox[
  TagBox[
   RowBox[{"KK", "(", "128", ")"}],
   HoldForm], TraditionalForm]], "Output",
 CellTags->"Isolate",
 CellLabel->"Out[1023]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{"Isolate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", "f"}], " ", "+", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"c", "+", "d"}], ")"}], " ", "f"}], " ", "+", " ", "e"}], ",", 
    "f"}], "]"}]}]], "Input",
 CellTags->"Isolate",
 CellLabel->"In[1024]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"e", "+", 
   RowBox[{"f", " ", 
    TagBox[
     RowBox[{"KK", "(", "128", ")"}],
     HoldForm]}], "+", 
   RowBox[{"f", " ", 
    TagBox[
     RowBox[{"KK", "(", "129", ")"}],
     HoldForm]}]}], TraditionalForm]], "Output",
 CellTags->"Isolate",
 CellLabel->"Out[1024]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", "t1", "]"}]], "Input",
 CellTags->"Isolate",
 CellLabel->"In[1025]:="],

Cell[BoxData[
 RowBox[{"e", "+", 
  RowBox[{"f", " ", 
   TagBox[
    RowBox[{"KK", "[", "128", "]"}],
    HoldForm]}], "+", 
  RowBox[{"f", " ", 
   TagBox[
    RowBox[{"KK", "[", "129", "]"}],
    HoldForm]}]}]], "Output",
 CellTags->"Isolate",
 CellLabel->"Out[1025]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"t0", ",", " ", "t1", ",", " ", 
   RowBox[{"ReleaseHold", "[", "t1", "]"}]}], "}"}]], "Input",
 CellTags->"Isolate",
 CellLabel->"In[1026]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    TagBox[
     RowBox[{"KK", "(", "128", ")"}],
     HoldForm], ",", 
    RowBox[{"e", "+", 
     RowBox[{"f", " ", 
      TagBox[
       RowBox[{"KK", "(", "128", ")"}],
       HoldForm]}], "+", 
     RowBox[{"f", " ", 
      TagBox[
       RowBox[{"KK", "(", "129", ")"}],
       HoldForm]}]}], ",", 
    RowBox[{
     RowBox[{"f", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}]}], "+", 
     RowBox[{"f", " ", 
      RowBox[{"(", 
       RowBox[{"c", "+", "d"}], ")"}]}], "+", "e"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Isolate",
 CellLabel->"Out[1026]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Isolate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"a", "[", "z", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{"b", "+", 
       RowBox[{"c", " ", 
        RowBox[{"(", 
         RowBox[{"y", "+", "z"}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"d", "[", "z", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{"y", "+", "z"}], ")"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "d"}], "}"}], ",", 
   RowBox[{"IsolateNames", "\[Rule]", "fF"}]}], "]"}]], "Input",
 CellTags->"Isolate",
 CellLabel->"In[1027]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    TagBox[
     RowBox[{"fF", "(", "131", ")"}],
     HoldForm], " ", 
    RowBox[{"a", "(", "z", ")"}]}], "+", 
   RowBox[{
    TagBox[
     RowBox[{"fF", "(", "130", ")"}],
     HoldForm], " ", 
    RowBox[{"d", "(", "z", ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Isolate",
 CellLabel->"Out[1027]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"??", "fF"}]], "Input",
 CellTags->"Isolate",
 CellLabel->"In[1028]:="],

Cell["Global`fF", "Print", "PrintUsage",
 CellTags->{"Info3522790362-4590919", "Isolate"}],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{
         RowBox[{"fF", "[", "130", "]"}], "=", 
         RowBox[{"y", "+", "z"}]}]},
       {" "},
       {
        RowBox[{
         RowBox[{"fF", "[", "131", "]"}], "=", 
         RowBox[{"b", "+", 
          RowBox[{"c", " ", 
           RowBox[{"\<\"HoldForm\"\>", "[", 
            RowBox[{"fF", "[", "130", "]"}], "]"}]}]}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition[$CellContext`fF],
  Editable->False]], "Print",
 CellTags->{"Info3522790362-4590919", "Isolate"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Isolate", "[", 
  RowBox[{
   RowBox[{"a", "-", "b", "-", "c", "-", "d", "-", "e"}], ",", 
   RowBox[{"IsolateNames", "\[Rule]", "L"}], ",", 
   RowBox[{"IsolateSplit", "\[Rule]", "15"}]}], "]"}]], "Input",
 CellTags->"Isolate",
 CellLabel->"In[1029]:="],

Cell[BoxData[
 FormBox[
  TagBox[
   RowBox[{"L", "(", "133", ")"}],
   HoldForm], TraditionalForm]], "Output",
 CellTags->"Isolate",
 CellLabel->"Out[1029]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"L", "[", "2", "]"}], ",", 
   RowBox[{"L", "[", "1", "]"}]}], "}"}]], "Input",
 CellTags->"Isolate",
 CellLabel->"In[1030]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"L", "(", "2", ")"}], ",", 
    RowBox[{"L", "(", "1", ")"}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"Isolate",
 CellLabel->"Out[1030]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"t0", ",", "t1", ",", "L", ",", "fF"}], "]"}]], "Input",
 CellTags->"Isolate",
 CellLabel->"In[1031]:="]
}, Open  ]],

Cell["IsolateHead", "ObjectName",
 CellTags->"IsolateHead"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"IsolateHead"],

Cell["IsolateHead is equivalent to IsolateNames.", "Text",
 CellTags->"IsolateHead"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["IsolateNames",
  BaseStyle->"AddOnsLink",
  ButtonData:>"IsolateNames",
  ButtonNote->"IsolateNames"],
 "."
}], "Text",
 CellTags->"IsolateHead"]
}, Open  ]],

Cell["IsolateNames", "ObjectName",
 CellTags->"IsolateNames"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"IsolateNames"],

Cell["\<\
IsolateNames is an option for Isolate and Collect2. Its default setting is \
KK. Instead of a symbol the setting may also be a list with the names of the \
abbrevations.\
\>", "Text",
 CellTags->"IsolateNames"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Isolate",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Isolate",
  ButtonNote->"Isolate"],
 ", ",
 ButtonBox["Collect2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Collect2",
  ButtonNote->"Collect2"],
 "."
}], "Text",
 CellTags->"IsolateNames"]
}, Open  ]],

Cell["IsolatePrint", "ObjectName",
 CellTags->"IsolatePrint"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"IsolatePrint"],

Cell["\<\
IsolatePrint is an option of Isolate. If it is set to OutputForm (or any \
other *Form) the definitions of the abbreviations are printed during the \
operation of Isolate. The setting IsolatePrint \[Rule] False suppresses \
printing.\
\>", "Text",
 CellTags->"IsolatePrint"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Isolate",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Isolate",
  ButtonNote->"Isolate"],
 "."
}], "Text",
 CellTags->"IsolatePrint"]
}, Open  ]],

Cell["IsolateSplit", "ObjectName",
 CellTags->"IsolateSplit"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"IsolateSplit"],

Cell["\<\
IsolateSplit is an option for Isolate. Its setting determines the maximum \
number of characters of FortranForm[expr] which are abbreviated by Isolate. \
If the expression is larger than the indicated number, it is split into \
smaller pieces and onto each subsum Isolate is applied. With the default \
setting IsolateSplit \[Rule] Infinity no splitting is done.\
\>", "Text",
 CellTags->"IsolateSplit"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Isolate",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Isolate",
  ButtonNote->"Isolate"],
 "."
}], "Text",
 CellTags->"IsolateSplit"]
}, Open  ]],

Cell["KeepOnly", "ObjectName",
 CellTags->"KeepOnly"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"KeepOnly"],

Cell["\<\
KeepOnly is an option of OneLoop. It may be set to B0, C0, D0 keeping only \
the corresponding coefficients. The default setting is False. If KeepOnly is \
set to {} then the part of the amplitude which is not coefficient of B0, C0, \
D0 is kept.\
\>", "Text",
 CellTags->"KeepOnly"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OneLoop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoop",
  ButtonNote->"OneLoop"],
 ", ",
 ButtonBox["B0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B0",
  ButtonNote->"B0"],
 ", ",
 ButtonBox["C0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"C0",
  ButtonNote->"C0"],
 ", ",
 ButtonBox["D0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"D0",
  ButtonNote->"D0"],
 "."
}], "Text",
 CellTags->"KeepOnly"]
}, Open  ]],

Cell["KK", "ObjectName",
 CellTags->"KK"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"KK"],

Cell["\<\
KK[i] is the default setting of IsolateNames, which is the head of \
abbreviations used by Isolate. A KK[i] returned by Isolate is given in \
HoldForm and can be recovered by ReleaseHold[KK[i]].\
\>", "Text",
 CellTags->"KK"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Isolate",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Isolate",
  ButtonNote->"Isolate"],
 ", ",
 ButtonBox["IsolateNames",
  BaseStyle->"AddOnsLink",
  ButtonData:>"IsolateNames",
  ButtonNote->"IsolateNames"],
 "."
}], "Text",
 CellTags->"KK"]
}, Open  ]],

Cell["Kummer", "ObjectName",
 CellTags->"Kummer"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Kummer"],

Cell["\<\
Kummer[i][exp] applies Kummer relation number i (i =1, ... 24, 94,95,96) to \
all Hypergeometric2F1 in exp. i = 94 corresponds to eq. 9.131.2, i = 95 to \
eq. 9.132.1 and i = 96 to eq. 9.132.2 in Gradsteyn & Ryzhik.\
\>", "Text",
 CellTags->"Kummer"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["HypergeometricAC",
  BaseStyle->"AddOnsLink",
  ButtonData:>"HypergeometricAC",
  ButtonNote->"HypergeometricAC"],
 "."
}], "Text",
 CellTags->"Kummer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Kummer"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "2", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1032]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c","z"},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{
      RowBox[{"-", "a"}], "-", "b", "+", "c"}]], " ", 
    TemplateBox[{RowBox[{"c", "-", "a"}],RowBox[{"c", "-", "b"}],"c","z"},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1032]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "3", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1033]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c","z"},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{"-", "a"}]], " ", 
    TemplateBox[{"a",RowBox[{"c", "-", "b"}],"c",RowBox[{"-", 
        FractionBox["z", 
         RowBox[{"1", "-", "z"}]]}]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1033]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "4", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1034]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c","z"},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{"-", "b"}]], " ", 
    TemplateBox[{"b",RowBox[{"c", "-", "a"}],"c",RowBox[{"-", 
        FractionBox["z", 
         RowBox[{"1", "-", "z"}]]}]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1034]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", 
    RowBox[{"1", "-", "z"}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "6", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", 
     RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1035]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c",RowBox[{"1", "-", "z"}]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox["z", 
     RowBox[{
      RowBox[{"-", "a"}], "-", "b", "+", "c"}]], " ", 
    TemplateBox[{
     RowBox[{"c", "-", "a"}],RowBox[{"c", "-", "b"}],"c",
      RowBox[{"1", "-", "z"}]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1035]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"a", "+", "b", "+", "1", "-", "c"}], ",", 
    RowBox[{"1", "-", "z"}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "6", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", 
     RowBox[{"a", "+", "b", "+", "1", "-", "c"}], ",", 
     RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1036]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{
    "a","b",RowBox[{"a", "+", "b", "-", "c", "+", "1"}],
     RowBox[{"1", "-", "z"}]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox["z", 
     RowBox[{"1", "-", "c"}]], " ", 
    TemplateBox[{
     RowBox[{"a", "-", "c", "+", "1"}],RowBox[{"b", "-", "c", "+", "1"}],
      RowBox[{"a", "+", "b", "-", "c", "+", "1"}],RowBox[{"1", "-", "z"}]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1036]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", 
    RowBox[{"1", "-", "z"}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "7", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", 
     RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1037]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c",RowBox[{"1", "-", "z"}]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox["z", 
     RowBox[{"-", "a"}]], " ", 
    TemplateBox[{"a",RowBox[{"c", "-", "b"}],"c",RowBox[{"-", 
        FractionBox[
         RowBox[{"1", "-", "z"}], "z"]}]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1037]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"a", "+", "b", "+", "1", "-", "c"}], ",", 
    RowBox[{"1", "-", "z"}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "7", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", 
     RowBox[{"a", "+", "b", "+", "1", "-", "c"}], ",", 
     RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1038]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{
    "a","b",RowBox[{"a", "+", "b", "-", "c", "+", "1"}],
     RowBox[{"1", "-", "z"}]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox["z", 
     RowBox[{"-", "a"}]], " ", 
    TemplateBox[{
     "a",RowBox[{"a", "-", "c", "+", "1"}],
      RowBox[{"a", "+", "b", "-", "c", "+", "1"}],RowBox[{"-", 
        FractionBox[
         RowBox[{"1", "-", "z"}], "z"]}]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1038]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", 
    RowBox[{"1", "-", "z"}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "8", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", 
     RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1039]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c",RowBox[{"1", "-", "z"}]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox["z", 
     RowBox[{"-", "b"}]], " ", 
    TemplateBox[{"b",RowBox[{"c", "-", "a"}],"c",RowBox[{"-", 
        FractionBox[
         RowBox[{"1", "-", "z"}], "z"]}]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1039]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"a", "+", "b", "+", "1", "-", "c"}], ",", 
    RowBox[{"1", "-", "z"}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "8", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", 
     RowBox[{"a", "+", "b", "+", "1", "-", "c"}], ",", 
     RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1040]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{
    "a","b",RowBox[{"a", "+", "b", "-", "c", "+", "1"}],
     RowBox[{"1", "-", "z"}]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox["z", 
     RowBox[{"-", "b"}]], " ", 
    TemplateBox[{
     "b",RowBox[{"b", "-", "c", "+", "1"}],
      RowBox[{"a", "+", "b", "-", "c", "+", "1"}],RowBox[{"-", 
        FractionBox[
         RowBox[{"1", "-", "z"}], "z"]}]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1040]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", 
    RowBox[{"z", "^", 
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "10", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", 
     RowBox[{"z", "^", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1041]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c",FractionBox["1", "z"]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{
      RowBox[{"-", "a"}], "-", "b", "+", "c"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "z"}], ")"}], 
     RowBox[{"a", "+", "b", "-", "c"}]], " ", 
    TemplateBox[{
     RowBox[{"c", "-", "a"}],RowBox[{"c", "-", "b"}],"c",FractionBox[
      "1", "z"]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1041]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", 
    RowBox[{"a", "+", "1", "-", "c"}], ",", 
    RowBox[{"a", "+", "1", "-", "b"}], ",", 
    RowBox[{"z", "^", 
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "10", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", 
     RowBox[{"a", "+", "1", "-", "c"}], ",", 
     RowBox[{"a", "+", "1", "-", "b"}], ",", 
     RowBox[{"z", "^", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1042]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{
    "a",RowBox[{"a", "-", "c", "+", "1"}],RowBox[{"a", "-", "b", "+", "1"}],
     FractionBox["1", "z"]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{
      RowBox[{"-", "a"}], "-", "b", "+", "c"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "z"}], ")"}], 
     RowBox[{"a", "+", "b", "-", "c"}]], " ", 
    TemplateBox[{
     RowBox[{"1", "-", "b"}],RowBox[{"c", "-", "b"}],
      RowBox[{"a", "-", "b", "+", "1"}],FractionBox["1", "z"]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1042]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", 
    RowBox[{"z", "^", 
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "11", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", 
     RowBox[{"z", "^", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1043]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c",FractionBox["1", "z"]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"1", "-", "z"}], "z"]}], ")"}], 
     RowBox[{"-", "a"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "z"}], ")"}], "a"], " ", 
    TemplateBox[{"a",RowBox[{"c", "-", "b"}],"c",FractionBox["1", 
       RowBox[{"1", "-", "z"}]]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1043]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", 
    RowBox[{"a", "+", "1", "-", "c"}], ",", 
    RowBox[{"a", "+", "1", "-", "b"}], ",", 
    RowBox[{"z", "^", 
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "11", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", 
     RowBox[{"a", "+", "1", "-", "c"}], ",", 
     RowBox[{"a", "+", "1", "-", "b"}], ",", 
     RowBox[{"z", "^", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1044]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{
    "a",RowBox[{"a", "-", "c", "+", "1"}],RowBox[{"a", "-", "b", "+", "1"}],
     FractionBox["1", "z"]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"1", "-", "z"}], "z"]}], ")"}], 
     RowBox[{"-", "a"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "z"}], ")"}], "a"], " ", 
    TemplateBox[{
     "a",RowBox[{"c", "-", "b"}],RowBox[{"a", "-", "b", "+", "1"}],
      FractionBox["1", 
       RowBox[{"1", "-", "z"}]]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1044]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", 
    RowBox[{"z", "^", 
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "12", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", 
     RowBox[{"z", "^", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1045]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c",FractionBox["1", "z"]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{"-", "b"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "z"}], ")"}], 
     RowBox[{"b", "-", "a"}]], " ", 
    TemplateBox[{"b",RowBox[{"c", "-", "a"}],"c",FractionBox["1", 
       RowBox[{"1", "-", "z"}]]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1045]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", 
    RowBox[{"a", "+", "1", "-", "c"}], ",", 
    RowBox[{"a", "+", "1", "-", "b"}], ",", 
    RowBox[{"z", "^", 
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "12", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", 
     RowBox[{"a", "+", "1", "-", "c"}], ",", 
     RowBox[{"a", "+", "1", "-", "b"}], ",", 
     RowBox[{"z", "^", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1046]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{
    "a",RowBox[{"a", "-", "c", "+", "1"}],RowBox[{"a", "-", "b", "+", "1"}],
     FractionBox["1", "z"]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "z"}], ")"}], 
     RowBox[{"1", "-", "c"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{
      RowBox[{"-", "a"}], "+", "c", "-", "1"}]], " ", 
    TemplateBox[{
     RowBox[{"1", "-", "b"}],RowBox[{"a", "-", "c", "+", "1"}],
      RowBox[{"a", "-", "b", "+", "1"}],FractionBox["1", 
       RowBox[{"1", "-", "z"}]]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1046]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", 
    RowBox[{"z", "^", 
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "14", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", 
     RowBox[{"z", "^", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1047]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c",FractionBox["1", "z"]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{
      RowBox[{"-", "a"}], "-", "b", "+", "c"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "z"}], ")"}], 
     RowBox[{"a", "+", "b", "-", "c"}]], " ", 
    TemplateBox[{
     RowBox[{"c", "-", "a"}],RowBox[{"c", "-", "b"}],"c",FractionBox[
      "1", "z"]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1047]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{
    RowBox[{"b", "+", "1", "-", "c"}], ",", "b", ",", 
    RowBox[{"b", "+", "1", "-", "a"}], ",", 
    RowBox[{"z", "^", 
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "14", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{
     RowBox[{"b", "+", "1", "-", "c"}], ",", "b", ",", 
     RowBox[{"b", "+", "1", "-", "a"}], ",", 
     RowBox[{"z", "^", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1048]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"b",RowBox[{"b", "-", "c", "+", "1"}],RowBox[{
       RowBox[{"-", "a"}], "+", "b", "+", "1"}],FractionBox["1", "z"]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{
      RowBox[{"-", "a"}], "-", "b", "+", "c"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "z"}], ")"}], 
     RowBox[{"a", "+", "b", "-", "c"}]], " ", 
    TemplateBox[{RowBox[{"1", "-", "a"}],RowBox[{"c", "-", "a"}],RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "1"}],FractionBox["1", "z"]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1048]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", 
    RowBox[{"z", "^", 
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "15", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", 
     RowBox[{"z", "^", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1049]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c",FractionBox["1", "z"]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{"-", "b"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "z"}], ")"}], "b"], " ", 
    TemplateBox[{"b",RowBox[{"c", "-", "a"}],"c",FractionBox["1", 
       RowBox[{"1", "-", "z"}]]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1049]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{
    RowBox[{"b", "+", "1", "-", "c"}], ",", "b", ",", 
    RowBox[{"b", "+", "1", "-", "a"}], ",", 
    RowBox[{"z", "^", 
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "15", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{
     RowBox[{"b", "+", "1", "-", "c"}], ",", "b", ",", 
     RowBox[{"b", "+", "1", "-", "a"}], ",", 
     RowBox[{"z", "^", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1050]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"b",RowBox[{"b", "-", "c", "+", "1"}],RowBox[{
       RowBox[{"-", "a"}], "+", "b", "+", "1"}],FractionBox["1", "z"]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{
      RowBox[{"-", "b"}], "+", "c", "-", "1"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "z"}], ")"}], 
     RowBox[{"b", "-", "c", "+", "1"}]], " ", 
    TemplateBox[{
     RowBox[{"1", "-", "a"}],RowBox[{"b", "-", "c", "+", "1"}],RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "1"}],FractionBox["1", 
       RowBox[{"1", "-", "z"}]]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1050]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", 
    RowBox[{"z", "^", 
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "16", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", 
     RowBox[{"z", "^", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1051]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c",FractionBox["1", "z"]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{"-", "a"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "z"}], ")"}], "a"], " ", 
    TemplateBox[{"a",RowBox[{"c", "-", "b"}],"c",FractionBox["1", 
       RowBox[{"1", "-", "z"}]]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1051]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{
    RowBox[{"b", "+", "1", "-", "c"}], ",", "b", ",", 
    RowBox[{"b", "+", "1", "-", "a"}], ",", 
    RowBox[{"z", "^", 
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}]}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "16", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{
     RowBox[{"b", "+", "1", "-", "c"}], ",", "b", ",", 
     RowBox[{"b", "+", "1", "-", "a"}], ",", 
     RowBox[{"z", "^", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}]}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1052]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"b",RowBox[{"b", "-", "c", "+", "1"}],RowBox[{
       RowBox[{"-", "a"}], "+", "b", "+", "1"}],FractionBox["1", "z"]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{"-", "b"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "z"}], ")"}], "b"], " ", 
    TemplateBox[{"b",RowBox[{"c", "-", "a"}],RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "1"}],FractionBox["1", 
       RowBox[{"1", "-", "z"}]]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1052]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{
    RowBox[{"a", "+", "1", "-", "c"}], ",", 
    RowBox[{"b", "+", "1", "-", "c"}], ",", 
    RowBox[{"2", "-", "c"}], ",", "z"}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "18", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{
     RowBox[{"a", "+", "1", "-", "c"}], ",", 
     RowBox[{"b", "+", "1", "-", "c"}], ",", 
     RowBox[{"2", "-", "c"}], ",", "z"}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1053]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{
    RowBox[{"a", "-", "c", "+", "1"}],RowBox[{"b", "-", "c", "+", "1"}],
     RowBox[{"2", "-", "c"}],"z"},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{
      RowBox[{"-", "a"}], "-", "b", "+", "c"}]], " ", 
    TemplateBox[{
     RowBox[{"1", "-", "a"}],RowBox[{"1", "-", "b"}],RowBox[{"2", "-", "c"}],
      "z"},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1053]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "18", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1054]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c","z"},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{
      RowBox[{"-", "a"}], "-", "b", "+", "c"}]], " ", 
    TemplateBox[{RowBox[{"c", "-", "a"}],RowBox[{"c", "-", "b"}],"c","z"},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1054]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{
    RowBox[{"a", "+", "1", "-", "c"}], ",", 
    RowBox[{"b", "+", "1", "-", "c"}], ",", 
    RowBox[{"2", "-", "c"}], ",", "z"}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "19", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{
     RowBox[{"a", "+", "1", "-", "c"}], ",", 
     RowBox[{"b", "+", "1", "-", "c"}], ",", 
     RowBox[{"2", "-", "c"}], ",", "z"}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1055]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{
    RowBox[{"a", "-", "c", "+", "1"}],RowBox[{"b", "-", "c", "+", "1"}],
     RowBox[{"2", "-", "c"}],"z"},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{
      RowBox[{"-", "a"}], "+", "c", "-", "1"}]], " ", 
    TemplateBox[{
     RowBox[{"1", "-", "b"}],RowBox[{"a", "-", "c", "+", "1"}],
      RowBox[{"2", "-", "c"}],FractionBox["z", 
       RowBox[{"z", "-", "1"}]]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1055]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "19", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1056]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c","z"},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{"-", "a"}]], " ", 
    TemplateBox[{"a",RowBox[{"c", "-", "b"}],"c",FractionBox["z", 
       RowBox[{"z", "-", "1"}]]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1056]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{
    RowBox[{"a", "+", "1", "-", "c"}], ",", 
    RowBox[{"b", "+", "1", "-", "c"}], ",", 
    RowBox[{"2", "-", "c"}], ",", "z"}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "20", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{
     RowBox[{"a", "+", "1", "-", "c"}], ",", 
     RowBox[{"b", "+", "1", "-", "c"}], ",", 
     RowBox[{"2", "-", "c"}], ",", "z"}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1057]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{
    RowBox[{"a", "-", "c", "+", "1"}],RowBox[{"b", "-", "c", "+", "1"}],
     RowBox[{"2", "-", "c"}],"z"},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{
      RowBox[{"-", "b"}], "+", "c", "-", "1"}]], " ", 
    TemplateBox[{
     RowBox[{"1", "-", "a"}],RowBox[{"b", "-", "c", "+", "1"}],
      RowBox[{"2", "-", "c"}],FractionBox["z", 
       RowBox[{"z", "-", "1"}]]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1057]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "20", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1058]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c","z"},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{"-", "b"}]], " ", 
    TemplateBox[{"b",RowBox[{"c", "-", "a"}],"c",FractionBox["z", 
       RowBox[{"z", "-", "1"}]]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1058]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{
    RowBox[{"c", "-", "a"}], ",", 
    RowBox[{"c", "-", "b"}], ",", 
    RowBox[{"c", "+", "1", "-", "a", "-", "b"}], ",", 
    RowBox[{"1", "-", "z"}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "22", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{
     RowBox[{"c", "-", "a"}], ",", 
     RowBox[{"c", "-", "b"}], ",", 
     RowBox[{"c", "+", "1", "-", "a", "-", "b"}], ",", 
     RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1059]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{RowBox[{"c", "-", "a"}],RowBox[{"c", "-", "b"}],RowBox[{
       RowBox[{"-", "a"}], "-", "b", "+", "c", "+", "1"}],
     RowBox[{"1", "-", "z"}]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox["z", 
     RowBox[{"1", "-", "c"}]], " ", 
    TemplateBox[{RowBox[{"1", "-", "a"}],RowBox[{"1", "-", "b"}],RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c", "+", "1"}],
      RowBox[{"1", "-", "z"}]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1059]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", 
    RowBox[{"1", "-", "z"}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "22", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", 
     RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1060]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c",RowBox[{"1", "-", "z"}]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox["z", 
     RowBox[{
      RowBox[{"-", "a"}], "-", "b", "+", "c"}]], " ", 
    TemplateBox[{
     RowBox[{"c", "-", "a"}],RowBox[{"c", "-", "b"}],"c",
      RowBox[{"1", "-", "z"}]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1060]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{
    RowBox[{"c", "-", "a"}], ",", 
    RowBox[{"c", "-", "b"}], ",", 
    RowBox[{"c", "+", "1", "-", "a", "-", "b"}], ",", 
    RowBox[{"1", "-", "z"}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "23", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{
     RowBox[{"c", "-", "a"}], ",", 
     RowBox[{"c", "-", "b"}], ",", 
     RowBox[{"c", "+", "1", "-", "a", "-", "b"}], ",", 
     RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1061]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{RowBox[{"c", "-", "a"}],RowBox[{"c", "-", "b"}],RowBox[{
       RowBox[{"-", "a"}], "-", "b", "+", "c", "+", "1"}],
     RowBox[{"1", "-", "z"}]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{"a", "-", "c"}]], " ", 
    TemplateBox[{RowBox[{"1", "-", "a"}],RowBox[{"c", "-", "a"}],RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c", "+", "1"}],RowBox[{"1", "-", 
        FractionBox["1", 
         RowBox[{"1", "-", "z"}]]}]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1061]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", 
    RowBox[{"1", "-", "z"}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "23", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", 
     RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1062]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c",RowBox[{"1", "-", "z"}]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "z"}], ")"}], 
     RowBox[{"-", "a"}]], " ", 
    TemplateBox[{"a",RowBox[{"c", "-", "b"}],"c",RowBox[{"1", "-", 
        FractionBox["1", 
         RowBox[{"1", "-", "z"}]]}]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1062]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{
    RowBox[{"c", "-", "a"}], ",", 
    RowBox[{"c", "-", "b"}], ",", 
    RowBox[{"c", "+", "1", "-", "a", "-", "b"}], ",", 
    RowBox[{"1", "-", "z"}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "24", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{
     RowBox[{"c", "-", "a"}], ",", 
     RowBox[{"c", "-", "b"}], ",", 
     RowBox[{"c", "+", "1", "-", "a", "-", "b"}], ",", 
     RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1063]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{RowBox[{"c", "-", "a"}],RowBox[{"c", "-", "b"}],RowBox[{
       RowBox[{"-", "a"}], "-", "b", "+", "c", "+", "1"}],
     RowBox[{"1", "-", "z"}]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox["z", 
     RowBox[{"b", "-", "c"}]], " ", 
    TemplateBox[{RowBox[{"1", "-", "b"}],RowBox[{"c", "-", "b"}],RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c", "+", "1"}],RowBox[{"-", 
        FractionBox[
         RowBox[{"1", "-", "z"}], "z"]}]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1063]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", 
    RowBox[{"1", "-", "z"}]}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "24", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", 
     RowBox[{"1", "-", "z"}]}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1064]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c",RowBox[{"1", "-", "z"}]},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    SuperscriptBox["z", 
     RowBox[{"-", "b"}]], " ", 
    TemplateBox[{"b",RowBox[{"c", "-", "a"}],"c",RowBox[{"-", 
        FractionBox[
         RowBox[{"1", "-", "z"}], "z"]}]},
     "Hypergeometric2F1"]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1064]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "94", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1065]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c","z"},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    FractionBox[
     RowBox[{
      TemplateBox[{"c"},
       "Gamma"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "z"}], ")"}], 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}]], " ", 
      TemplateBox[{RowBox[{"a", "+", "b", "-", "c"}]},
       "Gamma"], " ", 
      TemplateBox[{RowBox[{"c", "-", "a"}],RowBox[{"c", "-", "b"}],RowBox[{
          RowBox[{"-", "a"}], "-", "b", "+", "c", "+", "1"}],
        RowBox[{"1", "-", "z"}]},
       "Hypergeometric2F1"]}], 
     RowBox[{
      TemplateBox[{"a"},
       "Gamma"], " ", 
      TemplateBox[{"b"},
       "Gamma"]}]], "+", 
    FractionBox[
     RowBox[{
      TemplateBox[{"c"},
       "Gamma"], " ", 
      TemplateBox[{RowBox[{
          RowBox[{"-", "a"}], "-", "b", "+", "c"}]},
       "Gamma"], " ", 
      TemplateBox[{
       "a","b",RowBox[{"a", "+", "b", "-", "c", "+", "1"}],
        RowBox[{"1", "-", "z"}]},
       "Hypergeometric2F1"]}], 
     RowBox[{
      TemplateBox[{RowBox[{"c", "-", "a"}]},
       "Gamma"], " ", 
      TemplateBox[{RowBox[{"c", "-", "b"}]},
       "Gamma"]}]]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1065]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "95", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1066]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c","z"},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "z"}], ")"}], 
       RowBox[{"-", "a"}]], " ", 
      TemplateBox[{"c"},
       "Gamma"], " ", 
      TemplateBox[{RowBox[{"b", "-", "a"}]},
       "Gamma"], " ", 
      TemplateBox[{
       "a",RowBox[{"c", "-", "b"}],RowBox[{"a", "-", "b", "+", "1"}],
        FractionBox["1", 
         RowBox[{"1", "-", "z"}]]},
       "Hypergeometric2F1"]}], 
     RowBox[{
      TemplateBox[{"b"},
       "Gamma"], " ", 
      TemplateBox[{RowBox[{"c", "-", "a"}]},
       "Gamma"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", "z"}], ")"}], 
       RowBox[{"-", "b"}]], " ", 
      TemplateBox[{"c"},
       "Gamma"], " ", 
      TemplateBox[{RowBox[{"a", "-", "b"}]},
       "Gamma"], " ", 
      TemplateBox[{"b",RowBox[{"c", "-", "a"}],RowBox[{
          RowBox[{"-", "a"}], "+", "b", "+", "1"}],FractionBox["1", 
         RowBox[{"1", "-", "z"}]]},
       "Hypergeometric2F1"]}], 
     RowBox[{
      TemplateBox[{"a"},
       "Gamma"], " ", 
      TemplateBox[{RowBox[{"c", "-", "b"}]},
       "Gamma"]}]]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1066]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Hypergeometric2F1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "==", 
  RowBox[{
   RowBox[{"Kummer", "[", "96", "]"}], "[", 
   RowBox[{"Hypergeometric2F1", "[", 
    RowBox[{"a", ",", "b", ",", "c", ",", "z"}], "]"}], "]"}]}]], "Input",
 CellTags->"Kummer",
 CellLabel->"In[1067]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"a","b","c","z"},
    "Hypergeometric2F1"], "\[LongEqual]", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "a"], " ", 
      SuperscriptBox["z", 
       RowBox[{"-", "a"}]], " ", 
      TemplateBox[{"c"},
       "Gamma"], " ", 
      TemplateBox[{RowBox[{"b", "-", "a"}]},
       "Gamma"], " ", 
      TemplateBox[{
       "a",RowBox[{"a", "-", "c", "+", "1"}],
        RowBox[{"a", "-", "b", "+", "1"}],FractionBox["1", "z"]},
       "Hypergeometric2F1"]}], 
     RowBox[{
      TemplateBox[{"b"},
       "Gamma"], " ", 
      TemplateBox[{RowBox[{"c", "-", "a"}]},
       "Gamma"]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "b"], " ", 
      SuperscriptBox["z", 
       RowBox[{"-", "b"}]], " ", 
      TemplateBox[{"c"},
       "Gamma"], " ", 
      TemplateBox[{RowBox[{"a", "-", "b"}]},
       "Gamma"], " ", 
      TemplateBox[{"b",RowBox[{"b", "-", "c", "+", "1"}],RowBox[{
          RowBox[{"-", "a"}], "+", "b", "+", "1"}],FractionBox["1", "z"]},
       "Hypergeometric2F1"]}], 
     RowBox[{
      TemplateBox[{"a"},
       "Gamma"], " ", 
      TemplateBox[{RowBox[{"c", "-", "b"}]},
       "Gamma"]}]]}]}], TraditionalForm]], "Output",
 CellTags->"Kummer",
 CellLabel->"Out[1067]="]
}, Open  ]]
}, Open  ]],

Cell["Lagrangian", "ObjectName",
 CellTags->"Lagrangian"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Lagrangian"],

Cell["\<\
Lagrangian[\"oqu\"] gives the unpolarized OPE quark operator. \
Lagrangian[\"oqp\"] gives the polarized quark OPE operator. \
Lagrangian[\"ogu\"] gives the unpolarized gluon OPE operator. \
Lagrangian[\"ogp\"] gives the polarized gluon OPE operator. \
Lagrangian[\"ogd\"] gives the sigma-term part of the QCD lagrangian. \
Lagrangian[\"QCD\"] gives the gluon self interaction part of the QCD \
lagrangian.\
\>", "Text",
 CellTags->"Lagrangian"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynRule",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynRule",
  ButtonNote->"FeynRule"],
 "."
}], "Text",
 CellTags->"Lagrangian"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Lagrangian"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lagrangian", "[", "\"\<QCD\>\"", "]"}]], "Input",
 CellTags->"Lagrangian",
 CellLabel->"In[1068]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "4"]}], " ", 
   RowBox[{
    SubsuperscriptBox["F", 
     RowBox[{"\[Alpha]", "\[Beta]"}], "a"], ".", 
    SubsuperscriptBox["F", 
     RowBox[{"\[Alpha]", "\[Beta]"}], "a"]}]}], TraditionalForm]], "Output",
 CellTags->"Lagrangian",
 CellLabel->"Out[1068]="]
}, Open  ]],

Cell["Twist-2 operator product expansion operators", "Text",
 CellTags->"Lagrangian"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lagrangian", "[", "\"\<ogu\>\"", "]"}]], "Input",
 CellTags->"Lagrangian",
 CellLabel->"In[1069]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["\[ImaginaryI]", 
    RowBox[{"m", "-", "1"}]], " ", 
   RowBox[{
    SubsuperscriptBox["F", 
     RowBox[{"\[Alpha]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], "a"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      SubsuperscriptBox["D", 
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       RowBox[{"a", "b"}]], ")"}], 
     RowBox[{"m", "-", "2"}]], ".", 
    SubsuperscriptBox["F", 
     RowBox[{"\[Alpha]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], "b"]}]}], TraditionalForm]], "Output",
 CellTags->"Lagrangian",
 CellLabel->"Out[1069]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lagrangian", "[", "\"\<ogp\>\"", "]"}]], "Input",
 CellTags->"Lagrangian",
 CellLabel->"In[1070]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["\[ImaginaryI]", "m"], " ", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Alpha]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Beta]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Gamma]",
        TraditionalForm],
       TraditionalForm], 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}]], ".", 
    SubsuperscriptBox["F", 
     RowBox[{"\[Beta]", "\[Gamma]"}], "a"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      SubsuperscriptBox["D", 
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       RowBox[{"a", "b"}]], ")"}], 
     RowBox[{"m", "-", "2"}]], ".", 
    SubsuperscriptBox["F", 
     RowBox[{"\[Alpha]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], "b"]}]}], TraditionalForm]], "Output",
 CellTags->"Lagrangian",
 CellLabel->"Out[1070]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lagrangian", "[", "\"\<oqu\>\"", "]"}]], "Input",
 CellTags->"Lagrangian",
 CellLabel->"In[1071]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[ImaginaryI]", "m"], " ", 
   RowBox[{
    FormBox[
     OverscriptBox["\[Psi]", "_"],
     TraditionalForm], ".", 
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], ")"}], ".", 
    SuperscriptBox[
     SubscriptBox["D", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]], 
     RowBox[{"m", "-", "1"}]], ".", 
    FormBox["\[Psi]",
     TraditionalForm]}]}], TraditionalForm]], "Output",
 CellTags->"Lagrangian",
 CellLabel->"Out[1071]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lagrangian", "[", "\"\<oqp\>\"", "]"}]], "Input",
 CellTags->"Lagrangian",
 CellLabel->"In[1072]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[ImaginaryI]", "m"], " ", 
   RowBox[{
    FormBox[
     OverscriptBox["\[Psi]", "_"],
     TraditionalForm], ".", 
    SuperscriptBox["\[Gamma]", "5"], ".", 
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], ")"}], ".", 
    SuperscriptBox[
     SubscriptBox["D", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]], 
     RowBox[{"m", "-", "1"}]], ".", 
    FormBox["\[Psi]",
     TraditionalForm]}]}], TraditionalForm]], "Output",
 CellTags->"Lagrangian",
 CellLabel->"Out[1072]="]
}, Open  ]]
}, Open  ]],

Cell["LC", "ObjectName",
 CellTags->"LC"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"LC"],

Cell["\<\
LC[m,n,r,s] evaluates to 4-dimensional LeviCivita[m,n,r,s] by virtue of \
applying FeynCalcInternal. LC[m,...][p, ...] evaluates to 4-dimensional \
LeviCivita[m,...][p,...] applying FeynCalcInternal.\
\>", "Text",
 CellTags->"LC"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["LeviCivita",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LeviCivita",
  ButtonNote->"LeviCivita"],
 ", ",
 ButtonBox["LCD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LCD",
  ButtonNote->"LCD"],
 "."
}], "Text",
 CellTags->"LC"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"LC"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LC", "[", 
  RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
  "]"}]], "Input",
 CellTags->"LC",
 CellLabel->"In[1073]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{"\[Mu]", "\[Nu]", "\[Rho]", "\[Sigma]"}]], 
  TraditionalForm]], "Output",
 CellTags->"LC",
 CellLabel->"Out[1073]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "FCI"}]], "Input",
 CellTags->"LC",
 CellLabel->"In[1074]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Rho]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Sigma]",
      TraditionalForm],
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"LC",
 CellLabel->"Out[1074]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"LC",
 CellLabel->"In[1075]:="],

Cell[BoxData[
 RowBox[{"Eps", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], ",", 
   RowBox[{"LorentzIndex", "[", "\[Rho]", "]"}], ",", 
   RowBox[{"LorentzIndex", "[", "\[Sigma]", "]"}]}], "]"}]], "Output",
 CellTags->"LC",
 CellLabel->"Out[1075]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LC", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "[", 
  RowBox[{"p", ",", "q"}], "]"}]], "Input",
 CellTags->"LC",
 CellLabel->"In[1076]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{"\[Mu]", "\[Nu]", "p", "q"}]], TraditionalForm]], "Output",
 CellTags->"LC",
 CellLabel->"Out[1076]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"%", "//", "FCI"}], "//", "StandardForm"}]], "Input",
 CellTags->"LC",
 CellLabel->"In[1077]:="],

Cell[BoxData[
 RowBox[{"Eps", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], ",", 
   RowBox[{"Momentum", "[", 
    RowBox[{"p", ",", "D"}], "]"}], ",", 
   RowBox[{"Momentum", "[", 
    RowBox[{"q", ",", "D"}], "]"}]}], "]"}]], "Output",
 CellTags->"LC",
 CellLabel->"Out[1077]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Contract", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"LC", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]"}], "]"}], "[", "p", "]"}], 
    " ", 
    RowBox[{
     RowBox[{"LC", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]"}], "]"}], "[", "q", 
     "]"}]}], "]"}], " "}]], "Input",
 CellTags->"LC",
 CellLabel->"In[1078]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"18", " ", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]}], "-", 
   RowBox[{"24", " ", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 CellTags->"LC",
 CellLabel->"Out[1078]="]
}, Open  ]]
}, Open  ]],

Cell["LCD", "ObjectName",
 CellTags->"LCD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"LCD"],

Cell["\<\
LCD[m,n,r,s] evaluates to D-dimensional LeviCivita[m,n,r,s] by virtue of \
FeynCalcInternal. LCD[m,...][p, ...] evaluates to D-dimensional \
LeviCivita[m,...][p,...] applying FeynCalcInternal.\
\>", "Text",
 CellTags->"LCD"],

Cell["\<\
You need to do SetOptions[Eps, Dimension\[Rule]D] before LCD can be used as \
D-dimensional Levi-Civita input function.\
\>", "Text",
 CellTags->"LCD"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["LeviCivita",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LeviCivita",
  ButtonNote->"LeviCivita"],
 ", ",
 ButtonBox["LC",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LC",
  ButtonNote->"LC"],
 "."
}], "Text",
 CellTags->"LCD"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"LCD"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Eps", ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], ";"}]], "Input",
 CellTags->"LCD",
 CellLabel->"In[1079]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LCD", "[", 
  RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]"}], 
  "]"}]], "Input",
 CellTags->"LCD",
 CellLabel->"In[1080]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{"\[Mu]", "\[Nu]", "\[Rho]", "\[Sigma]"}]], 
  TraditionalForm]], "Output",
 CellTags->"LCD",
 CellLabel->"Out[1080]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "FCI"}]], "Input",
 CellTags->"LCD",
 CellLabel->"In[1081]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Rho]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Sigma]",
      TraditionalForm],
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"LCD",
 CellLabel->"Out[1081]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"LCD",
 CellLabel->"In[1082]:="],

Cell[BoxData[
 RowBox[{"Eps", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Nu]", ",", "D"}], "]"}], ",", 
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Rho]", ",", "D"}], "]"}], ",", 
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Sigma]", ",", "D"}], "]"}]}], "]"}]], "Output",
 CellTags->"LCD",
 CellLabel->"Out[1082]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LCD", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "[", 
  RowBox[{"p", ",", "q"}], "]"}]], "Input",
 CellTags->"LCD",
 CellLabel->"In[1083]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{"\[Mu]", "\[Nu]", "p", "q"}]], TraditionalForm]], "Output",
 CellTags->"LCD",
 CellLabel->"Out[1083]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"%", "//", "FCI"}], "//", "StandardForm"}]], "Input",
 CellTags->"LCD",
 CellLabel->"In[1084]:="],

Cell[BoxData[
 RowBox[{"Eps", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", 
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Nu]", ",", "D"}], "]"}], ",", 
   RowBox[{"Momentum", "[", 
    RowBox[{"p", ",", "D"}], "]"}], ",", 
   RowBox[{"Momentum", "[", 
    RowBox[{"q", ",", "D"}], "]"}]}], "]"}]], "Output",
 CellTags->"LCD",
 CellLabel->"Out[1084]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor2", "[", 
  RowBox[{"Contract", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"LCD", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]"}], "]"}], "[", "p", "]"}], 
    " ", 
    RowBox[{
     RowBox[{"LCD", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]"}], "]"}], "[", "q", 
     "]"}]}], "]"}], "]"}]], "Input",
 CellTags->"LCD",
 CellLabel->"In[1085]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", "D"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"2", "-", "D"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"3", "-", "D"}], ")"}], " ", 
   RowBox[{
    FormBox["p",
     TraditionalForm], "\[CenterDot]", 
    FormBox["q",
     TraditionalForm]}]}], TraditionalForm]], "Output",
 CellTags->"LCD",
 CellLabel->"Out[1085]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetOptions", "[", 
  RowBox[{"Eps", ",", 
   RowBox[{"Dimension", "\[Rule]", "4"}]}], "]"}]], "Input",
 CellTags->"LCD",
 CellLabel->"In[1086]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"Dimension", "\[Rule]", "4"}], "}"}], TraditionalForm]], "Output",
 CellTags->"LCD",
 CellLabel->"Out[1086]="]
}, Open  ]]
}, Open  ]],

Cell["LeftPartialD", "ObjectName",
 CellTags->"LeftPartialD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"LeftPartialD"],

Cell[TextData[{
 "LeftPartialD[\[Mu]] denotes ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], TraditionalForm]]],
 "acting to the left."
}], "Text",
 CellTags->"LeftPartialD"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["ExpandPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExpandPartialD",
  ButtonNote->"ExpandPartialD"],
 ", ",
 ButtonBox["PartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PartialD",
  ButtonNote->"PartialD"],
 ", ",
 ButtonBox["LeftRightPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LeftRightPartialD",
  ButtonNote->"LeftRightPartialD"],
 ", ",
 ButtonBox["RightPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RightPartialD",
  ButtonNote->"RightPartialD"],
 "."
}], "Text",
 CellTags->"LeftPartialD"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Examples"], "Subsubsection",
 CellTags->"LeftPartialD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"QuantumField", "[", 
   RowBox[{"A", ",", 
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}], ".", 
  RowBox[{"LeftPartialD", "[", "\[Nu]", "]"}]}]], "Input",
 CellTags->"LeftPartialD",
 CellLabel->"In[1087]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["A", "\[Mu]"], ".", 
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"LeftPartialD",
 CellLabel->"Out[1087]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
 CellTags->"LeftPartialD",
 CellLabel->"In[1088]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[PartialD]", 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]], 
   SubsuperscriptBox["A", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], "\[Null]"]}], TraditionalForm]], "Output",
 CellTags->"LeftPartialD",
 CellLabel->"Out[1088]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
 CellTags->"LeftPartialD",
 CellLabel->"In[1089]:="],

Cell[BoxData[
 RowBox[{"QuantumField", "[", 
  RowBox[{
   RowBox[{"PartialD", "[", 
    RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], "]"}], ",", "A", ",", 
   RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}]], "Output",
 CellTags->"LeftPartialD",
 CellLabel->"Out[1089]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"LeftPartialD", "[", "\[Mu]", "]"}], "]"}]], "Input",
 CellTags->"LeftPartialD",
 CellLabel->"In[1090]:="],

Cell[BoxData[
 RowBox[{"LeftPartialD", "[", 
  RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}]], "Output",
 CellTags->"LeftPartialD",
 CellLabel->"Out[1090]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"QuantumField", "[", 
   RowBox[{"A", ",", 
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}], ".", 
  RowBox[{"QuantumField", "[", 
   RowBox[{"A", ",", 
    RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], "]"}], ".", 
  RowBox[{"LeftPartialD", "[", "\[Rho]", "]"}]}]], "Input",
 CellTags->"LeftPartialD",
 CellLabel->"In[1091]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["A", "\[Mu]"], ".", 
   SubscriptBox["A", "\[Nu]"], ".", 
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
    FormBox[
     FormBox["\[Rho]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"LeftPartialD",
 CellLabel->"Out[1091]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
 CellTags->"LeftPartialD",
 CellLabel->"In[1092]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["A", "\[Mu]"], ".", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm], "\[Null]"]}]}], "+", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], "\[Null]"]}], ".", 
    SubscriptBox["A", "\[Nu]"]}]}], TraditionalForm]], "Output",
 CellTags->"LeftPartialD",
 CellLabel->"Out[1092]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
 CellTags->"LeftPartialD",
 CellLabel->"In[1093]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"QuantumField", "[", 
    RowBox[{"A", ",", 
     RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}], ".", 
   RowBox[{"QuantumField", "[", 
    RowBox[{
     RowBox[{"PartialD", "[", 
      RowBox[{"LorentzIndex", "[", "\[Rho]", "]"}], "]"}], ",", "A", ",", 
     RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"QuantumField", "[", 
    RowBox[{
     RowBox[{"PartialD", "[", 
      RowBox[{"LorentzIndex", "[", "\[Rho]", "]"}], "]"}], ",", "A", ",", 
     RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}], ".", 
   RowBox[{"QuantumField", "[", 
    RowBox[{"A", ",", 
     RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], "]"}]}]}]], "Output",
 CellTags->"LeftPartialD",
 CellLabel->"Out[1093]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["LeftRightPartialD", "ObjectName",
 CellTags->"LeftRightPartialD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"LeftRightPartialD"],

Cell[TextData[{
 "LeftRightPartialD[mu] denotes ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], TraditionalForm]]],
 ", acting to the left and right. ExplicitPartialD[LeftRightPartialD[",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "]] gives 1/2 (RightPartialD[",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "] - LeftPartialD[",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "])."
}], "Text",
 CellTags->"LeftRightPartialD"],

Cell[TextData[{
 "See also: ",
 ButtonBox["ExplicitPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExplicitPartialD",
  ButtonNote->"ExplicitPartialD"],
 ", ",
 ButtonBox["ExpandPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExpandPartialD",
  ButtonNote->"ExpandPartialD"],
 ", ",
 ButtonBox["PartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PartialD",
  ButtonNote->"PartialD"],
 ", ",
 ButtonBox["LeftPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LeftPartialD",
  ButtonNote->"LeftPartialD"],
 ", ",
 ButtonBox["LeftRightPartialD2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LeftRightPartialD2",
  ButtonNote->"LeftRightPartialD2"],
 ", ",
 ButtonBox["RightPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RightPartialD",
  ButtonNote->"RightPartialD"],
 "."
}], "Text",
 CellTags->"LeftRightPartialD"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"LeftRightPartialD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LeftRightPartialD", "[", "\[Mu]", "]"}]], "Input",
 CellTags->"LeftRightPartialD",
 CellLabel->"In[1094]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox[
   OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
   FormBox[
    FormBox["\[Mu]",
     TraditionalForm],
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"LeftRightPartialD",
 CellLabel->"Out[1094]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExplicitPartialD", "[", "%", "]"}]], "Input",
 CellTags->"LeftRightPartialD",
 CellLabel->"In[1095]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[RightArrow]"], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], "-", 
     SubscriptBox[
      OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"LeftRightPartialD",
 CellLabel->"Out[1095]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LeftRightPartialD", "[", "\[Mu]", "]"}], ".", 
  RowBox[{"QuantumField", "[", 
   RowBox[{"A", ",", 
    RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], "]"}]}]], "Input",
 CellTags->"LeftRightPartialD",
 CellLabel->"In[1096]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SubscriptBox["A", "\[Nu]"]}], TraditionalForm]], "Output",
 CellTags->"LeftRightPartialD",
 CellLabel->"Out[1096]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
 CellTags->"LeftRightPartialD",
 CellLabel->"In[1097]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], 
      SubsuperscriptBox["A", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm], "\[Null]"]}], "-", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], ".", 
      SubscriptBox["A", "\[Nu]"]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"LeftRightPartialD",
 CellLabel->"Out[1097]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"QuantumField", "[", 
   RowBox[{"A", ",", 
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}], ".", 
  RowBox[{"LeftRightPartialD", "[", "\[Nu]", "]"}], ".", 
  RowBox[{"QuantumField", "[", 
   RowBox[{"A", ",", 
    RowBox[{"LorentzIndex", "[", "\[Rho]", "]"}]}], "]"}]}]], "Input",
 CellTags->"LeftRightPartialD",
 CellLabel->"In[1098]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["A", "\[Mu]"], ".", 
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SubscriptBox["A", "\[Rho]"]}], TraditionalForm]], "Output",
 CellTags->"LeftRightPartialD",
 CellLabel->"Out[1098]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
 CellTags->"LeftRightPartialD",
 CellLabel->"In[1099]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["A", "\[Mu]"], ".", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["A", 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], "\[Null]"]}]}], "-", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], 
       SubsuperscriptBox["A", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], "\[Null]"]}], ".", 
      SubscriptBox["A", "\[Rho]"]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"LeftRightPartialD",
 CellLabel->"Out[1099]="]
}, Open  ]]
}, Open  ]],

Cell["LeftRightPartialD2", "ObjectName",
 CellTags->"LeftRightPartialD2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"LeftRightPartialD2"],

Cell[TextData[{
 "LeftRightPartialD2[mu] denotes ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], TraditionalForm]]],
 ", acting to the left and right. ExplicitPartialD[LeftRightPartialD2[",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "]] gives (RightPartialD[",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "] + LeftPartialD[",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "])."
}], "Text",
 CellTags->"LeftRightPartialD2"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["ExplicitPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExplicitPartialD",
  ButtonNote->"ExplicitPartialD"],
 ", ",
 ButtonBox["ExpandPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExpandPartialD",
  ButtonNote->"ExpandPartialD"],
 ", ",
 ButtonBox["PartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PartialD",
  ButtonNote->"PartialD"],
 ", ",
 ButtonBox["LeftPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LeftPartialD",
  ButtonNote->"LeftPartialD"],
 ", ",
 ButtonBox["RightPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RightPartialD",
  ButtonNote->"RightPartialD"],
 "."
}], "Text",
 CellTags->"LeftRightPartialD2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"LeftRightPartialD2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LeftRightPartialD2", "[", "\[Mu]", "]"}]], "Input",
 CellTags->"LeftRightPartialD2",
 CellLabel->"In[1100]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox[
   OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
   FormBox[
    FormBox["\[Mu]",
     TraditionalForm],
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"LeftRightPartialD2",
 CellLabel->"Out[1100]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExplicitPartialD", "[", "%", "]"}]], "Input",
 CellTags->"LeftRightPartialD2",
 CellLabel->"In[1101]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], "+", 
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[RightArrow]"], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"LeftRightPartialD2",
 CellLabel->"Out[1101]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LeftRightPartialD2", "[", "\[Mu]", "]"}], ".", 
  RowBox[{"QuantumField", "[", 
   RowBox[{"A", ",", 
    RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}]}], "]"}]}]], "Input",
 CellTags->"LeftRightPartialD2",
 CellLabel->"In[1102]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SubscriptBox["A", "\[Nu]"]}], TraditionalForm]], "Output",
 CellTags->"LeftRightPartialD2",
 CellLabel->"Out[1102]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
 CellTags->"LeftRightPartialD2",
 CellLabel->"In[1103]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], 
    SubsuperscriptBox["A", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], "\[Null]"]}], "+", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], ".", 
    SubscriptBox["A", "\[Nu]"]}]}], TraditionalForm]], "Output",
 CellTags->"LeftRightPartialD2",
 CellLabel->"Out[1103]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"QuantumField", "[", 
   RowBox[{"A", ",", 
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}], ".", 
  RowBox[{"LeftRightPartialD2", "[", "\[Nu]", "]"}], ".", 
  RowBox[{"QuantumField", "[", 
   RowBox[{"A", ",", 
    RowBox[{"LorentzIndex", "[", "\[Rho]", "]"}]}], "]"}]}]], "Input",
 CellTags->"LeftRightPartialD2",
 CellLabel->"In[1104]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["A", "\[Mu]"], ".", 
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[LeftRightArrow]"], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SubscriptBox["A", "\[Rho]"]}], TraditionalForm]], "Output",
 CellTags->"LeftRightPartialD2",
 CellLabel->"Out[1104]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
 CellTags->"LeftRightPartialD2",
 CellLabel->"In[1105]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["A", "\[Mu]"], ".", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm], "\[Null]"]}]}], "+", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["A", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], "\[Null]"]}], ".", 
    SubscriptBox["A", "\[Rho]"]}]}], TraditionalForm]], "Output",
 CellTags->"LeftRightPartialD2",
 CellLabel->"Out[1105]="]
}, Open  ]]
}, Open  ]],

Cell["LeviCivita ", "ObjectName",
 CellTags->"LeviCivita"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"LeviCivita"],

Cell[TextData[{
 "LeviCivita[",
 Cell[BoxData[
  FormBox[
   RowBox[{
   "\[Mu]", ",", " ", "\[Nu]", ",", " ", "\[Rho]", ",", " ", "\[Sigma]"}], 
   TraditionalForm]]],
 "] is an input function for the totally antisymmetric Levi-Civita tensor. It \
evaluates automatically to the internal representation Eps[LorentzIndex[",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "], LorentzIndex[",
 Cell[BoxData[
  FormBox["\[Nu]", TraditionalForm]]],
 "], LorentzIndex[",
 Cell[BoxData[
  FormBox[
   FormBox["\[Rho]",
    TraditionalForm], TraditionalForm]]],
 "], LorentzIndex[\[Sigma]]] (or with a second argument in LorentzIndex for \
the Dimension, if the option Dimension of LeviCivita is changed). LeviCivita[",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Mu]", ",", " ", 
    RowBox[{"\[Nu]", " ", "..."}]}], TraditionalForm]]],
 "][ ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", ",", " ", ".."}], TraditionalForm]]],
 ".] evaluates to Eps[LorentzIndex[",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "], LorentzIndex[",
 Cell[BoxData[
  FormBox["\[Nu]", TraditionalForm]]],
 "], ..., Momentum[",
 Cell[BoxData[
  FormBox["p", TraditionalForm]]],
 "], ...]."
}], "Text",
 CellTags->"LeviCivita"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "LeviCivita", "]"}]], "Input",
 CellTags->"LeviCivita",
 CellLabel->"In[1106]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"Dimension", "\[Rule]", "D"}], "}"}], TraditionalForm]], "Output",
 CellTags->"LeviCivita",
 CellLabel->"Out[1106]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Eps",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Eps",
  ButtonNote->"Eps"],
 ", ",
 ButtonBox["Contract",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Contract",
  ButtonNote->"Contract"],
 ", ",
 ButtonBox["LC",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LC",
  ButtonNote->"LC"],
 ", ",
 ButtonBox["LCD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LCD",
  ButtonNote->"LCD"],
 "."
}], "Text",
 CellTags->"LeviCivita"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"LeviCivita"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LeviCivita", "[", 
  RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Delta]"}], 
  "]"}]], "Input",
 CellTags->"LeviCivita",
 CellLabel->"In[1107]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{
    FormBox[
     FormBox["\[Alpha]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Beta]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Gamma]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Delta]",
      TraditionalForm],
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"LeviCivita",
 CellLabel->"Out[1107]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LeviCivita", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "[", 
  RowBox[{"OPEDelta", ",", "p"}], "]"}]], "Input",
 CellTags->"LeviCivita",
 CellLabel->"In[1108]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox["\[CapitalDelta]",
     TraditionalForm], 
    FormBox["p",
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"LeviCivita",
 CellLabel->"Out[1108]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LeviCivita", "[", "]"}], "[", 
  RowBox[{"p", ",", "q", ",", "r", ",", "s"}], "]"}]], "Input",
 CellTags->"LeviCivita",
 CellLabel->"In[1109]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{
    FormBox["p",
     TraditionalForm], 
    FormBox["q",
     TraditionalForm], 
    FormBox["r",
     TraditionalForm], 
    FormBox["s",
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"LeviCivita",
 CellLabel->"Out[1109]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LeviCivita", "[", 
  RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Beta]", ",", "\[Delta]"}], 
  "]"}]], "Input",
 CellTags->"LeviCivita",
 CellLabel->"In[1110]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"LeviCivita",
 CellLabel->"Out[1110]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"LeviCivita", "[", 
    RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "[", 
   RowBox[{"OPEDelta", ",", "p"}], "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"LeviCivita",
 CellLabel->"In[1111]:="],

Cell[BoxData[
 RowBox[{"Eps", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], ",", 
   RowBox[{"Momentum", "[", "OPEDelta", "]"}], ",", 
   RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]], "Output",
 CellTags->"LeviCivita",
 CellLabel->"Out[1111]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", " ", "=", " ", 
  RowBox[{
   RowBox[{"LeviCivita", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Rho]"}], 
    "]"}], ".", 
   RowBox[{"LeviCivita", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Rho]"}], 
    "]"}]}], " "}]], "Input",
 CellTags->"LeviCivita",
 CellLabel->"In[1112]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Epsilon]", 
    RowBox[{
     FormBox[
      FormBox["\[Alpha]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Beta]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Gamma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm]}]], ".", 
   SuperscriptBox["\[Epsilon]", 
    RowBox[{
     FormBox[
      FormBox["\[Alpha]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Beta]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Gamma]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"LeviCivita",
 CellLabel->"Out[1112]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", "t1", "]"}]], "Input",
 CellTags->"LeviCivita",
 CellLabel->"In[1113]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", "24"}], TraditionalForm]], "Output",
 CellTags->"LeviCivita",
 CellLabel->"Out[1113]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"LeviCivita", ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], ";", 
  RowBox[{"SetOptions", "[", 
   RowBox[{"Eps", ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], ";"}]], "Input",
 CellTags->"LeviCivita",
 CellLabel->"In[1114]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Contract", "[", " ", 
   RowBox[{
    RowBox[{"LeviCivita", "[", 
     RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Rho]"}], 
     "]"}], ".", 
    RowBox[{"LeviCivita", "[", 
     RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Rho]"}], 
     "]"}]}], "]"}], "//", "Factor2"}]], "Input",
 CellTags->"LeviCivita",
 CellLabel->"In[1115]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", "D"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"2", "-", "D"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"3", "-", "D"}], ")"}], " ", "D"}], TraditionalForm]], "Output",
 CellTags->"LeviCivita",
 CellLabel->"Out[1115]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"LeviCivita", ",", 
    RowBox[{"Dimension", "\[Rule]", "4"}]}], "]"}], ";", 
  RowBox[{"SetOptions", "[", 
   RowBox[{"Eps", ",", 
    RowBox[{"Dimension", "\[Rule]", "4"}]}], "]"}], ";"}]], "Input",
 CellTags->"LeviCivita",
 CellLabel->"In[1116]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LC", "[", 
  RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Delta]"}], 
  "]"}]], "Input",
 CellTags->"LeviCivita",
 CellLabel->"In[1117]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{"\[Alpha]", "\[Beta]", "\[Gamma]", "\[Delta]"}]], 
  TraditionalForm]], "Output",
 CellTags->"LeviCivita",
 CellLabel->"Out[1117]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "t1", "]"}]], "Input",
 CellTags->"LeviCivita",
 CellLabel->"In[1118]:="]
}, Open  ]],

Cell["LeviCivitaSign", "ObjectName",
 CellTags->"LeviCivitaSign"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"LeviCivitaSign"],

Cell["\<\
LeviCivitaSign is an option for DiracTrace and EpsChisholm. It determines the \
sign in the result of a Dirac trace of four gamma matrices and gamma5.\
\>", "Text",
 CellTags->"LeviCivitaSign"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracTrace",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrace",
  ButtonNote->"DiracTrace"],
 ", ",
 ButtonBox["EpsChisholm",
  BaseStyle->"AddOnsLink",
  ButtonData:>"EpsChisholm",
  ButtonNote->"EpsChisholm"],
 "."
}], "Text",
 CellTags->"LeviCivitaSign"]
}, Open  ]],

Cell["ListIntegrals  ***unfinished***", "ObjectName",
 CellTags->"ListIntegrals"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ListIntegrals"],

Cell["\<\
ListIntegrals[exp, {q1, q2}] gives a list of basic integrals  \
(FeynAmpDenominator's multiplied by scalar products involving q1, q2).  Any \
non-integer exponent (e.g. the (OPEm-1) in  \
ScalarProduct[OPEDelta,q1]^(OPEm-1)) is replaced by OPEm.  If the options \
Pair is set to True only integrals involving   scalar products (not counting \
those with OPEDelta) are given; with Pair \[Rule] False those are excluded.\
\>", "Text",
 CellTags->"ListIntegrals"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ListIntegrals"],

Cell[BoxData[""], "Input",
 CellTags->"ListIntegrals",
 CellLabel->"In[1119]:="]
}, Open  ]],

Cell["Li2 ", "ObjectName",
 CellTags->"Li2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Li2"],

Cell["\<\
 Li2 is an abbreviation for the dilog function, i.e., Li2 = PolyLog[2, #]&.\
\>", "Text",
 CellTags->"Li2"],

Cell[TextData[{
 "See also: ",
 ButtonBox["Li3",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Li3",
  ButtonNote->"Li3"],
 "."
}], "Text",
 CellTags->"Li2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Li2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Li2", "[", "x", "]"}]], "Input",
 CellTags->"Li2",
 CellLabel->"In[1120]:="],

Cell[BoxData[
 FormBox[
  TemplateBox[{"2","x"},
   "PolyLog"], TraditionalForm]], "Output",
 CellTags->"Li2",
 CellLabel->"Out[1120]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Li2", "//", "StandardForm"}]], "Input",
 CellTags->"Li2",
 CellLabel->"In[1121]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"PolyLog", "[", 
   RowBox[{"2", ",", "#1"}], "]"}], "&"}]], "Output",
 CellTags->"Li2",
 CellLabel->"Out[1121]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"\[Integral]", 
   RowBox[{
    FractionBox[
     RowBox[{"Log", "[", 
      RowBox[{"1", "-", "x"}], "]"}], "x"], 
    RowBox[{"\[DifferentialD]", "x"}]}]}]}]], "Input",
 CellTags->"Li2",
 CellLabel->"In[1122]:="],

Cell[BoxData[
 FormBox[
  TemplateBox[{"2","x"},
   "PolyLog"], TraditionalForm]], "Output",
 CellTags->"Li2",
 CellLabel->"Out[1122]="]
}, Open  ]]
}, Open  ]],

Cell["Li3 ", "ObjectName",
 CellTags->"Li3"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Li3"],

Cell["\<\
 Li3 is an abbreviation for the trilog function, i.e., Li3 = PolyLog[3, #]&.\
\>", "Text",
 CellTags->"Li3"],

Cell[TextData[{
 "See also: ",
 ButtonBox["Li2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Li2",
  ButtonNote->"Li2"],
 "."
}], "Text",
 CellTags->"Li3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Li3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Li3", "[", "x", "]"}]], "Input",
 CellTags->"Li3",
 CellLabel->"In[1123]:="],

Cell[BoxData[
 FormBox[
  TemplateBox[{"3","x"},
   "PolyLog"], TraditionalForm]], "Output",
 CellTags->"Li3",
 CellLabel->"Out[1123]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Li3", "//", "StandardForm"}]], "Input",
 CellTags->"Li3",
 CellLabel->"In[1124]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"PolyLog", "[", 
   RowBox[{"3", ",", "#1"}], "]"}], "&"}]], "Output",
 CellTags->"Li3",
 CellLabel->"Out[1124]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"Li3", "[", "x", "]"}], ",", "x"}], "]"}]], "Input",
 CellTags->"Li3",
 CellLabel->"In[1125]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   TemplateBox[{"2","x"},
    "PolyLog"], "x"], TraditionalForm]], "Output",
 CellTags->"Li3",
 CellLabel->"Out[1125]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Integral]", 
  RowBox[{
   FractionBox[
    RowBox[{"Li2", "[", "x", "]"}], "x"], 
   RowBox[{"\[DifferentialD]", "x"}]}]}]], "Input",
 CellTags->"Li3",
 CellLabel->"In[1126]:="],

Cell[BoxData[
 FormBox[
  TemplateBox[{"3","x"},
   "PolyLog"], TraditionalForm]], "Output",
 CellTags->"Li3",
 CellLabel->"Out[1126]="]
}, Open  ]]
}, Open  ]],

Cell["Loop", "ObjectName",
 CellTags->"Loop"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Loop"],

Cell["Loop is an option indicating the number of (virtual) loops.", "Text",
 CellTags->"Loop"]
}, Open  ]],

Cell["LorentzIndex", "ObjectName",
 CellTags->"LorentzIndex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"LorentzIndex"],

Cell["\<\
LorentzIndex[mu] denotes a four dimensional Lorentz index. For other than \
four dimensions: LorentzIndex[mu, D] or LorentzIndex[mu], etc. \
LorentzIndex[mu, 4] simplifies to LorentzIndex[mu].\
\>", "Text",
 CellTags->"LorentzIndex"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["ChangeDimension",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ChangeDimension",
  ButtonNote->"ChangeDimension"],
 ", ",
 ButtonBox["Momentum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Momentum",
  ButtonNote->"Momentum"],
 "."
}], "Text",
 CellTags->"LorentzIndex"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"LorentzIndex"],

Cell["This denotes a four-dimensional Lorentz index.", "Text",
 CellTags->"LorentzIndex"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LorentzIndex", "[", "\[Alpha]", "]"}]], "Input",
 CellTags->"LorentzIndex",
 CellLabel->"In[1127]:="],

Cell[BoxData[
 FormBox["\[Alpha]", TraditionalForm]], "Output",
 CellTags->"LorentzIndex",
 CellLabel->"Out[1127]="]
}, Open  ]],

Cell["\<\
An optional second argument can be given for a dimension different from 4.\
\>", "Text",
 CellTags->"LorentzIndex"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LorentzIndex", "[", 
  RowBox[{"\[Alpha]", ",", "n"}], "]"}]], "Input",
 CellTags->"LorentzIndex",
 CellLabel->"In[1128]:="],

Cell[BoxData[
 FormBox["\[Alpha]", TraditionalForm]], "Output",
 CellTags->"LorentzIndex",
 CellLabel->"Out[1128]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["LorentzIndex[ComplexIndex[\[Alpha]]]", "Input",
 CellTags->"LorentzIndex",
 CellLabel->"In[1129]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Alpha]", "*"], TraditionalForm]], "Output",
 CellTags->"LorentzIndex",
 CellLabel->"Out[1129]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ComplexConjugate", "[", 
  RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}]], "Input",
 CellTags->"LorentzIndex",
 CellLabel->"In[1130]:="],

Cell[BoxData[
 FormBox["\[Mu]", TraditionalForm]], "Output",
 CellTags->"LorentzIndex",
 CellLabel->"Out[1130]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ComplexConjugate", "[", 
  RowBox[{"LorentzIndex", "[", 
   RowBox[{"ComplexIndex", "[", "\[Beta]", "]"}], "]"}], "]"}]], "Input",
 CellTags->"LorentzIndex",
 CellLabel->"In[1131]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Beta]", "*"], TraditionalForm]], "Output",
 CellTags->"LorentzIndex",
 CellLabel->"Out[1131]="]
}, Open  ]],

Cell["\<\
Setting $LorentzIndices=True displays the dimension (if different from 4) as \
a subindex.\
\>", "Text",
 CellTags->"LorentzIndex"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$LorentzIndices", "=", "True"}], ";"}]], "Input",
 CellTags->"LorentzIndex",
 CellLabel->"In[1132]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Alpha]", ",", "D"}], "]"}], ",", 
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Nu]", ",", "n"}], "]"}], ",", 
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Beta]", ",", "4"}], "]"}]}], "}"}]], "Input",
 CellTags->"LorentzIndex",
 CellLabel->"In[1133]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    SubscriptBox[
     FormBox["\[Alpha]",
      TraditionalForm], 
     FormBox["D",
      TraditionalForm]], ",", 
    SubscriptBox[
     FormBox["\[Nu]",
      TraditionalForm], 
     FormBox["n",
      TraditionalForm]], ",", "\[Beta]"}], "}"}], TraditionalForm]], "Output",\

 CellTags->"LorentzIndex",
 CellLabel->"Out[1133]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"$LorentzIndices", " ", "=", " ", "False"}], ";"}]], "Input",
 CellTags->"LorentzIndex",
 CellLabel->"In[1134]:="]
}, Open  ]],

Cell["Lower", "ObjectName",
 CellTags->"Lower"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Lower"],

Cell["\<\
Lower may be used inside LorentzIndex to indicate an covariant LorentzIndex.\
\>", "Text",
 CellTags->"Lower"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["LorentzIndex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LorentzIndex",
  ButtonNote->"LorentzIndex"],
 ", ",
 ButtonBox["Upper",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Upper",
  ButtonNote->"Upper"],
 ", ",
 ButtonBox["Contract1",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Contract1",
  ButtonNote->"Contract1"],
 "."
}], "Text",
 CellTags->"Lower"]
}, Open  ]],

Cell["MakeContext", "ObjectName",
 CellTags->"MakeContext"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"MakeContext"],

Cell["\<\
MakeContext[string] constructs the context path of string. MakeContext is \
invoked at startup of FeynCalc. MakeContext[a, b] construct the context path \
of b defined in the context of a.\
\>", "Text",
 CellTags->"MakeContext"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynCalc",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalc",
  ButtonNote->"FeynCalc"],
 ", ",
 ButtonBox["CheckContext",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CheckContext",
  ButtonNote->"CheckContext"],
 ", ",
 ButtonBox["$FeynCalcStuff",
  BaseStyle->"AddOnsLink",
  ButtonData:>"$FeynCalcStuff",
  ButtonNote->"$FeynCalcStuff"],
 ", ",
 ButtonBox["Load",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Load",
  ButtonNote->"Load"],
 "."
}], "Text",
 CellTags->"MakeContext"]
}, Open  ]],

Cell["Mandelstam", "ObjectName",
 CellTags->"Mandelstam"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Mandelstam"],

Cell[TextData[{
 "Mandelstam is an option for DiracTrace, OneLoop, OneLoopSum, Tr and \
TrickMandelstam.  A typical setting is Mandelstam \[Rule] {",
 "s",
 ", ",
 "t",
 ", ",
 "u",
 ", ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox[
     StyleBox["m",
      FontSlant->"Plain"], "1"], "2"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox[
     StyleBox["m",
      FontSlant->"Plain"], "2"], "2"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox[
     StyleBox["m",
      FontSlant->"Plain"], "3"], "2"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox[
     StyleBox["m",
      FontSlant->"Plain"], "4"], "2"], TraditionalForm]]],
 "}, which stands for  ",
 "s",
 " + ",
 "t",
 " + ",
 "u",
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox[
     StyleBox["m",
      FontSlant->"Plain"], "1"], "2"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox[
     StyleBox["m",
      FontSlant->"Plain"], "2"], "2"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox[
     StyleBox["m",
      FontSlant->"Plain"], "3"], "2"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox[
     StyleBox["m",
      FontSlant->"Plain"], "4"], "2"], TraditionalForm]]],
 ". If other than four-particle processes are calculated the setting should \
be: Mandelstam \[Rule] {}."
}], "Text",
 CellTags->"Mandelstam"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracTrace",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrace",
  ButtonNote->"DiracTrace"],
 ", ",
 ButtonBox["OneLoop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoop",
  ButtonNote->"OneLoop"],
 ", ",
 ButtonBox["OneLoopSum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoopSum",
  ButtonNote->"OneLoopSum"],
 ", ",
 ButtonBox["Tr",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Tr",
  ButtonNote->"Tr"],
 ", ",
 ButtonBox["TrickMandelstam",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TrickMandelstam",
  ButtonNote->"TrickMandelstam"],
 ", ",
 ButtonBox["SetMandelstam",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SetMandelstam",
  ButtonNote->"SetMandelstam"],
 "."
}], "Text",
 CellTags->"Mandelstam"]
}, Open  ]],

Cell["Map2", "ObjectName",
 CellTags->"Map2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Map2"],

Cell["\<\
Map2[f, exp] is equivalent to Map if Nterms[exp] > 0, otherwise Map2[f, exp] \
gives f[exp].\
\>", "Text",
 CellTags->"Map2"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["NTerms",
  BaseStyle->"AddOnsLink",
  ButtonData:>"NTerms",
  ButtonNote->"NTerms"],
 "."
}], "Text",
 CellTags->"Map2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Map2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map2", "[", 
  RowBox[{"f", ",", 
   RowBox[{"a", "-", "b"}]}], "]"}]], "Input",
 CellTags->"Map2",
 CellLabel->"In[1135]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"f", "(", "a", ")"}], "+", 
   RowBox[{"f", "(", 
    RowBox[{"-", "b"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Map2",
 CellLabel->"Out[1135]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map2", "[", 
  RowBox[{"f", ",", "x"}], "]"}]], "Input",
 CellTags->"Map2",
 CellLabel->"In[1136]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"f", "(", "x", ")"}], TraditionalForm]], "Output",
 CellTags->"Map2",
 CellLabel->"Out[1136]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map2", "[", 
  RowBox[{"f", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]], "Input",
 CellTags->"Map2",
 CellLabel->"In[1137]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"f", "(", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], ")"}], 
  TraditionalForm]], "Output",
 CellTags->"Map2",
 CellLabel->"Out[1137]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map2", "[", 
  RowBox[{"f", ",", "1"}], "]"}]], "Input",
 CellTags->"Map2",
 CellLabel->"In[1138]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"f", "(", "1", ")"}], TraditionalForm]], "Output",
 CellTags->"Map2",
 CellLabel->"Out[1138]="]
}, Open  ]]
}, Open  ]],

Cell["MemoryAvailable", "ObjectName",
 CellTags->"MemoryAvailable"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"MemoryAvailable"],

Cell["\<\
MemoryAvailable is an option of MemSet. It can be set to an integer n, where \
n is the available amount of main memory in Mega Byte. The default setting is \
$MemoryAvailable.\
\>", "Text",
 CellTags->"MemoryAvailable"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["MemSet",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MemSet",
  ButtonNote->"MemSet"],
 ", ",
 ButtonBox["$MemoryAvailable",
  BaseStyle->"AddOnsLink",
  ButtonData:>"$MemoryAvailable",
  ButtonNote->"$MemoryAvailable"],
 "."
}], "Text",
 CellTags->"MemoryAvailable"]
}, Open  ]],

Cell["MemSet", "ObjectName",
 CellTags->"MemSet"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"MemSet"],

Cell[TextData[{
 "MemSet[f[x_], body] is like f[x_] := f[x] = body, but dependend on the \
value of the setting of MemoryAvailable \[Rule] memorycut (memorycut - \
MemoryInUse[]/",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "6"], TraditionalForm]]],
 ") MemSet[f[x_], body] may evaluate as f[x_] := body."
}], "Text",
 CellTags->"MemSet"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["MemoryAvailable",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MemoryAvailable",
  ButtonNote->"MemoryAvailable"],
 "."
}], "Text",
 CellTags->"MemSet"]
}, Open  ]],

Cell["MetricTensor", "ObjectName",
 CellTags->"MetricTensor"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"MetricTensor"],

Cell[TextData[{
 "MetricTensor[",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Mu]", ",", " ", "\[Nu]"}], TraditionalForm]]],
 "] is the metric tensor. The default dimension is 4."
}], "Text",
 CellTags->"MetricTensor"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynCalcExternal",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalcExternal",
  ButtonNote->"FeynCalcExternal"],
 ", ",
 ButtonBox["FCE",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCE",
  ButtonNote->"FCE"],
 ", ",
 ButtonBox["FCI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCI",
  ButtonNote->"FCI"],
 ", ",
 ButtonBox["MT",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MT",
  ButtonNote->"MT"],
 ", ",
 ButtonBox["MTD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MTD",
  ButtonNote->"MTD"],
 "."
}], "Text",
 CellTags->"MetricTensor"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"MetricTensor"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MetricTensor", "[", 
  RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]], "Input",
 CellTags->"MetricTensor",
 CellLabel->"In[1139]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["g", 
   RowBox[{"\[Alpha]", "\[Beta]"}]], TraditionalForm]], "Output",
 CellTags->"MetricTensor",
 CellLabel->"Out[1139]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", 
  RowBox[{"%", " ", "*", " ", "%"}], "]"}]], "Input",
 CellTags->"MetricTensor",
 CellLabel->"In[1140]:="],

Cell[BoxData[
 FormBox["4", TraditionalForm]], "Output",
 CellTags->"MetricTensor",
 CellLabel->"Out[1140]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MetricTensor", "[", 
  RowBox[{"\[Alpha]", ",", "\[Beta]", ",", 
   RowBox[{"Dimension", "\[Rule]", "n"}]}], "]"}]], "Input",
 CellTags->"MetricTensor",
 CellLabel->"In[1141]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["g", 
   RowBox[{"\[Alpha]", "\[Beta]"}]], TraditionalForm]], "Output",
 CellTags->"MetricTensor",
 CellLabel->"Out[1141]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", 
  RowBox[{"%", " ", "*", " ", "%"}], "]"}]], "Input",
 CellTags->"MetricTensor",
 CellLabel->"In[1142]:="],

Cell[BoxData[
 FormBox["n", TraditionalForm]], "Output",
 CellTags->"MetricTensor",
 CellLabel->"Out[1142]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"MetricTensor", "[", 
   RowBox[{"a", ",", "b"}], "]"}], "]"}]], "Input",
 CellTags->"MetricTensor",
 CellLabel->"In[1143]:="],

Cell[BoxData[
 RowBox[{"MetricTensor", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Output",
 CellTags->"MetricTensor",
 CellLabel->"Out[1143]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"MetricTensor", "[", 
   RowBox[{"a", ",", "b", ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], "]"}]], "Input",
 CellTags->"MetricTensor",
 CellLabel->"In[1144]:="],

Cell[BoxData[
 RowBox[{"MetricTensor", "[", 
  RowBox[{"a", ",", "b", ",", 
   RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}]], "Output",
 CellTags->"MetricTensor",
 CellLabel->"Out[1144]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"FCE", "[", 
   RowBox[{"MetricTensor", "[", 
    RowBox[{"a", ",", "b"}], "]"}], "]"}], "]"}]], "Input",
 CellTags->"MetricTensor",
 CellLabel->"In[1145]:="],

Cell[BoxData[
 RowBox[{"MetricTensor", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Output",
 CellTags->"MetricTensor",
 CellLabel->"Out[1145]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"FCE", "[", 
   RowBox[{"MetricTensor", "[", 
    RowBox[{"a", ",", "b", ",", 
     RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], "]"}], "]"}]], "Input",
 CellTags->"MetricTensor",
 CellLabel->"In[1146]:="],

Cell[BoxData[
 RowBox[{"MetricTensor", "[", 
  RowBox[{"a", ",", "b", ",", 
   RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}]], "Output",
 CellTags->"MetricTensor",
 CellLabel->"Out[1146]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["MLimit", "ObjectName",
 CellTags->"MLimit"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"MLimit"],

Cell["\<\
MLimit[expr, lims] takes multiple limits of expr using the limits lims.\
\>", "Text",
 CellTags->"MLimit"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"MLimit"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MLimit", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"y", " ", 
     RowBox[{"Log", "[", "y", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"x", "-", "1"}], "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"x", "-", "1"}], ")"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "1"}], ",", 
     RowBox[{"y", "\[Rule]", "0"}]}], "}"}]}], "]"}]], "Input",
 CellTags->"MLimit",
 CellLabel->"In[1147]:="],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellTags->"MLimit",
 CellLabel->"Out[1147]="]
}, Open  ]]
}, Open  ]],

Cell["Momentum", "ObjectName",
 CellTags->"Momentum"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Momentum"],

Cell["\<\
Momentum[p] is the head of a four momentum (p). The internal representation \
of a four-dimensional p is Momentum[p]. For other than four dimensions: \
Momentum[p, dim]. Momentum[p, 4] simplifies to Momentum[p].\
\>", "Text",
 CellTags->"Momentum"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracGamma",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracGamma",
  ButtonNote->"DiracGamma"],
 ", ",
 ButtonBox["Eps",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Eps",
  ButtonNote->"Eps"],
 ", ",
 ButtonBox["LorentzIndex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LorentzIndex",
  ButtonNote->"LorentzIndex"],
 ", ",
 ButtonBox["MomentumExpand",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MomentumExpand",
  ButtonNote->"MomentumExpand"],
 "."
}], "Text",
 CellTags->"Momentum"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Momentum"],

Cell["This is a four dimensional momentum.", "Text",
 CellTags->"Momentum"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Momentum", "[", "p", "]"}]], "Input",
 CellTags->"Momentum",
 CellLabel->"In[1148]:="],

Cell[BoxData[
 FormBox["p", TraditionalForm]], "Output",
 CellTags->"Momentum",
 CellLabel->"Out[1148]="]
}, Open  ]],

Cell["\<\
As an optional second argument the dimension must be specified if it is \
different from 4.\
\>", "Text",
 CellTags->"Momentum"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Momentum", "[", 
  RowBox[{"p", ",", "D"}], "]"}]], "Input",
 CellTags->"Momentum",
 CellLabel->"In[1149]:="],

Cell[BoxData[
 FormBox["p", TraditionalForm]], "Output",
 CellTags->"Momentum",
 CellLabel->"Out[1149]="]
}, Open  ]],

Cell["The dimension index is supressed in the output.", "Text",
 CellTags->"Momentum"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Momentum", "[", 
   RowBox[{"p", ",", "d"}], "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"Momentum",
 CellLabel->"In[1150]:="],

Cell[BoxData[
 RowBox[{"Momentum", "[", 
  RowBox[{"p", ",", "d"}], "]"}]], "Output",
 CellTags->"Momentum",
 CellLabel->"Out[1150]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1", "=", 
  RowBox[{"Momentum", "[", 
   RowBox[{"-", "q"}], "]"}]}]], "Input",
 CellTags->"Momentum",
 CellLabel->"In[1151]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", "q"}], TraditionalForm]], "Output",
 CellTags->"Momentum",
 CellLabel->"Out[1151]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1", "//", "StandardForm"}]], "Input",
 CellTags->"Momentum",
 CellLabel->"In[1152]:="],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"Momentum", "[", "q", "]"}]}]], "Output",
 CellTags->"Momentum",
 CellLabel->"Out[1152]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2", " ", "=", " ", 
  RowBox[{
   RowBox[{"Momentum", "[", 
    RowBox[{"p", "-", "q"}], "]"}], " ", "+", " ", 
   RowBox[{"Momentum", "[", 
    RowBox[{"2", "q"}], "]"}]}]}]], "Input",
 CellTags->"Momentum",
 CellLabel->"In[1153]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"p", "-", "q"}], ")"}], "+", 
   RowBox[{"2", " ", "q"}]}], TraditionalForm]], "Output",
 CellTags->"Momentum",
 CellLabel->"Out[1153]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2", "//", "StandardForm"}]], "Input",
 CellTags->"Momentum",
 CellLabel->"In[1154]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Momentum", "[", 
   RowBox[{"p", "-", "q"}], "]"}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Momentum", "[", "q", "]"}]}]}]], "Output",
 CellTags->"Momentum",
 CellLabel->"Out[1154]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"a2", "//", "MomentumExpand"}], "//", "StandardForm"}]], "Input",
 CellTags->"Momentum",
 CellLabel->"In[1155]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Momentum", "[", "p", "]"}], "+", 
  RowBox[{"Momentum", "[", "q", "]"}]}]], "Output",
 CellTags->"Momentum",
 CellLabel->"Out[1155]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"a2", "//", "MomentumCombine"}], "//", "StandardForm"}]], "Input",
 CellTags->"Momentum",
 CellLabel->"In[1156]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Momentum", "[", 
   RowBox[{"p", "-", "q"}], "]"}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Momentum", "[", "q", "]"}]}]}]], "Output",
 CellTags->"Momentum",
 CellLabel->"Out[1156]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ChangeDimension", "[", 
   RowBox[{
    RowBox[{"Momentum", "[", "p", "]"}], ",", "d"}], "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"Momentum",
 CellLabel->"In[1157]:="],

Cell[BoxData[
 RowBox[{"Momentum", "[", 
  RowBox[{"p", ",", "d"}], "]"}]], "Output",
 CellTags->"Momentum",
 CellLabel->"Out[1157]//StandardForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"a1", ",", "a2"}], "]"}]], "Input",
 CellTags->"Momentum",
 CellLabel->"In[1158]:="]
}, Open  ]],

Cell["MomentumCombine", "ObjectName",
 CellTags->"MomentumCombine"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"MomentumCombine"],

Cell["\<\
MomentumCombine[expr] is the inverse operation to MomentumExpand and \
ExpandScalarProduct. MomentumCombine combines also Pair`s.\
\>", "Text",
 CellTags->"MomentumCombine"],

Cell[TextData[{
 "See also: ",
 ButtonBox["ExpandScalarProduct",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExpandScalarProduct",
  ButtonNote->"ExpandScalarProduct"],
 ", ",
 ButtonBox["Momentum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Momentum",
  ButtonNote->"Momentum"],
 ", ",
 ButtonBox["MomentumExpand",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MomentumExpand",
  ButtonNote->"MomentumExpand"],
 ", ",
 ButtonBox["MomentumCombine2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MomentumCombine2",
  ButtonNote->"MomentumCombine2"],
 "."
}], "Text",
 CellTags->"MomentumCombine"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"MomentumCombine"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Momentum", "[", "p", "]"}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"Momentum", "[", "q", "]"}]}]}], " ", "//", " ", 
   "MomentumCombine"}], " ", "//", " ", "StandardForm"}]], "Input",
 CellTags->"MomentumCombine",
 CellLabel->"In[1159]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Momentum", "[", "p", "]"}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"Momentum", "[", "q", "]"}]}]}]], "Output",
 CellTags->"MomentumCombine",
 CellLabel->"Out[1159]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{
   RowBox[{"FV", "[", 
    RowBox[{"p", ",", "\[Mu]"}], "]"}], " ", "+", " ", 
   RowBox[{"2", " ", 
    RowBox[{"FV", "[", 
     RowBox[{"q", ",", "\[Mu]"}], "]"}]}], " "}]}]], "Input",
 CellTags->"MomentumCombine",
 CellLabel->"In[1160]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["p", "\[Mu]"], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["q", "\[Mu]"]}]}], TraditionalForm]], "Output",
 CellTags->"MomentumCombine",
 CellLabel->"Out[1160]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MomentumCombine", "[", "t1", "]"}]], "Input",
 CellTags->"MomentumCombine",
 CellLabel->"In[1161]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["p", "\[Mu]"], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["q", "\[Mu]"]}]}], TraditionalForm]], "Output",
 CellTags->"MomentumCombine",
 CellLabel->"Out[1161]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MomentumCombine", "[", "t1", "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"MomentumCombine",
 CellLabel->"In[1162]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"FV", "[", 
   RowBox[{"p", ",", "\[Mu]"}], "]"}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"FV", "[", 
    RowBox[{"q", ",", "\[Mu]"}], "]"}]}]}]], "Output",
 CellTags->"MomentumCombine",
 CellLabel->"Out[1162]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MomentumCombine", "[", "t1", "]"}], "//", 
  "ExpandScalarProduct"}]], "Input",
 CellTags->"MomentumCombine",
 CellLabel->"In[1163]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"MomentumCombine",
 CellLabel->"Out[1163]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
 CellTags->"MomentumCombine",
 CellLabel->"In[1164]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pair", "[", 
   RowBox[{
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
    RowBox[{"Momentum", "[", "p", "]"}]}], "]"}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Pair", "[", 
    RowBox[{
     RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
     RowBox[{"Momentum", "[", "q", "]"}]}], "]"}]}]}]], "Output",
 CellTags->"MomentumCombine",
 CellLabel->"Out[1164]//StandardForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "t1", "]"}]], "Input",
 CellTags->"MomentumCombine",
 CellLabel->"In[1165]:="]
}, Open  ]],

Cell["MomentumCombine2", "ObjectName",
 CellTags->"MomentumCombine2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"MomentumCombine2"],

Cell["\<\
MomentumCombine2[expr]  is the inverse operation to MomentumExpand and \
ExpandScalarProduct. MomentumCombine2 combines also FourVectors.\
\>", "Text",
 CellTags->"MomentumCombine2"],

Cell[TextData[{
 "See also: ",
 ButtonBox["MomentumCombine",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MomentumCombine",
  ButtonNote->"MomentumCombine"],
 ", ",
 ButtonBox["MomentumExpand",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MomentumExpand",
  ButtonNote->"MomentumExpand"],
 ", ",
 ButtonBox["ExpandScalarProduct",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExpandScalarProduct",
  ButtonNote->"ExpandScalarProduct"],
 ", ",
 ButtonBox["FourVector",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FourVector",
  ButtonNote->"FourVector"],
 "."
}], "Text",
 CellTags->"MomentumCombine2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"MomentumCombine2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"3", " ", 
   RowBox[{"Pair", "[", 
    RowBox[{
     RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
     RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Pair", "[", 
    RowBox[{
     RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
     RowBox[{"Momentum", "[", "q", "]"}]}], "]"}]}]}]], "Input",
 CellTags->"MomentumCombine2",
 CellLabel->"In[1166]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"MomentumCombine2",
 CellLabel->"Out[1166]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MomentumCombine2", "[", "%", "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"MomentumCombine2",
 CellLabel->"In[1167]:="],

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"Momentum", "[", 
    RowBox[{
     RowBox[{"3", " ", "p"}], "+", 
     RowBox[{"2", " ", "q"}]}], "]"}]}], "]"}]], "Output",
 CellTags->"MomentumCombine2",
 CellLabel->"Out[1167]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["MomentumExpand", "ObjectName",
 CellTags->"MomentumExpand"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"MomentumExpand"],

Cell["\<\
MomentumExpand[expr] expands Momentum[a+b+ ...] in expr into Momentum[a] + \
Momentum[b] + ... .\
\>", "Text",
 CellTags->"MomentumExpand"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["ExpandScalarProduct",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExpandScalarProduct",
  ButtonNote->"ExpandScalarProduct"],
 ", ",
 ButtonBox["MomentumCombine",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MomentumCombine",
  ButtonNote->"MomentumCombine"],
 "."
}], "Text",
 CellTags->"MomentumExpand"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"MomentumExpand"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MomentumExpand", "[", 
   RowBox[{"Momentum", "[", 
    RowBox[{"p", "+", "q"}], "]"}], "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"MomentumExpand",
 CellLabel->"In[1168]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Momentum", "[", "p", "]"}], "+", 
  RowBox[{"Momentum", "[", "q", "]"}]}]], "Output",
 CellTags->"MomentumExpand",
 CellLabel->"Out[1168]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScalarProduct", "[", 
  RowBox[{
   RowBox[{"p", "+", "q"}], ",", "r"}], "]"}]], "Input",
 CellTags->"MomentumExpand",
 CellLabel->"In[1169]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"(", 
   FormBox[
    RowBox[{"p", "+", "q"}],
    TraditionalForm], ")", "\[CenterDot]", 
   FormBox["r",
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"MomentumExpand",
 CellLabel->"Out[1169]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"MomentumExpand",
 CellLabel->"In[1170]:="],

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", 
    RowBox[{"p", "+", "q"}], "]"}], ",", 
   RowBox[{"Momentum", "[", "r", "]"}]}], "]"}]], "Output",
 CellTags->"MomentumExpand",
 CellLabel->"Out[1170]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MomentumExpand", "[", 
  RowBox[{"ScalarProduct", "[", 
   RowBox[{
    RowBox[{"p", "+", "q"}], ",", "r"}], "]"}], "]"}]], "Input",
 CellTags->"MomentumExpand",
 CellLabel->"In[1171]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"(", 
   TagBox[
    FormBox[
     RowBox[{"p", "+", "q"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ")", ".", "(", 
   TagBox[
    FormBox["r",
     TraditionalForm],
    TraditionalForm,
    Editable->True], ")"}], TraditionalForm]], "Output",
 CellTags->"MomentumExpand",
 CellLabel->"Out[1171]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"MomentumExpand",
 CellLabel->"In[1172]:="],

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Momentum", "[", "p", "]"}], "+", 
    RowBox[{"Momentum", "[", "q", "]"}]}], ",", 
   RowBox[{"Momentum", "[", "r", "]"}]}], "]"}]], "Output",
 CellTags->"MomentumExpand",
 CellLabel->"Out[1172]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MomentumExpand", "[", 
  RowBox[{"ScalarProduct", "[", 
   RowBox[{
    RowBox[{"p", "+", "q"}], ",", 
    RowBox[{"r", "-", "p"}]}], "]"}], "]"}]], "Input",
 CellTags->"MomentumExpand",
 CellLabel->"In[1173]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"(", 
   TagBox[
    FormBox[
     RowBox[{"p", "+", "q"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ")", ".", "(", 
   TagBox[
    FormBox[
     RowBox[{"r", "-", "p"}],
     TraditionalForm],
    TraditionalForm,
    Editable->True], ")"}], TraditionalForm]], "Output",
 CellTags->"MomentumExpand",
 CellLabel->"Out[1173]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"MomentumExpand",
 CellLabel->"In[1174]:="],

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Momentum", "[", "p", "]"}], "+", 
    RowBox[{"Momentum", "[", "q", "]"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Momentum", "[", "p", "]"}]}], "+", 
    RowBox[{"Momentum", "[", "r", "]"}]}]}], "]"}]], "Output",
 CellTags->"MomentumExpand",
 CellLabel->"Out[1174]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", "%", "]"}]], "Input",
 CellTags->"MomentumExpand",
 CellLabel->"In[1175]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]}], "+", 
   RowBox[{
    FormBox["p",
     TraditionalForm], "\[CenterDot]", 
    FormBox["r",
     TraditionalForm]}], "-", 
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], "2"], "+", 
   RowBox[{
    FormBox["q",
     TraditionalForm], "\[CenterDot]", 
    FormBox["r",
     TraditionalForm]}]}], TraditionalForm]], "Output",
 CellTags->"MomentumExpand",
 CellLabel->"Out[1175]="]
}, Open  ]]
}, Open  ]],

Cell["MT", "ObjectName",
 CellTags->"MT"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"MT"],

Cell[TextData[{
 "MT[",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Mu]", ",", " ", "\[Nu]"}], TraditionalForm]]],
 "] is the metric tensor in 4 dimensions."
}], "Text",
 CellTags->"MT"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynCalcExternal",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalcExternal",
  ButtonNote->"FeynCalcExternal"],
 ", ",
 ButtonBox["FCE",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCE",
  ButtonNote->"FCE"],
 ", ",
 ButtonBox["FCI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCI",
  ButtonNote->"FCI"],
 ", ",
 ButtonBox["MetricTensor",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MetricTensor",
  ButtonNote->"MetricTensor"],
 ", ",
 ButtonBox["MTD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MTD",
  ButtonNote->"MTD"],
 "."
}], "Text",
 CellTags->"MT"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"MT"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MT", "[", 
  RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]], "Input",
 CellTags->"MT",
 CellLabel->"In[1176]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["g", 
   RowBox[{"\[Alpha]", "\[Beta]"}]], TraditionalForm]], "Output",
 CellTags->"MT",
 CellLabel->"Out[1176]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", 
  RowBox[{
   RowBox[{"MT", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], " ", 
   RowBox[{"MT", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}], "]"}]], "Input",
 CellTags->"MT",
 CellLabel->"In[1177]:="],

Cell[BoxData[
 FormBox["4", TraditionalForm]], "Output",
 CellTags->"MT",
 CellLabel->"Out[1177]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MT", "[", 
   RowBox[{"a", ",", "b"}], "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"MT",
 CellLabel->"In[1178]:="],

Cell[BoxData[
 RowBox[{"MT", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Output",
 CellTags->"MT",
 CellLabel->"Out[1178]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FCI", "[", 
   RowBox[{"MT", "[", 
    RowBox[{"a", ",", "b"}], "]"}], "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"MT",
 CellLabel->"In[1179]:="],

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", "a", "]"}], ",", 
   RowBox[{"LorentzIndex", "[", "b", "]"}]}], "]"}]], "Output",
 CellTags->"MT",
 CellLabel->"Out[1179]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FCE", "[", 
   RowBox[{"FCI", "[", 
    RowBox[{"MT", "[", 
     RowBox[{"a", ",", "b"}], "]"}], "]"}], "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"MT",
 CellLabel->"In[1180]:="],

Cell[BoxData[
 RowBox[{"MT", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Output",
 CellTags->"MT",
 CellLabel->"Out[1180]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["MTD", "ObjectName",
 CellTags->"MTD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"MTD"],

Cell[TextData[{
 "MTD[",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Mu]", ",", " ", "\[Nu]"}], TraditionalForm]]],
 "] is the metric tensor in D dimensions."
}], "Text",
 CellTags->"MTD"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynCalcExternal",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalcExternal",
  ButtonNote->"FeynCalcExternal"],
 ", ",
 ButtonBox["FCE",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCE",
  ButtonNote->"FCE"],
 ", ",
 ButtonBox["FCI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCI",
  ButtonNote->"FCI"],
 ", ",
 ButtonBox["MetricTensor",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MetricTensor",
  ButtonNote->"MetricTensor"],
 ", ",
 ButtonBox["MT",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MT",
  ButtonNote->"MT"],
 "."
}], "Text",
 CellTags->"MTD"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"MTD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MTD", "[", 
  RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]], "Input",
 CellTags->"MTD",
 CellLabel->"In[1181]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["g", 
   RowBox[{"\[Alpha]", "\[Beta]"}]], TraditionalForm]], "Output",
 CellTags->"MTD",
 CellLabel->"Out[1181]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", 
  RowBox[{
   RowBox[{"MTD", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], " ", 
   RowBox[{"MTD", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}], "]"}]], "Input",
 CellTags->"MTD",
 CellLabel->"In[1182]:="],

Cell[BoxData[
 FormBox["D", TraditionalForm]], "Output",
 CellTags->"MTD",
 CellLabel->"Out[1182]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MTD", "[", 
   RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"MTD",
 CellLabel->"In[1183]:="],

Cell[BoxData[
 RowBox[{"MTD", "[", 
  RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]], "Output",
 CellTags->"MTD",
 CellLabel->"Out[1183]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FCI", "[", 
   RowBox[{"MTD", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"MTD",
 CellLabel->"In[1184]:="],

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Alpha]", ",", "D"}], "]"}], ",", 
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Beta]", ",", "D"}], "]"}]}], "]"}]], "Output",
 CellTags->"MTD",
 CellLabel->"Out[1184]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FCE", "[", 
   RowBox[{"FCI", "[", 
    RowBox[{"MTD", "[", 
     RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "]"}], "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"MTD",
 CellLabel->"In[1185]:="],

Cell[BoxData[
 RowBox[{"MTD", "[", 
  RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]], "Output",
 CellTags->"MTD",
 CellLabel->"Out[1185]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["NegativeInteger", "ObjectName",
 CellTags->"NegativeInteger"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"NegativeInteger"],

Cell["\<\
NegativeInteger is a data type. E.g. DataType[n, NegativeInteger] can be set \
to True.\
\>", "Text",
 CellTags->"NegativeInteger"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DataType",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DataType",
  ButtonNote->"DataType"],
 "."
}], "Text",
 CellTags->"NegativeInteger"]
}, Open  ]],

Cell["Nf", "ObjectName",
 CellTags->"Nf"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Nf"],

Cell["Nf denotes the number of flavors.", "Text",
 CellTags->"Nf"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Amplitude",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Amplitude",
  ButtonNote->"Amplitude"],
 ", ",
 ButtonBox["CounterTerm",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CounterTerm",
  ButtonNote->"CounterTerm"],
 ", ",
 ButtonBox["Convolute",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Convolute",
  ButtonNote->"Convolute"],
 ", ",
 ButtonBox["AnomalousDimension",
  BaseStyle->"AddOnsLink",
  ButtonData:>"AnomalousDimension",
  ButtonNote->"AnomalousDimension"],
 ", ",
 ButtonBox["SplittingFunction",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SplittingFunction",
  ButtonNote->"SplittingFunction"],
 "."
}], "Text",
 CellTags->"Nf"]
}, Open  ]],

Cell["Nielsen", "ObjectName",
 CellTags->"Nielsen"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Nielsen"],

Cell["Nielsen[i,j, x] denotes Nielsen's polylogarithm.", "Text",
 CellTags->"Nielsen"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Nielsen", "]"}]], "Input",
 CellTags->"Nielsen",
 CellLabel->"In[1186]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"PolyLog", "\[Rule]", "False"}], "}"}], TraditionalForm]], "Output",\

 CellTags->"Nielsen",
 CellLabel->"Out[1186]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["SimplifyPolyLog",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SimplifyPolyLog",
  ButtonNote->"SimplifyPolyLog"],
 "."
}], "Text",
 CellTags->"Nielsen"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Nielsen"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Nielsen", "[", 
  RowBox[{"1", ",", "2", ",", "x"}], "]"}]], "Input",
 CellTags->"Nielsen",
 CellLabel->"In[1187]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["S", 
    RowBox[{
     FormBox["1",
      TraditionalForm], 
     FormBox["2",
      TraditionalForm]}]], "(", "x", ")"}], TraditionalForm]], "Output",
 CellTags->"Nielsen",
 CellLabel->"Out[1187]="]
}, Open  ]],

Cell["\<\
Numerical evaluation is done via N[Nielsen[n_,p_,x_]] := \
(-1)^(n+p-1)/(n-1)!/p! NIntegrate[Log[1-x t]^p Log[t]^(n-1)/t,{t,0,1}];\
\>", "Text",
 CellTags->"Nielsen"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"Nielsen", "[", 
   RowBox[{"1", ",", "2", ",", ".45"}], "]"}], "]"}]], "Input",
 CellTags->"Nielsen",
 CellLabel->"In[1188]:="],

Cell[BoxData[
 FormBox["0.07287162612104658`", TraditionalForm]], "Output",
 CellTags->"Nielsen",
 CellLabel->"Out[1188]="]
}, Open  ]],

Cell["Some special values are built in.", "Text",
 CellTags->"Nielsen"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Nielsen", "[", 
    RowBox[{"1", ",", "2", ",", "0"}], "]"}], ",", 
   RowBox[{"Nielsen", "[", 
    RowBox[{"1", ",", "2", ",", 
     RowBox[{"-", "1"}]}], "]"}], ",", 
   RowBox[{"Nielsen", "[", 
    RowBox[{"1", ",", "2", ",", 
     RowBox[{"1", "/", "2"}]}], "]"}], ",", 
   RowBox[{"Nielsen", "[", 
    RowBox[{"1", ",", "2", ",", "1"}], "]"}]}], "}"}]], "Input",
 CellTags->"Nielsen",
 CellLabel->"In[1189]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", 
    FractionBox[
     TemplateBox[{"3"},
      "Zeta"], "8"], ",", 
    FractionBox[
     TemplateBox[{"3"},
      "Zeta"], "8"], ",", 
    TemplateBox[{"3"},
     "Zeta"]}], "}"}], TraditionalForm]], "Output",
 CellTags->"Nielsen",
 CellLabel->"Out[1189]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Nielsen", "[", 
  RowBox[{"1", ",", "2", ",", "x", ",", 
   RowBox[{"PolyLog", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"Nielsen",
 CellLabel->"In[1190]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    TemplateBox[{"3",RowBox[{"1", "-", "x"}]},
     "PolyLog"]}], "+", 
   RowBox[{
    TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
     "PolyLog"], " ", 
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"log", "(", "x", ")"}], " ", 
    RowBox[{
     SuperscriptBox["log", "2"], "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "+", 
   TemplateBox[{"3"},
    "Zeta"]}], TraditionalForm]], "Output",
 CellTags->"Nielsen",
 CellLabel->"Out[1190]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Nielsen", "[", 
  RowBox[{"1", ",", "3", ",", "x", ",", 
   RowBox[{"PolyLog", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"Nielsen",
 CellLabel->"In[1191]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    TemplateBox[{"4",RowBox[{"1", "-", "x"}]},
     "PolyLog"]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
     "PolyLog"], " ", 
    RowBox[{
     SuperscriptBox["log", "2"], "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "+", 
   RowBox[{
    TemplateBox[{"3",RowBox[{"1", "-", "x"}]},
     "PolyLog"], " ", 
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"log", "(", "x", ")"}], " ", 
    RowBox[{
     SuperscriptBox["log", "3"], "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "+", 
   FractionBox[
    SuperscriptBox["\[Pi]", "4"], "90"]}], TraditionalForm]], "Output",
 CellTags->"Nielsen",
 CellLabel->"Out[1191]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Nielsen", "[", 
  RowBox[{"3", ",", "1", ",", "x", ",", 
   RowBox[{"PolyLog", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"Nielsen",
 CellLabel->"In[1192]:="],

Cell[BoxData[
 FormBox[
  TemplateBox[{"4","x"},
   "PolyLog"], TraditionalForm]], "Output",
 CellTags->"Nielsen",
 CellLabel->"Out[1192]="]
}, Open  ]]
}, Open  ]],

Cell["NonCommFreeQ", "ObjectName",
 CellTags->"NonCommFreeQ"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"NonCommFreeQ"],

Cell["\<\
NonCommFreeQ[exp] yields True if exp contains no non-commutative objects \
(i.e. those objects which are listed in $NonComm) or only non-commutative \
objects inside DiracTrace's or SUNTrace's.\
\>", "Text",
 CellTags->"NonCommFreeQ"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["$NonComm",
  BaseStyle->"AddOnsLink",
  ButtonData:>"$NonComm",
  ButtonNote->"$NonComm"],
 ", ",
 ButtonBox["NonCommQ",
  BaseStyle->"AddOnsLink",
  ButtonData:>"NonCommQ",
  ButtonNote->"NonCommQ"],
 ", ",
 ButtonBox["DiracTrace",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrace",
  ButtonNote->"DiracTrace"],
 ", ",
 ButtonBox["SUNTrace",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNTrace",
  ButtonNote->"SUNTrace"],
 "."
}], "Text",
 CellTags->"NonCommFreeQ"]
}, Open  ]],

Cell["NonCommQ", "ObjectName",
 CellTags->"NonCommQ"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"NonCommQ"],

Cell["\<\
NonCommQ[exp] yields True if exp contains non-commutative objects (i.e. those \
objects which are listed in $NonComm) not inside DiracTrace's or SUNTrace's.\
\>", "Text",
 CellTags->"NonCommQ"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["$NonComm",
  BaseStyle->"AddOnsLink",
  ButtonData:>"$NonComm",
  ButtonNote->"$NonComm"],
 ", ",
 ButtonBox["NonCommFreeQ",
  BaseStyle->"AddOnsLink",
  ButtonData:>"NonCommFreeQ",
  ButtonNote->"NonCommFreeQ"],
 ", ",
 ButtonBox["DiracTrace",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrace",
  ButtonNote->"DiracTrace"],
 ", ",
 ButtonBox["SUNTrace",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNTrace",
  ButtonNote->"SUNTrace"],
 "."
}], "Text",
 CellTags->"NonCommQ"]
}, Open  ]],

Cell["NonCommutative", "ObjectName",
 CellTags->"NonCommutative"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"NonCommutative"],

Cell["\<\
NonCommutative is a data type which may be used, e.g.,  as: DataType[x, \
NonCommutative] = True.\
\>", "Text",
 CellTags->"NonCommutative"],

Cell[TextData[{
 "See also:",
 " ",
 ButtonBox["DataType",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DataType",
  ButtonNote->"DataType"],
 ", ",
 ButtonBox["DeclareNonCommutative",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DeclareNonCommutative",
  ButtonNote->"DeclareNonCommutative"],
 "."
}], "Text",
 CellTags->"NonCommutative"]
}, Open  ]],

Cell["NTerms", "ObjectName",
 CellTags->"NTerms"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"NTerms"],

Cell["\<\
NTerms[x] is equivalent to Length if x is a sum; otherwise NTerms[x] returns \
1, except NTerms[0] \[Rule] 0.\
\>", "Text",
 CellTags->"NTerms"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"NTerms"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NTerms", "[", 
  RowBox[{"a", "-", "b"}], "]"}]], "Input",
 CellTags->"NTerms",
 CellLabel->"In[1193]:="],

Cell[BoxData[
 FormBox["2", TraditionalForm]], "Output",
 CellTags->"NTerms",
 CellLabel->"Out[1193]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NTerms", "[", 
  RowBox[{"a", " ", "b", " ", "c"}], "]"}]], "Input",
 CellTags->"NTerms",
 CellLabel->"In[1194]:="],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellTags->"NTerms",
 CellLabel->"Out[1194]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NTerms", "[", "9", "]"}]], "Input",
 CellTags->"NTerms",
 CellLabel->"In[1195]:="],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellTags->"NTerms",
 CellLabel->"Out[1195]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NTerms", "[", "0", "]"}]], "Input",
 CellTags->"NTerms",
 CellLabel->"In[1196]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"NTerms",
 CellLabel->"Out[1196]="]
}, Open  ]]
}, Open  ]],

Cell["NumberOfMetricTensors", "ObjectName",
 CellTags->"NumberOfMetricTensors"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"NumberOfMetricTensors"],

Cell["NumberOfMetricTensors is an option of Tdec.", "Text",
 CellTags->"NumberOfMetricTensors"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Tdec",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Tdec",
  ButtonNote->"Tdec"],
 "."
}], "Text",
 CellTags->"NonCommQ"]
}, Open  ]],

Cell["NumericalFactor", "ObjectName",
 CellTags->"NumericalFactor"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"NumericalFactor"],

Cell["\<\
NumericalFactor[expr] gives the overall numerical factor of expr.\
\>", "Text",
 CellTags->"NumericalFactor"]
}, Open  ]],

Cell["NumericQ1", "ObjectName",
 CellTags->"NumericQ1"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"NumericQ1"],

Cell["\<\
NumericQ1[x,{a,b,..}] is like NumericQ, but assumes that {a,b,..} are numeric \
quantities.\
\>", "Text",
 CellTags->"NumericQ1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"NumericQ1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NumericQ", "[", 
  RowBox[{
   RowBox[{"3", " ", "a"}], "+", 
   RowBox[{"Log", "[", "b", "]"}], "+", 
   SuperscriptBox["c", "2"]}], "]"}]], "Input",
 CellTags->"NumericQ1",
 CellLabel->"In[1197]:="],

Cell[BoxData[
 FormBox["False", TraditionalForm]], "Output",
 CellTags->"NumericQ1",
 CellLabel->"Out[1197]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NumericQ1", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"3", " ", "a"}], "+", 
    RowBox[{"Log", "[", "b", "]"}], "+", 
    SuperscriptBox["c", "2"]}], ",", 
   RowBox[{"{", "}"}]}], "]"}]], "Input",
 CellTags->"NumericQ1",
 CellLabel->"In[1198]:="],

Cell[BoxData[
 FormBox["False", TraditionalForm]], "Output",
 CellTags->"NumericQ1",
 CellLabel->"Out[1198]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NumericQ1", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"3", " ", "a"}], "+", 
    RowBox[{"Log", "[", "b", "]"}], "+", 
    SuperscriptBox["c", "2"]}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]], "Input",
 CellTags->"NumericQ1",
 CellLabel->"In[1199]:="],

Cell[BoxData[
 FormBox["True", TraditionalForm]], "Output",
 CellTags->"NumericQ1",
 CellLabel->"Out[1199]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["OneLoop  ***unfinished***", "ObjectName",
 CellTags->"OneLoop"],

Cell[TextData[{
 "See also the old FeynCalc documentation at ",
 ButtonBox["http://www.mertig.com/oldfc/",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.mertig.com/oldfc/"], None}],
 ". NOTICE: While OneLoop is restricted to 't Hooft Feynman gauge the \
function ",
 ButtonBox["OneLoopSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoopSimplify",
  ButtonNote->"OneLoopSimplify"],
 " does not have this restriction (but is usually slower). OneLoop handles \
selfenergies, vertex and box-graphs (those only up to 3rd rank tensor in the \
integration variable)."
}], "Text",
 CellTags->"OneLoop"],

Cell[TextData[{
 "WARNING: If you encounter anomalies: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
    "The", " ", "default", " ", "setting", " ", "of", " ", "$West", " ", "is",
      " ", "True"}], ",", " ", 
    RowBox[{"i", ".", "e", "."}], ",", " ", 
    RowBox[{"the", " ", "way", " ", 
     RowBox[{"tr", "(", 
      RowBox[{
       SuperscriptBox["\[Gamma]", "\[Mu]"], 
       SuperscriptBox["\[Gamma]", "\[Nu]"], 
       SuperscriptBox["\[Gamma]", "\[Rho]"], 
       SuperscriptBox["\[Gamma]", "\[Sigma]"], 
       SuperscriptBox["\[Gamma]", "\[Tau]"], 
       SuperscriptBox["\[Gamma]", "\[Lambda]"], 
       SuperscriptBox["\[Gamma]", "5"]}], ")"}]}]}], TraditionalForm]]],
 " is calculated in D dimensions has changed compared to the old FeynCalc \
version. Please keep in mind that the issue of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Gamma]", "5"], TraditionalForm]]],
 "schemes is inherintly tricky."
}], "Text",
 CellTags->"OneLoop"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"OneLoop"],

Cell[TextData[{
 "OneLoop[",
 "q",
 ", amplitude] calculates the one-loop Feynman diagram amplitude (",
 StyleBox["n",
  FontSlant->"Italic"],
 "-point, where ",
 StyleBox["n",
  FontSlant->"Italic"],
 "\[LessEqual]4 and the highest tensor rank of the integration momenta (after \
cancellation of scalar products) may be 3; unless OneLoopSimplify is used)."
}], "Text",
 CellTags->"OneLoop"],

Cell["\<\
The argument q denotes the integration variable, i.e., the loop momentum. \
OneLoop[name, q, amplitude] has as first argument a name of the amplitude. If \
the second argument has head FeynAmp then OneLoop[q, FeynAmp[name, k, expr]] \
and OneLoop[FeynAmp[name, k, expr]] tranform to OneLoop[name, k, expr].\
\>", "Text",
 CellTags->"OneLoop"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "OneLoop", "]"}]], "Input",
 CellTags->"OneLoop",
 CellLabel->"In[1200]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Apart2", "\[Rule]", "True"}], ",", 
    RowBox[{"CancelQP", "\[Rule]", "True"}], ",", 
    RowBox[{"DenominatorOrder", "\[Rule]", "False"}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"FinalSubstitutions", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"Factoring", "\[Rule]", "False"}], ",", 
    RowBox[{"FormatType", "\[Rule]", "InputForm"}], ",", 
    RowBox[{"InitialSubstitutions", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"IntermediateSubstitutions", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"IsolateNames", "\[Rule]", "False"}], ",", 
    RowBox[{"Mandelstam", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"OneLoopSimplify", "\[Rule]", "False"}], ",", 
    RowBox[{"Prefactor", "\[Rule]", "1"}], ",", 
    RowBox[{"ReduceGamma", "\[Rule]", "False"}], ",", 
    RowBox[{"ReduceToScalars", "\[Rule]", "False"}], ",", 
    RowBox[{"SmallVariables", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"WriteOut", "\[Rule]", "False"}], ",", 
    RowBox[{"WriteOutPaVe", "\[Rule]", "False"}], ",", 
    RowBox[{"Sum", "\[Rule]", "True"}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"OneLoop",
 CellLabel->"Out[1200]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["B0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"B0",
  ButtonNote->"B0"],
 ", ",
 ButtonBox["C0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"C0",
  ButtonNote->"C0"],
 ", ",
 ButtonBox["D0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"D0",
  ButtonNote->"D0"],
 ", ",
 ButtonBox["OneLoopSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoopSimplify",
  ButtonNote->"OneLoopSimplify"],
 ", ",
 ButtonBox["TID",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TID",
  ButtonNote->"TID"],
 ", ",
 ButtonBox["TIDL",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TIDL",
  ButtonNote->"TIDL"],
 ", ",
 ButtonBox["$LimitTo4",
  BaseStyle->"AddOnsLink",
  ButtonData:>"$LimitTo4",
  ButtonNote->"$LimitTo4"],
 "."
}], "Text",
 CellTags->"OneLoop"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"OneLoop"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", "I"}], "/", 
    RowBox[{"Pi", "^", "2"}]}], " ", 
   RowBox[{"FAD", "[", 
    RowBox[{"{", 
     RowBox[{"q", ",", "m"}], "}"}], "]"}]}], "//", "FCI"}]], "Input",
 CellTags->"OneLoop",
 CellLabel->"In[1201]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox["\[ImaginaryI]", 
    RowBox[{
     SuperscriptBox["\[Pi]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q", "2"], "-", 
       SuperscriptBox["m", "2"]}], ")"}]}]]}], TraditionalForm]], "Output",
 CellTags->"OneLoop",
 CellLabel->"Out[1201]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OneLoop", "[", 
  RowBox[{"q", ",", "%"}], "]"}]], "Input",
 CellTags->"OneLoop",
 CellLabel->"In[1202]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    SubscriptBox["\<\"A\"\>", "\<\"0\"\>"],
    TraditionalForm], "(", 
   FormBox[
    SuperscriptBox["m", "2"],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"OneLoop",
 CellLabel->"Out[1202]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"mf", "/:", 
   RowBox[{"MakeBoxes", "[", 
    RowBox[{"mf", ",", "TraditionalForm"}], "]"}], "=", 
   RowBox[{"InterpretationBox", "[", 
    RowBox[{
     RowBox[{"SubscriptBox", "[", 
      RowBox[{"\"\<m\>\"", ",", "\"\<f\>\""}], "]"}], ",", "mf"}], "]"}]}], 
  ";"}]], "Input",
 CellTags->"OneLoop",
 CellLabel->"In[1203]:="],

Cell[TextData[{
 "Remember that FAD[{q,mf},{q-k,mf}] is a fast possibility to enter ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "/", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["q", "2"], "-", 
         SuperscriptBox["mf", "2"]}], ")"}], " ", 
       RowBox[{"(", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"q", "-", "k"}], ")"}], "2"], "-", 
         SuperscriptBox["mf", "2"]}], ")"}]}], " ", ")"}], "."}]}], 
   TraditionalForm]]]
}], "Text",
 CellTags->"OneLoop"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{
   RowBox[{"I", " ", 
    FractionBox[
     SuperscriptBox["el", "2"], 
     RowBox[{"16", " ", 
      SuperscriptBox["Pi", "4"], 
      RowBox[{"(", 
       RowBox[{"1", "-", "D"}], ")"}]}]], 
    RowBox[{"FAD", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q", ",", "mf"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"q", "-", "k"}], ",", "mf"}], "}"}]}], "]"}], 
    RowBox[{"DiracTrace", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"mf", "+", 
        RowBox[{"GS", "[", 
         RowBox[{"q", "-", "k"}], "]"}]}], ")"}], ".", 
      RowBox[{"GA", "[", "\[Mu]", "]"}], ".", 
      RowBox[{"(", 
       RowBox[{"mf", "+", 
        RowBox[{"GS", "[", "q", "]"}]}], ")"}], ".", 
      RowBox[{"GA", "[", "\[Mu]", "]"}]}], "]"}]}], " ", "//", " ", 
   "FCI"}]}]], "Input",
 CellTags->"OneLoop",
 CellLabel->"In[1204]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["el", "2"], " ", 
    RowBox[{"tr", "(", 
     FormBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         InterpretationBox[
          SubscriptBox["m", "f"],
          $CellContext`mf], "+", 
         RowBox[{
          FormBox["\<\"\[Gamma]\"\>",
           TraditionalForm], "\[CenterDot]", "(", 
          FormBox[
           RowBox[{"q", "-", "k"}],
           TraditionalForm], ")"}]}], ")"}], ".", 
       SuperscriptBox["\[Gamma]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], ".", 
       RowBox[{"(", 
        RowBox[{
         InterpretationBox[
          SubscriptBox["m", "f"],
          $CellContext`mf], "+", 
         RowBox[{
          FormBox["\<\"\[Gamma]\"\>",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}]}], ")"}], ".", 
       SuperscriptBox["\[Gamma]", 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]]}],
      TraditionalForm], ")"}]}], 
   RowBox[{"16", " ", 
    SuperscriptBox["\[Pi]", "4"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", "D"}], ")"}], " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q", "2"], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         InterpretationBox[
          SubscriptBox["m", "f"],
          $CellContext`mf], ")"}], "2"]}], ")"}], ".", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"q", "-", "k"}], ")"}], "2"], "-", 
       SuperscriptBox[
        RowBox[{"(", 
         InterpretationBox[
          SubscriptBox["m", "f"],
          $CellContext`mf], ")"}], "2"]}], ")"}]}]}]], 
  TraditionalForm]], "Output",
 CellTags->"OneLoop",
 CellLabel->"Out[1204]="]
}, Open  ]],

Cell["\<\
The input to OneLoop may be in 4 dimensions, since the function changes the \
dimension of the objects automatically to the setting of the Dimension option \
(D by default).\
\>", "Text",
 CellTags->"OneLoop"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OneLoop", "[", 
  RowBox[{"q", ",", "t"}], "]"}]], "Input",
 CellTags->"OneLoop",
 CellLabel->"In[1205]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["el", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{
         FractionBox["8", "3"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           InterpretationBox[
            SubscriptBox["m", "f"],
            $CellContext`mf], ")"}], "2"], " ", 
         RowBox[{
          SubscriptBox["B", "0"], "(", 
          SuperscriptBox[
           FormBox["k",
            TraditionalForm], "2"], ",", 
          SuperscriptBox[
           RowBox[{"(", 
            InterpretationBox[
             SubscriptBox["m", "f"],
             $CellContext`mf], ")"}], "2"], ",", 
          SuperscriptBox[
           RowBox[{"(", 
            InterpretationBox[
             SubscriptBox["m", "f"],
             $CellContext`mf], ")"}], "2"], ")"}]}]}], "-", 
       RowBox[{
        FractionBox["4", "3"], " ", 
        SuperscriptBox[
         FormBox["k",
          TraditionalForm], "2"], " ", 
        RowBox[{
         SubscriptBox["B", "0"], "(", 
         SuperscriptBox[
          FormBox["k",
           TraditionalForm], "2"], ",", 
         SuperscriptBox[
          RowBox[{"(", 
           InterpretationBox[
            SubscriptBox["m", "f"],
            $CellContext`mf], ")"}], "2"], ",", 
         SuperscriptBox[
          RowBox[{"(", 
           InterpretationBox[
            SubscriptBox["m", "f"],
            $CellContext`mf], ")"}], "2"], ")"}]}], "+", 
       RowBox[{
        FractionBox["8", "3"], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["\<\"A\"\>", "\<\"0\"\>"],
          TraditionalForm], "(", 
         FormBox[
          SuperscriptBox[
           RowBox[{"(", 
            InterpretationBox[
             SubscriptBox["m", "f"],
             $CellContext`mf], ")"}], "2"],
          TraditionalForm], ")"}]}], "-", 
       FractionBox[
        RowBox[{"8", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           InterpretationBox[
            SubscriptBox["m", "f"],
            $CellContext`mf], ")"}], "2"]}], "3"], "+", 
       FractionBox[
        RowBox[{"4", " ", 
         SuperscriptBox[
          FormBox["k",
           TraditionalForm], "2"]}], "9"]}], ")"}]}], 
    RowBox[{"16", " ", 
     SuperscriptBox["\[Pi]", "2"]}]]}], TraditionalForm]], "Output",
 CellTags->"OneLoop",
 CellLabel->"Out[1205]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", "%", "]"}]], "Input",
 CellTags->"OneLoop",
 CellLabel->"In[1206]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["el", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            InterpretationBox[
             SubscriptBox["m", "f"],
             $CellContext`mf], ")"}], "2"]}], "+", 
         SuperscriptBox[
          FormBox["k",
           TraditionalForm], "2"]}], ")"}], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", 
        SuperscriptBox[
         FormBox["k",
          TraditionalForm], "2"], ",", 
        SuperscriptBox[
         RowBox[{"(", 
          InterpretationBox[
           SubscriptBox["m", "f"],
           $CellContext`mf], ")"}], "2"], ",", 
        SuperscriptBox[
         RowBox[{"(", 
          InterpretationBox[
           SubscriptBox["m", "f"],
           $CellContext`mf], ")"}], "2"], ")"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{
        FormBox[
         SubscriptBox["\<\"A\"\>", "\<\"0\"\>"],
         TraditionalForm], "(", 
        FormBox[
         SuperscriptBox[
          RowBox[{"(", 
           InterpretationBox[
            SubscriptBox["m", "f"],
            $CellContext`mf], ")"}], "2"],
         TraditionalForm], ")"}]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         InterpretationBox[
          SubscriptBox["m", "f"],
          $CellContext`mf], ")"}], "2"]}], "-", 
      SuperscriptBox[
       FormBox["k",
        TraditionalForm], "2"]}], ")"}]}], 
   RowBox[{"36", " ", 
    SuperscriptBox["\[Pi]", "2"]}]], TraditionalForm]], "Output",
 CellTags->"OneLoop",
 CellLabel->"Out[1206]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SP", "[", 
    RowBox[{"k", ",", "r"}], "]"}], " ", 
   RowBox[{"FAD", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"k", ",", "m"}], "}"}], " ", ",", " ", 
     RowBox[{"k", " ", "-", " ", "p"}]}], "]"}]}], "//", "FCI"}]], "Input",
 CellTags->"OneLoop",
 CellLabel->"In[1207]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    FormBox["k",
     TraditionalForm], "\[CenterDot]", 
    FormBox["r",
     TraditionalForm]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "-", 
      SuperscriptBox["m", "2"]}], ")"}], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", "p"}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellTags->"OneLoop",
 CellLabel->"Out[1207]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OneLoop", "[", 
  RowBox[{"k", ",", "%"}], "]"}]], "Input",
 CellTags->"OneLoop",
 CellLabel->"In[1208]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SuperscriptBox["\[Pi]", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["m", "2"], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", "0", ",", 
        SuperscriptBox["m", "2"], ",", 
        SuperscriptBox["m", "2"], ")"}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["m", "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}], " ", 
       RowBox[{
        SubscriptBox["B", "0"], "(", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], ",", "0", ",", 
        SuperscriptBox["m", "2"], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]}]], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["r",
        TraditionalForm]}], " ", 
      RowBox[{
       SubscriptBox["B", "0"], "(", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"], ",", "0", ",", 
       SuperscriptBox["m", "2"], ")"}]}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["m", "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]}]]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"OneLoop",
 CellLabel->"Out[1208]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "t", "]"}]], "Input",
 CellTags->"OneLoop",
 CellLabel->"In[1209]:="]
}, Open  ]],

Cell["OneLoopSimplify", "ObjectName",
 CellTags->"OneLoopSimplify"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"OneLoopSimplify"],

Cell["\<\
OneLoopSimplify[amp, q] simplifies the one-loop amplitude amp. The second \
argument denotes the integration momentum.\
\>", "Text",
 CellTags->"OneLoopSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "OneLoopSimplify", "]"}]], "Input",
 CellTags->"OneLoopSimplify",
 CellLabel->"In[1210]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Collecting", "\[Rule]", "False"}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"DimensionalReduction", "\[Rule]", "False"}], ",", 
    RowBox[{"DiracSimplify", "\[Rule]", "True"}], ",", 
    RowBox[{"FinalSubstitutions", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"IntegralTable", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"OPE1Loop", "\[Rule]", "False"}], ",", 
    RowBox[{"ScalarProductCancel", "\[Rule]", "True"}], ",", 
    RowBox[{"SUNNToCACF", "\[Rule]", "True"}], ",", 
    RowBox[{"SUNTrace", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"OneLoopSimplify",
 CellLabel->"Out[1210]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OneLoop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoop",
  ButtonNote->"OneLoop"],
 ", ",
 ButtonBox["TID",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TID",
  ButtonNote->"TID"],
 ", ",
 ButtonBox["TIDL",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TIDL",
  ButtonNote->"TIDL"],
 "."
}], "Text",
 CellTags->"OneLoopSimplify"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"OneLoopSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SP", "[", 
    RowBox[{"k", ",", "r"}], "]"}], " ", 
   RowBox[{"FAD", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"k", ",", "m"}], "}"}], " ", ",", " ", 
     RowBox[{"k", " ", "-", " ", "p"}]}], "]"}]}], "//", "FCI"}]], "Input",
 CellTags->"OneLoopSimplify",
 CellLabel->"In[1211]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    FormBox["k",
     TraditionalForm], "\[CenterDot]", 
    FormBox["r",
     TraditionalForm]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "-", 
      SuperscriptBox["m", "2"]}], ")"}], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", "p"}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellTags->"OneLoopSimplify",
 CellLabel->"Out[1211]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OneLoopSimplify", "[", 
  RowBox[{"%", ",", "k"}], "]"}]], "Input",
 CellTags->"OneLoopSimplify",
 CellLabel->"In[1212]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["m", "2"], "+", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]}], ")"}], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["r",
       TraditionalForm]}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["k", "2"], "-", 
        SuperscriptBox["m", "2"]}], ")"}], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", "p"}], ")"}], "2"]}]}]], "-", 
   FractionBox[
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["r",
      TraditionalForm]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "-", 
       SuperscriptBox["m", "2"]}], ")"}]}]]}], TraditionalForm]], "Output",
 CellTags->"OneLoopSimplify",
 CellLabel->"Out[1212]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OneLoopSimplify", "[", 
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{"m", "\[Rule]", "0"}]}], ",", "k"}], "]"}]], "Input",
 CellTags->"OneLoopSimplify",
 CellLabel->"In[1213]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    FormBox["p",
     TraditionalForm], "\[CenterDot]", 
    FormBox["r",
     TraditionalForm]}], 
   RowBox[{"2", " ", 
    RowBox[{
     SuperscriptBox["k", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"k", "-", "p"}], ")"}], "2"]}]}]], TraditionalForm]], "Output",\

 CellTags->"OneLoopSimplify",
 CellLabel->"Out[1213]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FAD", "[", 
    RowBox[{"k", ",", "k", ",", " ", 
     RowBox[{"k", " ", "-", " ", 
      SubscriptBox["p", "1"]}], ",", " ", 
     RowBox[{"k", " ", "-", " ", 
      SubscriptBox["p", "2"]}]}], "]"}], " ", 
   RowBox[{"FVD", "[", 
    RowBox[{"k", ",", "\[Mu]"}], "]"}]}], "//", "FCI"}]], "Input",
 CellTags->"OneLoopSimplify",
 CellLabel->"In[1214]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   SuperscriptBox[
    FormBox["k",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], 
   RowBox[{
    SuperscriptBox["k", "2"], ".", 
    SuperscriptBox["k", "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", 
       SubscriptBox["p", "1"]}], ")"}], "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", 
       SubscriptBox["p", "2"]}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellTags->"OneLoopSimplify",
 CellLabel->"Out[1214]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OneLoopSimplify", "[", " ", 
  RowBox[{"%", ",", "k"}], "]"}]], "Input",
 CellTags->"OneLoopSimplify",
 CellLabel->"In[1215]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{
       SubsuperscriptBox["p", "1", "2"], " ", 
       SubsuperscriptBox["p", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SubsuperscriptBox["p", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox[
         SubscriptBox["p", "1"],
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["p", "2"],
         TraditionalForm]}]}]}], 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["k", "2"], ".", 
       SuperscriptBox["k", "2"], ".", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"k", "-", 
          SubscriptBox["p", "1"]}], ")"}], "2"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["p", "1", "2"], " ", 
         SubsuperscriptBox["p", "2", "2"]}], "-", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"]}], ")"}]}]]}], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["p", "1", "2"], " ", 
       SubsuperscriptBox["p", "2", "2"], " ", 
       SubsuperscriptBox["p", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]]}]}], "-", 
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm]}]}], "+", 
     RowBox[{
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm]}]}]}], 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["k", "2"], ".", 
      SuperscriptBox["k", "2"], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SubscriptBox["p", "1"]}], ")"}], "2"], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SubscriptBox["p", "2"]}], ")"}], "2"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}], "-", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox[
           SubscriptBox["p", "1"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["p", "2"],
           TraditionalForm]}],
         TraditionalForm], "2"]}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{
      SubsuperscriptBox["p", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]]}]}], 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["k", "2"], ".", 
      SuperscriptBox["k", "2"], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SubscriptBox["p", "2"]}], ")"}], "2"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox[
           SubscriptBox["p", "1"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["p", "2"],
           TraditionalForm]}],
         TraditionalForm], "2"], "-", 
       RowBox[{
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{
      SubsuperscriptBox["p", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      SubsuperscriptBox["p", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm]}]}]}], 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["k", "2"], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SubscriptBox["p", "1"]}], ")"}], "2"], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SubscriptBox["p", "2"]}], ")"}], "2"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}], "-", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox[
           SubscriptBox["p", "1"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["p", "2"],
           TraditionalForm]}],
         TraditionalForm], "2"]}], ")"}]}]]}], TraditionalForm]], "Output",
 CellTags->"OneLoopSimplify",
 CellLabel->"Out[1215]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FCE", "[", "%", "]"}], "/.", 
   RowBox[{
    RowBox[{"SPD", "[", 
     SubscriptBox["p", "1"], "]"}], "\[Rule]", "0"}]}], "//", 
  "FCI"}]], "Input",
 CellTags->"OneLoopSimplify",
 CellLabel->"In[1216]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SubsuperscriptBox["p", "2", "2"], " ", 
     SubsuperscriptBox["p", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["k", "2"], ".", 
      SuperscriptBox["k", "2"], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SubscriptBox["p", "1"]}], ")"}], "2"], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SubscriptBox["p", "2"]}], ")"}], "2"]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["p", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["p", "2"],
       TraditionalForm]}]}]], "-", 
   FractionBox[
    SubsuperscriptBox["p", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["k", "2"], ".", 
      SuperscriptBox["k", "2"], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SubscriptBox["p", "1"]}], ")"}], "2"]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["p", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["p", "2"],
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{
      SubsuperscriptBox["p", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]]}]}], 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["k", "2"], ".", 
      SuperscriptBox["k", "2"], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SubscriptBox["p", "2"]}], ")"}], "2"]}], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox[
         SubscriptBox["p", "1"],
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["p", "2"],
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{
      SubsuperscriptBox["p", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      SubsuperscriptBox["p", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm]}]}]}], 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["k", "2"], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SubscriptBox["p", "1"]}], ")"}], "2"], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"k", "-", 
         SubscriptBox["p", "2"]}], ")"}], "2"]}], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox[
         SubscriptBox["p", "1"],
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["p", "2"],
         TraditionalForm]}],
       TraditionalForm], "2"]}]]}], TraditionalForm]], "Output",
 CellTags->"OneLoopSimplify",
 CellLabel->"Out[1216]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OneLoopSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"FAD", "[", 
     RowBox[{
      RowBox[{"k", "-", 
       SubscriptBox["p", "1"]}], ",", 
      RowBox[{"k", "-", 
       SubscriptBox["p", "2"]}]}], "]"}], " ", 
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"k", ",", "l"}], "]"}], "^", "2"}]}], ",", "k"}], 
  "]"}]], "Input",
 CellTags->"OneLoopSimplify",
 CellLabel->"In[1217]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"D", " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["l",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["p", "1"],
         TraditionalForm]}],
       TraditionalForm], "2"]}], "+", 
    RowBox[{"2", " ", "D", " ", 
     RowBox[{
      FormBox["l",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["p", "2"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox["l",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["p", "1"],
       TraditionalForm]}]}], "+", 
    RowBox[{"D", " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["l",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["p", "2"],
         TraditionalForm]}],
       TraditionalForm], "2"]}], "-", 
    RowBox[{
     SuperscriptBox[
      FormBox["l",
       TraditionalForm], "2"], " ", 
     SubsuperscriptBox["p", "1", "2"]}], "-", 
    RowBox[{
     SuperscriptBox[
      FormBox["l",
       TraditionalForm], "2"], " ", 
     SubsuperscriptBox["p", "2", "2"]}], "-", 
    RowBox[{"4", " ", 
     RowBox[{
      FormBox["l",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["p", "2"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox["l",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["p", "1"],
       TraditionalForm]}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["l",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["p", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["p", "2"],
       TraditionalForm]}]}]}], 
   RowBox[{"4", " ", 
    RowBox[{"(", 
     RowBox[{"D", "-", "1"}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["k", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"k", "-", 
        SubscriptBox["p", "1"], "+", 
        SubscriptBox["p", "2"]}], ")"}], "2"]}]}]], 
  TraditionalForm]], "Output",
 CellTags->"OneLoopSimplify",
 CellLabel->"Out[1217]="]
}, Open  ]]
}, Open  ]],

Cell["OneLoopSum", "ObjectName",
 CellTags->"OneLoopSum"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"OneLoopSum"],

Cell["\<\
OneLoopSum[ FeynAmp[ ... ], FeynAmp[ ... ] , ...] will calculate a list of \
Feynman amplitudes by replacing FeynAmp step by step by OneLoop.\
\>", "Text",
 CellTags->"OneLoopSum"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OneLoop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoop",
  ButtonNote->"OneLoop"],
 "."
}], "Text",
 CellTags->"OneLoopSum"]
}, Open  ]],

Cell["OPE", "ObjectName",
 CellTags->"OPE"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"OPE"],

Cell["\<\
OPE is a convenience variable to separate OPE insertions.
OPE is also an option of several input functions like GluonPropagator.\
\>", "Text",
 CellTags->"OPE"],

Cell["\<\
The OPE variable has the property to vanish for higher powers:\
\>", "Text"],

Cell[CellGroupData[{

Cell["{OPE,OPE^2,OPE^3}", "Input",
 CellLabel->"In[1218]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"\[CapitalOmega]", ",", "0", ",", "0"}], "}"}], 
  TraditionalForm]], "Output",
 CellLabel->"Out[1218]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OPE1Loop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OPE1Loop",
  ButtonNote->"OPE1Loop"],
 "."
}], "Text",
 CellTags->"OPE"]
}, Open  ]],

Cell["OPEDelta", "ObjectName",
 CellTags->"OPEDelta"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"OPEDelta"],

Cell["\<\
OPEDelta is a lightlike axial vector as used e.g. in the operator product \
expansion in QCD.\
\>", "Text",
 CellTags->"OPEDelta"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Twist2QuarkOperator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Twist2QuarkOperator",
  ButtonNote->"Twist2QuarkOperator"],
 "."
}], "Text",
 CellTags->"OPEDelta"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"OPEDelta"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FourVector", "[", 
  RowBox[{"OPEDelta", ",", "\[Mu]"}], "]"}]], "Input",
 CellTags->"OPEDelta",
 CellLabel->"In[1219]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox[
   FormBox["\[CapitalDelta]",
    TraditionalForm], "\[Mu]"], TraditionalForm]], "Output",
 CellTags->"OPEDelta",
 CellLabel->"Out[1219]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", 
  RowBox[{"%", " ", "%"}], "]"}]], "Input",
 CellTags->"OPEDelta",
 CellLabel->"In[1220]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"OPEDelta",
 CellLabel->"Out[1220]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SP", "[", 
  RowBox[{"OPEDelta", ",", "OPEDelta"}], "]"}]], "Input",
 CellTags->"OPEDelta",
 CellLabel->"In[1221]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"OPEDelta",
 CellLabel->"Out[1221]="]
}, Open  ]]
}, Open  ]],

Cell["OPEi, OPEj, OPEk, OPEl, OPEm, OPEn, OPEo", "ObjectName",
 CellTags->"OPEi"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"OPEi"],

Cell["\<\
OPEi, etc. are variables with DataType PositiveInteger which are used in \
functions relating to the operator product expansion.\
\>", "Text",
 CellTags->"OPEi"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"OPEi"],

Cell[CellGroupData[{

Cell[BoxData["OPEi"], "Input",
 CellTags->"OPEi",
 CellLabel->"In[1222]:="],

Cell[BoxData[
 FormBox["i", TraditionalForm]], "Output",
 CellTags->"OPEi",
 CellLabel->"Out[1222]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DataType", "[", 
  RowBox[{
  "OPEi", ",", " ", "OPEj", ",", "OPEk", ",", "OPEl", ",", " ", "OPEm", ",", 
   " ", "OPEn", ",", " ", "OPEo", ",", " ", "PositiveInteger"}], 
  "]"}]], "Input",
 CellTags->"OPEi",
 CellLabel->"In[1223]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
    ",", "True"}], "}"}], TraditionalForm]], "Output",
 CellTags->"OPEi",
 CellLabel->"Out[1223]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PowerSimplify", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "^", 
     RowBox[{"(", 
      RowBox[{"2", "OPEi"}], ")"}]}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "^", 
     RowBox[{"(", 
      RowBox[{"2", "OPEj"}], ")"}]}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "^", 
     RowBox[{"(", 
      RowBox[{"2", "OPEk"}], ")"}]}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "^", 
     RowBox[{"(", 
      RowBox[{"2", "OPEl"}], ")"}]}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "^", 
     RowBox[{"(", 
      RowBox[{"2", "OPEm"}], ")"}]}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "^", 
     RowBox[{"(", 
      RowBox[{"2", "OPEn"}], ")"}]}], ",", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "^", 
     RowBox[{"(", 
      RowBox[{"2", "OPEo"}], ")"}]}]}], "}"}], "]"}]], "Input",
 CellTags->"OPEi",
 CellLabel->"In[1224]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1"}], 
   "}"}], TraditionalForm]], "Output",
 CellTags->"OPEi",
 CellLabel->"Out[1224]="]
}, Open  ]],

Cell["Re has been changed:", "Text",
 CellTags->"OPEi"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Re", "[", "OPEi", "]"}], ">", 
    RowBox[{"-", "3"}]}], ",", " ", 
   RowBox[{
    RowBox[{"Re", "[", "OPEi", "]"}], ">", 
    RowBox[{"-", "2"}]}], ",", " ", 
   RowBox[{
    RowBox[{"Re", "[", "OPEi", "]"}], ">", 
    RowBox[{"-", "1"}]}], ",", "   ", 
   RowBox[{
    RowBox[{"Re", "[", "OPEi", "]"}], ">", "0"}], ",", " ", 
   RowBox[{
    RowBox[{"Re", "[", "OPEi", "]"}], ">", "1"}]}], "}"}]], "Input",
 CellTags->"OPEi",
 CellLabel->"In[1225]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Re", "(", "i", ")"}], ">", 
     RowBox[{"-", "3"}]}], ",", 
    RowBox[{
     RowBox[{"Re", "(", "i", ")"}], ">", 
     RowBox[{"-", "2"}]}], ",", 
    RowBox[{
     RowBox[{"Re", "(", "i", ")"}], ">", 
     RowBox[{"-", "1"}]}], ",", 
    RowBox[{
     RowBox[{"Re", "(", "i", ")"}], ">", "0"}], ",", 
    RowBox[{
     RowBox[{"Re", "(", "i", ")"}], ">", "1"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"OPEi",
 CellLabel->"Out[1225]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{
      RowBox[{"-", "OPEi"}], " ", "+", " ", "OPEm"}], "]"}], " ", ">", " ", 
    "0"}], ",", " ", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{
      RowBox[{"-", "OPEi"}], " ", "+", " ", "OPEm"}], "]"}], " ", ">", " ", 
    "1"}], ",", 
   RowBox[{
    RowBox[{"Re", "[", 
     RowBox[{
      RowBox[{"-", "OPEi"}], " ", "+", " ", "OPEm"}], "]"}], " ", ">", " ", 
    "2"}]}], "}"}]], "Input",
 CellTags->"OPEi",
 CellLabel->"In[1226]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Re", "(", 
      RowBox[{"m", "-", "i"}], ")"}], ">", "0"}], ",", 
    RowBox[{
     RowBox[{"Re", "(", 
      RowBox[{"m", "-", "i"}], ")"}], ">", "1"}], ",", 
    RowBox[{
     RowBox[{"Re", "(", 
      RowBox[{"m", "-", "i"}], ")"}], ">", "2"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"OPEi",
 CellLabel->"Out[1226]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Re", "[", "OPEm", "]"}], ">", 
    RowBox[{"-", "3"}]}], ",", " ", 
   RowBox[{
    RowBox[{"Re", "[", "OPEm", "]"}], ">", 
    RowBox[{"-", "2"}]}], ",", " ", 
   RowBox[{
    RowBox[{"Re", "[", "OPEm", "]"}], ">", 
    RowBox[{"-", "1"}]}], ",", "   ", 
   RowBox[{
    RowBox[{"Re", "[", "OPEm", "]"}], ">", "0"}], ",", " ", 
   RowBox[{
    RowBox[{"Re", "[", "OPEm", "]"}], ">", "1"}]}], "}"}]], "Input",
 CellTags->"OPEi",
 CellLabel->"In[1227]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Re", "(", "m", ")"}], ">", 
     RowBox[{"-", "3"}]}], ",", 
    RowBox[{
     RowBox[{"Re", "(", "m", ")"}], ">", 
     RowBox[{"-", "2"}]}], ",", 
    RowBox[{
     RowBox[{"Re", "(", "m", ")"}], ">", 
     RowBox[{"-", "1"}]}], ",", 
    RowBox[{
     RowBox[{"Re", "(", "m", ")"}], ">", "0"}], ",", 
    RowBox[{
     RowBox[{"Re", "(", "m", ")"}], ">", "1"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"OPEi",
 CellLabel->"Out[1227]="]
}, Open  ]]
}, Open  ]],

Cell["OPEInsert  ***unfinished***", "ObjectName",
 CellTags->"OPEInsert"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"OPEInsert"],

Cell["\<\
OPEInsert[diagram_String, name_, rhifile_String] or OPEInsert[diagram_String, \
name_]. The setting of the option EpsContract (4 or D) determines whether the \
Levi-Civita tensors are contracted in 4 or D dimensions.\
\>", "Text",
 CellTags->"OPEInsert"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["RHI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RHI",
  ButtonNote->"RHI"],
 "."
}], "Text",
 CellTags->"OPEInsert"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"OPEInsert"],

Cell[BoxData[""], "Input",
 CellTags->"OPEInsert",
 CellLabel->"In[1228]:="]
}, Open  ]],

Cell["OPEInt  ***unfinished***", "ObjectName",
 CellTags->"OPEInt"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"OPEInt"],

Cell["\<\
OPEInt[expr, q, p, x].  The dimension is changed to the one indicated by the \
option  Dimension. The setting of the option EpsContract determines  the \
dimension in which the Levi-Civita tensors are contracted.\
\>", "Text",
 CellTags->"OPEInt"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["RHI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RHI",
  ButtonNote->"RHI"],
 "."
}], "Text",
 CellTags->"OPEInt"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"OPEInt"],

Cell[BoxData[""], "Input",
 CellTags->"OPEInt",
 CellLabel->"In[1229]:="]
}, Open  ]],

Cell["OPEIntDelta  ***unfinished***", "ObjectName",
 CellTags->"OPEIntDelta"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"OPEIntDelta"],

Cell[TextData[{
 "OPEIntDelta[expr, x, m] introduces the delta(1-x) (DeltaFunction[1-x]). The \
",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Integrate function is called and each integration  (from 0 to 1) is \
recorded for reference (and bug-checking) in the global list $MIntegrate. \n\
Notice that the dimension specified by the option should also be the \
dimension used in expr. It is replaced in OPEIntDelta by (4+Epsilon)."
}], "Text",
 CellTags->"OPEIntDelta"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["RHI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RHI",
  ButtonNote->"RHI"],
 "."
}], "Text",
 CellTags->"OPEIntDelta"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"OPEIntDelta"],

Cell[BoxData[""], "Input",
 CellTags->"OPEIntDelta",
 CellLabel->"In[1230]:="]
}, Open  ]],

Cell["OPEIntegrate  ***unfinished***", "ObjectName",
 CellTags->"OPEIntegrate"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"OPEIntegrate"],

Cell["\<\
OPEIntegrate[expr, q, x].  The dimension is changed to the one indicated by \
the option  Dimension. The setting of the option EpsContract determines  the \
dimension in which the Levi-Civita tensors are contracted.\
\>", "Text",
 CellTags->"OPEIntegrate"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["RHI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RHI",
  ButtonNote->"RHI"],
 "."
}], "Text",
 CellTags->"OPEIntegrate"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"OPEIntegrate"],

Cell[BoxData[""], "Input",
 CellTags->"OPEIntegrate",
 CellLabel->"In[1231]:="]
}, Open  ]],

Cell["OPEIntegrateDelta  ***unfinished***", "ObjectName",
 CellTags->"OPEIntegrateDelta"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"OPEIntegrateDelta"],

Cell[TextData[{
 "OPEIntegrateDelta[expr, x, m] introduces the \[Delta](1-x) \
(DeltaFunction[1-x]). The ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Integrate function is called and each integration  (from 0 to 1) is \
recorded for reference (and bug-checking) in the global list $MIntegrate. \n\
Notice that the dimension specified by the option should also be the \
dimension used in expr. It is replaced in OPEIntegrateDelta by (4+Epsilon)."
}], "Text",
 CellTags->"OPEIntegrateDelta"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["RHI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RHI",
  ButtonNote->"RHI"],
 "."
}], "Text",
 CellTags->"OPEIntegrateDelta"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"OPEIntegrateDelta"],

Cell[BoxData[""], "Input",
 CellTags->"OPEIntegrateDelta",
 CellLabel->"In[1232]:="]
}, Open  ]],

Cell["OPESumExplicit", "ObjectName",
 CellTags->"OPESumExplicit"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"OPESumExplicit"],

Cell["OPESumExplicit[exp] calculates OPESum's.", "Text",
 CellTags->"OPESumExplicit"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OPESum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OPESum",
  ButtonNote->"OPESum"],
 ", ",
 ButtonBox["OPESumSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OPESumSimplify",
  ButtonNote->"OPESumSimplify"],
 "."
}], "Text",
 CellTags->"OPESumExplicit"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"OPESumExplicit"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{"OPESum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"A", "^", "i"}], 
     RowBox[{"B", "^", 
      RowBox[{"(", 
       RowBox[{"m", "-", "i", "-", "3"}], ")"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "0", ",", 
      RowBox[{"m", "-", "3"}]}], "}"}]}], "]"}]}]], "Input",
 CellTags->"OPESumExplicit",
 CellLabel->"In[1233]:="],

Cell[BoxData[
 FormBox[
  TagBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "0"}], 
     RowBox[{
      RowBox[{"-", "3"}], "+", "m"}]], 
    RowBox[{
     SuperscriptBox["A", "i"], " ", 
     SuperscriptBox["B", 
      RowBox[{
       RowBox[{"-", "3"}], "-", "i", "+", "m"}]]}]}],
   HoldForm], TraditionalForm]], "Output",
 CellTags->"OPESumExplicit",
 CellLabel->"Out[1233]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OPESumExplicit", "[", "t1", "]"}]], "Input",
 CellTags->"OPESumExplicit",
 CellLabel->"In[1234]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    FormBox[
     SuperscriptBox["A", 
      RowBox[{"m", "-", "2"}]],
     TraditionalForm], 
    RowBox[{"A", "-", "B"}]], "-", 
   FractionBox[
    FormBox[
     SuperscriptBox["B", 
      RowBox[{"m", "-", "2"}]],
     TraditionalForm], 
    RowBox[{"A", "-", "B"}]]}], TraditionalForm]], "Output",
 CellTags->"OPESumExplicit",
 CellLabel->"Out[1234]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", " ", "=", " ", 
  RowBox[{"OPESum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "^", "i"}], 
     RowBox[{"b", "^", 
      RowBox[{"(", 
       RowBox[{"j", "-", "i"}], ")"}]}], 
     RowBox[{"c", "^", 
      RowBox[{"(", 
       RowBox[{"m", "-", "j", "-", "4"}], ")"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "0", ",", "j"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", 
      RowBox[{"m", "-", "4"}]}], "}"}]}], "]"}]}]], "Input",
 CellTags->"OPESumExplicit",
 CellLabel->"In[1235]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    TagBox[
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"j", "=", "0"}], 
       RowBox[{
        RowBox[{"-", "4"}], "+", "m"}]], "\<\"\"\>"}],
     HoldForm],
    TraditionalForm], 
   FormBox[
    RowBox[{"\<\"\"\>", " ", 
     RowBox[{"(", 
      RowBox[{"j", "+", "1"}], ")"}]}],
    TraditionalForm], 
   FormBox[
    RowBox[{
     SuperscriptBox["a", "i"], " ", 
     SuperscriptBox["b", 
      RowBox[{"j", "-", "i"}]], " ", 
     SuperscriptBox["c", 
      RowBox[{
       RowBox[{"-", "j"}], "+", "m", "-", "4"}]]}],
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"OPESumExplicit",
 CellLabel->"Out[1235]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OPESumExplicit", "[", "t2", "]"}]], "Input",
 CellTags->"OPESumExplicit",
 CellLabel->"In[1236]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    FormBox[
     SuperscriptBox["a", 
      RowBox[{"m", "-", "2"}]],
     TraditionalForm], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "c"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{"c", " ", 
     FormBox[
      SuperscriptBox["b", 
       RowBox[{"m", "-", "2"}]],
      TraditionalForm]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "c"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"b", "-", "c"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{"a", " ", 
     FormBox[
      SuperscriptBox["b", 
       RowBox[{"m", "-", "2"}]],
      TraditionalForm]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "c"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"b", "-", "c"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{"b", " ", 
     FormBox[
      SuperscriptBox["c", 
       RowBox[{"m", "-", "2"}]],
      TraditionalForm]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "c"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"b", "-", "c"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{"a", " ", 
     FormBox[
      SuperscriptBox["c", 
       RowBox[{"m", "-", "2"}]],
      TraditionalForm]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "c"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"b", "-", "c"}], ")"}]}]]}], TraditionalForm]], "Output",
 CellTags->"OPESumExplicit",
 CellLabel->"Out[1236]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"t1", ",", "t2"}], "]"}], ";"}]], "Input",
 CellTags->"OPESumExplicit",
 CellLabel->"In[1237]:="]
}, Open  ]],

Cell["OPESum", "ObjectName",
 CellTags->"OPESum"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"OPESum"],

Cell["\<\
OPESum[exp, {i, 0, m}] denotes a symbolic sum.The syntax is the same as for \
Sum.\
\>", "Text",
 CellTags->"OPESum"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OPESumExplicit",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OPESumExplicit",
  ButtonNote->"OPESumExplicit"],
 ", ",
 ButtonBox["OPESumSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OPESumSimplify",
  ButtonNote->"OPESumSimplify"],
 "."
}], "Text",
 CellTags->"OPESum"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"OPESum"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{"OPESum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"SO", "[", "p", "]"}], "^", "OPEi"}], 
     RowBox[{
      RowBox[{"SO", "[", "k", "]"}], "^", 
      RowBox[{"(", 
       RowBox[{"OPEm", "-", "OPEi", "-", "3"}], ")"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"OPEi", ",", "0", ",", 
      RowBox[{"OPEm", "-", "3"}]}], "}"}]}], "]"}]}]], "Input",
 CellTags->"OPESum",
 CellLabel->"In[1238]:="],

Cell[BoxData[
 FormBox[
  TagBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "0"}], 
     RowBox[{
      RowBox[{"-", "3"}], "+", "m"}]], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FormBox["\<\"\[CapitalDelta]\"\>",
         TraditionalForm], 
        FormBox["\<\"\[CenterDot]\"\>",
         TraditionalForm], 
        FormBox["k",
         TraditionalForm]}], ")"}], 
      RowBox[{
       RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FormBox["\<\"\[CapitalDelta]\"\>",
         TraditionalForm], 
        FormBox["\<\"\[CenterDot]\"\>",
         TraditionalForm], 
        FormBox["p",
         TraditionalForm]}], ")"}], "i"]}]}],
   HoldForm], TraditionalForm]], "Output",
 CellTags->"OPESum",
 CellLabel->"Out[1238]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OPESumExplicit", "[", "t1", "]"}]], "Input",
 CellTags->"OPESum",
 CellLabel->"In[1239]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    FormBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FormBox["\<\"\[CapitalDelta]\"\>",
         TraditionalForm], 
        FormBox["\<\"\[CenterDot]\"\>",
         TraditionalForm], 
        FormBox["k",
         TraditionalForm]}], ")"}], 
      RowBox[{"m", "-", "2"}]],
     TraditionalForm], 
    RowBox[{
     RowBox[{
      FormBox["\<\"\[CapitalDelta]\"\>",
       TraditionalForm], 
      FormBox["\<\"\[CenterDot]\"\>",
       TraditionalForm], 
      FormBox["k",
       TraditionalForm]}], "-", 
     RowBox[{
      FormBox["\<\"\[CapitalDelta]\"\>",
       TraditionalForm], 
      FormBox["\<\"\[CenterDot]\"\>",
       TraditionalForm], 
      FormBox["p",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    FormBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FormBox["\<\"\[CapitalDelta]\"\>",
         TraditionalForm], 
        FormBox["\<\"\[CenterDot]\"\>",
         TraditionalForm], 
        FormBox["p",
         TraditionalForm]}], ")"}], 
      RowBox[{"m", "-", "2"}]],
     TraditionalForm], 
    RowBox[{
     RowBox[{
      FormBox["\<\"\[CapitalDelta]\"\>",
       TraditionalForm], 
      FormBox["\<\"\[CenterDot]\"\>",
       TraditionalForm], 
      FormBox["k",
       TraditionalForm]}], "-", 
     RowBox[{
      FormBox["\<\"\[CapitalDelta]\"\>",
       TraditionalForm], 
      FormBox["\<\"\[CenterDot]\"\>",
       TraditionalForm], 
      FormBox["p",
       TraditionalForm]}]}]]}], TraditionalForm]], "Output",
 CellTags->"OPESum",
 CellLabel->"Out[1239]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", " ", "=", " ", 
  RowBox[{"OPESum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "^", "i"}], 
     RowBox[{"b", "^", 
      RowBox[{"(", 
       RowBox[{"j", "-", "i"}], ")"}]}], 
     RowBox[{"c", "^", 
      RowBox[{"(", 
       RowBox[{"m", "-", "j", "-", "4"}], ")"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "0", ",", "j"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", 
      RowBox[{"m", "-", "4"}]}], "}"}]}], "]"}]}]], "Input",
 CellTags->"OPESum",
 CellLabel->"In[1240]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    TagBox[
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"j", "=", "0"}], 
       RowBox[{
        RowBox[{"-", "4"}], "+", "m"}]], "\<\"\"\>"}],
     HoldForm],
    TraditionalForm], 
   FormBox[
    RowBox[{"\<\"\"\>", " ", 
     RowBox[{"(", 
      RowBox[{"j", "+", "1"}], ")"}]}],
    TraditionalForm], 
   FormBox[
    RowBox[{
     SuperscriptBox["a", "i"], " ", 
     SuperscriptBox["b", 
      RowBox[{"j", "-", "i"}]], " ", 
     SuperscriptBox["c", 
      RowBox[{
       RowBox[{"-", "j"}], "+", "m", "-", "4"}]]}],
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"OPESum",
 CellLabel->"Out[1240]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OPESumExplicit", "[", "t2", "]"}]], "Input",
 CellTags->"OPESum",
 CellLabel->"In[1241]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    FormBox[
     SuperscriptBox["a", 
      RowBox[{"m", "-", "2"}]],
     TraditionalForm], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "c"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{"c", " ", 
     FormBox[
      SuperscriptBox["b", 
       RowBox[{"m", "-", "2"}]],
      TraditionalForm]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "c"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"b", "-", "c"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{"a", " ", 
     FormBox[
      SuperscriptBox["b", 
       RowBox[{"m", "-", "2"}]],
      TraditionalForm]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "c"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"b", "-", "c"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{"b", " ", 
     FormBox[
      SuperscriptBox["c", 
       RowBox[{"m", "-", "2"}]],
      TraditionalForm]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "c"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"b", "-", "c"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{"a", " ", 
     FormBox[
      SuperscriptBox["c", 
       RowBox[{"m", "-", "2"}]],
      TraditionalForm]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"a", "-", "c"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"b", "-", "c"}], ")"}]}]]}], TraditionalForm]], "Output",
 CellTags->"OPESum",
 CellLabel->"Out[1241]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Clear", "[", 
   RowBox[{"t1", ",", "t2"}], "]"}]}]], "Input",
 CellTags->"OPESum",
 CellLabel->"In[1242]:="]
}, Open  ]],

Cell["OPESumSimplify", "ObjectName",
 CellTags->"OPESumSimplify"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"OPESumSimplify"],

Cell["OPESumSimplify[exp] simplifies OPESum's in exp.", "Text",
 CellTags->"OPESumSimplify"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OPESum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OPESum",
  ButtonNote->"OPESum"],
 ", ",
 ButtonBox["OPESumExplicit",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OPESumExplicit",
  ButtonNote->"OPESumExplicit"],
 "."
}], "Text",
 CellTags->"OPESumSimplify"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"OPESumSimplify"],

Cell[CellGroupData[{

Cell["\<\
OPESum[(-SOD[p])^(OPEi+1) SOD[p-q]^(OPEm-OPEi-2),{OPEi,0,OPEm}]\
\>", "Input",
 CellTags->"OPESumSimplify",
 CellLabel->"In[1243]:="],

Cell[BoxData[
 FormBox[
  TagBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "0"}], "m"], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          FormBox["\<\"\[CapitalDelta]\"\>",
           TraditionalForm], 
          FormBox["\<\"\[CenterDot]\"\>",
           TraditionalForm], 
          FormBox["p",
           TraditionalForm]}], ")"}]}], ")"}], 
      RowBox[{"1", "+", "i"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FormBox["\<\"\[CapitalDelta]\"\>",
         TraditionalForm], 
        FormBox["\<\"\[CenterDot]\"\>",
         TraditionalForm], 
        FormBox["\<\"(\"\>",
         TraditionalForm], 
        FormBox[
         RowBox[{"p", "-", "q"}],
         TraditionalForm], 
        FormBox["\<\")\"\>",
         TraditionalForm]}], ")"}], 
      RowBox[{
       RowBox[{"-", "2"}], "-", "i", "+", "m"}]]}]}],
   HoldForm], TraditionalForm]], "Output",
 CellTags->"OPESumSimplify",
 CellLabel->"Out[1243]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["OPESumSimplify[%]", "Input",
 CellTags->"OPESumSimplify",
 CellLabel->"In[1244]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FormBox["\[CapitalDelta]",
     TraditionalForm], "\[CenterDot]", 
    FormBox["p",
     TraditionalForm]}], " ", 
   RowBox[{"(", 
    RowBox[{"-", 
     FormBox[
      TagBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "0"}], "m"], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "i"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["p",
             TraditionalForm]}], ")"}], "i"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", "(", 
            FormBox[
             RowBox[{"p", "-", "q"}],
             TraditionalForm], ")"}], ")"}], 
          RowBox[{
           RowBox[{"-", "2"}], "-", "i", "+", "m"}]]}]}],
       HoldForm],
      TraditionalForm]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"OPESumSimplify",
 CellLabel->"Out[1244]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OPESumSimplify", "[", 
  RowBox[{
   RowBox[{"OPESum", "[", 
    RowBox[{"{", 
     RowBox[{"OPEi", ",", "0", ",", "OPEm"}], "}"}], "]"}], " ", 
   RowBox[{"a", "^", "OPEi"}]}], "]"}]], "Input",
 CellTags->"OPESumSimplify",
 CellLabel->"In[1245]:="],

Cell[BoxData[
 FormBox[
  TagBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "0"}], "m"], 
    FormBox[
     SuperscriptBox["a", "i"],
     TraditionalForm]}],
   HoldForm], TraditionalForm]], "Output",
 CellTags->"OPESumSimplify",
 CellLabel->"Out[1245]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OPESumSimplify", "[", 
  RowBox[{
   RowBox[{"OPESum", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "i"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "m"}], "}"}]}], "]"}], " ", 
   RowBox[{"a", "^", 
    RowBox[{"(", 
     RowBox[{"j", "-", "i"}], ")"}]}], " ", 
   RowBox[{"b", "^", "i"}]}], "]"}]], "Input",
 CellTags->"OPESumSimplify",
 CellLabel->"In[1246]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    TagBox[
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"i", "=", "0"}], "m"], "\<\"\"\>"}],
     HoldForm],
    TraditionalForm], 
   FormBox[
    RowBox[{"\<\"\"\>", " ", 
     RowBox[{"(", 
      RowBox[{"i", "+", "1"}], ")"}]}],
    TraditionalForm], 
   FormBox[
    RowBox[{
     SuperscriptBox["b", "i"], " ", 
     SuperscriptBox["a", 
      RowBox[{"j", "-", "i"}]]}],
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"OPESumSimplify",
 CellLabel->"Out[1246]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"OPESumSimplify",
 CellLabel->"In[1247]:="],

Cell[BoxData[
 RowBox[{"OPESum", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", 
     RowBox[{
      RowBox[{"-", "i"}], "+", "j"}]], " ", 
    SuperscriptBox["b", "i"]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "0", ",", "m"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "0", ",", "i"}], "}"}]}], "]"}]], "Output",
 CellTags->"OPESumSimplify",
 CellLabel->"Out[1247]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["OPE1Loop ", "ObjectName",
 CellTags->"OPE1Loop"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"OPE1Loop"],

Cell["\<\
OPE1Loop[q1, amp].  OPE1Loop[{q1,q2}, amp] does sub-loop  decomposition.\
\>", "Text",
 CellTags->"OPE1Loop"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OPESum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OPESum",
  ButtonNote->"OPESum"],
 "."
}], "Text",
 CellTags->"OPE1Loop"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"OPE1Loop"],

Cell[BoxData[""], "Input",
 CellTags->"OPE1Loop",
 CellLabel->"In[1248]:="]
}, Open  ]],

Cell["OPE2TID  ***unfinished***", "ObjectName",
 CellTags->"OPE2TID"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"OPE2TID"],

Cell["\<\
OPE2TID[exp, k1, k2, p]. The setting of the option EpsContract determines the \
dimension in which the Levi-Civita tensors are contracted.\
\>", "Text",
 CellTags->"OPE2TID"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "OPE2TID", "]"}]], "Input",
 CellTags->"OPE2TID",
 CellLabel->"In[1249]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Uncontract", "\[Rule]", "False"}], ",", 
    RowBox[{"Contract", "\[Rule]", "True"}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"EpsContract", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"OPE2TID",
 CellLabel->"Out[1249]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OPESum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OPESum",
  ButtonNote->"OPESum"],
 "."
}], "Text",
 CellTags->"OPE2TID"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"OPE2TID"],

Cell[BoxData[""], "Input",
 CellTags->"OPE2TID",
 CellLabel->"In[1250]:="]
}, Open  ]],

Cell["OptionsSelect", "ObjectName",
 CellTags->"OptionsSelect"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"OptionsSelect"],

Cell["\<\
OptionsSelect[function,opts] returns the option settings of opts accepted by \
function.  When an option occurs several times in opts, the first setting is \
selected.\
\>", "Text",
 CellTags->"OptionsSelect"]
}, Open  ]],

Cell["Pair", "ObjectName",
 CellTags->"Pair"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Pair"],

Cell[TextData[{
 "Pair[x, y] is the head of a special pairing used in the internal \
representation: x and y may have heads LorentzIndex or Momentum. If both x \
and y have head LorentzIndex, the metric tensor is understood. If x and y \
have head Momentum, a scalar product is meant. If one of x and y has head \
LorentzIndex and the other Momentum, a Lorentz vector ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["p", "\[Mu]"], TraditionalForm]]],
 " is understood."
}], "Text",
 CellTags->"Pair"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FourVector",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FourVector",
  ButtonNote->"FourVector"],
 ", ",
 ButtonBox["FV",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FV",
  ButtonNote->"FV"],
 ", ",
 ButtonBox["FVD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FVD",
  ButtonNote->"FVD"],
 ", ",
 ButtonBox["MetricTensor",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MetricTensor",
  ButtonNote->"MetricTensor"],
 ", ",
 ButtonBox["MT",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MT",
  ButtonNote->"MT"],
 ", ",
 ButtonBox["MTD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"MTD",
  ButtonNote->"MTD"],
 ", ",
 ButtonBox["ScalarProduct",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ScalarProduct",
  ButtonNote->"ScalarProduct"],
 ", ",
 ButtonBox["SP",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SP",
  ButtonNote->"SP"],
 ", ",
 ButtonBox["SPD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SPD",
  ButtonNote->"SPD"],
 "."
}], "Text",
 CellTags->"Pair"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Pair"],

Cell["This represents a four-dimensional metric tensor.", "Text",
 CellTags->"Pair"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", "\[Alpha]", "]"}], ",", 
   RowBox[{"LorentzIndex", "[", "\[Beta]", "]"}]}], "]"}]], "Input",
 CellTags->"Pair",
 CellLabel->"In[1251]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["g", 
   RowBox[{"\[Alpha]", "\[Beta]"}]], TraditionalForm]], "Output",
 CellTags->"Pair",
 CellLabel->"Out[1251]="]
}, Open  ]],

Cell["This is a D-dimensional metric tensor.", "Text",
 CellTags->"Pair"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Alpha]", ",", "D"}], "]"}], ",", 
   RowBox[{"LorentzIndex", "[", 
    RowBox[{"\[Beta]", ",", "D"}], "]"}]}], "]"}]], "Input",
 CellTags->"Pair",
 CellLabel->"In[1252]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["g", 
   RowBox[{"\[Alpha]", "\[Beta]"}]], TraditionalForm]], "Output",
 CellTags->"Pair",
 CellLabel->"Out[1252]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", "\[Alpha]", "]"}], ",", 
   RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]], "Input",
 CellTags->"Pair",
 CellLabel->"In[1253]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   FormBox["p",
    TraditionalForm], 
   FormBox[
    FormBox["\[Alpha]",
     TraditionalForm],
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"Pair",
 CellLabel->"Out[1253]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", "q", "]"}], ",", 
   RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]], "Input",
 CellTags->"Pair",
 CellLabel->"In[1254]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["p",
    TraditionalForm], "\[CenterDot]", 
   FormBox["q",
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"Pair",
 CellLabel->"Out[1254]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", "p", "]"}], ",", 
   RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]], "Input",
 CellTags->"Pair",
 CellLabel->"In[1255]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   FormBox["p",
    TraditionalForm], "2"], TraditionalForm]], "Output",
 CellTags->"Pair",
 CellLabel->"Out[1255]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", 
    RowBox[{"p", "-", "q"}], "]"}], ",", 
   RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]], "Input",
 CellTags->"Pair",
 CellLabel->"In[1256]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["p",
    TraditionalForm], "\[CenterDot]", "(", 
   FormBox[
    RowBox[{"p", "-", "q"}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"Pair",
 CellLabel->"Out[1256]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Pair", "[", 
   RowBox[{
    RowBox[{"Momentum", "[", "p", "]"}], ",", 
    RowBox[{"Momentum", "[", "p", "]"}]}], "]"}], "^", "2"}]], "Input",
 CellTags->"Pair",
 CellLabel->"In[1257]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   FormBox[
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"],
    TraditionalForm], "2"], TraditionalForm]], "Output",
 CellTags->"Pair",
 CellLabel->"Out[1257]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Pair", "[", 
   RowBox[{
    RowBox[{"Momentum", "[", "p", "]"}], ",", 
    RowBox[{"Momentum", "[", "p", "]"}]}], "]"}], "^", "3"}]], "Input",
 CellTags->"Pair",
 CellLabel->"In[1258]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   FormBox[
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"],
    TraditionalForm], "3"], TraditionalForm]], "Output",
 CellTags->"Pair",
 CellLabel->"Out[1258]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Pair", "[", 
   RowBox[{
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Alpha]", ",", 
      RowBox[{"n", "-", "4"}]}], "]"}], ",", 
    RowBox[{"LorentzIndex", "[", "\[Beta]", "]"}]}], "]"}], "//", 
  "Contract"}]], "Input",
 CellTags->"Pair",
 CellLabel->"In[1259]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"Pair",
 CellLabel->"Out[1259]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandScalarProduct", "[", 
  RowBox[{"Pair", "[", 
   RowBox[{
    RowBox[{"Momentum", "[", 
     RowBox[{"p", "-", "q"}], "]"}], ",", 
    RowBox[{"Momentum", "[", "p", "]"}]}], "]"}], "]"}]], "Input",
 CellTags->"Pair",
 CellLabel->"In[1260]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], "2"], "-", 
   RowBox[{
    FormBox["p",
     TraditionalForm], "\[CenterDot]", 
    FormBox["q",
     TraditionalForm]}]}], TraditionalForm]], "Output",
 CellTags->"Pair",
 CellLabel->"Out[1260]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Pair", "[", 
   RowBox[{
    RowBox[{"Momentum", "[", 
     RowBox[{"-", "q"}], "]"}], ",", 
    RowBox[{"Momentum", "[", "p", "]"}]}], "]"}], " ", "+", " ", 
  RowBox[{"Pair", "[", 
   RowBox[{
    RowBox[{"Momentum", "[", "q", "]"}], ",", 
    RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]}]], "Input",
 CellTags->"Pair",
 CellLabel->"In[1261]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"Pair",
 CellLabel->"Out[1261]="]
}, Open  ]]
}, Open  ]],

Cell["PairCollect", "ObjectName",
 CellTags->"PairCollect"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PairCollect"],

Cell["\<\
PairCollect is an option for DiracTrace specifying if the result is collected \
with respect to Pair's.\
\>", "Text",
 CellTags->"PairCollect"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracTrace",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrace",
  ButtonNote->"DiracTrace"],
 ", ",
 ButtonBox["Pair",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Pair",
  ButtonNote->"Pair"],
 "."
}], "Text",
 CellTags->"PairCollect"]
}, Open  ]],

Cell["PairContract", "ObjectName",
 CellTags->"PairContract"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PairContract"],

Cell["\<\
PairContract is like Pair, but with (local) contraction properties.\
\>", "Text",
 CellTags->"PairContract"],

Cell[TextData[{
 "See also: ",
 ButtonBox["Pair",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Pair",
  ButtonNote->"Pair"],
 ", ",
 ButtonBox["Contract",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Contract",
  ButtonNote->"Contract"],
 "."
}], "Text",
 CellTags->"PairContract"]
}, Open  ]],

Cell["PairContract2", "ObjectName",
 CellTags->"PairContract2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PairContract2"],

Cell["\<\
PairContract2 is like Pair, but with local contraction properties among \
PairContract2's.\
\>", "Text",
 CellTags->"PairContract2"],

Cell[TextData[{
 "See also: ",
 ButtonBox["Pair",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Pair",
  ButtonNote->"Pair"],
 ", ",
 ButtonBox["Contract",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Contract",
  ButtonNote->"Contract"],
 ", ",
 ButtonBox["PairContract",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PairContract",
  ButtonNote->"PairContract"],
 "."
}], "Text",
 CellTags->"PairContract2"]
}, Open  ]],

Cell["PairContract3", "ObjectName",
 CellTags->"PairContract3"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PairContract3"],

Cell["\<\
PairContract3 is like Pair, but with local contraction properties among \
PairContract3's.\
\>", "Text",
 CellTags->"PairContract3"],

Cell[TextData[{
 "See also: ",
 ButtonBox["Pair",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Pair",
  ButtonNote->"Pair"],
 ", ",
 ButtonBox["Contract",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Contract",
  ButtonNote->"Contract"],
 ", ",
 ButtonBox["PairContract",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PairContract",
  ButtonNote->"PairContract"],
 "."
}], "Text",
 CellTags->"PairContract3"]
}, Open  ]],

Cell["PartialD", "ObjectName",
 CellTags->"PartialD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PartialD"],

Cell[TextData[{
 "PartialD[",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "] denotes the four-dimensional ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], "."}], TraditionalForm]]],
 " PartialD is used to denote derivative fields. PartialD[LorentzIndex[",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Mu]", ",", 
    StyleBox["D",
     FontSlant->"Plain"]}], TraditionalForm]]],
 "]] denotes the ",
 Cell[BoxData[
  FormBox[
   StyleBox["D",
    FontSlant->"Plain"], TraditionalForm]]],
 "-dimensional ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[PartialD]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], "."}], TraditionalForm]]]
}], "Text",
 ZeroWidthTimes->True,
 CellTags->"PartialD"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["ExpandPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExpandPartialD",
  ButtonNote->"ExpandPartialD"],
 ", ",
 ButtonBox["LeftPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LeftPartialD",
  ButtonNote->"LeftPartialD"],
 ", ",
 ButtonBox["LeftRightPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LeftRightPartialD",
  ButtonNote->"LeftRightPartialD"],
 ", ",
 ButtonBox["RightPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RightPartialD",
  ButtonNote->"RightPartialD"],
 "."
}], "Text",
 CellTags->"PartialD"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Examples"], "Subsubsection",
 CellTags->"PartialD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"QuantumField", "[", 
   RowBox[{"A", ",", 
    RowBox[{"{", "\[Mu]", "}"}]}], "]"}], ".", 
  RowBox[{"LeftPartialD", "[", "\[Nu]", "]"}]}]], "Input",
 CellTags->"PartialD",
 CellLabel->"In[1262]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["A", "\[Mu]"], ".", 
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"PartialD",
 CellLabel->"Out[1262]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
 CellTags->"PartialD",
 CellLabel->"In[1263]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[PartialD]", 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]], 
   SubsuperscriptBox["A", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], "\[Null]"]}], TraditionalForm]], "Output",
 CellTags->"PartialD",
 CellLabel->"Out[1263]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
 CellTags->"PartialD",
 CellLabel->"In[1264]:="],

Cell[BoxData[
 RowBox[{"QuantumField", "[", 
  RowBox[{
   RowBox[{"PartialD", "[", 
    RowBox[{"LorentzIndex", "[", "\[Nu]", "]"}], "]"}], ",", "A", ",", 
   RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}]], "Output",
 CellTags->"PartialD",
 CellLabel->"Out[1264]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["PartialDRelations", "ObjectName",
 CellTags->"PartialDRelations"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PartialDRelations"],

Cell["\<\
PartialDRelations is an option for ExpandPartialD. It is a list of rules \
applied by ExpandPartialD at the end.\
\>", "Text",
 ZeroWidthTimes->True,
 CellTags->"PartialDRelations"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["PartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PartialD",
  ButtonNote->"PartialD"],
 ", ",
 ButtonBox["ExpandPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExpandPartialD",
  ButtonNote->"ExpandPartialD"],
 ", ",
 ButtonBox["LeftPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LeftPartialD",
  ButtonNote->"LeftPartialD"],
 ", ",
 ButtonBox["LeftRightPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LeftRightPartialD",
  ButtonNote->"LeftRightPartialD"],
 ", ",
 ButtonBox["RightPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RightPartialD",
  ButtonNote->"RightPartialD"],
 "."
}], "Text",
 CellTags->"PartialDRelations"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Examples"], "Subsubsection",
 CellTags->"PartialDRelations"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"QuantumField", "[", 
   RowBox[{"A", ",", 
    RowBox[{"{", "\[Mu]", "}"}]}], "]"}], ".", 
  RowBox[{"QuantumField", "[", 
   RowBox[{"B", ",", 
    RowBox[{"{", "\[Mu]", "}"}]}], "]"}], ".", 
  RowBox[{"LeftPartialD", "[", "\[Nu]", "]"}]}]], "Input",
 CellTags->"PartialDRelations",
 CellLabel->"In[1265]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["A", "\[Mu]"], ".", 
   SubscriptBox["B", "\[Mu]"], ".", 
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[LeftArrow]"], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"PartialDRelations",
 CellLabel->"Out[1265]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandPartialD", "[", 
  RowBox[{"%", ",", " ", 
   RowBox[{"PartialDRelations", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"A", "\[Rule]", "C"}], "}"}]}]}], "]"}]], "Input",
 CellTags->"PartialDRelations",
 CellLabel->"In[1266]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox[
     FormBox["C",
      TraditionalForm], "\[Mu]"], ".", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox["B", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], "\[Null]"]}]}], "+", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], 
     SubsuperscriptBox[
      FormBox["C",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], "\[Null]"]}], ".", 
    SubscriptBox["B", "\[Mu]"]}]}], TraditionalForm]], "Output",
 CellTags->"PartialDRelations",
 CellLabel->"Out[1266]="]
}, Open  ]]
}, Open  ]],

Cell["PartialFourVector", "ObjectName",
 CellTags->"PartialFourVector"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PartialFourVector"],

Cell["\<\
PartialFourVector[exp, FourVector[p, mu]]  calculates the partial derivative \
of exp w.r.t. p(mu). PartialFourVector[exp, FourVector[p, mu], \
FourVector[p,nu], ...]  gives the multiple derivative.\
\>", "Text",
 ZeroWidthTimes->True,
 CellTags->"PartialFourVector"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FourVector",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FourVector",
  ButtonNote->"FourVector"],
 ", ",
 ButtonBox["Pair",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Pair",
  ButtonNote->"Pair"],
 ", ",
 ButtonBox["Contract",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Contract",
  ButtonNote->"Contract"],
 "."
}], "Text",
 CellTags->"PartialFourVector"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Examples"], "Subsubsection",
 CellTags->"PartialFourVector"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PartialFourVector", "[", 
  RowBox[{
   RowBox[{"a", " ", 
    SuperscriptBox["\[ExponentialE]", 
     SuperscriptBox[
      RowBox[{"FourVector", "[", 
       RowBox[{"p", ",", "\[Nu]"}], "]"}], "2"]]}], ",", 
   RowBox[{"FourVector", "[", 
    RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "]"}]], "Input",
 CellTags->"PartialFourVector",
 CellLabel->"In[1267]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "a", " ", 
   SuperscriptBox["\[ExponentialE]", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], " ", 
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"PartialFourVector",
 CellLabel->"Out[1267]="]
}, Open  ]]
}, Open  ]],

Cell["PartialIntegrate", "ObjectName",
 CellTags->"PartialIntegrate"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PartialIntegrate"],

Cell["\<\
 PartialIntegrate[exp, ap, t] does a partial integration of the definite \
integral Integrate[exp,{t,0,1}], with ap the factor that is to be integrated \
and exp/ap the factor that is to be differentiated.\
\>", "Text",
 ZeroWidthTimes->True,
 CellTags->"PartialIntegrate"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "PartialIntegrate", "]"}]], "Input",
 CellTags->"PartialIntegrate",
 CellLabel->"In[1268]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"Integrate", "\[Rule]", "Integrate"}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"PartialIntegrate",
 CellLabel->"Out[1268]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Examples"], "Subsubsection",
 CellTags->"PartialIntegrate"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PartialIntegrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"f", "[", "x", "]"}], 
    RowBox[{"g", "[", "x", "]"}]}], ",", 
   RowBox[{"g", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"PartialIntegrate",
 CellLabel->"In[1269]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     TagBox[
      RowBox[{
       RowBox[{
        RowBox[{"f", "(", "x", ")"}], " ", 
        RowBox[{"\[Integral]", 
         RowBox[{
          RowBox[{"g", "(", "x", ")"}], 
          RowBox[{"\[DifferentialD]", "x"}]}]}]}], "/.", "\[VeryThinSpace]", 
       RowBox[{"x", "\[Rule]", "0"}]}],
      HoldForm], ")"}]}], "+", 
   RowBox[{"(", 
    TagBox[
     RowBox[{
      RowBox[{
       RowBox[{"f", "(", "x", ")"}], " ", 
       RowBox[{"\[Integral]", 
        RowBox[{
         RowBox[{"g", "(", "x", ")"}], 
         RowBox[{"\[DifferentialD]", "x"}]}]}]}], "/.", "\[VeryThinSpace]", 
      RowBox[{"x", "\[Rule]", "1"}]}],
     HoldForm], ")"}], "-", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "(", "x", ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"\[Integral]", 
        RowBox[{
         RowBox[{"g", "(", "x", ")"}], 
         RowBox[{"\[DifferentialD]", "x"}]}]}], ")"}]}], 
     RowBox[{"\[DifferentialD]", "x"}]}]}]}], TraditionalForm]], "Output",
 CellTags->"PartialIntegrate",
 CellLabel->"Out[1269]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "InputForm"}]], "Input",
 CellLabel->"In[1270]:="],

Cell["\<\
-HoldForm[f[x]*Integrate[g[x], x] /. x -> 0] + HoldForm[f[x]*Integrate[g[x], \
x] /. x -> 1] - 
 Integrate[Integrate[g[x], x]*Derivative[1][f][x], {x, 0, 1}]\
\>", "Output",
 CellLabel->"Out[1270]//InputForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "x_", "]"}], "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"Log", "[", 
     RowBox[{
      RowBox[{"3", "x"}], "+", "2"}], "]"}], ",", "x"}], "]"}]}]], "Input",
 CellTags->"PartialIntegrate",
 CellLabel->"In[1271]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", "x"}], "+", "2"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"log", "(", 
      RowBox[{
       RowBox[{"3", " ", "x"}], "+", "2"}], ")"}], "-", "1"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"PartialIntegrate",
 CellLabel->"Out[1271]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "[", "x_", "]"}], "=", 
  RowBox[{"D", "[", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"Log", "[", 
      RowBox[{
       RowBox[{"3", "x"}], "+", "2"}], "]"}]], ",", "x"}], "]"}]}]], "Input",
 CellTags->"PartialIntegrate",
 CellLabel->"In[1272]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox["3", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "x"}], "+", "2"}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["log", "2"], "(", 
      RowBox[{
       RowBox[{"3", " ", "x"}], "+", "2"}], ")"}]}]]}], 
  TraditionalForm]], "Output",
 CellTags->"PartialIntegrate",
 CellLabel->"Out[1272]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"PartialIntegrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], 
       RowBox[{"g", "[", "x", "]"}]}], ",", 
      RowBox[{"f", "[", "x", "]"}], ",", "x"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
  "FullSimplify"}]], "Input",
 CellTags->"PartialIntegrate",
 CellLabel->"In[1273]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["2", 
    RowBox[{"log", "(", "8", ")"}]], "-", 
   FractionBox["5", 
    RowBox[{"log", "(", "125", ")"}]]}], TraditionalForm]], "Output",
 CellTags->"PartialIntegrate",
 CellLabel->"Out[1273]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "x", "]"}], 
     RowBox[{"g", "[", "x", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
  "Simplify"}]], "Input",
 CellTags->"PartialIntegrate",
 CellLabel->"In[1274]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["2", 
    RowBox[{"log", "(", "8", ")"}]], "-", 
   FractionBox["5", 
    RowBox[{"log", "(", "125", ")"}]]}], TraditionalForm]], "Output",
 CellTags->"PartialIntegrate",
 CellLabel->"Out[1274]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"f", ",", "g"}], "]"}]], "Input",
 CellTags->"PartialIntegrate",
 CellLabel->"In[1275]:="]
}, Open  ]],

Cell["PartitHead", "ObjectName",
 CellTags->"PartitHead"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PartitHead"],

Cell["\<\
PartitHead[expr, h] returns a list {ex1, h[ex2]} with ex1 free of expressions \
with head h, and h[ex2] having head h.\
\>", "Text",
 CellTags->"PartitHead"]
}, Open  ]],

Cell["PauliSigma", "ObjectName",
 CellTags->"PauliSigma"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PauliSigma"],

Cell["\<\
PauliSigma denotes the vector of the 3 Pauli matrices. PauliSigma[1], \
PauliSigma[2], PauliSigma[3] give the explicit Pauli matrices. PauliSigma[] \
yields {PauliSigma[1], PauliSigma[2], PauliSigma[3]}.\
\>", "Text",
 CellTags->"PauliSigma"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PauliSigma", "[", "]"}], "//", "MatrixForm"}]], "Input",
 CellTags->"PauliSigma",
 CellLabel->"In[1276]:="],

Cell[BoxData[
 FormBox[
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{"(", "\[NoBreak]", 
        TagBox[GridBox[{
           {"0"},
           {"1"}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.5599999999999999]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         Column], "\[NoBreak]", ")"}], 
       RowBox[{"(", "\[NoBreak]", 
        TagBox[GridBox[{
           {"1"},
           {"0"}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.5599999999999999]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         Column], "\[NoBreak]", ")"}]},
      {
       RowBox[{"(", "\[NoBreak]", 
        TagBox[GridBox[{
           {"0"},
           {
            RowBox[{"-", "\[ImaginaryI]"}]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.5599999999999999]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         Column], "\[NoBreak]", ")"}], 
       RowBox[{"(", "\[NoBreak]", 
        TagBox[GridBox[{
           {"\[ImaginaryI]"},
           {"0"}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.5599999999999999]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         Column], "\[NoBreak]", ")"}]},
      {
       RowBox[{"(", "\[NoBreak]", 
        TagBox[GridBox[{
           {"1"},
           {"0"}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.5599999999999999]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         Column], "\[NoBreak]", ")"}], 
       RowBox[{"(", "\[NoBreak]", 
        TagBox[GridBox[{
           {"0"},
           {
            RowBox[{"-", "1"}]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.5599999999999999]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         Column], "\[NoBreak]", ")"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellTags->"PauliSigma",
 CellLabel->"Out[1276]//MatrixForm="]
}, Open  ]]
}, Open  ]],

Cell["PaVe", "ObjectName",
 CellTags->"PaVe"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PaVe"],

Cell["\<\
 PaVe[ i,j,... {p10,p12,...},{m1^2, mw^2, ...} ] denotes the invariant (and \
scalar) Passarino-Veltman integrals, i.e. the coefficient functions of the \
tensor integral decomposition. Joining plist and mlist gives the same \
conventions as for A0, B0, C0, D0. Automatic simlifications are performed for \
the coefficient functions of two-point integrals and for the scalar integrals.\
\>", "Text",
 CellTags->"PaVe"],

Cell[TextData[{
 "For a more detailed description see the manual (no changes from there \
basically): ",
 ButtonBox["http://www.mertig.com/oldfc",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.mertig.com/oldfc"], None}]
}], "Text",
 CellTags->"PaVe"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["PaVeReduce",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVeReduce",
  ButtonNote->"PaVeReduce"],
 "."
}], "Text",
 CellTags->"PaVe"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"PaVe"],

Cell["Some of the PaVe's reduce to special cases.", "Text",
 CellTags->"PaVe"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PaVe", "[", 
  RowBox[{"0", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"m1", ",", "m2", ",", "m3", ",", "m4"}], "}"}]}], "]"}]], "Input",\

 CellTags->"PaVe",
 CellLabel->"In[1277]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    SubscriptBox["\<\"D\"\>", "\<\"0\"\>"],
    TraditionalForm], "(", "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", 
   "f", ",", "m1", ",", "m2", ",", "m3", ",", "m4", ")"}], 
  TraditionalForm]], "Output",
 CellTags->"PaVe",
 CellLabel->"Out[1277]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PaVe", "[", 
  RowBox[{"0", ",", "0", ",", 
   RowBox[{"{", "pp", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"m", "^", "2"}], ",", 
     RowBox[{"M", "^", "2"}]}], "}"}]}], "]"}]], "Input",
 CellTags->"PaVe",
 CellLabel->"In[1278]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"PaVe", "(", 
   RowBox[{"0", ",", "0", ",", 
    RowBox[{"{", "pp", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      SuperscriptBox["m", "2"], ",", 
      SuperscriptBox["M", "2"]}], "}"}]}], ")"}], TraditionalForm]], "Output",\

 CellTags->"PaVe",
 CellLabel->"Out[1278]="]
}, Open  ]]
}, Open  ]],

Cell["PaVeOrderList", "ObjectName",
 CellTags->"PaVeOrderList"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PaVeOrderList"],

Cell["\<\
PaVeOrderList is an option for PaVeOrder and PaVeReduce, specifying in which \
order the arguments of D0 are to be permuted.\
\>", "Text",
 CellTags->"PaVeOrderList"],

Cell[TextData[{
 "See also: ",
 ButtonBox["PaVeOrder",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVeOrder",
  ButtonNote->"PaVeOrder"],
 ", ",
 ButtonBox["PaVeReduce",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVeReduce",
  ButtonNote->"PaVeReduce"],
 ", ",
 ButtonBox["PaVe",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVe",
  ButtonNote->"PaVe"],
 ", ",
 ButtonBox["D0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"D0",
  ButtonNote->"D0"],
 "."
}], "Text",
 CellTags->"PaVeOrderList"]
}, Open  ]],

Cell["PaVeOrder", "ObjectName",
 CellTags->"PaVeOrder"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PaVeOrder"],

Cell[TextData[{
 "PaVeOrder[expr] orders the arguments of all D0 in expr in a standard way. \
PaVeOrder[expr, PaVeOrderList \[Rule] { {..., s, u, ...}, {... ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["m", "1"], "2"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["m", "2"], "2"], TraditionalForm]]],
 " ...}, ...}] orders the arguments of all D0 in expr according to the \
specified ordering lists. The lists may contain only a subsequence of the \
D0-variables."
}], "Text",
 CellTags->"PaVeOrder"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["PaVeReduce",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVeReduce",
  ButtonNote->"PaVeReduce"],
 "."
}], "Text",
 CellTags->"PaVeOrder"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"PaVeOrder"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PaVeOrder", "[", 
  RowBox[{
   RowBox[{"D0", "[", 
    RowBox[{
    "me2", ",", "me2", ",", "mw2", ",", "mw2", ",", "t", ",", "s", ",", "me2",
      ",", "0", ",", "me2", ",", "0"}], "]"}], ",", 
   RowBox[{"PaVeOrderList", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"me2", ",", "me2", ",", "0", ",", "0"}], "}"}]}]}], 
  "]"}]], "Input",
 CellTags->"PaVeOrder",
 CellLabel->"In[1279]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    SubscriptBox["\<\"D\"\>", "\<\"0\"\>"],
    TraditionalForm], "(", "me2", ",", "s", ",", "mw2", ",", "t", ",", "mw2", 
   ",", "me2", ",", "me2", ",", 
   FormBox["0",
    TraditionalForm], ",", 
   FormBox["0",
    TraditionalForm], ",", "me2", ")"}], TraditionalForm]], "Output",
 CellTags->"PaVeOrder",
 CellLabel->"Out[1279]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PaVeOrder", "[", 
  RowBox[{
   RowBox[{"D0", "[", 
    RowBox[{
    "me2", ",", "me2", ",", "mw2", ",", "mw2", ",", "t", ",", "s", ",", "me2",
      ",", "0", ",", "me2", ",", "0"}], "]"}], ",", 
   RowBox[{"PaVeOrderList", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"me2", ",", "me2", ",", "0", ",", "0"}], "}"}]}]}], 
  "]"}]], "Input",
 CellTags->"PaVeOrder",
 CellLabel->"In[1280]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    SubscriptBox["\<\"D\"\>", "\<\"0\"\>"],
    TraditionalForm], "(", "me2", ",", "s", ",", "mw2", ",", "t", ",", "mw2", 
   ",", "me2", ",", "me2", ",", 
   FormBox["0",
    TraditionalForm], ",", 
   FormBox["0",
    TraditionalForm], ",", "me2", ")"}], TraditionalForm]], "Output",
 CellTags->"PaVeOrder",
 CellLabel->"Out[1280]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PaVeOrder", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"D0", "[", 
     RowBox[{
     "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "m12", ",", 
      "m22", ",", "m32", ",", "m42"}], "]"}], "+", 
    RowBox[{"D0", "[", 
     RowBox[{
     "me2", ",", "me2", ",", "mw2", ",", "mw2", ",", "t", ",", "s", ",", 
      "me2", ",", "0", ",", "me2", ",", "0"}], "]"}]}], ",", 
   RowBox[{"PaVeOrderList", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"me2", ",", "me2", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"f", ",", "e"}], "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellTags->"PaVeOrder",
 CellLabel->"In[1281]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FormBox[
     SubscriptBox["\<\"D\"\>", "\<\"0\"\>"],
     TraditionalForm], "(", "a", ",", "d", ",", "c", ",", "b", ",", "f", ",", 
    "e", ",", "m22", ",", "m12", ",", "m42", ",", "m32", ")"}], "+", 
   RowBox[{
    FormBox[
     SubscriptBox["\<\"D\"\>", "\<\"0\"\>"],
     TraditionalForm], "(", "me2", ",", "s", ",", "mw2", ",", "t", ",", "mw2",
     ",", "me2", ",", "me2", ",", 
    FormBox["0",
     TraditionalForm], ",", 
    FormBox["0",
     TraditionalForm], ",", "me2", ")"}]}], TraditionalForm]], "Output",
 CellTags->"PaVeOrder",
 CellLabel->"Out[1281]="]
}, Open  ]]
}, Open  ]],

Cell["PaVeReduce", "ObjectName",
 CellTags->"PaVeReduce"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PaVeReduce"],

Cell["\<\
PaVeReduce[expr] reduces all Passarino-Veltman integrals (i.e. all PaVe's) in \
expr down to scalar A0, B0, C0 and D0.\
\>", "Text",
 CellTags->"PaVeReduce"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "PaVeReduce", "]"}]], "Input",
 CellTags->"PaVeReduce",
 CellLabel->"In[1282]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Dimension", "\[Rule]", "True"}], ",", 
    RowBox[{"IsolateNames", "\[Rule]", "False"}], ",", 
    RowBox[{"Mandelstam", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"PaVeOrderList", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"WriteOutPaVe", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"PaVeReduce",
 CellLabel->"Out[1282]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "WriteOutPaVe"}]], "Input",
 CellTags->"PaVeReduce",
 CellLabel->"In[1283]:="],

Cell[BoxData[
 StyleBox["\<\"WriteOutPaVe is an option for PaVeReduce and OneLoopSum. If \
set to a string, the results of all Passarino-Veltman PaVe's are stored in \
files with names generated from this string and the arguments of PaVe.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellTags->{"Info3522790398-4590919", "PaVeReduce"}]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FRH",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FRH",
  ButtonNote->"FRH"],
 ", ",
 ButtonBox["PaVeOrder",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVeOrder",
  ButtonNote->"PaVeOrder"],
 "."
}], "Text",
 CellTags->"PaVeReduce"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"PaVeReduce"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PaVeReduce", "[", 
  RowBox[{
   RowBox[{"PaVe", "[", 
    RowBox[{"1", ",", "2", ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", 
       RowBox[{"m", "^", "2"}], ",", 
       RowBox[{"m", "^", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"m", "^", "2"}], ",", 
       RowBox[{"m", "^", "2"}], ",", 
       RowBox[{"M", "^", "2"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"IsolateHead", "\[Rule]", "L"}]}], "]"}]], "Input",
 CellTags->"PaVeReduce",
 CellLabel->"In[1284]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["M", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"8", " ", 
        SuperscriptBox["m", "2"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["M", "2"]}], "-", 
       RowBox[{"2", " ", "s"}]}], ")"}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["\<\"C\"\>", "\<\"0\"\>"],
       TraditionalForm], "(", 
      FormBox[
       SuperscriptBox["m", "2"],
       TraditionalForm], ",", 
      FormBox[
       SuperscriptBox["m", "2"],
       TraditionalForm], ",", "s", ",", 
      FormBox[
       SuperscriptBox["m", "2"],
       TraditionalForm], ",", 
      FormBox[
       SuperscriptBox["M", "2"],
       TraditionalForm], ",", 
      FormBox[
       SuperscriptBox["m", "2"],
       TraditionalForm], ")"}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox["m", "2"]}], "-", "s"}], ")"}], "2"]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["m", "2"], "-", 
       SuperscriptBox["M", "2"]}], ")"}], " ", 
     RowBox[{
      SubscriptBox["B", "0"], "(", "0", ",", 
      SuperscriptBox["m", "2"], ",", 
      SuperscriptBox["M", "2"], ")"}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox["m", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox["m", "2"]}], "-", "s"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox["m", "2"]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["M", "2"]}], "-", "s"}], ")"}], " ", 
     RowBox[{
      SubscriptBox["B", "0"], "(", "s", ",", 
      SuperscriptBox["m", "2"], ",", 
      SuperscriptBox["m", "2"], ")"}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         SuperscriptBox["m", "2"]}], "-", "s"}], ")"}], "2"]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"8", " ", 
        SuperscriptBox["m", "4"]}], "-", 
       RowBox[{"10", " ", 
        SuperscriptBox["m", "2"], " ", 
        SuperscriptBox["M", "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["m", "2"], " ", "s"}], "+", 
       RowBox[{
        SuperscriptBox["M", "2"], " ", "s"}]}], ")"}], " ", 
     RowBox[{
      SubscriptBox["B", "0"], "(", 
      SuperscriptBox["m", "2"], ",", 
      SuperscriptBox["m", "2"], ",", 
      SuperscriptBox["M", "2"], ")"}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox["m", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         SuperscriptBox["m", "2"]}], "-", "s"}], ")"}], "2"]}]], "+", 
   FractionBox["1", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox["m", "2"]}], "-", "s"}], ")"}]}]]}], 
  TraditionalForm]], "Output",
 CellTags->"PaVeReduce",
 CellLabel->"Out[1284]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"L", "[", "10", "]"}]], "Input",
 CellTags->"PaVeReduce",
 CellLabel->"In[1285]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"L", "(", "10", ")"}], TraditionalForm]], "Output",
 CellTags->"PaVeReduce",
 CellLabel->"Out[1285]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FRH", "[", "%", "]"}]], "Input",
 CellTags->"PaVeReduce",
 CellLabel->"In[1286]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"L", "(", "10", ")"}], TraditionalForm]], "Output",
 CellTags->"PaVeReduce",
 CellLabel->"Out[1286]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PaVeReduce", "[", 
  RowBox[{
   RowBox[{"PaVe", "[", 
    RowBox[{"2", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SmallVariable", "[", "me2", "]"}], ",", "mw2", ",", "t"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SmallVariable", "[", "me2", "]"}], ",", "0", ",", "mw2"}], 
      "}"}]}], "]"}], ",", 
   RowBox[{"WriteOutPaVe", "\[Rule]", "\"\<p\>\""}]}], "]"}]], "Input",
 CellTags->"PaVeReduce",
 CellLabel->"In[1287]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SubscriptBox["B", "0"], "(", "t", ",", "mw2", ",", "me2", ")"}], 
     RowBox[{"mw2", "-", "t"}]]}], "+", 
   FractionBox[
    RowBox[{
     SubscriptBox["B", "0"], "(", "0", ",", "mw2", ",", "mw2", ")"}], 
    RowBox[{"mw2", "-", "t"}]], "+", 
   FractionBox["2", 
    RowBox[{"mw2", "-", "t"}]]}], TraditionalForm]], "Output",
 CellTags->"PaVeReduce",
 CellLabel->"Out[1287]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"ReadList", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", "\"\<:\>\"",
        ",", "\"\<\>\""}], "]"}], "<>", 
     "\"\<pPaVe2Csmame2mw2tCsmame20mw2.s\>\""}], ",", "String"}], "]"}], 
  "]"}]], "Input",
 CellTags->"PaVeReduce",
 CellLabel->"In[1288]:="],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {"\<\"( 2/(mw2 - t) + B0[0, mw2, mw2]/(mw2 - t) - B0[t, mw2, \
SmallVariable[me2]]/\"\>"},
      {"\<\"  (mw2 - t)\"\>"},
      {"\<\"  ) \"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellTags->"PaVeReduce",
 CellLabel->"Out[1288]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"DeleteFile", "/@", 
   RowBox[{
   "FileNames", "[", "\"\<pPaVe2Csmame2mw2tCsmame20mw2.s\>\"", "]"}]}], 
  ";"}]], "Input",
 CellTags->"PaVeReduce",
 CellLabel->"In[1289]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"se", "=", 
   RowBox[{"SmallVariable", "[", "ME2", "]"}]}], ";"}]], "Input",
 CellTags->"PaVeReduce",
 CellLabel->"In[1290]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"d122", "=", 
  RowBox[{"PaVeReduce", "[", 
   RowBox[{
    RowBox[{"PaVe", "[", 
     RowBox[{"1", ",", "2", ",", "2", ",", 
      RowBox[{"{", 
       RowBox[{"se", ",", "MW2", ",", "MW2", ",", "se", ",", "S", ",", "T"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "se", ",", "0", ",", "se"}], "}"}]}], "]"}], ",", 
    RowBox[{"Mandelstam", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"S", ",", "T", ",", "U", ",", 
       RowBox[{"2", " ", "MW2"}]}], "}"}]}], ",", 
    RowBox[{"IsolateHead", "\[Rule]", "F"}]}], "]"}]}]], "Input",
 CellTags->"PaVeReduce",
 CellLabel->"In[1291]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["S", "2"], " ", 
      SuperscriptBox["T", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"MW2", "-", "S"}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["\<\"C\"\>", "\<\"0\"\>"],
        TraditionalForm], "(", "T", ",", 
       FormBox["ME2",
        TraditionalForm], ",", 
       FormBox["ME2",
        TraditionalForm], ",", 
       FormBox["ME2",
        TraditionalForm], ",", 
       FormBox["ME2",
        TraditionalForm], ",", 
       FormBox["0",
        TraditionalForm], ")"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["MW2", "2"], "-", 
         RowBox[{"S", " ", "U"}]}], ")"}], "3"]}]]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["S", "2"], " ", "T", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"MW2", "-", "S"}], ")"}], "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["\<\"C\"\>", "\<\"0\"\>"],
       TraditionalForm], "(", "MW2", ",", "S", ",", 
      FormBox["ME2",
       TraditionalForm], ",", 
      FormBox["ME2",
       TraditionalForm], ",", 
      FormBox["0",
       TraditionalForm], ",", 
      FormBox["0",
       TraditionalForm], ")"}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["MW2", "2"], "-", 
       RowBox[{"S", " ", "U"}]}], ")"}], "3"]], "-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", "MW2"}], "-", "T"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["MW2", "2"], "-", 
         RowBox[{"S", " ", "U"}]}], ")"}], "3"]}]], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"MW2", "+", "S"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["MW2", "6"]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["MW2", "5"], " ", "S"}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["MW2", "5"], " ", "T"}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["MW2", "4"], " ", 
        SuperscriptBox["S", "2"]}], "+", 
       RowBox[{"20", " ", 
        SuperscriptBox["MW2", "4"], " ", "S", " ", "T"}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["MW2", "3"], " ", 
        SuperscriptBox["S", "3"]}], "-", 
       RowBox[{"36", " ", 
        SuperscriptBox["MW2", "3"], " ", 
        SuperscriptBox["S", "2"], " ", "T"}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["MW2", "3"], " ", "S", " ", 
        SuperscriptBox["T", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["MW2", "2"], " ", 
        SuperscriptBox["S", "4"]}], "+", 
       RowBox[{"20", " ", 
        SuperscriptBox["MW2", "2"], " ", 
        SuperscriptBox["S", "3"], " ", "T"}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["MW2", "2"], " ", 
        SuperscriptBox["S", "2"], " ", 
        SuperscriptBox["T", "2"]}], "-", 
       RowBox[{"2", " ", "MW2", " ", 
        SuperscriptBox["S", "4"], " ", "T"}], "-", 
       RowBox[{"6", " ", "MW2", " ", 
        SuperscriptBox["S", "3"], " ", 
        SuperscriptBox["T", "2"]}], "+", 
       RowBox[{"4", " ", "MW2", " ", 
        SuperscriptBox["S", "2"], " ", 
        SuperscriptBox["T", "3"]}], "-", 
       RowBox[{
        SuperscriptBox["S", "2"], " ", 
        SuperscriptBox["T", "4"]}]}], ")"}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["\<\"C\"\>", "\<\"0\"\>"],
       TraditionalForm], "(", "MW2", ",", "MW2", ",", "T", ",", 
      FormBox["ME2",
       TraditionalForm], ",", 
      FormBox["0",
       TraditionalForm], ",", 
      FormBox["ME2",
       TraditionalForm], ")"}]}]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["S", "3"], " ", 
     SuperscriptBox["T", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"MW2", "-", "S"}], ")"}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["\<\"D\"\>", "\<\"0\"\>"],
       TraditionalForm], "(", "MW2", ",", "MW2", ",", 
      FormBox["ME2",
       TraditionalForm], ",", 
      FormBox["ME2",
       TraditionalForm], ",", "T", ",", "S", ",", 
      FormBox["ME2",
       TraditionalForm], ",", 
      FormBox["0",
       TraditionalForm], ",", 
      FormBox["ME2",
       TraditionalForm], ",", 
      FormBox["0",
       TraditionalForm], ")"}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["MW2", "2"], "-", 
        RowBox[{"S", " ", "U"}]}], ")"}], "3"]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"MW2", "+", "S"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox["MW2", "3"]}], "-", 
       RowBox[{"9", " ", 
        SuperscriptBox["MW2", "2"], " ", "S"}], "-", 
       RowBox[{
        SuperscriptBox["MW2", "2"], " ", "U"}], "-", 
       RowBox[{"4", " ", "MW2", " ", "S", " ", "U"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["S", "3"]}], "+", 
       RowBox[{"5", " ", 
        SuperscriptBox["S", "2"], " ", "U"}], "+", 
       RowBox[{"3", " ", "S", " ", 
        SuperscriptBox["U", "2"]}]}], ")"}], " ", 
     RowBox[{
      SubscriptBox["B", "0"], "(", "T", ",", "ME2", ",", "ME2", ")"}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", "MW2"}], "-", "T"}], ")"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["MW2", "2"], "-", 
        RowBox[{"S", " ", "U"}]}], ")"}], "2"]}]], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         SuperscriptBox["MW2", "5"]}], "-", 
        RowBox[{"5", " ", 
         SuperscriptBox["MW2", "4"], " ", "S"}], "-", 
        RowBox[{
         SuperscriptBox["MW2", "4"], " ", "U"}], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox["MW2", "3"], " ", 
         SuperscriptBox["S", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["MW2", "2"], " ", 
         SuperscriptBox["S", "3"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["MW2", "2"], " ", 
         SuperscriptBox["S", "2"], " ", "U"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["MW2", "2"], " ", "S", " ", 
         SuperscriptBox["U", "2"]}], "+", 
        RowBox[{"4", " ", "MW2", " ", 
         SuperscriptBox["S", "4"]}], "+", 
        RowBox[{"8", " ", "MW2", " ", 
         SuperscriptBox["S", "3"], " ", "U"}], "+", 
        RowBox[{
         SuperscriptBox["S", "3"], " ", 
         SuperscriptBox["U", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["S", "2"], " ", 
         SuperscriptBox["U", "3"]}]}], ")"}], " ", 
      RowBox[{
       SubscriptBox["B", "0"], "(", "MW2", ",", "0", ",", "ME2", ")"}]}], 
     ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"MW2", "-", "S"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", "MW2"}], "-", "T"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["MW2", "2"], "-", 
         RowBox[{"S", " ", "U"}]}], ")"}], "2"]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{"S", " ", 
     RowBox[{
      SubscriptBox["B", "0"], "(", "S", ",", "0", ",", "0", ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["MW2", "2"], "-", 
       RowBox[{"4", " ", "MW2", " ", "S"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["S", "2"]}], "+", 
       RowBox[{"S", " ", "U"}]}], ")"}]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"MW2", "-", "S"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["MW2", "2"], "-", 
        RowBox[{"S", " ", "U"}]}], ")"}], "2"]}]], "-", 
   FractionBox[
    RowBox[{"MW2", "+", "S"}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "MW2"}], "-", "T"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["MW2", "2"], "-", 
       RowBox[{"S", " ", "U"}]}], ")"}]}]]}], TraditionalForm]], "Output",
 CellTags->"PaVeReduce",
 CellLabel->"Out[1291]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Write2", "[", 
   RowBox[{"\"\<fctd122.for\>\"", ",", 
    RowBox[{"d122res", "==", "d122"}], ",", 
    RowBox[{"FormatType", "\[Rule]", "FortranForm"}]}], "]"}], ";"}]], "Input",\

 CellTags->"PaVeReduce",
 CellLabel->"In[1292]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"ReadList", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", "\"\<:\>\"",
        ",", "\"\<\>\""}], "]"}], "<>", "\"\<fctd122.for\>\""}], ",", 
    "String"}], "]"}], "]"}]], "Input",
 CellTags->"PaVeReduce",
 CellLabel->"In[1293]:="],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {"\<\"        d122res = (-5D0D-1*(MW2 + S))/\"\>"},
      {"\<\"     &   ((4D0*MW2 - 1D0*T)*(MW2**2 - 1D0*S*U)) - \"\>"},
      {"\<\"     &  (5.D-1*(4D0*MW2**5 - 5D0*MW2**4*S - \"\>"},
      {"\<\"     &       16D1*MW2**3*S**2 + 4D0*MW2**2*S**3 + \"\>"},
      {"\<\"     &       4D0*MW2*S**4 - 1D0*MW2**4*U - \"\>"},
      {"\<\"     &       4D0*MW2**2*S**2*U + 8D0*MW2*S**3*U + \"\>"},
      {"\<\"     &       4D0*MW2**2*S*U**2 + S**3*U**2 + S**2*U**3)*\"\>"},
      {"\<\"     &     B0(MW2,0D0,ME2))/\"\>"},
      {"\<\"     &   ((MW2 - 1D0*S)*(4D0*MW2 - 1D0*T)**2*\"\>"},
      {"\<\"     &     (MW2**2 - 1D0*S*U)**2) + \"\>"},
      {"\<\"     &  (5.D-1*S*(MW2**2 - 4D0*MW2*S + 2D0*S**2 + S*U)*\"\>"},
      {"\<\"     &     B0(S,0D0,0D0))/\"\>"},
      {"\<\"     &   ((MW2 - 1D0*S)*(MW2**2 - 1D0*S*U)**2) + \"\>"},
      {"\<\"     &  (5.D-1*(MW2 + S)*\"\>"},
      {"\<\"     &     (4D0*MW2**3 - 9D0*MW2**2*S + 2D0*S**3 - \"\>"},
      {"\<\"     &       1D0*MW2**2*U - 4D0*MW2*S*U + 5D0*S**2*U + \"\>"},
      {"\<\"     &       3D0*S*U**2)*B0(T,ME2,ME2))/\"\>"},
      {"\<\"     &   ((4D0*MW2 - 1D0*T)**2*(MW2**2 - 1D0*S*U)**2) - \"\>"},
      {"\<\"     &  (5.D-1*(MW2 + S)*\"\>"},
      {"\<\"     &     (2D0*MW2**6 - 8D0*MW2**5*S + 12D1*MW2**4*S**2 - \
\"\>"},
      {"\<\"     &       8D0*MW2**3*S**3 + 2D0*MW2**2*S**4 - \"\>"},
      {"\<\"     &       2D0*MW2**5*T + 20D1*MW2**4*S*T - \"\>"},
      {"\<\"     &       36D1*MW2**3*S**2*T + 20D1*MW2**2*S**3*T - \"\>"},
      {"\<\"     &       2D0*MW2*S**4*T - 6D0*MW2**3*S*T**2 + \"\>"},
      {"\<\"     &       6D0*MW2**2*S**2*T**2 - 6D0*MW2*S**3*T**2 + \"\>"},
      {"\<\"     &       4D0*MW2*S**2*T**3 - 1D0*S**2*T**4)*\"\>"},
      {"\<\"     &     C0(MW2,MW2,T,ME2,0D0,ME2))/\"\>"},
      {"\<\"     &   ((4D0*MW2 - 1D0*T)**2*(MW2**2 - 1D0*S*U)**3) + \"\>"},
      {"\<\"     &  ((MW2 - 1D0*S)**2*S**2*T*C0(MW2,S,ME2,ME2,0D0,0D0))/\"\>"},
      {"\<\"     &   (MW2**2 - 1D0*S*U)**3 - \"\>"},
      {"\<\"     &  (5.D-1*(MW2 - 1D0*S)*S**2*T**2*\"\>"},
      {"\<\"     &     C0(T,ME2,ME2,ME2,ME2,0D0))/(MW2**2 - 1D0*S*U)**3 + \
\"\>"},
      {"\<\"     &  (5.D-1*(MW2 - 1D0*S)*S**3*T**2*\"\>"},
      {"\<\"     &     D0(MW2,MW2,ME2,ME2,T,S,ME2,0D0,ME2,0D0))/\"\>"},
      {"\<\"     &   (MW2**2 - 1D0*S*U)**3\"\>"},
      {"\<\"                  \"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellTags->"PaVeReduce",
 CellLabel->"Out[1293]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"DeleteFile", "/@", 
   RowBox[{"FileNames", "[", "\"\<fctd122.for\>\"", "]"}]}], ";", 
  RowBox[{"Clear", "[", 
   RowBox[{"d122", ",", "se"}], "]"}], ";"}]], "Input",
 CellTags->"PaVeReduce",
 CellLabel->"In[1294]:="]
}, Open  ]],

Cell["PD", "ObjectName",
 CellTags->"PD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PD"],

Cell["PD is an abbreviation for PropagatorDenominator.", "Text",
 CellTags->"PD"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["PropagatorDenominator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PropagatorDenominator",
  ButtonNote->"PropagatorDenominator"],
 ", ",
 ButtonBox["IFPD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"IFPD",
  ButtonNote->"IFPD"],
 "."
}], "Text",
 CellTags->"PD"]
}, Open  ]],

Cell["PlusDistribution", "ObjectName",
 CellTags->"PlusDistribution"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PlusDistribution"],

Cell["\<\
PlusDistribution[1/(1-x)] denotes a distribution (in the sense of the \"+\" \
prescription).\
\>", "Text",
 CellTags->"PlusDistribution"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Integrate2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Integrate2",
  ButtonNote->"Integrate2"],
 "."
}], "Text",
 CellTags->"PlusDistribution"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"PlusDistribution"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlusDistribution", "[", 
  RowBox[{"1", "/", 
   RowBox[{"(", 
    RowBox[{"1", "-", "x"}], ")"}]}], "]"}]], "Input",
 CellTags->"PlusDistribution",
 CellLabel->"In[1295]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox[
   RowBox[{"(", 
    FractionBox["1", 
     RowBox[{"1", "-", "x"}]], ")"}], "+"], TraditionalForm]], "Output",
 CellTags->"PlusDistribution",
 CellLabel->"Out[1295]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlusDistribution", "[", 
  RowBox[{
   RowBox[{"Log", "[", 
    RowBox[{"1", "-", "x"}], "]"}], "/", 
   RowBox[{"(", 
    RowBox[{"1", "-", "x"}], ")"}]}], "]"}]], "Input",
 CellTags->"PlusDistribution",
 CellLabel->"In[1296]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox[
   RowBox[{"(", 
    FractionBox[
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "x"}], ")"}], 
     RowBox[{"1", "-", "x"}]], ")"}], "+"], TraditionalForm]], "Output",
 CellTags->"PlusDistribution",
 CellLabel->"Out[1296]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{"PlusDistribution", "[", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"PlusDistribution",
 CellLabel->"In[1297]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"PlusDistribution",
 CellLabel->"Out[1297]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{"PlusDistribution", "[", 
    RowBox[{
     RowBox[{"Log", "[", 
      RowBox[{"1", "-", "x"}], "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"PlusDistribution",
 CellLabel->"In[1298]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"PlusDistribution",
 CellLabel->"Out[1298]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{"PlusDistribution", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Log", "[", 
       RowBox[{"1", "-", "x"}], "]"}], "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"PlusDistribution",
 CellLabel->"In[1299]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"PlusDistribution",
 CellLabel->"Out[1299]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlusDistribution", "[", 
  RowBox[{
   RowBox[{"Log", "[", 
    RowBox[{"x", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "]"}], "/", 
   RowBox[{"(", 
    RowBox[{"1", "-", "x"}], ")"}]}], "]"}]], "Input",
 CellTags->"PlusDistribution",
 CellLabel->"In[1300]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"log", "(", "x", ")"}], 
    RowBox[{"1", "-", "x"}]], "+", 
   SubscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{"log", "(", 
       RowBox[{"1", "-", "x"}], ")"}], 
      RowBox[{"1", "-", "x"}]], ")"}], "+"]}], TraditionalForm]], "Output",
 CellTags->"PlusDistribution",
 CellLabel->"Out[1300]="]
}, Open  ]]
}, Open  ]],

Cell["Polarization", "ObjectName",
 CellTags->"Polarization"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Polarization"],

Cell["\<\
Polarization[k] = Polarization[k, I] is the head of a polarization momentum \
with (incoming) momentum k. A slashed polarization vector (e1(k) slash) has \
to be entered as DiracSlash[Polarization[k]]. The internal representation for \
a polarization vector e1 corresponding to a boson with four momentum k is: \
Momentum[ Polarization[ k, I ] ]. With this notation transversality of \
polarization vectors is provided, i.e. , Pair[ Momentum[k], Momentum[ \
Polarization[k, I] ] ] yields 0. Polarization[k,-I] denotes the complex \
conjugate polarization. Polarization is also an option of various functions \
related to the operator product expansion. The setting 0 denotes the \
unpolarized and 1 the polarized case.\
\>", "Text",
 CellTags->"Polarization"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["PolarizationVector",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PolarizationVector",
  ButtonNote->"PolarizationVector"],
 ", ",
 ButtonBox["PolarizationSum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PolarizationSum",
  ButtonNote->"PolarizationSum"],
 ", ",
 ButtonBox["DoPolarizationSums",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DoPolarizationSums",
  ButtonNote->"DoPolarizationSums"],
 "."
}], "Text",
 CellTags->"Polarization"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Polarization"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Polarization", "[", "k", "]"}]], "Input",
 CellTags->"Polarization",
 CellLabel->"In[1301]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[CurlyEpsilon]", "(", "k", ")"}], TraditionalForm]], "Output",
 CellTags->"Polarization",
 CellLabel->"Out[1301]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Polarization", "[", "k", "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"Polarization",
 CellLabel->"In[1302]:="],

Cell[BoxData[
 RowBox[{"Polarization", "[", 
  RowBox[{"k", ",", "\[ImaginaryI]"}], "]"}]], "Output",
 CellTags->"Polarization",
 CellLabel->"Out[1302]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Polarization", "[", "k", "]"}], "//", 
  "ComplexConjugate"}]], "Input",
 CellTags->"Polarization",
 CellLabel->"In[1303]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    TemplateBox[{"\"\[CurlyEpsilon]\"","\"*\""},
     "Superscript"],
    TraditionalForm], "(", "k", ")"}], TraditionalForm]], "Output",
 CellTags->"Polarization",
 CellLabel->"Out[1303]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Polarization", "[", "k", "]"}], "//", "ComplexConjugate"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"Polarization",
 CellLabel->"In[1304]:="],

Cell[BoxData[
 RowBox[{"Polarization", "[", 
  RowBox[{"k", ",", 
   RowBox[{"-", "\[ImaginaryI]"}]}], "]"}]], "Output",
 CellTags->"Polarization",
 CellLabel->"Out[1304]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSlash", "[", 
  RowBox[{"Polarization", "[", "k", "]"}], "]"}]], "Input",
 CellTags->"Polarization",
 CellLabel->"In[1305]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["\<\"\[Gamma]\"\>",
    TraditionalForm], "\[CenterDot]", 
   FormBox[
    RowBox[{"\[CurlyEpsilon]", "(", "k", ")"}],
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"Polarization",
 CellLabel->"Out[1305]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracSlash", "[", 
   RowBox[{"Polarization", "[", "k", "]"}], "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"Polarization",
 CellLabel->"In[1306]:="],

Cell[BoxData[
 RowBox[{"DiracSlash", "[", 
  RowBox[{"Polarization", "[", 
   RowBox[{"k", ",", "\[ImaginaryI]"}], "]"}], "]"}]], "Output",
 CellTags->"Polarization",
 CellLabel->"Out[1306]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pair", "[", " ", 
  RowBox[{
   RowBox[{"Momentum", "[", "k", "]"}], ",", " ", 
   RowBox[{"Momentum", "[", " ", 
    RowBox[{"Polarization", "[", 
     RowBox[{"k", ",", " ", "I"}], "]"}], " ", "]"}]}], " ", "]"}]], "Input",
 CellTags->"Polarization",
 CellLabel->"In[1307]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"Polarization",
 CellLabel->"Out[1307]="]
}, Open  ]]
}, Open  ]],

Cell["PolarizationSum", "ObjectName",
 CellTags->"PolarizationSum"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PolarizationSum"],

Cell["\<\
PolarizationSum[ mu,nu, ... ] defines (as abbreviations) several polarization \
sums. The first two arguments are the interpreted as Lorentz indices, all \
further ones are momenta. PolarizationSum performs no calculations.\
\>", "Text",
 CellTags->"PolarizationSum"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "PolarizationSum", "]"}]], "Input",
 CellTags->"PolarizationSum",
 CellLabel->"In[1308]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"Dimension", "\[Rule]", "4"}], "}"}], TraditionalForm]], "Output",
 CellTags->"PolarizationSum",
 CellLabel->"Out[1308]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Polarization",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Polarization",
  ButtonNote->"Polarization"],
 "."
}], "Text",
 CellTags->"PolarizationSum"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"PolarizationSum"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PolarizationSum", "[", 
  RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]], "Input",
 CellTags->"PolarizationSum",
 CellLabel->"In[1309]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   SuperscriptBox["g", 
    RowBox[{"\[Mu]", "\[Nu]"}]]}], TraditionalForm]], "Output",
 CellTags->"PolarizationSum",
 CellLabel->"Out[1309]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PolarizationSum", "[", 
  RowBox[{"\[Mu]", ",", "\[Nu]", ",", "k"}], "]"}]], "Input",
 CellTags->"PolarizationSum",
 CellLabel->"In[1310]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["k",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["k",
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["k",
      TraditionalForm], "2"]], "-", 
   SuperscriptBox["g", 
    RowBox[{"\[Mu]", "\[Nu]"}]]}], TraditionalForm]], "Output",
 CellTags->"PolarizationSum",
 CellLabel->"Out[1310]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PolarizationSum", "[", 
  RowBox[{"\[Mu]", ",", "\[Nu]", ",", "k", ",", "n"}], "]"}]], "Input",
 CellTags->"PolarizationSum",
 CellLabel->"In[1311]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]]}], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["n",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox["k",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["k",
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["k",
        TraditionalForm], "\[CenterDot]", 
       FormBox["n",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox[
       FormBox["k",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["n",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["k",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["n",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]]}]}], 
    RowBox[{
     FormBox["k",
      TraditionalForm], "\[CenterDot]", 
     FormBox["n",
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"PolarizationSum",
 CellLabel->"Out[1311]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PolarizationSum", "[", 
  RowBox[{"\[Mu]", ",", "\[Nu]", ",", "k", ",", 
   RowBox[{
    SubscriptBox["p", "1"], "-", 
    SubscriptBox["p", "2"]}]}], "]"}]], "Input",
 CellTags->"PolarizationSum",
 CellLabel->"In[1312]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]]}], "-", 
   FractionBox[
    RowBox[{
     SubsuperscriptBox["p", "1", "2"], " ", 
     SuperscriptBox[
      FormBox["k",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["k",
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FormBox["k",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["p", "1"],
         TraditionalForm]}], "-", 
       RowBox[{
        FormBox["k",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["p", "2"],
         TraditionalForm]}]}], ")"}], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["k",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["k",
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["p", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["p", "2"],
       TraditionalForm]}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FormBox["k",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["p", "1"],
         TraditionalForm]}], "-", 
       RowBox[{
        FormBox["k",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["p", "2"],
         TraditionalForm]}]}], ")"}], "2"]], "-", 
   FractionBox[
    RowBox[{
     SubsuperscriptBox["p", "2", "2"], " ", 
     SuperscriptBox[
      FormBox["k",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["k",
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FormBox["k",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["p", "1"],
         TraditionalForm]}], "-", 
       RowBox[{
        FormBox["k",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["p", "2"],
         TraditionalForm]}]}], ")"}], "2"]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox[
       FormBox["k",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FormBox[
         RowBox[{
          SubscriptBox["p", "1"], "-", 
          SubscriptBox["p", "2"]}],
         TraditionalForm], ")"}], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["k",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FormBox[
         RowBox[{
          SubscriptBox["p", "1"], "-", 
          SubscriptBox["p", "2"]}],
         TraditionalForm], ")"}], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]]}]}], 
    RowBox[{
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["p", "1"],
       TraditionalForm]}], "-", 
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["p", "2"],
       TraditionalForm]}]}]]}], TraditionalForm]], "Output",
 CellTags->"PolarizationSum",
 CellLabel->"Out[1312]="]
}, Open  ]]
}, Open  ]],

Cell["PolarizationUncontract", "ObjectName",
 CellTags->"PolarizationUncontract"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PolarizationUncontract"],

Cell["\<\
PolarizationUncontract does Uncontract on scalar products involving \
polarization vectors.\
\>", "Text",
 CellTags->"PolarizationUncontract"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Polarization",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Polarization",
  ButtonNote->"Polarization"],
 ", ",
 ButtonBox["Uncontract",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Uncontract",
  ButtonNote->"Uncontract"],
 "."
}], "Text",
 CellTags->"PolarizationUncontract"]
}, Open  ]],

Cell["PolarizationVector", "ObjectName",
 CellTags->"PolarizationVector"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PolarizationVector"],

Cell["PolarizationVector[p, mu] gives a polarization vector.", "Text",
 CellTags->"PolarizationVector"],

Cell[TextData[{
 "See also: ",
 ButtonBox["FourVector",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FourVector",
  ButtonNote->"FourVector"],
 ", ",
 ButtonBox["Pair",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Pair",
  ButtonNote->"Pair"],
 ", ",
 ButtonBox["Polarization",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Polarization",
  ButtonNote->"Polarization"],
 "."
}], "Text",
 CellTags->"PolarizationVector"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"PolarizationVector"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PolarizationVector", "[", 
  RowBox[{"k", ",", "\[Mu]"}], "]"}]], "Input",
 CellTags->"PolarizationVector",
 CellLabel->"In[1313]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[CurlyEpsilon]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], "(", "k", ")"}], TraditionalForm]], "Output",
 CellTags->"PolarizationVector",
 CellLabel->"Out[1313]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Conjugate", "[", 
  RowBox[{"PolarizationVector", "[", 
   RowBox[{"k", ",", "\[Mu]"}], "]"}], "]"}]], "Input",
 CellTags->"PolarizationVector",
 CellLabel->"In[1314]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubsuperscriptBox["\[CurlyEpsilon]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], "*"], "(", "k", ")"}], TraditionalForm]], "Output",
 CellTags->"PolarizationVector",
 CellLabel->"Out[1314]="]
}, Open  ]],

Cell[TextData[{
 "A polarization vector ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[CurlyEpsilon]", "\[Mu]"], "(", "k", ")"}], 
   TraditionalForm]]],
 "is a special four-vector."
}], "Text",
 CellTags->"PolarizationVector"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PolarizationVector", "[", 
   RowBox[{"k", ",", "mu"}], "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"PolarizationVector",
 CellLabel->"In[1315]:="],

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"LorentzIndex", "[", "mu", "]"}], ",", 
   RowBox[{"Momentum", "[", 
    RowBox[{"Polarization", "[", 
     RowBox[{"k", ",", "\[ImaginaryI]"}], "]"}], "]"}]}], "]"}]], "Output",
 CellTags->"PolarizationVector",
 CellLabel->"Out[1315]//StandardForm="]
}, Open  ]],

Cell[TextData[{
 "The transverality property ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      FormBox["k",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     RowBox[{
      SubscriptBox["\[CurlyEpsilon]", "\[Mu]"], "(", "k", ")"}]}], "=", "0"}],
    TraditionalForm]]],
 " is built in."
}], "Text",
 CellTags->"PolarizationVector"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1", " ", "=", " ", 
  RowBox[{
   RowBox[{"PolarizationVector", "[", 
    RowBox[{"k", ",", "\[Mu]"}], "]"}], " ", 
   RowBox[{"FourVector", "[", 
    RowBox[{"k", ",", "\[Mu]"}], "]"}]}]}]], "Input",
 CellTags->"PolarizationVector",
 CellLabel->"In[1316]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["k", "\[Mu]"], " ", 
   RowBox[{
    SubscriptBox["\[CurlyEpsilon]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], "(", "k", ")"}]}], TraditionalForm]], "Output",
 CellTags->"PolarizationVector",
 CellLabel->"Out[1316]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", "a1", "]"}]], "Input",
 CellTags->"PolarizationVector",
 CellLabel->"In[1317]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"PolarizationVector",
 CellLabel->"Out[1317]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2", " ", "=", " ", 
  RowBox[{
   RowBox[{"PolarizationVector", "[", 
    RowBox[{
     RowBox[{"k", "-", "p"}], ",", "\[Mu]"}], "]"}], " ", 
   RowBox[{"FourVector", "[", 
    RowBox[{"k", ",", "\[Mu]"}], "]"}]}]}]], "Input",
 CellTags->"PolarizationVector",
 CellLabel->"In[1318]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["k", "\[Mu]"], " ", 
   RowBox[{
    SubscriptBox["\[CurlyEpsilon]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], "(", 
    FormBox[
     RowBox[{"k", "-", "p"}],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellTags->"PolarizationVector",
 CellLabel->"Out[1318]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", "a2", "]"}]], "Input",
 CellTags->"PolarizationVector",
 CellLabel->"In[1319]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["k",
    TraditionalForm], "\[CenterDot]", "(", 
   FormBox[
    RowBox[{"\[CurlyEpsilon]", "(", 
     FormBox[
      RowBox[{"k", "-", "p"}],
      TraditionalForm], ")"}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"PolarizationVector",
 CellLabel->"Out[1319]="]
}, Open  ]],

Cell[TextData[{
 "Depending on the alphabetical ordering of the momenta simplifcations are \
done, e.g., ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     RowBox[{
      SubscriptBox["\[CurlyEpsilon]", "\[Mu]"], "(", 
      FormBox[
       RowBox[{"k", "-", "p"}],
       TraditionalForm], ")"}]}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"k", "-", "p", "-", "k"}], ")"}], "\[Mu]"]}], 
      RowBox[{
       SubscriptBox["\[CurlyEpsilon]", "\[Mu]"], "(", 
       FormBox[
        RowBox[{"k", "-", "p"}],
        TraditionalForm], ")"}]}], "=", 
     RowBox[{
      RowBox[{
       SuperscriptBox["k", "\[Mu]"], 
       RowBox[{
        SubscriptBox["\[CurlyEpsilon]", "\[Mu]"], "(", 
        FormBox[
         RowBox[{"k", "-", "p"}],
         TraditionalForm], ")"}]}], "=", 
      RowBox[{
       FormBox["k",
        TraditionalForm], "\[NoBreak]", "\[CenterDot]", "\[NoBreak]", 
       RowBox[{
        RowBox[{"(", "\[NoBreak]", 
         FormBox[
          RowBox[{"\[CurlyEpsilon]", "\[NoBreak]", "(", "\[NoBreak]", 
           FormBox[
            RowBox[{"k", "-", "p"}],
            TraditionalForm], "\[NoBreak]", ")"}],
          TraditionalForm], "\[NoBreak]", ")"}], "."}]}]}]}]}], 
   TraditionalForm]]]
}], "Text",
 CellTags->"PolarizationVector"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3", " ", "=", " ", 
  RowBox[{
   RowBox[{"PolarizationVector", "[", 
    RowBox[{
     RowBox[{"k", "-", "p"}], ",", "\[Mu]"}], "]"}], " ", 
   RowBox[{"FourVector", "[", 
    RowBox[{"p", ",", "\[Mu]"}], "]"}]}]}]], "Input",
 CellTags->"PolarizationVector",
 CellLabel->"In[1320]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["p", "\[Mu]"], " ", 
   RowBox[{
    SubscriptBox["\[CurlyEpsilon]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], "(", 
    FormBox[
     RowBox[{"k", "-", "p"}],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellTags->"PolarizationVector",
 CellLabel->"Out[1320]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", "a3", "]"}]], "Input",
 CellTags->"PolarizationVector",
 CellLabel->"In[1321]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["k",
    TraditionalForm], "\[CenterDot]", "(", 
   FormBox[
    RowBox[{"\[CurlyEpsilon]", "(", 
     FormBox[
      RowBox[{"k", "-", "p"}],
      TraditionalForm], ")"}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"PolarizationVector",
 CellLabel->"Out[1321]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"a1", ",", "a2", ",", "a3"}], "]"}]], "Input",
 CellTags->"PolarizationVector",
 CellLabel->"In[1322]:="]
}, Open  ]],

Cell["PositiveInteger", "ObjectName",
 CellTags->"PositiveInteger"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PositiveInteger"],

Cell["\<\
PositiveInteger is a data type. E.g. DataType[OPEm, PositiveInteger] gives \
True.\
\>", "Text",
 CellTags->"PositiveInteger"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DataType",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DataType",
  ButtonNote->"DataType"],
 "."
}], "Text",
 CellTags->"PositiveInteger"]
}, Open  ]],

Cell["PositiveNumber", "ObjectName",
 CellTags->"PositiveNumber"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PositiveNumber"],

Cell["\<\
PositiveNumber is a data type. E.g. DataType[Epsilon, PositiveNumber] = True \
(by default). \
\>", "Text",
 CellTags->"PositiveNumber"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DataType",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DataType",
  ButtonNote->"DataType"],
 "."
}], "Text",
 CellTags->"PositiveNumber"]
}, Open  ]],

Cell["PowerFactor", "ObjectName",
 CellTags->"PowerFactor"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PowerFactor"],

Cell[TextData[{
 "PowerFactor[exp] replaces ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "a"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["y", "a"], TraditionalForm]]],
 "with ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"x", " ", "y"}], ")"}], "a"], TraditionalForm]]],
 "."
}], "Text",
 CellTags->"PowerFactor"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["PowerSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PowerSimplify",
  ButtonNote->"PowerSimplify"],
 "."
}], "Text",
 CellTags->"PowerFactor"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"PowerFactor"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SuperscriptBox["x", "a"], 
  SuperscriptBox["y", "a"]}]], "Input",
 CellTags->"PowerFactor",
 CellLabel->"In[1323]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["x", "a"], " ", 
   SuperscriptBox["y", "a"]}], TraditionalForm]], "Output",
 CellTags->"PowerFactor",
 CellLabel->"Out[1323]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PowerFactor", "[", "%", "]"}]], "Input",
 CellTags->"PowerFactor",
 CellLabel->"In[1324]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"x", " ", "y"}], ")"}], "a"], TraditionalForm]], "Output",
 CellTags->"PowerFactor",
 CellLabel->"Out[1324]="]
}, Open  ]]
}, Open  ]],

Cell["PowerSimplify", "ObjectName",
 CellTags->"PowerSimplify"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PowerSimplify"],

Cell[TextData[{
 "PowerSimplify[exp] simplifies",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "x"}], ")"}], "a"]}], TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "a"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["x", "a"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"y", "-", "x"}], ")"}], "n"], TraditionalForm]]],
 " to ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "n"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"x", "-", "y"}], ")"}], "n"], TraditionalForm]]],
 "; thus assuming that the exponent is an integer (even if it is symbolic). \
Furthermore ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{"a", "+", "n"}]], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ImaginaryI]", 
    RowBox[{"a", "+", "n"}]], TraditionalForm]]],
 " are expanded and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ImaginaryI]", 
    RowBox[{"2", " ", "m"}]], TraditionalForm]]],
 " \[Rule] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "m"], TraditionalForm]]],
 " and (-1)^(",
 StyleBox["n",
  FontSlant->"Italic"],
 " ",
 StyleBox["m",
  FontSlant->"Italic"],
 ") \[Rule] 1 and (-1)^(",
 StyleBox["n",
  FontSlant->"Italic"],
 " ",
 StyleBox["m",
  FontSlant->"Italic"],
 ") \[Rule] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    FormBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}],
     TraditionalForm], "m"], TraditionalForm]]],
 " for ",
 StyleBox["n",
  FontSlant->"Italic"],
 " even and odd respectively and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{"-", "n"}]], TraditionalForm]]],
 " \[Rule] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "n"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[ExponentialE]", 
    StyleBox[
     RowBox[{"\[ImaginaryI]", 
      StyleBox["m",
       FontSlant->"Italic"], "\[Pi]"}]]], TraditionalForm]]],
 " \[Rule] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "m"], TraditionalForm]]],
 "."
}], "Text",
 CellTags->"PowerSimplify"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DataType",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DataType",
  ButtonNote->"DataType"],
 ", ",
 ButtonBox["OPEm",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OPEi",
  ButtonNote->"OPEm"],
 "."
}], "Text",
 CellTags->"PowerSimplify"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"PowerSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PowerSimplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"-", "1"}], ")"}], "^", 
   RowBox[{"(", 
    RowBox[{"2", "OPEm"}], ")"}]}], "]"}]], "Input",
 CellTags->"PowerSimplify",
 CellLabel->"In[1325]:="],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellTags->"PowerSimplify",
 CellLabel->"Out[1325]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PowerSimplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"-", "1"}], ")"}], "^", 
   RowBox[{"(", 
    RowBox[{"OPEm", "+", "2"}], ")"}]}], "]"}]], "Input",
 CellTags->"PowerSimplify",
 CellLabel->"In[1326]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"-", "1"}], ")"}], "m"], TraditionalForm]], "Output",
 CellTags->"PowerSimplify",
 CellLabel->"Out[1326]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PowerSimplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"-", "1"}], ")"}], "^", 
   RowBox[{"(", 
    RowBox[{"OPEm", "-", "2"}], ")"}]}], "]"}]], "Input",
 CellTags->"PowerSimplify",
 CellLabel->"In[1327]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"-", "1"}], ")"}], "m"], TraditionalForm]], "Output",
 CellTags->"PowerSimplify",
 CellLabel->"Out[1327]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PowerSimplify", "[", 
  RowBox[{"I", "^", 
   RowBox[{"(", 
    RowBox[{"2", "OPEm"}], ")"}]}], "]"}]], "Input",
 CellTags->"PowerSimplify",
 CellLabel->"In[1328]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"-", "1"}], ")"}], "m"], TraditionalForm]], "Output",
 CellTags->"PowerSimplify",
 CellLabel->"Out[1328]="]
}, Open  ]]
}, Open  ]],

Cell["Power2", "ObjectName",
 CellTags->"Power2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Power2"],

Cell["\<\
Power2[x, y] represents x^y.  Sometimes Power2 is more useful than the \
Mathematica Power. Power2[-a,b] simplifies to (-1)^b Power2[a,b] (if no \
Epsilon is in b ...).\
\>", "Text",
 CellTags->"Power2"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["PowerFactor",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PowerFactor",
  ButtonNote->"PowerFactor"],
 "."
}], "Text",
 CellTags->"Power2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Power2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Power", "[", 
  RowBox[{
   RowBox[{"-", "a"}], ",", "b"}], "]"}]], "Input",
 CellTags->"Power2",
 CellLabel->"In[1329]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"-", "a"}], ")"}], "b"], TraditionalForm]], "Output",
 CellTags->"Power2",
 CellLabel->"Out[1329]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Power2", "[", 
  RowBox[{
   RowBox[{"-", "a"}], ",", "b"}], "]"}]], "Input",
 CellTags->"Power2",
 CellLabel->"In[1330]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "b"], " ", 
   FormBox[
    SuperscriptBox["a", "b"],
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"Power2",
 CellLabel->"Out[1330]="]
}, Open  ]]
}, Open  ]],

Cell["PostFortranFile", "ObjectName",
 CellTags->"PostFortranFile"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PostFortranFile"],

Cell["\<\
PostFortranFile is an option for Write2 which may be set to a file name (or a \
list of file names) or a string,  which will be put at the end of the \
generated Fortran file.\
\>", "Text",
 CellTags->"PostFortranFile"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Write2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Write2",
  ButtonNote->"Write2"],
 ", ",
 ButtonBox["PreFortranFile",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PreFortranFile",
  ButtonNote->"PreFortranFile"],
 "."
}], "Text",
 CellTags->"PostFortranFile"]
}, Open  ]],

Cell["Prefactor", "ObjectName",
 CellTags->"Prefactor"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Prefactor"],

Cell["\<\
Prefactor is an option for OneLoop and OneLoopSum. If set as option of \
OneLoop, the amplitude is multiplied by Prefactor before calculation; if \
specified as option of OneLoopSum, after calculation in the final result as a \
global factor.\
\>", "Text",
 CellTags->"Prefactor"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OneLoop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoop",
  ButtonNote->"OneLoop"],
 ", ",
 ButtonBox["OneLoopSum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoopSum",
  ButtonNote->"OneLoopSum"],
 "."
}], "Text",
 CellTags->"Prefactor"]
}, Open  ]],

Cell["PreFortranFile", "ObjectName",
 CellTags->"PreFortranFile"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PreFortranFile"],

Cell["\<\
PreFortranFile is an option for Write2 which may be set to a file name (or a \
list of file names) or a string, which will be put at the beginning of the \
generated Fortran file.\
\>", "Text",
 CellTags->"PreFortranFile"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Write2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Write2",
  ButtonNote->"Write2"],
 ", ",
 ButtonBox["PostFortranFile",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PostFortranFile",
  ButtonNote->"PostFortranFile"],
 "."
}], "Text",
 CellTags->"PreFortranFile"]
}, Open  ]],

Cell["PropagatorDenominator", "ObjectName",
 CellTags->"PropagatorDenominator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PropagatorDenominator"],

Cell[TextData[{
 "PropagatorDenominator[q, m] is a factor of the denominator of a propagator. \
If p is supposed to be D-dimensional enter: PropagatorDenominator[Momentum[q, \
D], m]. What is meant is ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"q", "^", "2"}]}]}]}], TraditionalForm]]],
 " - ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "^", "2"}], TraditionalForm]]],
 "). PropagatorDenominator[p] evaluates to PropagatorDenominator[p, 0]. "
}], "Text",
 CellTags->"PropagatorDenominator"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynAmpDenominator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynAmpDenominator",
  ButtonNote->"FeynAmpDenominator"],
 ", ",
 ButtonBox["PropagatorDenominatorExplicit",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PropagatorDenominatorExplicit",
  ButtonNote->"PropagatorDenominatorExplicit"],
 ", ",
 ButtonBox["IFPD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"IFPD",
  ButtonNote->"IFPD"],
 "."
}], "Text",
 CellTags->"PropagatorDenominator"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"PropagatorDenominator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"PropagatorDenominator", "[", 
   RowBox[{"p", ",", "m"}], "]"}]}]], "Input",
 CellTags->"PropagatorDenominator",
 CellLabel->"In[1331]:="],

Cell[BoxData[
 FormBox[
  FractionBox["1", 
   RowBox[{
    SuperscriptBox["p", "2"], "-", 
    SuperscriptBox["m", "2"]}]], TraditionalForm]], "Output",
 CellTags->"PropagatorDenominator",
 CellLabel->"Out[1331]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PropagatorDenominator", "[", "p", "]"}]], "Input",
 CellTags->"PropagatorDenominator",
 CellLabel->"In[1332]:="],

Cell[BoxData[
 FormBox[
  FractionBox["1", 
   SuperscriptBox["p", "2"]], TraditionalForm]], "Output",
 CellTags->"PropagatorDenominator",
 CellLabel->"Out[1332]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{"PropagatorDenominator", "[", 
   RowBox[{"q", ",", "m"}], "]"}], " "}]], "Input",
 CellTags->"PropagatorDenominator",
 CellLabel->"In[1333]:="],

Cell[BoxData[
 FormBox[
  FractionBox["1", 
   RowBox[{
    SuperscriptBox["q", "2"], "-", 
    SuperscriptBox["m", "2"]}]], TraditionalForm]], "Output",
 CellTags->"PropagatorDenominator",
 CellLabel->"Out[1333]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"FCI", "[", "t1", "]"}], "]"}]], "Input",
 CellTags->"PropagatorDenominator",
 CellLabel->"In[1334]:="],

Cell[BoxData[
 RowBox[{"PropagatorDenominator", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", 
    RowBox[{"q", ",", "D"}], "]"}], ",", "m"}], "]"}]], "Output",
 CellTags->"PropagatorDenominator",
 CellLabel->"Out[1334]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"ChangeDimension", "[", 
   RowBox[{"t1", ",", "D"}], "]"}], "]"}]], "Input",
 CellTags->"PropagatorDenominator",
 CellLabel->"In[1335]:="],

Cell[BoxData[
 RowBox[{"PropagatorDenominator", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", 
    RowBox[{"q", ",", "D"}], "]"}], ",", "m"}], "]"}]], "Output",
 CellTags->"PropagatorDenominator",
 CellLabel->"Out[1335]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PropagatorDenominatorExplicit", "[", "t1", "]"}]], "Input",
 CellTags->"PropagatorDenominator",
 CellLabel->"In[1336]:="],

Cell[BoxData[
 FormBox[
  FractionBox["1", 
   RowBox[{
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], "2"], "-", 
    SuperscriptBox["m", "2"]}]], TraditionalForm]], "Output",
 CellTags->"PropagatorDenominator",
 CellLabel->"Out[1336]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", "%", "]"}]], "Input",
 CellTags->"PropagatorDenominator",
 CellLabel->"In[1337]:="],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["m", "2"]}], "+", 
   RowBox[{"Pair", "[", 
    RowBox[{
     RowBox[{"Momentum", "[", "q", "]"}], ",", 
     RowBox[{"Momentum", "[", "q", "]"}]}], "]"}]}]]], "Output",
 CellTags->"PropagatorDenominator",
 CellLabel->"Out[1337]//StandardForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "t1", "]"}]], "Input",
 CellTags->"PropagatorDenominator",
 CellLabel->"In[1338]:="]
}, Open  ]],

Cell["PropagatorDenominatorExplicit", "ObjectName",
 CellTags->"PropagatorDenominatorExplicit"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"PropagatorDenominatorExplicit"],

Cell["\<\
PropagatorDenominatorExplicit[exp] changes each occurence of \
PropagatorDenominator[a,b] in exp into 1/(ScalarProduct[a,a]-b^2) and \
replaces FeynAmpDenominator by Identity.\
\>", "Text",
 CellTags->"PropagatorDenominatorExplicit"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynAmpDenominator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynAmpDenominator",
  ButtonNote->"FeynAmpDenominator"],
 ", ",
 ButtonBox["PropagatorDenominator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PropagatorDenominator",
  ButtonNote->"PropagatorDenominator"],
 "."
}], "Text",
 CellTags->"PropagatorDenominatorExplicit"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"PropagatorDenominatorExplicit"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FAD", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"q", ",", "m"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"q", "-", "p"}], ",", "0"}], "}"}]}], "]"}], "//", 
  "FCI"}]], "Input",
 CellTags->"PropagatorDenominatorExplicit",
 CellLabel->"In[1339]:="],

Cell[BoxData[
 FormBox[
  FractionBox["1", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["q", "2"], "-", 
      SuperscriptBox["m", "2"]}], ")"}], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q", "-", "p"}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellTags->"PropagatorDenominatorExplicit",
 CellLabel->"Out[1339]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PropagatorDenominatorExplicit", "[", "%", "]"}], "//", 
  "FCE"}]], "Input",
 CellTags->"PropagatorDenominatorExplicit",
 CellLabel->"In[1340]:="],

Cell[BoxData[
 FormBox[
  FractionBox["1", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox[
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], "2"],
       TraditionalForm], "-", 
      SuperscriptBox["m", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["m", "2"], "-", 
      RowBox[{"2", " ", 
       FormBox[
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}],
        TraditionalForm]}], "+", 
      FormBox[
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], "2"],
       TraditionalForm]}], ")"}]}]], TraditionalForm]], "Output",
 CellTags->"PropagatorDenominatorExplicit",
 CellLabel->"Out[1340]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"PropagatorDenominatorExplicit",
 CellLabel->"In[1341]:="],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["m", "2"]}], "+", 
     RowBox[{"SPD", "[", 
      RowBox[{"q", ",", "q"}], "]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["m", "2"], "-", 
     RowBox[{"2", " ", 
      RowBox[{"SPD", "[", 
       RowBox[{"p", ",", "q"}], "]"}]}], "+", 
     RowBox[{"SPD", "[", 
      RowBox[{"q", ",", "q"}], "]"}]}], ")"}]}]]], "Output",
 CellTags->"PropagatorDenominatorExplicit",
 CellLabel->"Out[1341]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["QGV", "ObjectName",
 CellTags->"QGV"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"QGV"],

Cell["QGV is equivalent to QuarkGluonVertex.", "Text",
 CellTags->"QGV"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["QuarkGluonVertex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"QuarkGluonVertex",
  ButtonNote->"QuarkGluonVertex"],
 "."
}], "Text",
 CellTags->"QGV"]
}, Open  ]],

Cell["QO", "ObjectName",
 CellTags->"QO"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"QO"],

Cell["QO is equivalent to Twist2QuarkOperator.", "Text",
 CellTags->"QO"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Twist2QuarkOperator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Twist2QuarkOperator",
  ButtonNote->"Twist2QuarkOperator"],
 "."
}], "Text",
 CellTags->"QO"]
}, Open  ]],

Cell["QP", "ObjectName",
 CellTags->"QP"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"QP"],

Cell["\<\
QP is an alias for QuarkPropagator. QP[p] is the massless quark propagator. \
QP[{p,m}] gives the  quark propagator with mass m.\
\>", "Text",
 CellTags->"QP"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["QuarkPropagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"QuarkPropagator",
  ButtonNote->"QuarkPropagator"],
 "."
}], "Text",
 CellTags->"QP"]
}, Open  ]],

Cell["QuantumField", "ObjectName",
 CellTags->"QuantumField"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"QuantumField"],

Cell[TextData[{
 "QuantumField is the head of quantized fields and their derivatives. \
QuantumField[par, ftype, {lorind}, {sunind}] denotes a quantum field of type \
ftype with (possible) Lorentz-indices lorind and SU(",
 StyleBox["N",
  FontSlant->"Italic"],
 ") indices sunind. The optional first argument par denotes a partial \
derivative acting on the field."
}], "Text",
 CellTags->"QuantumField"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynRule",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynRule",
  ButtonNote->"FeynRule"],
 ", ",
 ButtonBox["PartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PartialD",
  ButtonNote->"PartialD"],
 ", ",
 ButtonBox["ExpandPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExpandPartialD",
  ButtonNote->"ExpandPartialD"],
 "."
}], "Text",
 CellTags->"QuantumField"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"QuantumField"],

Cell["This denotes a scalar field.", "Text",
 CellTags->"QuantumField"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuantumField", "[", "S", "]"}]], "Input",
 CellTags->"QuantumField",
 CellLabel->"In[1342]:="],

Cell[BoxData[
 FormBox["S", TraditionalForm]], "Output",
 CellTags->"QuantumField",
 CellLabel->"Out[1342]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuantumField", "[", "AntiQuarkField", "]"}]], "Input",
 CellTags->"QuantumField",
 CellLabel->"In[1343]:="],

Cell[BoxData[
 FormBox[
  OverscriptBox["\[Psi]", "_"], TraditionalForm]], "Output",
 CellTags->"QuantumField",
 CellLabel->"Out[1343]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuantumField", "[", "QuarkField", "]"}]], "Input",
 CellTags->"QuantumField",
 CellLabel->"In[1344]:="],

Cell[BoxData[
 FormBox["\[Psi]", TraditionalForm]], "Output",
 CellTags->"QuantumField",
 CellLabel->"Out[1344]="]
}, Open  ]],

Cell["This is a field with a Lorentz index.", "Text",
 CellTags->"QuantumField"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuantumField", "[", 
  RowBox[{"B", ",", 
   RowBox[{"{", "\[Mu]", "}"}]}], "]"}]], "Input",
 CellTags->"QuantumField",
 CellLabel->"In[1345]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["B", "\[Mu]"], TraditionalForm]], "Output",
 CellTags->"QuantumField",
 CellLabel->"Out[1345]="]
}, Open  ]],

Cell["Color indices should be put after the Lorentz ones.", "Text",
 CellTags->"QuantumField"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuantumField", "[", 
  RowBox[{"GaugeField", ",", 
   RowBox[{"{", "\[Mu]", "}"}], ",", 
   RowBox[{"{", "a", "}"}]}], "]"}]], "Input",
 CellTags->"QuantumField",
 CellLabel->"In[1346]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox[
   FormBox["A",
    TraditionalForm], 
   FormBox[
    FormBox["\[Mu]",
     TraditionalForm],
    TraditionalForm], 
   FormBox[
    FormBox["a",
     TraditionalForm],
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"QuantumField",
 CellLabel->"Out[1346]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"QuantumField",
 CellLabel->"In[1347]:="],

Cell[BoxData[
 RowBox[{"QuantumField", "[", 
  RowBox[{"GaugeField", ",", 
   RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
   RowBox[{"SUNIndex", "[", "a", "]"}]}], "]"}]], "Output",
 CellTags->"QuantumField",
 CellLabel->"Out[1347]//StandardForm="]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["A", "\[CapitalDelta]", "a"], TraditionalForm]]],
 " is a short form for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[CapitalDelta]", "^", "\[Mu]"}], " ", 
    RowBox[{
     SubsuperscriptBox["A", "\[Mu]", "a"], "."}]}], TraditionalForm]]],
 " "
}], "Text",
 CellTags->"QuantumField"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuantumField", "[", 
  RowBox[{"A", ",", 
   RowBox[{"{", "OPEDelta", "}"}], ",", 
   RowBox[{"{", "a", "}"}]}], "]"}]], "Input",
 CellTags->"QuantumField",
 CellLabel->"In[1348]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox["A", 
   FormBox["\[CapitalDelta]",
    TraditionalForm], 
   FormBox[
    FormBox["a",
     TraditionalForm],
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"QuantumField",
 CellLabel->"Out[1348]="]
}, Open  ]],

Cell["\<\
 The first list of indices is usually interpreted as type LorentzIndex, \
except for OPEDelta, which gets converted to type Momentum. \
\>", "Text",
 CellTags->"QuantumField"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"QuantumField", "[", 
   RowBox[{"A", ",", 
    RowBox[{"{", "OPEDelta", "}"}], ",", 
    RowBox[{"{", "a", "}"}]}], "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"QuantumField",
 CellLabel->"In[1349]:="],

Cell[BoxData[
 RowBox[{"QuantumField", "[", 
  RowBox[{"A", ",", 
   RowBox[{"Momentum", "[", "OPEDelta", "]"}], ",", 
   RowBox[{"SUNIndex", "[", "a", "]"}]}], "]"}]], "Output",
 CellTags->"QuantumField",
 CellLabel->"Out[1349]//StandardForm="]
}, Open  ]],

Cell["Derivatives of fields are denoted as follows.", "Text",
 CellTags->"QuantumField"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuantumField", "[", 
  RowBox[{
   RowBox[{"PartialD", "[", "\[Mu]", "]"}], ",", "A", ",", 
   RowBox[{"{", "\[Mu]", "}"}]}], "]"}]], "Input",
 CellTags->"QuantumField",
 CellLabel->"In[1350]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[PartialD]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], 
   SubsuperscriptBox["A", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], "\[Null]"]}], TraditionalForm]], "Output",
 CellTags->"QuantumField",
 CellLabel->"Out[1350]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuantumField", "[", 
  RowBox[{
   RowBox[{"PartialD", "[", "OPEDelta", "]"}], ",", "S"}], "]"}]], "Input",
 CellTags->"QuantumField",
 CellLabel->"In[1351]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[PartialD]", 
    FormBox["\[CapitalDelta]",
     TraditionalForm]], 
   SubsuperscriptBox["S", "\[Null]", "\[Null]"]}], TraditionalForm]], "Output",\

 CellTags->"QuantumField",
 CellLabel->"Out[1351]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuantumField", "[", 
  RowBox[{
   RowBox[{"PartialD", "[", "OPEDelta", "]"}], ",", "A", ",", 
   RowBox[{"{", "OPEDelta", "}"}], ",", 
   RowBox[{"{", "a", "}"}]}], "]"}]], "Input",
 CellTags->"QuantumField",
 CellLabel->"In[1352]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    SubscriptBox["\[PartialD]", 
     FormBox["\[CapitalDelta]",
      TraditionalForm]],
    TraditionalForm], 
   SubsuperscriptBox["A", 
    FormBox["\[CapitalDelta]",
     TraditionalForm], 
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"QuantumField",
 CellLabel->"Out[1352]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuantumField", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PartialD", "[", "OPEDelta", "]"}], "^", "OPEm"}], ",", "A", ",", 
   
   RowBox[{"{", "OPEDelta", "}"}], ",", 
   RowBox[{"{", "a", "}"}]}], "]"}]], "Input",
 CellTags->"QuantumField",
 CellLabel->"In[1353]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubsuperscriptBox["\[PartialD]", 
    FormBox["\[CapitalDelta]",
     TraditionalForm], 
    FormBox["m",
     TraditionalForm]], 
   SubsuperscriptBox["A", 
    FormBox["\[CapitalDelta]",
     TraditionalForm], 
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"QuantumField",
 CellLabel->"Out[1353]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"QuantumField", "[", 
   RowBox[{"QuantumField", "[", "A", "]"}], "]"}], " ", "===", " ", 
  RowBox[{"QuantumField", "[", "A", "]"}]}]], "Input",
 CellTags->"QuantumField",
 CellLabel->"In[1354]:="],

Cell[BoxData[
 FormBox["True", TraditionalForm]], "Output",
 CellTags->"QuantumField",
 CellLabel->"Out[1354]="]
}, Open  ]]
}, Open  ]],

Cell["QuarkField", "ObjectName",
 CellTags->"QuarkField"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"QuarkField"],

Cell["\<\
QuarkField is the name of a fermionic field. QuarkField is just a name with \
no functional properties. Only typesetting rules are attached.\
\>", "Text",
 CellTags->"QuarkField"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["AntiQuarkField",
  BaseStyle->"AddOnsLink",
  ButtonData:>"AntiQuarkField",
  ButtonNote->"AntiQuarkField"],
 ", ",
 ButtonBox["QuantumField",
  BaseStyle->"AddOnsLink",
  ButtonData:>"QuantumField",
  ButtonNote->"QuantumField"],
 "."
}], "Text",
 CellTags->"QuarkField"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"QuarkField"],

Cell[CellGroupData[{

Cell[BoxData["QuarkField"], "Input",
 CellTags->"QuarkField",
 CellLabel->"In[1355]:="],

Cell[BoxData[
 FormBox["\[Psi]", TraditionalForm]], "Output",
 CellTags->"QuarkField",
 CellLabel->"Out[1355]="]
}, Open  ]]
}, Open  ]],

Cell["QuarkGluonVertex", "ObjectName",
 CellTags->"QuarkGluonVertex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"QuarkGluonVertex"],

Cell[TextData[{
 "QuarkGluonVertex[",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Mu]", ",", " ", 
    StyleBox["a",
     FontSlant->"Plain"]}], TraditionalForm]]],
 "] gives the Feynman rule for the quark-gluon vertex. "
}], "Text",
 CellTags->"QuarkGluonVertex"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "QuarkGluonVertex", "]"}]], "Input",
 CellTags->"QuarkGluonVertex",
 CellLabel->"In[1356]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"CounterTerm", "\[Rule]", "False"}], ",", 
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Explicit", "\[Rule]", "False"}], ",", 
    RowBox[{"\[CapitalOmega]", "\[Rule]", "False"}], ",", 
    RowBox[{"Polarization", "\[Rule]", "0"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"QuarkGluonVertex",
 CellLabel->"Out[1356]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["GluonVertex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonVertex",
  ButtonNote->"GluonVertex"],
 "."
}], "Text",
 CellTags->"QuarkGluonVertex"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"QuarkGluonVertex"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuarkGluonVertex", "[", 
  RowBox[{"\[Mu]", ",", "a"}], "]"}]], "Input",
 CellTags->"QuarkGluonVertex",
 CellLabel->"In[1357]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox["Q", "a", "\[Mu]"], TraditionalForm]], "Output",
 CellTags->"QuarkGluonVertex",
 CellLabel->"Out[1357]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuarkGluonVertex", "[", 
  RowBox[{"\[Mu]", ",", "a", ",", 
   RowBox[{"CounterTerm", " ", "\[Rule]", "1"}]}], "]"}]], "Input",
 CellTags->"QuarkGluonVertex",
 CellLabel->"In[1358]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox["Q", "a", "\[Mu]"], TraditionalForm]], "Output",
 CellTags->"QuarkGluonVertex",
 CellLabel->"Out[1358]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuarkGluonVertex", "[", 
  RowBox[{"\[Mu]", ",", "a", ",", 
   RowBox[{"CounterTerm", " ", "\[Rule]", "2"}]}], "]"}]], "Input",
 CellTags->"QuarkGluonVertex",
 CellLabel->"In[1359]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox["Q", "a", "\[Mu]"], TraditionalForm]], "Output",
 CellTags->"QuarkGluonVertex",
 CellLabel->"Out[1359]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuarkGluonVertex", "[", 
  RowBox[{"\[Mu]", ",", "a", ",", 
   RowBox[{"CounterTerm", " ", "\[Rule]", "3"}]}], "]"}]], "Input",
 CellTags->"QuarkGluonVertex",
 CellLabel->"In[1360]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox["Q", "a", "\[Mu]"], TraditionalForm]], "Output",
 CellTags->"QuarkGluonVertex",
 CellLabel->"Out[1360]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuarkGluonVertex", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", "q", "}"}], ",", 
   RowBox[{"{", "k", "}"}], ",", 
   RowBox[{"OPE", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"QuarkGluonVertex",
 CellLabel->"In[1361]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"QuarkGluonVertex", "(", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
    RowBox[{"{", "q", "}"}], ",", 
    RowBox[{"{", "k", "}"}], ",", 
    RowBox[{"\[CapitalOmega]", "\[Rule]", "True"}]}], ")"}], 
  TraditionalForm]], "Output",
 CellTags->"QuarkGluonVertex",
 CellLabel->"Out[1361]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuarkGluonVertex", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", "q", "}"}], ",", 
   RowBox[{"{", "k", "}"}], ",", 
   RowBox[{"OPE", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"QuarkGluonVertex",
 CellLabel->"In[1362]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"QuarkGluonVertex", "(", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
    RowBox[{"{", "q", "}"}], ",", 
    RowBox[{"{", "k", "}"}], ",", 
    RowBox[{"\[CapitalOmega]", "\[Rule]", "False"}]}], ")"}], 
  TraditionalForm]], "Output",
 CellTags->"QuarkGluonVertex",
 CellLabel->"Out[1362]="]
}, Open  ]]
}, Open  ]],

Cell["QuarkMass", "ObjectName",
 CellTags->"QuarkMass"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"QuarkMass"],

Cell["QuarkMass is an option of Amplitude.", "Text",
 CellTags->"QuarkMass"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Amplitude",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Amplitude",
  ButtonNote->"Amplitude"],
 "."
}], "Text",
 CellTags->"QuarkMass"]
}, Open  ]],

Cell["QuarkPropagator", "ObjectName",
 CellTags->"QuarkPropagator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"QuarkPropagator"],

Cell["\<\
QuarkPropagator[p] is the massless quark propagator. QuarkPropagator[{p,m}] \
or gives the quark propagator with mass m.\
\>", "Text",
 CellTags->"QuarkPropagator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "QuarkPropagator", "]"}]], "Input",
 CellTags->"QuarkPropagator",
 CellLabel->"In[1363]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"CounterTerm", "\[Rule]", "False"}], ",", 
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Explicit", "\[Rule]", "False"}], ",", 
    RowBox[{"Loop", "\[Rule]", "0"}], ",", 
    RowBox[{"\[CapitalOmega]", "\[Rule]", "False"}], ",", 
    RowBox[{"Polarization", "\[Rule]", "0"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"QuarkPropagator",
 CellLabel->"Out[1363]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["GluonPropagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonPropagator",
  ButtonNote->"GluonPropagator"],
 ", ",
 ButtonBox["QuarkGluonVertex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"QuarkGluonVertex",
  ButtonNote->"QuarkGluonVertex"],
 "."
}], "Text",
 CellTags->"QuarkPropagator"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"QuarkPropagator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuarkPropagator", "[", "p", "]"}]], "Input",
 CellTags->"QuarkPropagator",
 CellLabel->"In[1364]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[CapitalPi]", "q"], "(", "p", ")"}], 
  TraditionalForm]], "Output",
 CellTags->"QuarkPropagator",
 CellLabel->"Out[1364]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuarkPropagator", "[", 
  RowBox[{"{", 
   RowBox[{"p", ",", "m"}], "}"}], "]"}]], "Input",
 CellTags->"QuarkPropagator",
 CellLabel->"In[1365]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[CapitalPi]", "q"], "(", "p", ")"}], 
  TraditionalForm]], "Output",
 CellTags->"QuarkPropagator",
 CellLabel->"Out[1365]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QuarkPropagator", "[", 
  RowBox[{"p", ",", "1", ",", "2"}], "]"}]], "Input",
 CellTags->"QuarkPropagator",
 CellLabel->"In[1366]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[CapitalPi]", "q"], "(", "p", ")"}], 
  TraditionalForm]], "Output",
 CellTags->"QuarkPropagator",
 CellLabel->"Out[1366]="]
}, Open  ]]
}, Open  ]],

Cell["ReduceGamma", "ObjectName",
 CellTags->"ReduceGamma"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ReduceGamma"],

Cell["\<\
ReduceGamma is an option of OneLoop. If set to True all DiracMatrix[6] and \
DiracMatrix[7] (i.e. all ChiralityProjector) are reduced to Gamma5.\
\>", "Text",
 CellTags->"ReduceGamma"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OneLoop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoop",
  ButtonNote->"OneLoop"],
 "."
}], "Text",
 CellTags->"ReduceGamma"]
}, Open  ]],

Cell["ReduceToScalars", "ObjectName",
 CellTags->"ReduceToScalars"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ReduceToScalars"],

Cell["\<\
ReduceToScalars is an option for OneLoop  and OneLoopSum that specifies \
whether the result will be reduced to scalar A0, B0, C0 and D0 scalar \
integrals.\
\>", "Text",
 CellTags->"ReduceToScalars"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OneLoop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoop",
  ButtonNote->"OneLoop"],
 ", ",
 ButtonBox["OneLoopSum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoopSum",
  ButtonNote->"OneLoopSum"],
 "."
}], "Text",
 CellTags->"ReduceToScalars"]
}, Open  ]],

Cell["Rename", "ObjectName",
 CellTags->"Rename"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Rename"],

Cell["\<\
Rename is an option for Contract. If set to True, dummy indices in Eps are \
renamed, using $MU[i].\
\>", "Text",
 CellTags->"Rename"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Contract",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Contract",
  ButtonNote->"Contract"],
 "."
}], "Text",
 CellTags->"Rename"]
}, Open  ]],

Cell["RHI  ***unfinished***", "ObjectName",
 CellTags->"RHI"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"RHI"],

Cell["\<\
RHI[{v,w,x,y,z},{a,b,c,d,e,f,g}, {al,be,ga,de,ep}]. (sn \[Rule] 1, mark1 \
\[Rule] 1, mark2 \[Rule] 1, mark3 \[Rule] 1, eph \[Rule] Epsilon/2 ). The \
exponents of the numerator scalar product are (dl = OPEDelta): 
v: k1.k1, w: k2.k2,  x: p.k1, y: p.k2, z: k1.k2. 
a: dl.k1, b: dl.k2,  c: dl.(p-k1), d: dl.(p-k2), e: dl.(k1-k2), f: \
dl.(p+k1-k2), g: dl.(p-k1-k2) 
RHI[any___,{a,b,c,d,e,0,0}, {al,be,ga,de,ep}] simplifies to  RHI[any, \
{a,b,c,d,e}, {al,be,ga,de,ep}]; 
RHI[{0,0,0,0,0},{a,b,c,d,e}, {al,be,ga,de,ep}] simplifies to  \
RHI[{a,b,c,d,e}, {al,be,ga,de,ep}].\
\>", "Text",
 CellTags->"RHI"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["RHI2FC",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RHI2FC",
  ButtonNote->"RHI2FC"],
 "."
}], "Text",
 CellTags->"RHI"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"RHI"],

Cell[BoxData[""], "Input",
 CellTags->"RHI",
 CellLabel->"In[1367]:="]
}, Open  ]],

Cell["RHI2FC  ***unfinished***", "ObjectName",
 CellTags->"RHI2FC"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"RHI2FC"],

Cell["\<\
RHI[{v,w,x,y,z},{a,b,c,d,e,f,g}, {al,be,ga,de,ep}]. (sn \[Rule] 1, mark1 \
\[Rule] 1, mark2 \[Rule] 1, mark3 \[Rule] 1, eph \[Rule] Epsilon/2 ). The \
exponents of the numerator scalar product are (dl = OPEDelta): 
v: k1.k1, w: k2.k2,  x: p.k1, y: p.k2, z: k1.k2. 
a: dl.k1, b: dl.k2,  c: dl.(p-k1), d: dl.(p-k2), e: dl.(k1-k2), f: \
dl.(p+k1-k2), g: dl.(p-k1-k2) 
RHI[any___,{a,b,c,d,e,0,0}, {al,be,ga,de,ep}] simplifies to  RHI[any, \
{a,b,c,d,e}, {al,be,ga,de,ep}]; 
RHI[{0,0,0,0,0},{a,b,c,d,e}, {al,be,ga,de,ep}] simplifies to  \
RHI[{a,b,c,d,e}, {al,be,ga,de,ep}].\
\>", "Text",
 CellTags->"RHI2FC"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["RHI2FC",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RHI2FC",
  ButtonNote->"RHI2FC"],
 "."
}], "Text",
 CellTags->"RHI2FC"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"RHI2FC"],

Cell[BoxData[""], "Input",
 CellTags->"RHI2FC",
 CellLabel->"In[1368]:="]
}, Open  ]],

Cell["RHM  ***unfinished***", "ObjectName",
 CellTags->"RHM"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"RHM"],

Cell["RHM[] is like RHI[], gives Gamma functions.", "Text",
 CellTags->"RHM"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["RHI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RHI",
  ButtonNote->"RHI"],
 "."
}], "Text",
 CellTags->"RHM"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"RHM"],

Cell[BoxData[""], "Input",
 CellTags->"RHM",
 CellLabel->"In[1369]:="]
}, Open  ]],

Cell["RHO  ***unfinished***", "ObjectName",
 CellTags->"RHO"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"RHO"],

Cell["\<\
RHO[i] with i from 1 to 4 is an abbreviation for the 4 operators (eq. \
(3.2.17) -- (3.2.20)) defined in R.Hambergs thesis. The Lorentz indices are \
suppressed. The explicit expressions may be recovered by RHO[i, mu, nu, p].\
\>", "Text",
 CellTags->"RHO"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["RHI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RHI",
  ButtonNote->"RHI"],
 "."
}], "Text",
 CellTags->"RHO"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"RHO"],

Cell[BoxData[""], "Input",
 CellTags->"RHO",
 CellLabel->"In[1370]:="]
}, Open  ]],

Cell["RHP  ", "ObjectName",
 CellTags->"RHP"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"RHP"],

Cell["\<\
RHP[i, mu, nu, p] with i from 1 to 4 gives the projectors for RHO[i]. RHP[mu, \
nu, p] gives Sum[RHP[i,mu, nu, p] RHO[i], {i, 4}] collected with respect to \
mu and nu. See the thesis of Roelof Hamberg (but correcting a misprint).\
\>", "Text",
 CellTags->"RHP"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["RHO",
  BaseStyle->"AddOnsLink",
  ButtonData:>"RHO",
  ButtonNote->"RHO"],
 "."
}], "Text",
 CellTags->"RHP"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"RHP"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RHP", "[", 
  RowBox[{"1", ",", "\[Mu]", ",", "\[Nu]", ",", "p"}], "]"}]], "Input",
 CellLabel->"In[1371]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", "\[Nu]"}]], 
    RowBox[{"D", "-", "2"}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox["\[CapitalDelta]",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["\[CapitalDelta]",
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]]}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "-", "D"}], ")"}], " ", 
     RowBox[{
      FormBox["\[CapitalDelta]",
       TraditionalForm], "\[CenterDot]", 
      FormBox["p",
       TraditionalForm]}]}]]}], TraditionalForm]], "Output",
 CellLabel->"Out[1371]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RHP", "[", 
  RowBox[{"2", ",", "\[Mu]", ",", "\[Nu]", ",", "p"}], "]"}]], "Input",
 CellLabel->"In[1372]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]]}], 
   SuperscriptBox[
    FormBox[
     RowBox[{
      FormBox["\[CapitalDelta]",
       TraditionalForm], "\[CenterDot]", 
      FormBox["p",
       TraditionalForm]}],
     TraditionalForm], "2"]], TraditionalForm]], "Output",
 CellLabel->"Out[1372]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RHP", "[", 
  RowBox[{"3", ",", "\[Mu]", ",", "\[Nu]", ",", "p"}], "]"}]], "Input",
 CellLabel->"In[1373]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]]}]}], 
    RowBox[{
     FormBox["\[CapitalDelta]",
      TraditionalForm], "\[CenterDot]", 
     FormBox["p",
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellLabel->"Out[1373]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RHP", "[", 
  RowBox[{"4", ",", "\[Mu]", ",", "\[Nu]", ",", "p"}], "]"}]], "Input",
 CellLabel->"In[1374]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]}]], TraditionalForm]], "Output",
 CellLabel->"Out[1374]="]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellTags->"RHP",
 CellLabel->"In[1375]:="]
}, Open  ]],

Cell["RTL  ***unfinished***", "ObjectName",
 CellTags->"RTL"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"RTL"],

Cell["\<\
RTL[exp] inserts the list of known TLI integrals into exp, substitutes D\
\[RightArrow]4+Epsilon and expands around Epsilon up to the finite part.\
\>", "Text",
 CellTags->"RTL"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["TLI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TLI",
  ButtonNote->"TLI"],
 ", ",
 ButtonBox["Epsilon",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Epsilon",
  ButtonNote->"Epsilon"],
 "."
}], "Text",
 CellTags->"RTL"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"RTL"],

Cell[BoxData[""], "Input",
 CellTags->"RTL",
 CellLabel->"In[1376]:="]
}, Open  ]],

Cell["RightPartialD", "ObjectName",
 CellTags->"RightPartialD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"RightPartialD"],

Cell[TextData[{
 "RightPartialD[",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]]],
 "] denotes ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[PartialD]", "\[Mu]"], TraditionalForm]]],
 ", acting to the right."
}], "Text",
 CellTags->"RightPartialD"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["ExpandPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExpandPartialD",
  ButtonNote->"ExpandPartialD"],
 ", ",
 ButtonBox["PartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PartialD",
  ButtonNote->"PartialD"],
 ", ",
 ButtonBox["LeftPartialD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LeftPartialD",
  ButtonNote->"LeftPartialD"],
 "."
}], "Text",
 CellTags->"RightPartialD"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"RightPartialD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RightPartialD", "[", "\[Mu]", "]"}]], "Input",
 CellTags->"RightPartialD",
 CellLabel->"In[1377]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox[
   OverscriptBox["\[PartialD]", "\[RightArrow]"], 
   FormBox[
    FormBox["\[Mu]",
     TraditionalForm],
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"RightPartialD",
 CellLabel->"Out[1377]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RightPartialD", "[", "\[Mu]", "]"}], ".", 
  RowBox[{"QuantumField", "[", 
   RowBox[{"A", ",", 
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}]}]], "Input",
 CellTags->"RightPartialD",
 CellLabel->"In[1378]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox[
    OverscriptBox["\[PartialD]", "\[RightArrow]"], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SubscriptBox["A", "\[Mu]"]}], TraditionalForm]], "Output",
 CellTags->"RightPartialD",
 CellLabel->"Out[1378]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandPartialD", "[", "%", "]"}]], "Input",
 CellTags->"RightPartialD",
 CellLabel->"In[1379]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[PartialD]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], 
   SubsuperscriptBox["A", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], "\[Null]"]}], TraditionalForm]], "Output",
 CellTags->"RightPartialD",
 CellLabel->"Out[1379]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"RightPartialD",
 CellLabel->"In[1380]:="],

Cell[BoxData[
 RowBox[{"QuantumField", "[", 
  RowBox[{
   RowBox[{"PartialD", "[", 
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}], ",", "A", ",", 
   RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}]}], "]"}]], "Output",
 CellTags->"RightPartialD",
 CellLabel->"Out[1380]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RightPartialD", "[", "\[Mu]", "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"RightPartialD",
 CellLabel->"In[1381]:="],

Cell[BoxData[
 RowBox[{"RightPartialD", "[", 
  RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], "]"}]], "Output",
 CellTags->"RightPartialD",
 CellLabel->"Out[1381]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["RussianTrick", "ObjectName",
 CellTags->"RussianTrick"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"RussianTrick"],

Cell["\<\
RussianTrick[exp, k, {q1,q2,p}] (=RussianTrick[exp,p,p,{q1,q2,p}]) does the \
integration by parts where p is the external momentum. RussianTrick[exp, k,l, \
{q1,q2,p}] (=RussianTrick[exp,k,l]) does integration by parts where l is the \
momentum to be differentiated.\
\>", "Text",
 CellTags->"RussianTrick"],

Cell["The result is an expression which is vanishing.", "Text",
 CellTags->"RussianTrick"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FourDivergence",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FourDivergence",
  ButtonNote->"FourDivergence"],
 ", ",
 ButtonBox["FourLaplacian",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FourLaplacian",
  ButtonNote->"FourLaplacian"],
 "."
}], "Text",
 CellTags->"RussianTrick"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"RussianTrick"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{"RHI", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"OPEm", ",", "0", ",", " ", "0", ",", "0", ",", " ", "0"}], 
     "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
     "1", ",", " ", "1", ",", " ", "1", ",", " ", "1", ",", " ", "1"}], 
     "}"}]}], "]"}]}]], "Input",
 CellTags->"RussianTrick",
 CellLabel->"In[1382]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox[
   StyleBox["T",
    FontFamily->"Times",
    FontWeight->"Bold"], 
   StyleBox[
    RowBox[{"1", "1", "1", "1", "1"}],
    FontColor->RGBColor[0, 0, 1]], 
   RowBox[{
    FormBox["m",
     TraditionalForm], 
    FormBox["0",
     TraditionalForm], 
    FormBox["0",
     TraditionalForm], 
    FormBox["0",
     TraditionalForm], 
    FormBox["0",
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"RussianTrick",
 CellLabel->"Out[1382]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "//", "RHI2FC"}]], "Input",
 CellTags->"RussianTrick",
 CellLabel->"In[1383]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FormBox["\[CapitalDelta]",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q1",
       TraditionalForm]}], ")"}], "m"], 
   RowBox[{
    SuperscriptBox["q1", "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q1", "-", "p"}], ")"}], "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q1", "-", "q2"}], ")"}], "2"], ".", 
    SuperscriptBox["q2", "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q2", "-", "p"}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellTags->"RussianTrick",
 CellLabel->"Out[1383]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RussianTrick", "[", 
  RowBox[{
   RowBox[{"%", "//", "RHI2FC"}], ",", "q2"}], "]"}]], "Input",
 CellTags->"RussianTrick",
 CellLabel->"In[1384]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "4"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q1",
         TraditionalForm]}], ")"}], "m"]}], 
    RowBox[{
     SuperscriptBox["q1", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q1", "-", "p"}], ")"}], "2"], ".", 
     SuperscriptBox["q2", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q2", "-", "p"}], ")"}], "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q2", "-", "q1"}], ")"}], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q1",
         TraditionalForm]}], ")"}], "m"]}], 
    RowBox[{
     SuperscriptBox["q1", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q1", "-", "p"}], ")"}], "2"], ".", 
     SuperscriptBox["q2", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q2", "-", "p"}], ")"}], "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q2", "-", "p"}], ")"}], "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q2", "-", "q1"}], ")"}], "2"]}]], "-", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q1",
        TraditionalForm]}], ")"}], "m"], 
    RowBox[{
     SuperscriptBox["q1", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q1", "-", "p"}], ")"}], "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q2", "-", "p"}], ")"}], "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q2", "-", "p"}], ")"}], "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q2", "-", "q1"}], ")"}], "2"]}]], "-", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q1",
        TraditionalForm]}], ")"}], "m"], 
    RowBox[{
     SuperscriptBox["q1", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q1", "-", "p"}], ")"}], "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q2", "-", "p"}], ")"}], "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q2", "-", "q1"}], ")"}], "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q2", "-", "q1"}], ")"}], "2"]}]], "+", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q1",
        TraditionalForm]}], ")"}], "m"], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q1", "-", "p"}], ")"}], "2"], ".", 
     SuperscriptBox["q2", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q2", "-", "p"}], ")"}], "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q2", "-", "q1"}], ")"}], "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q2", "-", "q1"}], ")"}], "2"]}]]}], 
  TraditionalForm]], "Output",
 CellTags->"RussianTrick",
 CellLabel->"Out[1384]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FC2RHI", "[", "%", "]"}]], "Input",
 CellTags->"RussianTrick",
 CellLabel->"In[1385]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"D", "-", "4"}], ")"}], " ", 
    FormBox[
     SubsuperscriptBox[
      StyleBox["T",
       FontFamily->"Times",
       FontWeight->"Bold"], 
      StyleBox[
       RowBox[{"1", "1", "1", "1", "1"}],
       FontColor->RGBColor[0, 0, 1]], 
      RowBox[{
       FormBox["m",
        TraditionalForm], 
       FormBox["0",
        TraditionalForm], 
       FormBox["0",
        TraditionalForm], 
       FormBox["0",
        TraditionalForm], 
       FormBox["0",
        TraditionalForm]}]],
     TraditionalForm]}], "+", 
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    FormBox[
     SubsuperscriptBox[
      StyleBox["T",
       FontFamily->"Times",
       FontWeight->"Bold"], 
      StyleBox[
       RowBox[{"1", "1", "1", "2", "1"}],
       FontColor->RGBColor[0, 0, 1]], 
      RowBox[{
       FormBox["m",
        TraditionalForm], 
       FormBox["0",
        TraditionalForm], 
       FormBox["0",
        TraditionalForm], 
       FormBox["0",
        TraditionalForm], 
       FormBox["0",
        TraditionalForm]}]],
     TraditionalForm]}], "+", 
   FormBox[
    SubsuperscriptBox[
     StyleBox["T",
      FontFamily->"Times",
      FontWeight->"Bold"], 
     StyleBox[
      RowBox[{"0", "1", "1", "1", "2"}],
      FontColor->RGBColor[0, 0, 1]], 
     RowBox[{
      FormBox["m",
       TraditionalForm], 
      FormBox["0",
       TraditionalForm], 
      FormBox["0",
       TraditionalForm], 
      FormBox["0",
       TraditionalForm], 
      FormBox["0",
       TraditionalForm]}]],
    TraditionalForm], "-", 
   FormBox[
    SubsuperscriptBox[
     StyleBox["T",
      FontFamily->"Times",
      FontWeight->"Bold"], 
     StyleBox[
      RowBox[{"1", "0", "1", "1", "2"}],
      FontColor->RGBColor[0, 0, 1]], 
     RowBox[{
      FormBox["m",
       TraditionalForm], 
      FormBox["0",
       TraditionalForm], 
      FormBox["0",
       TraditionalForm], 
      FormBox["0",
       TraditionalForm], 
      FormBox["0",
       TraditionalForm]}]],
    TraditionalForm], "-", 
   FormBox[
    SubsuperscriptBox[
     StyleBox["T",
      FontFamily->"Times",
      FontWeight->"Bold"], 
     StyleBox[
      RowBox[{"1", "0", "1", "2", "1"}],
      FontColor->RGBColor[0, 0, 1]], 
     RowBox[{
      FormBox["m",
       TraditionalForm], 
      FormBox["0",
       TraditionalForm], 
      FormBox["0",
       TraditionalForm], 
      FormBox["0",
       TraditionalForm], 
      FormBox["0",
       TraditionalForm]}]],
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"RussianTrick",
 CellLabel->"Out[1385]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve2", "[", 
  RowBox[{"%", ",", "t"}], "]"}]], "Input",
 CellTags->"RussianTrick",
 CellLabel->"In[1386]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FormBox[
     SubsuperscriptBox[
      StyleBox["T",
       FontFamily->"Times",
       FontWeight->"Bold"], 
      StyleBox[
       RowBox[{"1", "1", "1", "1", "1"}],
       FontColor->RGBColor[0, 0, 1]], 
      RowBox[{
       FormBox["m",
        TraditionalForm], 
       FormBox["0",
        TraditionalForm], 
       FormBox["0",
        TraditionalForm], 
       FormBox["0",
        TraditionalForm], 
       FormBox["0",
        TraditionalForm]}]],
     TraditionalForm], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"], " ", 
       FormBox[
        SubsuperscriptBox[
         StyleBox["T",
          FontFamily->"Times",
          FontWeight->"Bold"], 
         StyleBox[
          RowBox[{"1", "1", "1", "2", "1"}],
          FontColor->RGBColor[0, 0, 1]], 
         RowBox[{
          FormBox["m",
           TraditionalForm], 
          FormBox["0",
           TraditionalForm], 
          FormBox["0",
           TraditionalForm], 
          FormBox["0",
           TraditionalForm], 
          FormBox["0",
           TraditionalForm]}]],
        TraditionalForm]}], "+", 
      FormBox[
       SubsuperscriptBox[
        StyleBox["T",
         FontFamily->"Times",
         FontWeight->"Bold"], 
        StyleBox[
         RowBox[{"0", "1", "1", "1", "2"}],
         FontColor->RGBColor[0, 0, 1]], 
        RowBox[{
         FormBox["m",
          TraditionalForm], 
         FormBox["0",
          TraditionalForm], 
         FormBox["0",
          TraditionalForm], 
         FormBox["0",
          TraditionalForm], 
         FormBox["0",
          TraditionalForm]}]],
       TraditionalForm], "-", 
      FormBox[
       SubsuperscriptBox[
        StyleBox["T",
         FontFamily->"Times",
         FontWeight->"Bold"], 
        StyleBox[
         RowBox[{"1", "0", "1", "1", "2"}],
         FontColor->RGBColor[0, 0, 1]], 
        RowBox[{
         FormBox["m",
          TraditionalForm], 
         FormBox["0",
          TraditionalForm], 
         FormBox["0",
          TraditionalForm], 
         FormBox["0",
          TraditionalForm], 
         FormBox["0",
          TraditionalForm]}]],
       TraditionalForm], "-", 
      FormBox[
       SubsuperscriptBox[
        StyleBox["T",
         FontFamily->"Times",
         FontWeight->"Bold"], 
        StyleBox[
         RowBox[{"1", "0", "1", "2", "1"}],
         FontColor->RGBColor[0, 0, 1]], 
        RowBox[{
         FormBox["m",
          TraditionalForm], 
         FormBox["0",
          TraditionalForm], 
         FormBox["0",
          TraditionalForm], 
         FormBox["0",
          TraditionalForm], 
         FormBox["0",
          TraditionalForm]}]],
       TraditionalForm]}], 
     RowBox[{"4", "-", "D"}]]}], "}"}], TraditionalForm]], "Output",
 CellTags->"RussianTrick",
 CellLabel->"Out[1386]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "t", "]"}]], "Input",
 CellTags->"RussianTrick",
 CellLabel->"In[1387]:="]
}, Open  ]],

Cell["ScalarGluonVertex", "ObjectName",
 CellTags->"ScalarGluonVertex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ScalarGluonVertex"],

Cell["\<\
ScalarGluonVertex[{p}, {q}, {mu,a}] or ScalarGluonVertex[ p,  q,  mu, a ] \
yields the scalar-scalar-gluon vertex (p and q are incoming momenta).
ScalarGluonVertex[{mu,a}, {nu,b}] yields the scalar-scalar-gluon-gluon vertex \
(p and q are incoming momenta).
The dimension  and the name of the coupling constant are determined by the \
options Dimension and CouplingConstant.\
\>", "Text",
 CellTags->"ScalarGluonVertex"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "ScalarGluonVertex", "]"}]], "Input",
 CellTags->"ScalarGluonVertex",
 CellLabel->"In[1388]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"ScalarGluonVertex",
 CellLabel->"Out[1388]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ScalarGluonVertex"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScalarGluonVertex", "[", 
  RowBox[{
   RowBox[{"{", "p", "}"}], ",", " ", 
   RowBox[{"{", "q", "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"mu", ",", " ", "a"}], "}"}]}], "]"}]], "Input",
 CellTags->"ScalarGluonVertex",
 CellLabel->"In[1389]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubscriptBox["T", 
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubscriptBox["g", "s"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     FormBox[
      RowBox[{"p", "-", "q"}],
      TraditionalForm], ")"}], 
    FormBox[
     FormBox["mu",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"ScalarGluonVertex",
 CellLabel->"Out[1389]="]
}, Open  ]]
}, Open  ]],

Cell["ScalarProduct", "ObjectName",
 CellTags->"ScalarProduct"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ScalarProduct"],

Cell[TextData[{
 "ScalarProduct[p, q] is the input for scalar product. ScalarProduct[p] is \
equivalent to ScalarProduct[p, p]. Expansion of sums of momenta in \
ScalarProduct is done with ExpandScalarProduct. Scalar product may be set, \
e.g., ScalarProduct[a, b] = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "^", "2"}], TraditionalForm]]],
 "; but a and b must not contain sums. Note that ScalarProduct[a, b] = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "^", "2"}], TraditionalForm]]],
 " actually sets also: Pair[Momentum[a, ___], Momentum[b, ___]] = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "^", "2"}], TraditionalForm]]],
 ". It is encouraged to always set ScalarProduct's ",
 StyleBox["before",
  FontWeight->"Bold"],
 " any calculation. This improves the performance of FeynCalc ."
}], "Text",
 CellTags->"ScalarProduct"],

Cell[TextData[{
 "See also: ",
 ButtonBox["Calc",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Calc",
  ButtonNote->"Calc"],
 ", ",
 ButtonBox["ClearScalarProducts",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ClearScalarProducts",
  ButtonNote->"ClearScalarProducts"],
 ", ",
 ButtonBox["ExpandScalarProduct",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExpandScalarProduct",
  ButtonNote->"ExpandScalarProduct"],
 ", ",
 ButtonBox["ScalarProductCancel",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ScalarProductCancel",
  ButtonNote->"ScalarProductCancel"],
 ", ",
 ButtonBox["Pair",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Pair",
  ButtonNote->"Pair"],
 ", ",
 ButtonBox["SP",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SP",
  ButtonNote->"SP"],
 ", ",
 ButtonBox["SPD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SPD",
  ButtonNote->"SPD"],
 "."
}], "Text",
 CellTags->"ScalarProduct"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ScalarProduct"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScalarProduct", "[", 
  RowBox[{"p", ",", "q"}], "]"}]], "Input",
 CellTags->"ScalarProduct",
 CellLabel->"In[1390]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["p",
    TraditionalForm], "\[CenterDot]", 
   FormBox["q",
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"ScalarProduct",
 CellLabel->"Out[1390]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScalarProduct", "[", 
  RowBox[{
   RowBox[{"p", "+", "q"}], ",", 
   RowBox[{"-", "q"}]}], "]"}]], "Input",
 CellTags->"ScalarProduct",
 CellLabel->"In[1391]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     FormBox["q",
      TraditionalForm], "\[CenterDot]", "(", 
     FormBox[
      RowBox[{"p", "+", "q"}],
      TraditionalForm], ")"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"ScalarProduct",
 CellLabel->"Out[1391]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScalarProduct", "[", 
  RowBox[{"p", ",", "p"}], "]"}]], "Input",
 CellTags->"ScalarProduct",
 CellLabel->"In[1392]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   FormBox["p",
    TraditionalForm], "2"], TraditionalForm]], "Output",
 CellTags->"ScalarProduct",
 CellLabel->"Out[1392]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScalarProduct", "[", "q", "]"}]], "Input",
 CellTags->"ScalarProduct",
 CellLabel->"In[1393]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox[
   FormBox["q",
    TraditionalForm], "2"], TraditionalForm]], "Output",
 CellTags->"ScalarProduct",
 CellLabel->"Out[1393]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ScalarProduct", "[", 
   RowBox[{"p", ",", "q"}], "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"ScalarProduct",
 CellLabel->"In[1394]:="],

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", "p", "]"}], ",", 
   RowBox[{"Momentum", "[", "q", "]"}]}], "]"}]], "Output",
 CellTags->"ScalarProduct",
 CellLabel->"Out[1394]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ScalarProduct", "[", 
   RowBox[{"p", ",", "q", ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}]}], "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"ScalarProduct",
 CellLabel->"In[1395]:="],

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", 
    RowBox[{"p", ",", "D"}], "]"}], ",", 
   RowBox[{"Momentum", "[", 
    RowBox[{"q", ",", "D"}], "]"}]}], "]"}]], "Output",
 CellTags->"ScalarProduct",
 CellLabel->"Out[1395]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ScalarProduct", "[", 
   RowBox[{
    SubscriptBox["p", "1"], ",", 
    SubscriptBox["p", "2"]}], "]"}], " ", "=", " ", 
  RowBox[{"s", "/", "2"}]}]], "Input",
 CellTags->"ScalarProduct",
 CellLabel->"In[1396]:="],

Cell[BoxData[
 FormBox[
  FractionBox["s", "2"], TraditionalForm]], "Output",
 CellTags->"ScalarProduct",
 CellLabel->"Out[1396]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandScalarProduct", "[", " ", 
  RowBox[{"ScalarProduct", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["p", "1"], "-", "q"}], ",", 
    RowBox[{
     SubscriptBox["p", "2"], "-", "k"}]}], "]"}], "]"}]], "Input",
 CellTags->"ScalarProduct",
 CellLabel->"In[1397]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FormBox["k",
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["p", "1"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FormBox["k",
     TraditionalForm], "\[CenterDot]", 
    FormBox["q",
     TraditionalForm]}], "-", 
   RowBox[{
    FormBox["q",
     TraditionalForm], "\[CenterDot]", 
    FormBox[
     SubscriptBox["p", "2"],
     TraditionalForm]}], "+", 
   FractionBox["s", "2"]}], TraditionalForm]], "Output",
 CellTags->"ScalarProduct",
 CellLabel->"Out[1397]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", " ", 
  RowBox[{"ScalarProduct", "[", 
   RowBox[{
    RowBox[{
     SubscriptBox["p", "1"], "-", "q"}], ",", 
    RowBox[{
     SubscriptBox["p", "2"], "-", "k"}]}], "]"}], "]"}]], "Input",
 CellTags->"ScalarProduct",
 CellLabel->"In[1398]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FormBox["k",
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["p", "1"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FormBox["k",
     TraditionalForm], "\[CenterDot]", 
    FormBox["q",
     TraditionalForm]}], "-", 
   RowBox[{
    FormBox["q",
     TraditionalForm], "\[CenterDot]", 
    FormBox[
     SubscriptBox["p", "2"],
     TraditionalForm]}], "+", 
   FractionBox["s", "2"]}], TraditionalForm]], "Output",
 CellTags->"ScalarProduct",
 CellLabel->"Out[1398]="]
}, Open  ]],

Cell[BoxData["ClearScalarProducts"], "Input",
 CellTags->"ScalarProduct",
 CellLabel->"In[1399]:="]
}, Open  ]],

Cell["ScalarProductCancel", "ObjectName",
 CellTags->"ScalarProductCancel"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ScalarProductCancel"],

Cell["\<\
ScalarProductCancel[exp, q1, q2, ...] cancels scalar products with \
propagators. ScalarProductCancel[exp] cancels simple cases.\
\>", "Text",
 CellTags->"ScalarProductCancel"],

Cell[CellGroupData[{

Cell[BoxData["SPC"], "Input",
 CellTags->"ScalarProductCancel",
 CellLabel->"In[1400]:="],

Cell[BoxData[
 FormBox["ScalarProductCancel", TraditionalForm]], "Output",
 CellTags->"ScalarProductCancel",
 CellLabel->"Out[1400]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScalarProductCancel", "//", "Options"}]], "Input",
 CellTags->"ScalarProductCancel",
 CellLabel->"In[1401]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ChangeDimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Collecting", "\[Rule]", "True"}], ",", 
    RowBox[{"FeynAmpDenominatorSimplify", "\[Rule]", "False"}], ",", 
    RowBox[{"FeynAmpDenominatorCombine", "\[Rule]", "True"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"ScalarProductCancel",
 CellLabel->"Out[1401]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "SPC"}]], "Input",
 CellTags->"ScalarProductCancel",
 CellLabel->"In[1402]:="],

Cell[BoxData[
 StyleBox["\<\"SPC is an abbreviation for ScalarProductCancel.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellTags->{"Info3522766000-2743550", "ScalarProductCancel"}]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 ButtonBox["Calc",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Calc",
  ButtonNote->"Calc"],
 ", ",
 ButtonBox["ClearScalarProducts",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ClearScalarProducts",
  ButtonNote->"ClearScalarProducts"],
 ", ",
 ButtonBox["ExpandScalarProduct",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExpandScalarProduct",
  ButtonNote->"ExpandScalarProduct"],
 ", ",
 ButtonBox["Pair",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Pair",
  ButtonNote->"Pair"],
 ", ",
 ButtonBox["SP",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SP",
  ButtonNote->"SP"],
 ", ",
 ButtonBox["SPD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SPD",
  ButtonNote->"SPD"],
 "."
}], "Text",
 CellTags->"ScalarProductCancel"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ScalarProductCancel"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynAmpDenominatorSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynAmpDenominatorSimplify",
  ButtonNote->"FeynAmpDenominatorSimplify"],
 "."
}], "Text",
 CellTags->"ScalarProductCancel"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"SPD", "[", 
     RowBox[{"q", ",", "p"}], "]"}], " ", 
    RowBox[{"FAD", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q", ",", "m"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"q", "-", "p"}], ",", "0"}], "}"}]}], "]"}]}], "//", 
   "FCI"}]}]], "Input",
 CellTags->"ScalarProductCancel",
 CellLabel->"In[1403]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    FormBox["p",
     TraditionalForm], "\[CenterDot]", 
    FormBox["q",
     TraditionalForm]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["q", "2"], "-", 
      SuperscriptBox["m", "2"]}], ")"}], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q", "-", "p"}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellTags->"ScalarProductCancel",
 CellLabel->"Out[1403]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ScalarProductCancel", "[", 
  RowBox[{"t1", ",", "q"}], "]"}]], "Input",
 CellTags->"ScalarProductCancel",
 CellLabel->"In[1404]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     FractionBox[
      SuperscriptBox["m", "2"], "2"], "+", 
     FractionBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"], "2"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q", "2"], "-", 
       SuperscriptBox["m", "2"]}], ")"}], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "-", 
   FractionBox["1", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q", "2"], "-", 
       SuperscriptBox["m", "2"]}], ")"}]}]], "+", 
   FractionBox["1", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q", "-", "p"}], ")"}], "2"]}]]}], TraditionalForm]], "Output",\

 CellTags->"ScalarProductCancel",
 CellLabel->"Out[1404]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FeynAmpDenominatorSimplify", "[", 
  RowBox[{"%", ",", "q"}], "]"}]], "Input",
 CellTags->"ScalarProductCancel",
 CellLabel->"In[1405]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     FractionBox[
      SuperscriptBox["m", "2"], "2"], "+", 
     FractionBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"], "2"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q", "2"], "-", 
       SuperscriptBox["m", "2"]}], ")"}], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "-", 
   FractionBox["1", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q", "2"], "-", 
       SuperscriptBox["m", "2"]}], ")"}]}]]}], TraditionalForm]], "Output",
 CellTags->"ScalarProductCancel",
 CellLabel->"Out[1405]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SPC", "[", 
  RowBox[{"t1", ",", "q", ",", 
   RowBox[{"FDS", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"ScalarProductCancel",
 CellLabel->"In[1406]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     FractionBox[
      SuperscriptBox["m", "2"], "2"], "+", 
     FractionBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"], "2"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q", "2"], "-", 
       SuperscriptBox["m", "2"]}], ")"}], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q", "-", "p"}], ")"}], "2"]}]], "-", 
   FractionBox["1", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q", "2"], "-", 
       SuperscriptBox["m", "2"]}], ")"}]}]]}], TraditionalForm]], "Output",
 CellTags->"ScalarProductCancel",
 CellLabel->"Out[1406]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"SPD", "[", 
     RowBox[{"q2", ",", "p"}], "]"}], 
    RowBox[{"SPD", "[", 
     RowBox[{"q1", ",", "p"}], "]"}], " ", 
    RowBox[{"FAD", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q1", ",", "m"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q2", ",", "m"}], "}"}], ",", 
      RowBox[{"q1", "-", "p"}], ",", 
      RowBox[{"q2", "-", "p"}], ",", 
      RowBox[{"q2", "-", "q1"}]}], "]"}]}], "//", "FCI"}]}]], "Input",
 CellTags->"ScalarProductCancel",
 CellLabel->"In[1407]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q1",
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q2",
      TraditionalForm]}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["q1", "2"], "-", 
      SuperscriptBox["m", "2"]}], ")"}], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q1", "-", "p"}], ")"}], "2"], ".", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["m", "2"]}], ")"}], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q2", "-", "p"}], ")"}], "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q2", "-", "q1"}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellTags->"ScalarProductCancel",
 CellLabel->"Out[1407]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SPC", "[", 
  RowBox[{"t2", ",", "q1", ",", "q2", ",", 
   RowBox[{"FDS", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"ScalarProductCancel",
 CellLabel->"In[1408]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       SuperscriptBox["m", "2"], "2"]}], "-", 
     FractionBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"], "2"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q1", "2"], "-", 
       SuperscriptBox["m", "2"]}], ")"}], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q1", "-", "p"}], ")"}], "2"], ".", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q2", "2"], "-", 
       SuperscriptBox["m", "2"]}], ")"}], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q2", "-", "q1"}], ")"}], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     FractionBox[
      SuperscriptBox["m", "2"], "2"], "+", 
     FractionBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"], "2"]}], 
    RowBox[{
     SuperscriptBox["q1", "2"], ".", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"q1", "-", "p"}], ")"}], "2"], "-", 
       SuperscriptBox["m", "2"]}], ")"}], ".", 
     SuperscriptBox["q2", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q2", "-", "q1"}], ")"}], "2"]}]], "-", 
   FractionBox["1", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"q1", "-", "p"}], ")"}], "2"], ".", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["q2", "2"], "-", 
        SuperscriptBox["m", "2"]}], ")"}], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"q2", "-", "q1"}], ")"}], "2"]}]}]], "+", 
   FractionBox["1", 
    RowBox[{"4", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["q1", "2"], "-", 
        SuperscriptBox["m", "2"]}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["q2", "2"], "-", 
        SuperscriptBox["m", "2"]}], ")"}], ".", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"q2", "-", "q1"}], ")"}], "2"]}]}]], "+", 
   FractionBox[
    RowBox[{
     FractionBox[
      SuperscriptBox["m", "4"], "4"], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["m", "2"], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]}], "2"], "+", 
     FractionBox[
      SuperscriptBox[
       FormBox[
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"],
        TraditionalForm], "2"], "4"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q1", "2"], "-", 
       SuperscriptBox["m", "2"]}], ")"}], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q1", "-", "p"}], ")"}], "2"], ".", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["q2", "2"], "-", 
       SuperscriptBox["m", "2"]}], ")"}], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q2", "-", "p"}], ")"}], "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"q2", "-", "q1"}], ")"}], "2"]}]]}], 
  TraditionalForm]], "Output",
 CellTags->"ScalarProductCancel",
 CellLabel->"Out[1408]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"t1", ",", "t2"}], "]"}], ";"}]], "Input",
 CellTags->"ScalarProductCancel",
 CellLabel->"In[1409]:="]
}, Open  ]],

Cell["ScaleMu", "ObjectName",
 CellTags->"ScaleMu"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ScaleMu"],

Cell["\<\
ScaleMu is the mass scale used for dimensional regularization of loop \
integrals.\
\>", "Text",
 CellTags->"ScaleMu"],

Cell[CellGroupData[{

Cell[BoxData["ScaleMu"], "Input",
 CellTags->"ScaleMu",
 CellLabel->"In[1410]:="],

Cell[BoxData[
 FormBox["\[Mu]", TraditionalForm]], "Output",
 CellTags->"ScaleMu",
 CellLabel->"Out[1410]="]
}, Open  ]]
}, Open  ]],

Cell["Schouten", "ObjectName",
 CellTags->"Schouten"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Schouten"],

Cell["\<\
Schouten[expr] applies the Schouten identity on at most 42 terms in a sum. If \
Schouten should operate on larger expression you can give a second argument, \
e.g.: Schouten[expr, 4711] which will work on sums with less than 4711 terms.
Schouten is also an option of Contract and DiracTrace. It may be set to an \
integer indicating the maximum number of terms onto which the function \
Schouten will be applied .\
\>", "Text",
 CellTags->"Schouten"],

Cell[TextData[{
 "See also: ",
 ButtonBox["Contract",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Contract",
  ButtonNote->"Contract"],
 ", ",
 ButtonBox["DiracTrace",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrace",
  ButtonNote->"DiracTrace"],
 "."
}], "Text",
 CellTags->"Schouten"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Schouten"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"a", "=", "1"}], "4"], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"SP", "[", 
         RowBox[{"k", ",", 
          RowBox[{"q", "[", "a", "]"}]}], "]"}], 
        RowBox[{"(", 
         RowBox[{
          FractionBox["1", "6"], 
          RowBox[{"Eps", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", "a", "]"}], ",", 
            RowBox[{"LorentzIndex", "[", "b", "]"}], ",", 
            RowBox[{"LorentzIndex", "[", "c", "]"}], ",", 
            RowBox[{"LorentzIndex", "[", "d", "]"}]}], "]"}], 
          RowBox[{"Eps", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{"q", "[", "b", "]"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{"q", "[", "c", "]"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{"q", "[", "d", "]"}], "]"}]}], "]"}]}], ")"}]}], ")"}]}],
      ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c", ",", "1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"d", ",", "1", ",", "4"}], "}"}]}], "]"}], "-", 
   RowBox[{
    RowBox[{"Eps", "[", 
     RowBox[{
      RowBox[{"Momentum", "[", 
       RowBox[{"q", "[", "1", "]"}], "]"}], ",", 
      RowBox[{"Momentum", "[", 
       RowBox[{"q", "[", "2", "]"}], "]"}], ",", 
      RowBox[{"Momentum", "[", 
       RowBox[{"q", "[", "3", "]"}], "]"}], ",", 
      RowBox[{"Momentum", "[", 
       RowBox[{"q", "[", "4", "]"}], "]"}]}], "]"}], "*", 
    RowBox[{"Pair", "[", 
     RowBox[{
      RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
      RowBox[{"Momentum", "[", "k", "]"}]}], "]"}]}]}]}]], "Input",
 CellTags->"Schouten",
 CellLabel->"In[1411]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     FormBox["k",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{"-", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         RowBox[{"q", "(", "1", ")"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"q", "(", "2", ")"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"q", "(", "3", ")"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"q", "(", "4", ")"}],
         TraditionalForm]}]]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    FormBox[
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       RowBox[{"q", "(", "4", ")"}],
       TraditionalForm]}],
     TraditionalForm], " ", 
    SuperscriptBox["\[Epsilon]", 
     RowBox[{
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "3", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "2", ")"}],
       TraditionalForm], 
      FormBox[
       RowBox[{"q", "(", "1", ")"}],
       TraditionalForm]}]]}]}], TraditionalForm]], "Output",
 CellTags->"Schouten",
 CellLabel->"Out[1411]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "//", "Schouten"}]], "Input",
 CellTags->"Schouten",
 CellLabel->"In[1412]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"Schouten",
 CellLabel->"Out[1412]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "t", "]"}]], "Input",
 CellLabel->"In[1413]:="]
}, Open  ]],

Cell["SD", "ObjectName",
 CellTags->"SD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SD"],

Cell[TextData[{
 "SD[i, j] is the (FeynCalc-external) Kronecker-delta for SU(",
 StyleBox["N",
  FontSlant->"Italic"],
 ") with color indices i and j. SD[i,j] is transformed into \
SUNDelta[SUNIndex[i],SUNIndex[j]] by FeynCalcInternal."
}], "Text",
 CellTags->"SD"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["SUNDelta",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNDelta",
  ButtonNote->"SUNDelta"],
 "."
}], "Text",
 CellTags->"SD"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SD", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Input",
 CellTags->"SD",
 CellLabel->"In[1414]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["\[Delta]", 
   RowBox[{"a", "b"}]], TraditionalForm]], "Output",
 CellTags->"SD",
 CellLabel->"Out[1414]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"%", "//", "FCI"}], "//", "StandardForm"}]], "Input",
 CellTags->"SD",
 CellLabel->"In[1415]:="],

Cell[BoxData[
 RowBox[{"SUNDelta", "[", 
  RowBox[{
   RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
   RowBox[{"SUNIndex", "[", "b", "]"}]}], "]"}]], "Output",
 CellTags->"SD",
 CellLabel->"Out[1415]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"%", "//", "FCE"}], "//", "StandardForm"}]], "Input",
 CellTags->"SD",
 CellLabel->"In[1416]:="],

Cell[BoxData[
 RowBox[{"SD", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Output",
 CellTags->"SD",
 CellLabel->"Out[1416]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["SelectFree", "ObjectName",
 CellTags->"SelectFree"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SelectFree"],

Cell["\<\
SelectFree[expr, a, b, ...] is equivalent to Select[expr, FreeQ2[#, {a,b, \
...}]&], except the special cases: SelectFree[a, b] returns a and \
SelectFree[a,a] returns 1 (where a is not a product or a sum).\
\>", "Text",
 CellTags->"SelectFree"],

Cell["SelectFree is equivalent to Select1.", "Text",
 CellTags->"SelectFree"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FreeQ2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FreeQ2",
  ButtonNote->"FreeQ2"],
 ", ",
 ButtonBox["SelectNotFree",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SelectNotFree",
  ButtonNote->"SelectNotFree"],
 "."
}], "Text",
 CellTags->"SelectFree"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SelectFree"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SelectFree", "[", 
  RowBox[{
   RowBox[{"a", "+", "b", "+", 
    RowBox[{"f", "[", "a", "]"}], "+", "d"}], ",", "a"}], "]"}]], "Input",
 CellTags->"SelectFree",
 CellLabel->"In[1417]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"b", "+", "d"}], TraditionalForm]], "Output",
 CellTags->"SelectFree",
 CellLabel->"Out[1417]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SelectFree", "[", 
  RowBox[{
   RowBox[{"x", " ", "y"}], ",", " ", "x"}], "]"}]], "Input",
 CellTags->"SelectFree",
 CellLabel->"In[1418]:="],

Cell[BoxData[
 FormBox["y", TraditionalForm]], "Output",
 CellTags->"SelectFree",
 CellLabel->"Out[1418]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SelectFree", "[", 
  RowBox[{
   RowBox[{"2", " ", "x", " ", "y", " ", "z", " ", 
    RowBox[{"f", "[", "x", "]"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input",
 CellTags->"SelectFree",
 CellLabel->"In[1419]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "z"}], TraditionalForm]], "Output",
 CellTags->"SelectFree",
 CellLabel->"Out[1419]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SelectFree", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Input",
 CellTags->"SelectFree",
 CellLabel->"In[1420]:="],

Cell[BoxData[
 FormBox["a", TraditionalForm]], "Output",
 CellTags->"SelectFree",
 CellLabel->"Out[1420]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SelectFree", "[", 
  RowBox[{"a", ",", "a"}], "]"}]], "Input",
 CellTags->"SelectFree",
 CellLabel->"In[1421]:="],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellTags->"SelectFree",
 CellLabel->"Out[1421]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SelectFree", "[", 
  RowBox[{"1", ",", "c"}], "]"}]], "Input",
 CellTags->"SelectFree",
 CellLabel->"In[1422]:="],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellTags->"SelectFree",
 CellLabel->"Out[1422]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SelectFree", "[", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], ",", "x"}], "]"}]], "Input",
 CellTags->"SelectFree",
 CellLabel->"In[1423]:="],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellTags->"SelectFree",
 CellLabel->"Out[1423]="]
}, Open  ]]
}, Open  ]],

Cell["SelectGraphs", "ObjectName",
 CellTags->"SelectGraphs"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SelectGraphs"],

Cell["\<\
SelectGraphs is an option for OneLoopSum indicating that only a slected set \
of graphs of the list provided to OneLoopSum is to be calculated. Possible \
settings are: SelectGraphs\[RightArrow]{ i, j,  ... } or SelectGraphs\
\[RightArrow]{ a, {b, c}, ... } which indicates the graphs to be taken from \
the list provided to OneLoopSum. In the second setting the list {b, c} \
indicates that all amplitudes from b to c should be taken.\
\>", "Text",
 CellTags->"SelectGraphs"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OneLoopSum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoopSum",
  ButtonNote->"OneLoopSum"],
 "."
}], "Text",
 CellTags->"SelectGraphs"]
}, Open  ]],

Cell["SelectNotFree", "ObjectName",
 CellTags->"SelectNotFree"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SelectNotFree"],

Cell["\<\
SelectNotFree[expr, x] returns that part of expr which is not free of any \
occurance of x.\
\>", "Text",
 CellTags->"SelectNotFree"],

Cell["\<\
SelectNotFree[expr, a, b, ...] is equivalent to Select[expr, !FreeQ2[#, {a, \
b, ...}]&], except the special cases: SelectNotFree[a, b] returns 1 and \
SelectNotFree[a, a] returns a (where a is not a product or a sum).\
\>", "Text",
 CellTags->"SelectNotFree"],

Cell["SelectNotFree is equivalent to Select2.", "Text",
 CellTags->"SelectNotFree"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FreeQ2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FreeQ2",
  ButtonNote->"FreeQ2"],
 ", ",
 ButtonBox["SelectFree",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SelectFree",
  ButtonNote->"SelectFree"],
 "."
}], "Text",
 CellTags->"SelectNotFree"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SelectNotFree"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SelectNotFree", "[", 
  RowBox[{
   RowBox[{"a", "+", "b", "+", 
    RowBox[{"f", "[", "a", "]"}]}], ",", "a"}], "]"}]], "Input",
 CellTags->"SelectNotFree",
 CellLabel->"In[1424]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"f", "(", "a", ")"}], "+", "a"}], TraditionalForm]], "Output",
 CellTags->"SelectNotFree",
 CellLabel->"Out[1424]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SelectNotFree", "[", 
  RowBox[{
   RowBox[{"2", " ", "x", " ", "y", " ", 
    RowBox[{"f", "[", "x", "]"}], " ", "z"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input",
 CellTags->"SelectNotFree",
 CellLabel->"In[1425]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"x", " ", "y", " ", 
   RowBox[{"f", "(", "x", ")"}]}], TraditionalForm]], "Output",
 CellTags->"SelectNotFree",
 CellLabel->"Out[1425]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SelectNotFree", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Input",
 CellTags->"SelectNotFree",
 CellLabel->"In[1426]:="],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellTags->"SelectNotFree",
 CellLabel->"Out[1426]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SelectNotFree", "[", 
  RowBox[{
   RowBox[{"a", "+", "x"}], ",", "b"}], "]"}]], "Input",
 CellTags->"SelectNotFree",
 CellLabel->"In[1427]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"SelectNotFree",
 CellLabel->"Out[1427]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SelectNotFree", "[", 
  RowBox[{"a", ",", "a"}], "]"}]], "Input",
 CellTags->"SelectNotFree",
 CellLabel->"In[1428]:="],

Cell[BoxData[
 FormBox["a", TraditionalForm]], "Output",
 CellTags->"SelectNotFree",
 CellLabel->"Out[1428]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SelectNotFree", "[", 
  RowBox[{"1", ",", "c"}], "]"}]], "Input",
 CellTags->"SelectNotFree",
 CellLabel->"In[1429]:="],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellTags->"SelectNotFree",
 CellLabel->"Out[1429]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SelectNotFree", "[", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], ",", "x"}], "]"}]], "Input",
 CellTags->"SelectNotFree",
 CellLabel->"In[1430]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"f", "(", "x", ")"}], TraditionalForm]], "Output",
 CellTags->"SelectNotFree",
 CellLabel->"Out[1430]="]
}, Open  ]]
}, Open  ]],

Cell["SelectSplit", "ObjectName",
 CellTags->"SelectSplit"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SelectSplit"],

Cell["\<\
SelectSplit[l, p] Construct list of mutually exclusive subsets from l in \
which every element li satisfies a criterium pj[li] with pj from p and \
appends the subset of remaining unmatched elements.\
\>", "Text",
 CellTags->"SelectSplit"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SelectSplit"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SelectSplit", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["a", "2"], ",", 
     SuperscriptBox["b", "3"], ",", 
     SuperscriptBox["c", "4"], ",", 
     SuperscriptBox["d", "5"], ",", 
     SuperscriptBox["e", "6"], ",", 
     RowBox[{"f", "+", "g"}], ",", 
     SuperscriptBox["h", "4"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"MatchQ", "[", 
       RowBox[{"#", ",", 
        RowBox[{"_", "^", "2"}]}], "]"}], "&"}], ",", 
     RowBox[{
      RowBox[{"MatchQ", "[", 
       RowBox[{"#", ",", 
        RowBox[{"_", "^", "4"}]}], "]"}], "&"}], ",", 
     RowBox[{
      RowBox[{"FreeQ", "[", 
       RowBox[{"#", ",", "Power"}], "]"}], "&"}]}], "}"}]}], "]"}]], "Input",
 CellTags->"SelectSplit",
 CellLabel->"In[1431]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     SuperscriptBox["a", "2"], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      SuperscriptBox["c", "4"], ",", 
      SuperscriptBox["h", "4"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"f", "+", "g"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      SuperscriptBox["b", "3"], ",", 
      SuperscriptBox["d", "5"], ",", 
      SuperscriptBox["e", "6"]}], "}"}]}], "}"}], TraditionalForm]], "Output",\

 CellTags->"SelectSplit",
 CellLabel->"Out[1431]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SelectSplit", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["a", "2"], ",", 
     SuperscriptBox["b", "3"], ",", 
     SuperscriptBox["c", "4"], ",", 
     SuperscriptBox["d", "5"], ",", 
     SuperscriptBox["e", "6"], ",", 
     RowBox[{"f", "+", "g"}], ",", 
     SuperscriptBox["h", "4"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"FreeQ", "[", 
       RowBox[{"#", ",", "Plus"}], "]"}], "&"}], ",", 
     RowBox[{
      RowBox[{"FreeQ", "[", 
       RowBox[{"#", ",", "Power"}], "]"}], "&"}]}], "}"}]}], "]"}]], "Input",
 CellTags->"SelectSplit",
 CellLabel->"In[1432]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SuperscriptBox["a", "2"], ",", 
      SuperscriptBox["b", "3"], ",", 
      SuperscriptBox["c", "4"], ",", 
      SuperscriptBox["d", "5"], ",", 
      SuperscriptBox["e", "6"], ",", 
      SuperscriptBox["h", "4"]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"f", "+", "g"}], "}"}], ",", 
    RowBox[{"{", "}"}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"SelectSplit",
 CellLabel->"Out[1432]="]
}, Open  ]]
}, Open  ]],

Cell["Select1", "ObjectName",
 CellTags->"Select1"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Select1"],

Cell["\<\
Select1[expr, a, b, ...] is equivalent to Select[expr, FreeQ2[#, {a,b, \
...}]&], except the special cases: Select1[a, b] returns a and Select1[a,a] \
returns 1 (where a is not a product or a sum).\
\>", "Text",
 CellTags->"Select1"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Select2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Select2",
  ButtonNote->"Select2"],
 "."
}], "Text",
 CellTags->"Select1"]
}, Open  ]],

Cell["Select2", "ObjectName",
 CellTags->"Select2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Select2"],

Cell["\<\
Select2[expr, a, b, ...] is equivalent to Select[expr, !FreeQ2[#, {a,b, \
...}]&], except the special cases: Select2[a, b] returns 1 and  Select2[a,a] \
returns a (where a is not a product or a sum).\
\>", "Text",
 CellTags->"Select2"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Select1",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Select1",
  ButtonNote->"Select1"],
 "."
}], "Text",
 CellTags->"Select2"]
}, Open  ]],

Cell["Series2", "ObjectName",
 CellTags->"Series2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Series2"],

Cell[TextData[{
 " Series2 performs a series expansion around 0. Series2 is (up to the \
Gamma-bug in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " versions smaller than 5.0) equivalent to Series, except that it applies \
Normal on the result and has an option FinalSubstitutions. Series2[f, e, n] \
is equivalent to Series2[f, {e, 0, n}]."
}], "Text",
 CellTags->"Series2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Series2", "]"}]], "Input",
 CellTags->"Series2",
 CellLabel->"In[1433]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Collecting", "\[Rule]", "False"}], ",", 
    RowBox[{"Factoring", "\[Rule]", "True"}], ",", 
    RowBox[{"FinalSubstitutions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       TagBox["\[DoubledGamma]",
        Function[{}, EulerGamma]], "\[Rule]", "0"}], "}"}]}], ",", 
    RowBox[{"Print", "\[Rule]", "False"}], ",", 
    RowBox[{"SimplifyPolyLog", "\[Rule]", "True"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Series2",
 CellLabel->"Out[1433]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Series2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series2", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"x", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "x"}], ")"}]}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"\[Delta]", "/", "2"}], ")"}]}], ",", "\[Delta]", ",", "1"}], 
  "]"}]], "Input",
 CellTags->"Series2",
 CellLabel->"In[1434]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[Delta]", " ", 
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[Delta]", " ", 
    RowBox[{"log", "(", "x", ")"}]}], "+", "1"}], TraditionalForm]], "Output",\

 CellTags->"Series2",
 CellLabel->"Out[1434]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series2", "[", 
  RowBox[{
   RowBox[{"Gamma", "[", "x", "]"}], ",", "x", ",", "1"}], "]"}]], "Input",
 CellTags->"Series2",
 CellLabel->"In[1435]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"\[Zeta]", "(", "2", ")"}], " ", "x"}], "+", 
   FractionBox["1", "x"]}], TraditionalForm]], "Output",
 CellTags->"Series2",
 CellLabel->"Out[1435]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{"Gamma", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"Series2",
 CellLabel->"In[1436]:="],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    FractionBox["1", "x"], "-", 
    TagBox["\[DoubledGamma]",
     Function[{}, EulerGamma]], "+", 
    RowBox[{
     FractionBox["1", "12"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", 
        SuperscriptBox[
         TagBox["\[DoubledGamma]",
          Function[{}, EulerGamma]], "2"]}], "+", 
       SuperscriptBox["\[Pi]", "2"]}], ")"}], " ", "x"}], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox["x", "2"], ")"}],
     SeriesData[$CellContext`x, 0, {}, -1, 2, 1],
     Editable->False]}],
   SeriesData[$CellContext`x, 0, {
    1, -EulerGamma, Rational[1, 12] (6 EulerGamma^2 + Pi^2)}, -1, 2, 1],
   Editable->False], TraditionalForm]], "Output",
 CellTags->"Series2",
 CellLabel->"Out[1436]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series2", "[", 
  RowBox[{
   RowBox[{"Gamma", "[", "x", "]"}], ",", "x", ",", "2"}], "]"}]], "Input",
 CellTags->"Series2",
 CellLabel->"In[1437]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      TemplateBox[{"3"},
       "Zeta"]}], "3"]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"\[Zeta]", "(", "2", ")"}], " ", "x"}], "+", 
   FractionBox["1", "x"]}], TraditionalForm]], "Output",
 CellTags->"Series2",
 CellLabel->"Out[1437]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Series2", "[", 
   RowBox[{
    RowBox[{"Gamma", "[", "x", "]"}], ",", "x", ",", "2", ",", 
    RowBox[{"FinalSubstitutions", "\[Rule]", 
     RowBox[{"{", "}"}]}]}], "]"}], "//", "FullSimplify"}]], "Input",
 CellTags->"Series2",
 CellLabel->"In[1438]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "6"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"3", " ", 
       TagBox["\[DoubledGamma]",
        Function[{}, EulerGamma]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
          SuperscriptBox["x", "2"]}], "+", "2"}], ")"}]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["x", "2"], " ", 
      TemplateBox[{"3"},
       "Zeta"]}], "-", 
     RowBox[{
      SuperscriptBox[
       TagBox["\[DoubledGamma]",
        Function[{}, EulerGamma]], "3"], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"3", " ", 
      RowBox[{"\[Zeta]", "(", "2", ")"}], " ", "x"}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox[
       TagBox["\[DoubledGamma]",
        Function[{}, EulerGamma]], "2"], " ", "x"}], "+", 
     FractionBox["6", "x"]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Series2",
 CellLabel->"Out[1438]="]
}, Open  ]],

Cell[TextData[{
 "In earlier ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " versions the Gamma functions was not expanded far enough, in 5.0 this got \
finally fixed:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"Gamma", "[", "x", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"$VersionNumber", "<", "5"}], ",", "4", ",", "2"}], "]"}]}],
        "}"}]}], "]"}], "//", "Normal"}], "//", "Expand"}], "//", 
  "FullSimplify"}]], "Input",
 CellTags->"Series2",
 CellLabel->"In[1439]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "12"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        TagBox["\[DoubledGamma]",
         Function[{}, EulerGamma]], "3"], " ", 
       SuperscriptBox["x", "2"]}]}], "-", 
     RowBox[{
      TagBox["\[DoubledGamma]",
       Function[{}, EulerGamma]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Pi]", "2"], " ", 
         SuperscriptBox["x", "2"]}], "+", "12"}], ")"}]}], "+", 
     RowBox[{"x", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Pi]", "2"], "-", 
        RowBox[{"4", " ", "x", " ", 
         TemplateBox[{"3"},
          "Zeta"]}]}], ")"}]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox[
       TagBox["\[DoubledGamma]",
        Function[{}, EulerGamma]], "2"], " ", "x"}], "+", 
     FractionBox["12", "x"]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Series2",
 CellLabel->"Out[1439]="]
}, Open  ]],

Cell["\<\
There is a table of expansions of special hypergeometric functions.\
\>", "Text",
 CellTags->"Series2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series2", "[", 
  RowBox[{
   RowBox[{"HypergeometricPFQ", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"OPEm", "-", "1"}], ",", 
       RowBox[{
        RowBox[{"Epsilon", "/", "2"}], "+", "OPEm"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"OPEm", ",", 
       RowBox[{"OPEm", "+", "Epsilon"}]}], "}"}], ",", "1"}], "]"}], ",", 
   "Epsilon", ",", "1"}], "]"}]], "Input",
 CellTags->"Series2",
 CellLabel->"In[1440]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["2", 
     TagBox["\[CurlyEpsilon]",
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"2", " ", "m"}], 
    TagBox["\[CurlyEpsilon]",
     TraditionalForm]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    TagBox["\[CurlyEpsilon]",
     TraditionalForm], " ", "m", " ", 
    TemplateBox[{"1","m"},
     "PolyGamma2"]}], "-", 
   FractionBox[
    RowBox[{
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], " ", 
     TemplateBox[{"1","m"},
      "PolyGamma2"]}], "2"], "+", "1"}], TraditionalForm]], "Output",
 CellTags->"Series2",
 CellLabel->"Out[1440]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Series2", "[", 
   RowBox[{
    RowBox[{"HypergeometricPFQ", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", " ", "OPEm", ",", " ", 
        RowBox[{
         RowBox[{"Epsilon", "/", "2"}], " ", "+", " ", "OPEm"}]}], "}"}], ",",
       " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", " ", "+", " ", "OPEm"}], ",", " ", 
        RowBox[{"Epsilon", " ", "+", " ", "OPEm"}]}], "}"}], ",", "  ", "1"}],
      "]"}], ",", "Epsilon", ",", "1"}], "]"}]}]], "Input",
 CellTags->"Series2",
 CellLabel->"In[1441]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", 
    TagBox["\[CurlyEpsilon]",
     TraditionalForm], " ", 
    RowBox[{"\[Zeta]", "(", "2", ")"}], " ", "m"}], "+", 
   FractionBox[
    RowBox[{"2", " ", "m"}], 
    TagBox["\[CurlyEpsilon]",
     TraditionalForm]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    TagBox["\[CurlyEpsilon]",
     TraditionalForm], " ", "m", " ", 
    SuperscriptBox[
     TemplateBox[{"0","m"},
      "PolyGamma2"], "2"]}], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", 
    TagBox["\[CurlyEpsilon]",
     TraditionalForm], " ", "m", " ", 
    TemplateBox[{"1","m"},
     "PolyGamma2"]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    TagBox["\[CurlyEpsilon]",
     TraditionalForm], " ", "m", " ", 
    RowBox[{
     SubscriptBox["S", "11"], "(", 
     FormBox[
      RowBox[{"m", "-", "1"}],
      TraditionalForm], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Series2",
 CellLabel->"Out[1441]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Hypergeometric2F1", "[", 
  RowBox[{"1", ",", " ", "Epsilon", ",", " ", 
   RowBox[{"1", " ", "+", " ", 
    RowBox[{"2", " ", "Epsilon"}]}], ",", "x"}], "]"}]], "Input",
 CellTags->"Series2",
 CellLabel->"In[1442]:="],

Cell[BoxData[
 FormBox[
  TemplateBox[{"1",TagBox["\[CurlyEpsilon]", TraditionalForm],RowBox[{
      RowBox[{"2", " ", 
        TagBox["\[CurlyEpsilon]", TraditionalForm]}], "+", "1"}],"x"},
   "Hypergeometric2F1"], TraditionalForm]], "Output",
 CellTags->"Series2",
 CellLabel->"Out[1442]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series2", "[", 
  RowBox[{"%", ",", "Epsilon", ",", "3"}], "]"}]], "Input",
 CellTags->"Series2",
 CellLabel->"In[1443]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], "2"], " ", 
     RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "3"], " ", 
    TemplateBox[{"3",RowBox[{"1", "-", "x"}]},
     "PolyLog"]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "2"], " ", 
    TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
     "PolyLog"]}], "-", 
   RowBox[{"4", " ", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "3"], " ", 
    TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
     "PolyLog"], " ", 
    RowBox[{"log", "(", "x", ")"}]}], "-", 
   RowBox[{"4", " ", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "3"], " ", 
    RowBox[{
     SubscriptBox["S", 
      RowBox[{
       FormBox["1",
        TraditionalForm], 
       FormBox["2",
        TraditionalForm]}]], "(", 
     FormBox[
      RowBox[{"1", "-", "x"}],
      TraditionalForm], ")"}]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "3"], " ", 
    RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "+", 
   RowBox[{"4", " ", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "3"], " ", 
    RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
    RowBox[{"log", "(", "x", ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "3"], " ", 
    RowBox[{
     SuperscriptBox["log", "3"], "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "3"], " ", 
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "3"], " ", 
    RowBox[{
     SuperscriptBox["log", "2"], "(", 
     RowBox[{"1", "-", "x"}], ")"}], " ", 
    RowBox[{"log", "(", "x", ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "2"], " ", 
    RowBox[{
     SuperscriptBox["log", "2"], "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "2"], " ", 
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}], " ", 
    RowBox[{"log", "(", "x", ")"}]}], "-", 
   RowBox[{
    TagBox["\[CurlyEpsilon]",
     TraditionalForm], " ", 
    RowBox[{"log", "(", 
     RowBox[{"1", "-", "x"}], ")"}]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "3"], " ", 
    TemplateBox[{"3"},
     "Zeta"]}], "+", "1"}], TraditionalForm]], "Output",
 CellTags->"Series2",
 CellLabel->"Out[1443]="]
}, Open  ]],

Cell[TextData[{
 "There are over 100 more special expansions of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[ThinSpace]", 
    RowBox[{
     SubscriptBox["", "2"], 
     SubscriptBox["F", "1"]}]}], TraditionalForm]]],
 " tabulated in Series2.m. The interested user can consult the source code \
(search for HYPERLIST)."
}], "Text",
 CellTags->"Series2"]
}, Open  ]],

Cell["Series3", "ObjectName",
 CellTags->"Series3"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Series3"],

Cell["\<\
Series3 performs a series expansion around 0. Series3 is equivalent to \
Series, except that it applies Normal on the result and that some Series bugs \
are fixed. Series3[f, e, n] is equivalent to  Series3[f, {e, 0, n}].\
\>", "Text",
 CellTags->"Series3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Series3", "]"}]], "Input",
 CellTags->"Series3",
 CellLabel->"In[1444]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Factoring", "\[Rule]", "True"}], ",", 
    RowBox[{"FinalSubstitutions", "\[Rule]", 
     RowBox[{"{", "}"}]}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"Series3",
 CellLabel->"Out[1444]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Series2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Series2",
  ButtonNote->"Series2"],
 "."
}], "Text",
 CellTags->"Series3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Series3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series3", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"x", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "x"}], ")"}]}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"\[Delta]", "/", "2"}], ")"}]}], ",", "\[Delta]", ",", "1"}], 
  "]"}]], "Input",
 CellTags->"Series3",
 CellLabel->"In[1445]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[Delta]", " ", 
    RowBox[{"log", "(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "+", "1"}], 
  TraditionalForm]], "Output",
 CellTags->"Series3",
 CellLabel->"Out[1445]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Series3", "[", 
   RowBox[{
    RowBox[{"Gamma", "[", "x", "]"}], ",", "x", ",", "1"}], "]"}], "//", 
  "FullSimplify"}]], "Input",
 CellTags->"Series3",
 CellLabel->"In[1446]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "x"], "-", 
   TagBox["\[DoubledGamma]",
    Function[{}, EulerGamma]], "+", "1"}], TraditionalForm]], "Output",
 CellTags->"Series3",
 CellLabel->"Out[1446]="]
}, Open  ]]
}, Open  ]],

Cell["SetMandelstam", "ObjectName",
 CellTags->"SetMandelstam"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SetMandelstam"],

Cell["\<\
SetMandelstam[s, t, u, p1, p2, p3, p4, m1, m2, m3, m4] defines the Mandelstam \
variables  s=(p1+p2)^2, t=(p1+p3)^2, u=(p1+p4)^2 and sets the pi on-shell: \
p1^2=m1^2, p2^2=m2^2, p3^2=m3^2, p4^2=m4^2. Note that p1 +  p2 + p3 + p4 = 0 \
is assumed.
SetMandelstam[x, {p1, p2, p3, p4, p5}, {m1, m2, m3, m4, m5}] defines x[i, j] \
= (pi+pj)^2 and sets the pi on-shell. The pi satisfy: p1 + p2 + p3 + p4 + p5 \
= 0.\
\>", "Text",
 CellTags->"SetMandelstam"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "SetMandelstam", "]"}]], "Input",
 CellTags->"SetMandelstam",
 CellLabel->"In[1447]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"Dimension", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"4", ",", "D", ",", "___"}], "}"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"SetMandelstam",
 CellLabel->"Out[1447]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Mandelstam",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Mandelstam",
  ButtonNote->"Mandelstam"],
 "."
}], "Text",
 CellTags->"SetMandelstam"]
}, Open  ]],

Cell["SimplifyDeltaFunction", "ObjectName",
 CellTags->"SimplifyDeltaFunction"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SimplifyDeltaFunction"],

Cell["\<\
SimplifyDeltaFunction[exp, x] simplifies f[x]*DeltaFunction[1-x] \
toLimit[f[x],x\[Rule]1] DeltaFunction[1-x] and applies a list of \
transformation rules for DeltaFunctionPrime[1-x]*x^(OPEm-1)*f[x] where \
x^(OPEm-1) is suppressed in exp.\
\>", "Text",
 CellTags->"SimplifyDeltaFunction"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DeltaFunction",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DeltaFunction",
  ButtonNote->"DeltaFunction"],
 ", ",
 ButtonBox["DeltaFunctionPrime",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DeltaFunctionPrime",
  ButtonNote->"DeltaFunctionPrime"],
 "."
}], "Text",
 CellTags->"SimplifyDeltaFunction"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SimplifyDeltaFunction"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "[", "x", "]"}], " ", 
  RowBox[{"DeltaFunction", "[", 
   RowBox[{"1", "-", "x"}], "]"}]}]], "Input",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"In[1448]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"g", "(", "x", ")"}], " ", 
   RowBox[{"\[Delta]", "(", 
    FormBox[
     RowBox[{"1", "-", "x"}],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"Out[1448]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SimplifyDeltaFunction", "[", " ", 
  RowBox[{"%", ",", "x"}], "]"}]], "Input",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"In[1449]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[Delta]", "(", 
    FormBox[
     RowBox[{"1", "-", "x"}],
     TraditionalForm], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"x", "\[Rule]", "1"}]], "\[ThinSpace]", 
     RowBox[{"g", "(", "x", ")"}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"Out[1449]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "[", "x", "]"}], 
  RowBox[{"DeltaFunctionPrime", "[", 
   RowBox[{"1", "-", "x"}], "]"}]}]], "Input",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"In[1450]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"g", "(", "x", ")"}], " ", 
   RowBox[{
    SuperscriptBox["\[Delta]", "\[Prime]"], "(", 
    FormBox[
     RowBox[{"1", "-", "x"}],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"Out[1450]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SimplifyDeltaFunction", "[", " ", 
  RowBox[{"%", ",", "x"}], "]"}]], "Input",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"In[1451]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"\[Delta]", "(", 
     FormBox[
      RowBox[{"1", "-", "x"}],
      TraditionalForm], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"x", "\[Rule]", "1"}]], "\[ThinSpace]", 
      RowBox[{
       SuperscriptBox["g", "\[Prime]",
        MultilineFunction->None], "(", "x", ")"}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Delta]", "\[Prime]"], "(", 
     FormBox[
      RowBox[{"1", "-", "x"}],
      TraditionalForm], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      UnderscriptBox["lim", 
       RowBox[{"x", "\[Rule]", "1"}]], "\[ThinSpace]", 
      RowBox[{"g", "(", "x", ")"}]}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"Out[1451]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x", " ", 
  RowBox[{"Log", "[", "x", "]"}], " ", 
  RowBox[{"DeltaFunctionPrime", "[", 
   RowBox[{"1", "-", "x"}], "]"}]}]], "Input",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"In[1452]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"x", " ", 
   RowBox[{"log", "(", "x", ")"}], " ", 
   RowBox[{
    SuperscriptBox["\[Delta]", "\[Prime]"], "(", 
    FormBox[
     RowBox[{"1", "-", "x"}],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"Out[1452]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SimplifyDeltaFunction", "[", " ", 
  RowBox[{"%", ",", "x"}], "]"}]], "Input",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"In[1453]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[Delta]", "(", 
   FormBox[
    RowBox[{"1", "-", "x"}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"Out[1453]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PolyLog", "[", 
   RowBox[{"2", ",", 
    RowBox[{"1", "-", "x"}]}], "]"}], " ", 
  RowBox[{"DeltaFunctionPrime", "[", 
   RowBox[{"1", "-", "x"}], "]"}]}]], "Input",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"In[1454]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
    "PolyLog"], " ", 
   RowBox[{
    SuperscriptBox["\[Delta]", "\[Prime]"], "(", 
    FormBox[
     RowBox[{"1", "-", "x"}],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"Out[1454]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SimplifyDeltaFunction", "[", " ", 
  RowBox[{"%", ",", "x"}], "]"}]], "Input",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"In[1455]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   RowBox[{"\[Delta]", "(", 
    FormBox[
     RowBox[{"1", "-", "x"}],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"Out[1455]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Log", "[", "x", "]"}], 
  RowBox[{"PolyLog", "[", 
   RowBox[{"2", ",", 
    RowBox[{"1", "-", "x"}]}], "]"}], " ", 
  RowBox[{"DeltaFunctionPrime", "[", 
   RowBox[{"1", "-", "x"}], "]"}]}]], "Input",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"In[1456]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
    "PolyLog"], " ", 
   RowBox[{"log", "(", "x", ")"}], " ", 
   RowBox[{
    SuperscriptBox["\[Delta]", "\[Prime]"], "(", 
    FormBox[
     RowBox[{"1", "-", "x"}],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"Out[1456]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SimplifyDeltaFunction", "[", " ", 
  RowBox[{"%", ",", "x"}], "]"}]], "Input",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"In[1457]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"Out[1457]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PolyLog", "[", 
   RowBox[{"3", ",", 
    RowBox[{"1", "-", "x"}]}], "]"}], " ", 
  RowBox[{"DeltaFunctionPrime", "[", 
   RowBox[{"1", "-", "x"}], "]"}]}]], "Input",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"In[1458]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"3",RowBox[{"1", "-", "x"}]},
    "PolyLog"], " ", 
   RowBox[{
    SuperscriptBox["\[Delta]", "\[Prime]"], "(", 
    FormBox[
     RowBox[{"1", "-", "x"}],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"Out[1458]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SimplifyDeltaFunction", "[", " ", 
  RowBox[{"%", ",", "x"}], "]"}]], "Input",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"In[1459]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   RowBox[{"\[Delta]", "(", 
    FormBox[
     RowBox[{"1", "-", "x"}],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyDeltaFunction",
 CellLabel->"Out[1459]="]
}, Open  ]]
}, Open  ]],

Cell["SimplifyGTI  ***unfinished***", "ObjectName",
 CellTags->"SimplifyGTI"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SimplifyGTI"],

Cell["SimplifyGTI simplifies GTI's.", "Text",
 CellTags->"SimplifyGTI"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["GTI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GTI",
  ButtonNote->"GTI"],
 "."
}], "Text",
 CellTags->"SimplifyGTI"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SimplifyGTI"],

Cell[BoxData[""], "Input",
 CellTags->"SimplifyGTI",
 CellLabel->"In[1460]:="]
}, Open  ]],

Cell["SimplifyPolyLog", "ObjectName",
 CellTags->"SimplifyPolyLog"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SimplifyPolyLog"],

Cell["\<\
SimplifyPolyLog[y] performs several simplifications assuming that the \
variables occuring in the Log and PolyLog functions are between 0 and 1. \
\>", "Text",
 CellTags->"SimplifyPolyLog"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Nielsen",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Nielsen",
  ButtonNote->"Nielsen"],
 "."
}], "Text",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SimplifyPolyLog"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sip", "[", "y_", "]"}], " ", ":=", " ", 
  RowBox[{"y", " ", "==", " ", 
   RowBox[{"SimplifyPolyLog", "[", "y", "]"}]}]}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1461]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sip", "[", 
  RowBox[{"PolyLog", "[", 
   RowBox[{"2", ",", 
    RowBox[{"1", "/", "x"}]}], "]"}], "]"}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1462]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"2",FractionBox["1", "x"]},
    "PolyLog"], "\[LongEqual]", 
   RowBox[{
    RowBox[{"\[Zeta]", "(", "2", ")"}], "+", 
    TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
     "PolyLog"], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
    RowBox[{
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "x"}], ")"}], " ", 
     RowBox[{"log", "(", "x", ")"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "\[Pi]", " ", 
     RowBox[{"log", "(", "x", ")"}]}]}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyPolyLog",
 CellLabel->"Out[1462]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sip", "[", 
  RowBox[{"PolyLog", "[", 
   RowBox[{"2", ",", "x"}], "]"}], "]"}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1463]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"2","x"},
    "PolyLog"], "\[LongEqual]", 
   RowBox[{
    RowBox[{"\[Zeta]", "(", "2", ")"}], "-", 
    TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
     "PolyLog"], "-", 
    RowBox[{
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "x"}], ")"}], " ", 
     RowBox[{"log", "(", "x", ")"}]}]}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyPolyLog",
 CellLabel->"Out[1463]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sip", "[", 
  RowBox[{"PolyLog", "[", 
   RowBox[{"2", ",", 
    RowBox[{"1", "-", 
     RowBox[{"x", "^", "2"}]}]}], "]"}], "]"}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1464]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"2",RowBox[{"1", "-", 
       SuperscriptBox["x", "2"]}]},
    "PolyLog"], "\[LongEqual]", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"\[Zeta]", "(", "2", ")"}]}], "+", 
    RowBox[{"2", " ", 
     TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
      "PolyLog"]}], "-", 
    RowBox[{"2", " ", 
     TemplateBox[{"2",RowBox[{"-", "x"}]},
      "PolyLog"]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"log", "(", "x", ")"}], " ", 
     RowBox[{"log", "(", 
      RowBox[{"x", "+", "1"}], ")"}]}]}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyPolyLog",
 CellLabel->"Out[1464]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sip", "[", 
  RowBox[{"PolyLog", "[", 
   RowBox[{"2", ",", 
    RowBox[{"x", "^", "2"}]}], "]"}], "]"}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1465]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"2",SuperscriptBox["x", "2"]},
    "PolyLog"], "\[LongEqual]", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"\[Zeta]", "(", "2", ")"}]}], "-", 
    RowBox[{"2", " ", 
     TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
      "PolyLog"]}], "+", 
    RowBox[{"2", " ", 
     TemplateBox[{"2",RowBox[{"-", "x"}]},
      "PolyLog"]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "x"}], ")"}], " ", 
     RowBox[{"log", "(", "x", ")"}]}]}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyPolyLog",
 CellLabel->"Out[1465]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sip", "[", 
  RowBox[{"PolyLog", "[", 
   RowBox[{"2", ",", 
    RowBox[{"-", 
     RowBox[{"x", "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "x"}], ")"}]}]}]}], "]"}], "]"}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1466]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"2",RowBox[{"-", 
       FractionBox["x", 
        RowBox[{"1", "-", "x"}]]}]},
    "PolyLog"], "\[LongEqual]", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"\[Zeta]", "(", "2", ")"}]}], "+", 
    TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
     "PolyLog"], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      SuperscriptBox["log", "2"], "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"log", "(", "x", ")"}], " ", 
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "x"}], ")"}]}]}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyPolyLog",
 CellLabel->"Out[1466]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sip", "[", 
  RowBox[{"PolyLog", "[", 
   RowBox[{"2", ",", 
    RowBox[{"x", "/", 
     RowBox[{"(", 
      RowBox[{"x", "-", "1"}], ")"}]}]}], "]"}], "]"}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1467]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"2",FractionBox["x", 
      RowBox[{"x", "-", "1"}]]},
    "PolyLog"], "\[LongEqual]", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"\[Zeta]", "(", "2", ")"}]}], "+", 
    TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
     "PolyLog"], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      SuperscriptBox["log", "2"], "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"log", "(", "x", ")"}], " ", 
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "x"}], ")"}]}]}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyPolyLog",
 CellLabel->"Out[1467]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sip", "[", 
  RowBox[{"Nielsen", "[", 
   RowBox[{"1", ",", "2", ",", 
    RowBox[{"-", 
     RowBox[{"x", "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "x"}], ")"}]}]}]}], "]"}], "]"}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1468]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["S", 
     RowBox[{
      FormBox["1",
       TraditionalForm], 
      FormBox["2",
       TraditionalForm]}]], "(", 
    FormBox[
     RowBox[{"-", 
      FractionBox["x", 
       RowBox[{"1", "-", "x"}]]}],
     TraditionalForm], ")"}], "\[LongEqual]", 
   RowBox[{
    RowBox[{
     SubscriptBox["S", 
      RowBox[{
       FormBox["1",
        TraditionalForm], 
       FormBox["2",
        TraditionalForm]}]], "(", "x", ")"}], "-", 
    RowBox[{
     FractionBox["1", "6"], " ", 
     RowBox[{
      SuperscriptBox["log", "3"], "(", 
      RowBox[{"1", "-", "x"}], ")"}]}]}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyPolyLog",
 CellLabel->"Out[1468]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sip", "[", 
  RowBox[{"PolyLog", "[", 
   RowBox[{"3", ",", 
    RowBox[{"-", 
     RowBox[{"1", "/", "x"}]}]}], "]"}], "]"}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1469]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"3",RowBox[{"-", 
       FractionBox["1", "x"]}]},
    "PolyLog"], "\[LongEqual]", 
   RowBox[{
    TemplateBox[{"3",RowBox[{"-", "x"}]},
     "PolyLog"], "+", 
    RowBox[{
     RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
     RowBox[{"log", "(", "x", ")"}]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["log", "3"], "(", "x", ")"}], "6"]}]}], 
  TraditionalForm]], "Output",
 CellTags->"SimplifyPolyLog",
 CellLabel->"Out[1469]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sip", "[", 
  RowBox[{"PolyLog", "[", 
   RowBox[{"3", ",", 
    RowBox[{"1", "-", "x"}]}], "]"}], "]"}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1470]:="],

Cell[BoxData[
 FormBox["True", TraditionalForm]], "Output",
 CellTags->"SimplifyPolyLog",
 CellLabel->"Out[1470]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sip", "[", 
  RowBox[{"PolyLog", "[", 
   RowBox[{"3", ",", 
    RowBox[{"x", "^", "2"}]}], "]"}], "]"}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1471]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"3",SuperscriptBox["x", "2"]},
    "PolyLog"], "\[LongEqual]", 
   RowBox[{
    RowBox[{"4", " ", 
     TemplateBox[{"3",RowBox[{"-", "x"}]},
      "PolyLog"]}], "-", 
    RowBox[{"4", " ", 
     TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
      "PolyLog"], " ", 
     RowBox[{"log", "(", "x", ")"}]}], "-", 
    RowBox[{"4", " ", 
     RowBox[{
      SubscriptBox["S", 
       RowBox[{
        FormBox["1",
         TraditionalForm], 
        FormBox["2",
         TraditionalForm]}]], "(", 
      FormBox[
       RowBox[{"1", "-", "x"}],
       TraditionalForm], ")"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
     RowBox[{"log", "(", "x", ")"}]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "x"}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
    RowBox[{"4", " ", 
     TemplateBox[{"3"},
      "Zeta"]}]}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyPolyLog",
 CellLabel->"Out[1471]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sip", "[", 
  RowBox[{"PolyLog", "[", 
   RowBox[{"3", ",", 
    RowBox[{"-", 
     RowBox[{"x", "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "x"}], ")"}]}]}]}], "]"}], "]"}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1472]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"3",RowBox[{"-", 
       FractionBox["x", 
        RowBox[{"1", "-", "x"}]]}]},
    "PolyLog"], "\[LongEqual]", 
   RowBox[{
    RowBox[{"-", 
     TemplateBox[{"3",RowBox[{"1", "-", "x"}]},
      "PolyLog"]}], "+", 
    RowBox[{
     TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
      "PolyLog"], " ", 
     RowBox[{"log", "(", "x", ")"}]}], "+", 
    RowBox[{
     SubscriptBox["S", 
      RowBox[{
       FormBox["1",
        TraditionalForm], 
       FormBox["2",
        TraditionalForm]}]], "(", 
     FormBox[
      RowBox[{"1", "-", "x"}],
      TraditionalForm], ")"}], "+", 
    RowBox[{
     RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
     RowBox[{"log", "(", "x", ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "6"], " ", 
     RowBox[{
      SuperscriptBox["log", "3"], "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"log", "(", "x", ")"}], " ", 
     RowBox[{
      SuperscriptBox["log", "2"], "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      SuperscriptBox["log", "2"], "(", "x", ")"}], " ", 
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "x"}], ")"}]}]}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyPolyLog",
 CellLabel->"Out[1472]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sip", "[", 
  RowBox[{"PolyLog", "[", 
   RowBox[{"3", ",", 
    RowBox[{"1", "-", 
     RowBox[{"1", "/", "x"}]}]}], "]"}], "]"}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1473]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"3",RowBox[{"1", "-", 
       FractionBox["1", "x"]}]},
    "PolyLog"], "\[LongEqual]", 
   RowBox[{
    RowBox[{
     TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
      "PolyLog"], " ", 
     RowBox[{"log", "(", "x", ")"}]}], "-", 
    RowBox[{
     TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
      "PolyLog"], " ", 
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["S", 
      RowBox[{
       FormBox["1",
        TraditionalForm], 
       FormBox["2",
        TraditionalForm]}]], "(", 
     FormBox[
      RowBox[{"1", "-", "x"}],
      TraditionalForm], ")"}], "+", 
    RowBox[{
     SubscriptBox["S", 
      RowBox[{
       FormBox["1",
        TraditionalForm], 
       FormBox["2",
        TraditionalForm]}]], "(", "x", ")"}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["log", "3"], "(", "x", ")"}], "6"], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      SuperscriptBox["log", "2"], "(", 
      RowBox[{"1", "-", "x"}], ")"}], " ", 
     RowBox[{"log", "(", "x", ")"}]}], "-", 
    TemplateBox[{"3"},
     "Zeta"]}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyPolyLog",
 CellLabel->"Out[1473]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sip", "[", 
  RowBox[{"PolyLog", "[", 
   RowBox[{"4", ",", 
    RowBox[{"-", 
     RowBox[{"x", "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "x"}], ")"}]}]}]}], "]"}], "]"}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1474]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[{"4",RowBox[{"-", 
       FractionBox["x", 
        RowBox[{"1", "-", "x"}]]}]},
    "PolyLog"], "\[LongEqual]", 
   RowBox[{
    RowBox[{"-", 
     TemplateBox[{"4","x"},
      "PolyLog"]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
      "PolyLog"], " ", 
     RowBox[{
      SuperscriptBox["log", "2"], "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "-", 
    RowBox[{
     TemplateBox[{"2",RowBox[{"1", "-", "x"}]},
      "PolyLog"], " ", 
     RowBox[{"log", "(", "x", ")"}], " ", 
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "-", 
    RowBox[{
     SubscriptBox["S", 
      RowBox[{
       FormBox["1",
        TraditionalForm], 
       FormBox["3",
        TraditionalForm]}]], "(", "x", ")"}], "+", 
    RowBox[{
     SubscriptBox["S", 
      RowBox[{
       FormBox["2",
        TraditionalForm], 
       FormBox["2",
        TraditionalForm]}]], "(", "x", ")"}], "-", 
    RowBox[{
     RowBox[{
      SubscriptBox["S", 
       RowBox[{
        FormBox["1",
         TraditionalForm], 
        FormBox["2",
         TraditionalForm]}]], "(", 
      FormBox[
       RowBox[{"1", "-", "x"}],
       TraditionalForm], ")"}], " ", 
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "-", 
    RowBox[{
     RowBox[{
      SubscriptBox["S", 
       RowBox[{
        FormBox["1",
         TraditionalForm], 
        FormBox["2",
         TraditionalForm]}]], "(", "x", ")"}], " ", 
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
     RowBox[{
      SuperscriptBox["log", "2"], "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
     RowBox[{"log", "(", "x", ")"}], " ", 
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "+", 
    RowBox[{
     TemplateBox[{"3"},
      "Zeta"], " ", 
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "-", 
    RowBox[{
     FractionBox["1", "24"], " ", 
     RowBox[{
      SuperscriptBox["log", "4"], "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"log", "(", "x", ")"}], " ", 
     RowBox[{
      SuperscriptBox["log", "3"], "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      SuperscriptBox["log", "2"], "(", "x", ")"}], " ", 
     RowBox[{
      SuperscriptBox["log", "2"], "(", 
      RowBox[{"1", "-", "x"}], ")"}]}]}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyPolyLog",
 CellLabel->"Out[1474]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sip", "[", 
  RowBox[{"Log", "[", 
   RowBox[{"a", "+", 
    RowBox[{"b", "/", "c"}]}], "]"}], "]"}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1475]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"log", "(", 
    RowBox[{"a", "+", 
     FractionBox["b", "c"]}], ")"}], "\[LongEqual]", 
   RowBox[{"log", "(", 
    FractionBox[
     RowBox[{
      RowBox[{"a", " ", "c"}], "+", "b"}], "c"], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"SimplifyPolyLog",
 CellLabel->"Out[1475]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sip", "[", 
  RowBox[{"Log", "[", 
   RowBox[{"1", "/", "x"}], "]"}], "]"}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1476]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"log", "(", 
    FractionBox["1", "x"], ")"}], "\[LongEqual]", 
   RowBox[{"-", 
    RowBox[{"log", "(", "x", ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyPolyLog",
 CellLabel->"Out[1476]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sip", "[", 
  RowBox[{"ArcTanh", "[", "x", "]"}], "]"}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1477]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["tanh", 
     RowBox[{"-", "1"}]], "(", "x", ")"}], "\[LongEqual]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"log", "(", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"x", "+", "1"}], 
       RowBox[{"1", "-", "x"}]]}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"SimplifyPolyLog",
 CellLabel->"Out[1477]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sip", "[", 
  RowBox[{"ArcSinh", "[", "x", "]"}], "]"}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1478]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["sinh", 
     RowBox[{"-", "1"}]], "(", "x", ")"}], "\[LongEqual]", 
   RowBox[{"log", "(", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["x", "2"], "+", "1"}]], "+", "x"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"SimplifyPolyLog",
 CellLabel->"Out[1478]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sip", "[", 
  RowBox[{"ArcCosh", "[", "x", "]"}], "]"}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1479]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["cosh", 
     RowBox[{"-", "1"}]], "(", "x", ")"}], "\[LongEqual]", 
   RowBox[{"log", "(", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["x", "2"], "-", "1"}]], "+", "x"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"SimplifyPolyLog",
 CellLabel->"Out[1479]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "sip", "]"}]], "Input",
 CellTags->"SimplifyPolyLog",
 CellLabel->"In[1480]:="]
}, Open  ]],

Cell["Simplify2  ***unfinished***", "ObjectName",
 CellTags->"Simplify2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Simplify2"],

Cell["Simplify2 is a special ordering function.", "Text",
 CellTags->"Simplify2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Simplify2"],

Cell[BoxData[""], "Input",
 CellTags->"Simplify2",
 CellLabel->"In[1481]:="]
}, Open  ]],

Cell["SmallDelta", "ObjectName",
 CellTags->"SmallDelta"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SmallDelta"],

Cell["SmallDelta denotes some small positive number.", "Text",
 CellTags->"SmallDelta"]
}, Open  ]],

Cell["SmallEpsilon", "ObjectName",
 CellTags->"SmallEpsilon"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SmallEpsilon"],

Cell["SmallEpsilon denotes some small positive number.", "Text",
 CellTags->"SmallEpsilon"]
}, Open  ]],

Cell["SmallVariable", "ObjectName",
 CellTags->"SmallVariable"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SmallVariable"],

Cell["\<\
SmallVariable[me] is the head of small (negligible) variables. This means any \
mass with this head can be neglected if it appears in a sum, but not as an \
argument of Passarino-Veltman (PaVe) functions or PropagatorDenominator.\
\>", "Text",
 CellTags->"SmallVariable"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["PaVe",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVe",
  ButtonNote->"PaVe"],
 ", ",
 ButtonBox["PaVeReduce",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVeReduce",
  ButtonNote->"PaVeReduce"],
 ", ",
 ButtonBox["PropagatorDenominator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PropagatorDenominator",
  ButtonNote->"PropagatorDenominator"],
 "."
}], "Text",
 CellTags->"SmallVariable"]
}, Open  ]],

Cell["SmallVariables", "ObjectName",
 CellTags->"SmallVariables"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SmallVariables"],

Cell["\<\
SmallVariables is an option for OneLoop. \"SmallVariables\[Rule]{Melectron}\" \
i.e. will substitute \"SmallVariable[Melectron]\"  for all Melectron's in the \
calculation.\
\>", "Text",
 CellTags->"SmallVariables"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OneLoop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoop",
  ButtonNote->"OneLoop"],
 "."
}], "Text",
 CellTags->"SmallVariables"]
}, Open  ]],

Cell["SMP", "ObjectName",
 CellTags->"SMP"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SMP"],

Cell["\<\
SMP[par] substitutes a symbol for the  Standard Model parameter par.  SMP[] \
gives the list of substitutions. par should be a string; e.g., SMP[\"SW\"] \
gives  sw (in the Global` context).\
\>", "Text",
 CellTags->"SMP"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SMP", "[", "]"}], "//", "InputForm"}]], "Input",
 CellTags->"SMP",
 CellLabel->"In[1482]:="],

Cell["\<\
{\"EL\" :> e, \"CW\" :> cw, \"ME\" :> me, \"MH\" :> mh, \"MW\" :> mw, \"SW\" \
:> sw}\
\>", "Output",
 CellTags->"SMP",
 CellLabel->"Out[1482]//InputForm="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 ButtonBox["SMVertex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SMVertex",
  ButtonNote->"SMVertex"],
 "."
}], "Text",
 CellTags->"SMP"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SMP"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SMP", "[", "\"\<ME\>\"", "]"}]], "Input",
 CellTags->"SMP",
 CellLabel->"In[1483]:="],

Cell[BoxData[
 FormBox["me", TraditionalForm]], "Output",
 CellTags->"SMP",
 CellLabel->"Out[1483]="]
}, Open  ]]
}, Open  ]],

Cell["SMVertex", "ObjectName",
 CellTags->"SMVertex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SMVertex"],

Cell["\<\
SMVertex[\"AWW\", p,mu, q,nu, k,rho] gives the photon-W-W vertex (p,mu \
correspond to the photon, q,nu to the (incoming) W+ and k,rho to the \
(incoming) W-. All momenta are flowing into the vertex.  SMVertex[\"HHH\", \
___] give the three-higgs coupling. \
\>", "Text",
 CellTags->"SMVertex"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SMVertex", "//", "Options"}]], "Input",
 CellTags->"SMVertex",
 CellLabel->"In[1484]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Dimension", "\[Rule]", "4"}], ",", 
    RowBox[{"Explicit", "\[Rule]", "True"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"SMVertex",
 CellLabel->"Out[1484]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SMVertex"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SMVertex", "[", 
  RowBox[{
  "\"\<AWW\>\"", ",", "p", ",", "\[Mu]", ",", " ", "q", ",", "\[Nu]", ",", 
   " ", "k", ",", "\[Rho]"}], "]"}]], "Input",
 CellTags->"SMVertex",
 CellLabel->"In[1485]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", "e", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FormBox[
          RowBox[{"k", "-", "p"}],
          TraditionalForm], ")"}], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]]}]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FormBox[
         RowBox[{"k", "-", "q"}],
         TraditionalForm], ")"}], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FormBox[
         RowBox[{"p", "-", "q"}],
         TraditionalForm], ")"}], 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"SMVertex",
 CellLabel->"Out[1485]="]
}, Open  ]]
}, Open  ]],

Cell["Smu  ***unfinished***", "ObjectName",
 CellTags->"Smu"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Smu"],

Cell["Smu  is ...", "Text",
 CellTags->"Smu"]
}, Open  ]],

Cell["Sn", "ObjectName",
 CellTags->"Sn"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Sn"],

Cell[TextData[{
 "Sn is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Pi]", 
    RowBox[{"n", "/", "2"}]], TraditionalForm]]],
 "/",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"2", " ", "\[Pi]"}], ")"}], "n"], TraditionalForm]]],
 "."
}], "Text",
 CellTags->"Sn"]
}, Open  ]],

Cell["SO", "ObjectName",
 CellTags->"SO"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SO"],

Cell["\<\
SO[q] is a four-dimensional scalar product of OPEDelta with q. It is \
transformed into Pair[Momentum[q], Momentum[OPEDelta] by FCI.\
\>", "Text",
 CellTags->"SO"],

Cell[TextData[{
 "See also: ",
 ButtonBox["FCI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FCI",
  ButtonNote->"FCI"],
 ", ",
 ButtonBox["OPEDelta",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OPEDelta",
  ButtonNote->"OPEDelta"],
 ", ",
 ButtonBox["Pair",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Pair",
  ButtonNote->"Pair"],
 ", ",
 ButtonBox["ScalarProduct",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ScalarProduct",
  ButtonNote->"ScalarProduct"],
 ", ",
 ButtonBox["SOD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SOD",
  ButtonNote->"SOD"],
 "."
}], "Text",
 CellTags->"SO"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SO"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SO", "[", "p", "]"}]], "Input",
 CellTags->"SO",
 CellLabel->"In[1486]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["\<\"\[CapitalDelta]\"\>",
    TraditionalForm], 
   FormBox["\<\"\[CenterDot]\"\>",
    TraditionalForm], 
   FormBox["p",
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"SO",
 CellLabel->"Out[1486]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SO", "[", 
  RowBox[{"p", "-", "q"}], "]"}]], "Input",
 CellTags->"SO",
 CellLabel->"In[1487]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["\<\"\[CapitalDelta]\"\>",
    TraditionalForm], 
   FormBox["\<\"\[CenterDot]\"\>",
    TraditionalForm], 
   FormBox["\<\"(\"\>",
    TraditionalForm], 
   FormBox[
    RowBox[{"p", "-", "q"}],
    TraditionalForm], 
   FormBox["\<\")\"\>",
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"SO",
 CellLabel->"Out[1487]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SO", "[", "p", "]"}], "//", "FCI"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SO",
 CellLabel->"In[1488]:="],

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", "OPEDelta", "]"}], ",", 
   RowBox[{"Momentum", "[", "p", "]"}]}], "]"}]], "Output",
 CellTags->"SO",
 CellLabel->"Out[1488]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["SOD", "ObjectName",
 CellTags->"SOD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SOD"],

Cell["\<\
SOD[q] is a D-dimensional scalar product of OPEDelta with q. It is \
transformed into Pair[Momentum[q,D], Momentum[OPEDelta,D] by FeynCalcInternal.\
\>", "Text",
 CellTags->"SOD"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OPEDelta",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OPEDelta",
  ButtonNote->"OPEDelta"],
 ", ",
 ButtonBox["Pair",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Pair",
  ButtonNote->"Pair"],
 ", ",
 ButtonBox["ScalarProduct",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ScalarProduct",
  ButtonNote->"ScalarProduct"],
 ", ",
 ButtonBox["SOD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SOD",
  ButtonNote->"SOD"],
 "."
}], "Text",
 CellTags->"SOD"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SOD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SOD", "[", "p", "]"}]], "Input",
 CellTags->"SOD",
 CellLabel->"In[1489]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["\<\"\[CapitalDelta]\"\>",
    TraditionalForm], 
   FormBox["\<\"\[CenterDot]\"\>",
    TraditionalForm], 
   FormBox["p",
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"SOD",
 CellLabel->"Out[1489]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SOD", "[", 
  RowBox[{"p", "-", "q"}], "]"}]], "Input",
 CellTags->"SOD",
 CellLabel->"In[1490]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["\<\"\[CapitalDelta]\"\>",
    TraditionalForm], 
   FormBox["\<\"\[CenterDot]\"\>",
    TraditionalForm], 
   FormBox["\<\"(\"\>",
    TraditionalForm], 
   FormBox[
    RowBox[{"p", "-", "q"}],
    TraditionalForm], 
   FormBox["\<\")\"\>",
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"SOD",
 CellLabel->"Out[1490]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SOD", "[", "p", "]"}], "//", "FCI"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SOD",
 CellLabel->"In[1491]:="],

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", 
    RowBox[{"OPEDelta", ",", "D"}], "]"}], ",", 
   RowBox[{"Momentum", "[", 
    RowBox[{"p", ",", "D"}], "]"}]}], "]"}]], "Output",
 CellTags->"SOD",
 CellLabel->"Out[1491]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["Solve2", "ObjectName",
 CellTags->"Solve2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Solve2"],

Cell["\<\
Solve2 is equivalent to Solve, except that it works only for linear equations \
(and returns just a list) and accepts the options Factoring and \
FinalSubstitutions. Solve2 uses the \"high school algorithm\" and factors \
intermediate results. Therefore it can be drastically more useful than Solve.\
\
\>", "Text",
 CellTags->"Solve2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Solve2", "]"}]], "Input",
 CellTags->"Solve2",
 CellLabel->"In[1492]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Factoring", "\[Rule]", "Factor2"}], ",", 
    RowBox[{"FinalSubstitutions", "\[Rule]", 
     RowBox[{"{", "}"}]}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"Solve2",
 CellLabel->"Out[1492]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Solve2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve2", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "x"}], "==", 
      RowBox[{"b", "-", 
       RowBox[{"w", "/", "2"}]}]}], ",", 
     RowBox[{
      RowBox[{"y", "-", "d"}], "==", "p"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input",
 CellTags->"Solve2",
 CellLabel->"In[1493]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "\[Rule]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "b"}], "-", "w"}], ")"}]}]}], ",", 
    RowBox[{"y", "\[Rule]", 
     RowBox[{"d", "+", "p"}]}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"Solve2",
 CellLabel->"Out[1493]="]
}, Open  ]],

Cell["\<\
If no equation sign is given the polynomials are supposed to be 0.\
\>", "Text",
 CellTags->"Solve2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve2", "[", 
  RowBox[{
   RowBox[{"x", "+", "y"}], ",", "x"}], "]"}]], "Input",
 CellTags->"Solve2",
 CellLabel->"In[1494]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"x", "\[Rule]", 
    RowBox[{"-", "y"}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"Solve2",
 CellLabel->"Out[1494]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve2", "[", 
  RowBox[{
   RowBox[{"x", "+", "y"}], ",", "x", ",", 
   RowBox[{"FinalSubstitutions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"y", "\[Rule]", "h"}], "}"}]}]}], "]"}]], "Input",
 CellTags->"Solve2",
 CellLabel->"In[1495]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"x", "\[Rule]", 
    RowBox[{"-", "h"}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"Solve2",
 CellLabel->"Out[1495]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve2", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "x"}], "==", 
      RowBox[{"b", "-", 
       RowBox[{"w", "/", "2"}]}]}], ",", 
     RowBox[{
      RowBox[{"y", "-", "d"}], "==", "p"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}], ",", 
   RowBox[{"Factoring", "\[Rule]", "Expand"}]}], "]"}]], "Input",
 CellTags->"Solve2",
 CellLabel->"In[1496]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "\[Rule]", 
     RowBox[{
      FractionBox["b", "2"], "-", 
      FractionBox["w", "4"]}]}], ",", 
    RowBox[{"y", "\[Rule]", 
     RowBox[{"d", "+", "p"}]}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"Solve2",
 CellLabel->"Out[1496]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "x"}], "==", 
      RowBox[{"b", "-", 
       RowBox[{"w", "/", "2"}]}]}], ",", 
     RowBox[{
      RowBox[{"y", "-", "d"}], "==", "p"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input",
 CellTags->"Solve2",
 CellLabel->"In[1497]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "b"}], "-", "w"}], ")"}]}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"d", "+", "p"}]}]}], "}"}], "}"}], TraditionalForm]], "Output",
 CellTags->"Solve2",
 CellLabel->"Out[1497]="]
}, Open  ]]
}, Open  ]],

Cell["Solve3", "ObjectName",
 CellTags->"Solve3"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Solve3"],

Cell["\<\
Solve3 is equivalent to Solve, except that it works only for linear equations \
(and returns just a list) and uses the \"high school algorithm\" and is \
sometimes better than Solve for systems involving rational polyonomials.\
\>", "Text",
 CellTags->"Solve3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Solve3", "]"}]], "Input",
 CellTags->"Solve3",
 CellLabel->"In[1498]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Factoring", "\[Rule]", "False"}], ",", 
    RowBox[{"FinalSubstitutions", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"ParallelMap", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Solve3",
 CellLabel->"Out[1498]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 ButtonBox["Solve2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Solve2",
  ButtonNote->"Solve2"],
 "."
}], "Text",
 CellTags->"SMP"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Solve3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve3", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", "x"}], "==", 
      RowBox[{"b", "-", 
       RowBox[{"w", "/", "2"}]}]}], ",", 
     RowBox[{
      RowBox[{"y", "-", "d"}], "==", "p"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input",
 CellTags->"Solve3",
 CellLabel->"In[1499]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "\[Rule]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "b"}], "-", "w"}], ")"}]}]}], ",", 
    RowBox[{"y", "\[Rule]", 
     RowBox[{"d", "+", "p"}]}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"Solve3",
 CellLabel->"Out[1499]="]
}, Open  ]]
}, Open  ]],

Cell["SP", "ObjectName",
 CellTags->"SP"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SP"],

Cell[TextData[{
 "SP[a, b] denotes a four-dimensional scalar product. SP[a, b] is transformed \
into ScalarProduct[a, b] by FeynCalcInternal. SP[p] is the same as SP[p, p] \
",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"=", 
     SuperscriptBox["p", "2"]}]}], TraditionalForm]]],
 ")."
}], "Text",
 CellTags->"SP"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Calc",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Calc",
  ButtonNote->"Calc"],
 ", ",
 ButtonBox["ExpandScalarProduct",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExpandScalarProduct",
  ButtonNote->"ExpandScalarProduct"],
 ", ",
 ButtonBox["ScalarProduct",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ScalarProduct",
  ButtonNote->"ScalarProduct"],
 "."
}], "Text",
 CellTags->"SP"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SP"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SP", "[", 
   RowBox[{"p", ",", "q"}], "]"}], " ", "+", " ", 
  RowBox[{"SP", "[", "q", "]"}]}]], "Input",
 CellTags->"SP",
 CellLabel->"In[1500]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}],
    TraditionalForm], "+", 
   FormBox[
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], "2"],
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"SP",
 CellLabel->"Out[1500]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SP", "[", 
  RowBox[{
   RowBox[{"p", "-", "q"}], ",", 
   RowBox[{"q", "+", 
    RowBox[{"2", "p"}]}]}], "]"}]], "Input",
 CellTags->"SP",
 CellLabel->"In[1501]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"(", 
   FormBox[
    RowBox[{"p", "-", "q"}],
    TraditionalForm], ")", "\[CenterDot]", "(", 
   FormBox[
    RowBox[{
     RowBox[{"2", " ", "p"}], "+", "q"}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"SP",
 CellLabel->"Out[1501]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", " ", 
  RowBox[{"SP", "[", 
   RowBox[{
    RowBox[{"p", "-", "q"}], ",", 
    RowBox[{"q", "+", 
     RowBox[{"2", "p"}]}]}], "]"}], " ", "]"}]], "Input",
 CellTags->"SP",
 CellLabel->"In[1502]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]}], "-", 
   SuperscriptBox[
    FormBox["q",
     TraditionalForm], "2"]}], TraditionalForm]], "Output",
 CellTags->"SP",
 CellLabel->"Out[1502]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandScalarProduct", "[", 
  RowBox[{"SP", "[", 
   RowBox[{"p", "-", "q"}], "]"}], "]"}]], "Input",
 CellTags->"SP",
 CellLabel->"In[1503]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]}], "+", 
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], "2"], "+", 
   SuperscriptBox[
    FormBox["q",
     TraditionalForm], "2"]}], TraditionalForm]], "Output",
 CellTags->"SP",
 CellLabel->"Out[1503]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SP", "[", 
   RowBox[{"a", ",", "b"}], "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"SP",
 CellLabel->"In[1504]:="],

Cell[BoxData[
 RowBox[{"SP", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Output",
 CellTags->"SP",
 CellLabel->"Out[1504]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SP", "[", 
    RowBox[{"a", ",", "b"}], "]"}], "//", "FCI"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SP",
 CellLabel->"In[1505]:="],

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", "a", "]"}], ",", 
   RowBox[{"Momentum", "[", "b", "]"}]}], "]"}]], "Output",
 CellTags->"SP",
 CellLabel->"Out[1505]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SP", "[", 
     RowBox[{"a", ",", "b"}], "]"}], "//", "FCI"}], "//", "FCE"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SP",
 CellLabel->"In[1506]:="],

Cell[BoxData[
 RowBox[{"SP", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Output",
 CellTags->"SP",
 CellLabel->"Out[1506]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["SPC", "ObjectName",
 CellTags->"SPC"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SPC"],

Cell["SPC is an abbreviation for ScalarProductCancel.", "Text",
 CellTags->"SPC"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["ScalarProductCancel",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ScalarProductCancel",
  ButtonNote->"ScalarProductCancel"],
 "."
}], "Text",
 CellTags->"SPC"]
}, Open  ]],

Cell["SPD", "ObjectName",
 CellTags->"SPD"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SPD"],

Cell[TextData[{
 "SPD[a, b] denotes a D-dimensional scalar product. SPD[a, b] is transformed \
into ScalarProduct[a, b,Dimension\[Rule]D] by FeynCalcInternal. SPD[p] is the \
same as SPD[p,p] ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"=", 
     SuperscriptBox["p", "2"]}]}], TraditionalForm]]],
 ")."
}], "Text",
 CellTags->"SPD"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["PD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PD",
  ButtonNote->"PD"],
 ", ",
 ButtonBox["Calc",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Calc",
  ButtonNote->"Calc"],
 ", ",
 ButtonBox["ExpandScalarProduct",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExpandScalarProduct",
  ButtonNote->"ExpandScalarProduct"],
 ", ",
 ButtonBox["ScalarProduct",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ScalarProduct",
  ButtonNote->"ScalarProduct"],
 "."
}], "Text",
 CellTags->"SPD"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SPD"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SPD", "[", 
   RowBox[{"p", ",", "q"}], "]"}], " ", "+", " ", 
  RowBox[{"SPD", "[", "q", "]"}]}]], "Input",
 CellTags->"SPD",
 CellLabel->"In[1507]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}],
    TraditionalForm], "+", 
   FormBox[
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], "2"],
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"SPD",
 CellLabel->"Out[1507]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SPD", "[", 
  RowBox[{
   RowBox[{"p", "-", "q"}], ",", 
   RowBox[{"q", "+", 
    RowBox[{"2", "p"}]}]}], "]"}]], "Input",
 CellTags->"SPD",
 CellLabel->"In[1508]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"(", 
   FormBox[
    RowBox[{"p", "-", "q"}],
    TraditionalForm], ")", "\[CenterDot]", "(", 
   FormBox[
    RowBox[{
     RowBox[{"2", " ", "p"}], "+", "q"}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"SPD",
 CellLabel->"Out[1508]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", " ", 
  RowBox[{"SPD", "[", 
   RowBox[{
    RowBox[{"p", "-", "q"}], ",", 
    RowBox[{"q", "+", 
     RowBox[{"2", "p"}]}]}], "]"}], " ", "]"}]], "Input",
 CellTags->"SPD",
 CellLabel->"In[1509]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]}], "-", 
   SuperscriptBox[
    FormBox["q",
     TraditionalForm], "2"]}], TraditionalForm]], "Output",
 CellTags->"SPD",
 CellLabel->"Out[1509]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ExpandScalarProduct", "[", 
  RowBox[{"SPD", "[", 
   RowBox[{"p", "-", "q"}], "]"}], "]"}]], "Input",
 CellTags->"SPD",
 CellLabel->"In[1510]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]}], "+", 
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], "2"], "+", 
   SuperscriptBox[
    FormBox["q",
     TraditionalForm], "2"]}], TraditionalForm]], "Output",
 CellTags->"SPD",
 CellLabel->"Out[1510]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SPD", "[", 
   RowBox[{"a", ",", "b"}], "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"SPD",
 CellLabel->"In[1511]:="],

Cell[BoxData[
 RowBox[{"SPD", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Output",
 CellTags->"SPD",
 CellLabel->"Out[1511]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SPD", "[", 
    RowBox[{"a", ",", "b"}], "]"}], "//", "FCI"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SPD",
 CellLabel->"In[1512]:="],

Cell[BoxData[
 RowBox[{"Pair", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", 
    RowBox[{"a", ",", "D"}], "]"}], ",", 
   RowBox[{"Momentum", "[", 
    RowBox[{"b", ",", "D"}], "]"}]}], "]"}]], "Output",
 CellTags->"SPD",
 CellLabel->"Out[1512]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SPD", "[", 
     RowBox[{"a", ",", "b"}], "]"}], "//", "FCI"}], "//", "FCE"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SPD",
 CellLabel->"In[1513]:="],

Cell[BoxData[
 RowBox[{"SPD", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Output",
 CellTags->"SPD",
 CellLabel->"Out[1513]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FCE", "[", 
   RowBox[{"ChangeDimension", "[", 
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"p", ",", "q"}], "]"}], ",", " ", "D"}], "]"}], "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SPD",
 CellLabel->"In[1514]:="],

Cell[BoxData[
 RowBox[{"SPD", "[", 
  RowBox[{"p", ",", "q"}], "]"}]], "Output",
 CellTags->"SPD",
 CellLabel->"Out[1514]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["Spinor", "ObjectName",
 CellTags->"Spinor"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Spinor"],

Cell[TextData[{
 "Spinor[p, m, o] is the head of Dirac spinors. Which of the spinors ",
 StyleBox["u",
  FontSlant->"Italic"],
 ", ",
 StyleBox["v",
  FontSlant->"Italic"],
 ", ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["u", "_"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{",", " "}], TraditionalForm]]],
 "or ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", 
    RowBox[{"_", " "}]], TraditionalForm]]],
 "is understood, depends on the sign of the momentum (p) argument and the \
relative position of DiracSlash[p]: Spinor[sign p, mass] is that spinor which \
yields: sign*mass*Spinor[p, mass] if the Dirac equation is applied (by \
DiracEquation or DiracSimplify).\nThe optional argument o can be used for \
additional degrees of freedom. If no optional argument o is supplied, a 1 is \
subsituted in.\nSpinors of fermions of mass ",
 StyleBox["m",
  FontSlant->"Italic"],
 " are normalized to have square ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["u", "_"], TraditionalForm]]],
 StyleBox["u",
  FontSlant->"Italic"],
 "=2 ",
 StyleBox["m",
  FontSlant->"Italic"],
 " and  ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", 
    RowBox[{"_", " "}]], TraditionalForm]]],
 StyleBox["v=",
  FontSlant->"Italic"],
 "-2 ",
 StyleBox["m",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellTags->"Spinor"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FermionSpinSum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FermionSpinSum",
  ButtonNote->"FermionSpinSum"],
 ", ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 ", ",
 ButtonBox["SpinorU",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SpinorU",
  ButtonNote->"SpinorU"],
 ", ",
 ButtonBox["SpinorV",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SpinorV",
  ButtonNote->"SpinorV"],
 ", ",
 ButtonBox["SpinorUBar",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SpinorUBar",
  ButtonNote->"SpinorUBar"],
 ", ",
 ButtonBox["SpinorVBar",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SpinorVBar",
  ButtonNote->"SpinorVBar"],
 "."
}], "Text",
 CellTags->"Spinor"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Spinor"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Spinor", "[", "p", "]"}]], "Input",
 CellTags->"Spinor",
 CellLabel->"In[1515]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[CurlyPhi]", "(", 
   FormBox["p",
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"Spinor",
 CellLabel->"Out[1515]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Spinor", "[", 
  RowBox[{"p", ",", "m"}], "]"}]], "Input",
 CellTags->"Spinor",
 CellLabel->"In[1516]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[CurlyPhi]", "(", 
   FormBox["p",
    TraditionalForm], ",", "m", ")"}], TraditionalForm]], "Output",
 CellTags->"Spinor",
 CellLabel->"Out[1516]="]
}, Open  ]],

Cell["\<\
FeynCalc uses covariant normalization (as opposed to e.g. the normalization \
used in Bjorken&Drell).\
\>", "Text",
 CellTags->"Spinor"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Spinor", "[", 
    RowBox[{"p", ",", "m"}], "]"}], ".", 
   RowBox[{"Spinor", "[", 
    RowBox[{"p", ",", "m"}], "]"}]}], "//", "DiracSimplify"}]], "Input",
 CellTags->"Spinor",
 CellLabel->"In[1517]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "m"}], TraditionalForm]], "Output",
 CellTags->"Spinor",
 CellLabel->"Out[1517]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DiracSimplify", "[", 
  RowBox[{
   RowBox[{"Spinor", "[", 
    RowBox[{
     RowBox[{"-", "p"}], ",", "m"}], "]"}], ".", 
   RowBox[{"DiracSlash", "[", "p", "]"}]}], "]"}]], "Input",
 CellTags->"Spinor",
 CellLabel->"In[1518]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "m"}], " ", 
   RowBox[{"\[CurlyPhi]", "(", 
    FormBox[
     RowBox[{"-", "p"}],
     TraditionalForm], ",", "m", ")"}]}], TraditionalForm]], "Output",
 CellTags->"Spinor",
 CellLabel->"Out[1518]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Spinor", "[", "p", "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"Spinor",
 CellLabel->"In[1519]:="],

Cell[BoxData[
 RowBox[{"Spinor", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", "p", "]"}], ",", "0", ",", "1"}], "]"}]], "Output",\

 CellTags->"Spinor",
 CellLabel->"Out[1519]//StandardForm="]
}, Open  ]],

Cell["\<\
By convention, ChangeDimension does not operate on momenta in Spinor's (but \
on e.g.  DiracSlash[Momentum[p]]). \
\>", "Text",
 CellTags->"Spinor"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ChangeDimension", "[", 
   RowBox[{
    RowBox[{"Spinor", "[", "p", "]"}], ",", "D"}], "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"Spinor",
 CellLabel->"In[1520]:="],

Cell[BoxData[
 RowBox[{"Spinor", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", "p", "]"}], ",", "0", ",", "1"}], "]"}]], "Output",\

 CellTags->"Spinor",
 CellLabel->"Out[1520]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Spinor", "[", 
   RowBox[{"p", ",", "m"}], "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"Spinor",
 CellLabel->"In[1521]:="],

Cell[BoxData[
 RowBox[{"Spinor", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", "p", "]"}], ",", "m", ",", "1"}], "]"}]], "Output",\

 CellTags->"Spinor",
 CellLabel->"Out[1521]//StandardForm="]
}, Open  ]],

Cell["SmallVariable's are discarded by Spinor.", "Text",
 CellTags->"Spinor"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Spinor", "[", 
   RowBox[{"p", ",", 
    RowBox[{"SmallVariable", "[", "m", "]"}]}], "]"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"Spinor",
 CellLabel->"In[1522]:="],

Cell[BoxData[
 RowBox[{"Spinor", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", "p", "]"}], ",", "0", ",", "1"}], "]"}]], "Output",\

 CellTags->"Spinor",
 CellLabel->"Out[1522]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["SpinorCollect", "ObjectName",
 CellTags->"SpinorCollect"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SpinorCollect"],

Cell["\<\
SpinorCollect is an option for FermionSpinSum. If set to False the  argument \
of FermionSpinSum has to be already collected w.r.t. Spinor.\
\>", "Text",
 CellTags->"SpinorCollect"],

Cell[TextData[{
 "See also:  ",
 ButtonBox["FermionSpinSum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FermionSpinSum",
  ButtonNote->"FermionSpinSum"],
 ", ",
 ButtonBox["Spinor",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Spinor",
  ButtonNote->"Spinor"],
 "."
}], "Text",
 CellTags->"SpinorCollect"]
}, Open  ]],

Cell["SpinorUBar", "ObjectName",
 CellTags->"SpinorUBar"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SpinorUBar"],

Cell[TextData[{
 "SpinorUBar[p, m] denotes a ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["u", "_"], TraditionalForm]]],
 "-spinor."
}], "Text",
 CellTags->"SpinorUBar"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Spinor",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Spinor",
  ButtonNote->"Spinor"],
 ", ",
 ButtonBox["SpinorU",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SpinorU",
  ButtonNote->"SpinorU"],
 ", ",
 ButtonBox["SpinorV",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SpinorV",
  ButtonNote->"SpinorV"],
 ", ",
 ButtonBox["SpinorVBar",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SpinorVBar",
  ButtonNote->"SpinorVBar"],
 "."
}], "Text",
 CellTags->"SpinorUBar"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SpinorUBar"],

Cell["One argument only assumes a massless spinor.", "Text",
 CellTags->"SpinorUBar"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SpinorUBar", "[", "p", "]"}]], "Input",
 CellTags->"SpinorUBar",
 CellLabel->"In[1523]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    OverscriptBox["\<\"u\"\>", "_"],
    TraditionalForm], "(", "p", ")"}], TraditionalForm]], "Output",
 CellTags->"SpinorUBar",
 CellLabel->"Out[1523]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SpinorUBar", "[", 
  RowBox[{"p", ",", "m"}], "]"}]], "Input",
 CellTags->"SpinorUBar",
 CellLabel->"In[1524]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    OverscriptBox["\<\"u\"\>", "_"],
    TraditionalForm], "(", "p", ",", "m", ")"}], TraditionalForm]], "Output",
 CellTags->"SpinorUBar",
 CellLabel->"Out[1524]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SpinorUBar", "[", 
   RowBox[{"p", ",", "m"}], "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"SpinorUBar",
 CellLabel->"In[1525]:="],

Cell[BoxData[
 RowBox[{"SpinorUBar", "[", 
  RowBox[{"p", ",", "m"}], "]"}]], "Output",
 CellTags->"SpinorUBar",
 CellLabel->"Out[1525]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SpinorUBar", "[", 
    RowBox[{"p", ",", "m"}], "]"}], "//", "FCI"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SpinorUBar",
 CellLabel->"In[1526]:="],

Cell[BoxData[
 RowBox[{"Spinor", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", "p", "]"}], ",", "m", ",", "1"}], "]"}]], "Output",\

 CellTags->"SpinorUBar",
 CellLabel->"Out[1526]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SpinorUBar", "[", 
     RowBox[{"p", ",", "m"}], "]"}], "//", "FCI"}], "//", "FCE"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SpinorUBar",
 CellLabel->"In[1527]:="],

Cell[BoxData[
 RowBox[{"Spinor", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", "p", "]"}], ",", "m", ",", "1"}], "]"}]], "Output",\

 CellTags->"SpinorUBar",
 CellLabel->"Out[1527]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["SpinorU", "ObjectName",
 CellTags->"SpinorU"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SpinorU"],

Cell["SpinorU[p, m, optarg] denotes a u-spinor.", "Text",
 CellTags->"SpinorU"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Spinor",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Spinor",
  ButtonNote->"Spinor"],
 ", ",
 ButtonBox["SpinorUBar",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SpinorUBar",
  ButtonNote->"SpinorUBar"],
 ", ",
 ButtonBox["SpinorV",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SpinorV",
  ButtonNote->"SpinorV"],
 ", ",
 ButtonBox["SpinorVBar",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SpinorVBar",
  ButtonNote->"SpinorVBar"],
 "."
}], "Text",
 CellTags->"SpinorU"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SpinorU"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SpinorU", "[", "p", "]"}]], "Input",
 CellTags->"SpinorU",
 CellLabel->"In[1528]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"u", "(", "p", ")"}], TraditionalForm]], "Output",
 CellTags->"SpinorU",
 CellLabel->"Out[1528]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SpinorU", "[", 
  RowBox[{"p", ",", "m"}], "]"}]], "Input",
 CellTags->"SpinorU",
 CellLabel->"In[1529]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"u", "(", "p", ",", "m", ")"}], TraditionalForm]], "Output",
 CellTags->"SpinorU",
 CellLabel->"Out[1529]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SpinorU", "[", 
   RowBox[{"p", ",", "m"}], "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"SpinorU",
 CellLabel->"In[1530]:="],

Cell[BoxData[
 RowBox[{"SpinorU", "[", 
  RowBox[{"p", ",", "m"}], "]"}]], "Output",
 CellTags->"SpinorU",
 CellLabel->"Out[1530]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SpinorU", "[", 
    RowBox[{"p", ",", "m"}], "]"}], "//", "FCI"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SpinorU",
 CellLabel->"In[1531]:="],

Cell[BoxData[
 RowBox[{"Spinor", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", "p", "]"}], ",", "m", ",", "1"}], "]"}]], "Output",\

 CellTags->"SpinorU",
 CellLabel->"Out[1531]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SpinorU", "[", 
     RowBox[{"p", ",", "m"}], "]"}], "//", "FCI"}], "//", "FCE"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SpinorU",
 CellLabel->"In[1532]:="],

Cell[BoxData[
 RowBox[{"Spinor", "[", 
  RowBox[{
   RowBox[{"Momentum", "[", "p", "]"}], ",", "m", ",", "1"}], "]"}]], "Output",\

 CellTags->"SpinorU",
 CellLabel->"Out[1532]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["SpinorVBar", "ObjectName",
 CellTags->"SpinorVBar"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SpinorVBar"],

Cell[TextData[{
 "SpinorVBar[p, m] denotes a ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "_"], TraditionalForm]]],
 "(p,m)-spinor."
}], "Text",
 CellTags->"SpinorVBar"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Spinor",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Spinor",
  ButtonNote->"Spinor"],
 ", ",
 ButtonBox["SpinorU",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SpinorU",
  ButtonNote->"SpinorU"],
 ", ",
 ButtonBox["SpinorV",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SpinorV",
  ButtonNote->"SpinorV"],
 ", ",
 ButtonBox["SpinorUBar",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SpinorUBar",
  ButtonNote->"SpinorUBar"],
 "."
}], "Text",
 CellTags->"SpinorVBar"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SpinorVBar"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SpinorVBar", "[", "p", "]"}]], "Input",
 CellTags->"SpinorVBar",
 CellLabel->"In[1533]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    OverscriptBox["\<\"v\"\>", "_"],
    TraditionalForm], "(", "p", ")"}], TraditionalForm]], "Output",
 CellTags->"SpinorVBar",
 CellLabel->"Out[1533]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SpinorVBar", "[", 
  RowBox[{"p", ",", "m"}], "]"}]], "Input",
 CellTags->"SpinorVBar",
 CellLabel->"In[1534]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    OverscriptBox["\<\"v\"\>", "_"],
    TraditionalForm], "(", "p", ",", "m", ")"}], TraditionalForm]], "Output",
 CellTags->"SpinorVBar",
 CellLabel->"Out[1534]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SpinorVBar", "[", 
   RowBox[{"p", ",", "m"}], "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"SpinorVBar",
 CellLabel->"In[1535]:="],

Cell[BoxData[
 RowBox[{"SpinorVBar", "[", 
  RowBox[{"p", ",", "m"}], "]"}]], "Output",
 CellTags->"SpinorVBar",
 CellLabel->"Out[1535]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SpinorVBar", "[", 
    RowBox[{"p", ",", "m"}], "]"}], "//", "FCI"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SpinorVBar",
 CellLabel->"In[1536]:="],

Cell[BoxData[
 RowBox[{"Spinor", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"Momentum", "[", "p", "]"}]}], ",", "m", ",", "1"}], 
  "]"}]], "Output",
 CellTags->"SpinorVBar",
 CellLabel->"Out[1536]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SpinorVBar", "[", 
     RowBox[{"p", ",", "m"}], "]"}], "//", "FCI"}], "//", "FCE"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SpinorVBar",
 CellLabel->"In[1537]:="],

Cell[BoxData[
 RowBox[{"Spinor", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"Momentum", "[", "p", "]"}]}], ",", "m", ",", "1"}], 
  "]"}]], "Output",
 CellTags->"SpinorVBar",
 CellLabel->"Out[1537]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["SpinorV", "ObjectName",
 CellTags->"SpinorV"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SpinorV"],

Cell["SpinorV[p, m, optarg] denotes a v-spinor.", "Text",
 CellTags->"SpinorV"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Spinor",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Spinor",
  ButtonNote->"Spinor"],
 ", ",
 ButtonBox["SpinorUBar",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SpinorUBar",
  ButtonNote->"SpinorUBar"],
 ", ",
 ButtonBox["SpinorU",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SpinorU",
  ButtonNote->"SpinorU"],
 ", ",
 ButtonBox["SpinorVBar",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SpinorVBar",
  ButtonNote->"SpinorVBar"],
 "."
}], "Text",
 CellTags->"SpinorV"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SpinorV"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SpinorV", "[", "p", "]"}]], "Input",
 CellTags->"SpinorV",
 CellLabel->"In[1538]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"v", "(", "p", ")"}], TraditionalForm]], "Output",
 CellTags->"SpinorV",
 CellLabel->"Out[1538]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SpinorV", "[", 
  RowBox[{"p", ",", "m"}], "]"}]], "Input",
 CellTags->"SpinorV",
 CellLabel->"In[1539]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"v", "(", "p", ",", "m", ")"}], TraditionalForm]], "Output",
 CellTags->"SpinorV",
 CellLabel->"Out[1539]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SpinorV", "[", 
   RowBox[{"p", ",", "m"}], "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"SpinorV",
 CellLabel->"In[1540]:="],

Cell[BoxData[
 RowBox[{"SpinorV", "[", 
  RowBox[{"p", ",", "m"}], "]"}]], "Output",
 CellTags->"SpinorV",
 CellLabel->"Out[1540]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SpinorV", "[", 
    RowBox[{"p", ",", "m"}], "]"}], "//", "FCI"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SpinorV",
 CellLabel->"In[1541]:="],

Cell[BoxData[
 RowBox[{"Spinor", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"Momentum", "[", "p", "]"}]}], ",", "m", ",", "1"}], 
  "]"}]], "Output",
 CellTags->"SpinorV",
 CellLabel->"Out[1541]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SpinorV", "[", 
     RowBox[{"p", ",", "m"}], "]"}], "//", "FCI"}], "//", "FCE"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SpinorV",
 CellLabel->"In[1542]:="],

Cell[BoxData[
 RowBox[{"Spinor", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"Momentum", "[", "p", "]"}]}], ",", "m", ",", "1"}], 
  "]"}]], "Output",
 CellTags->"SpinorV",
 CellLabel->"Out[1542]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["SpinPolarizationSum", "ObjectName",
 CellTags->"SpinPolarizationSum"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SpinPolarizationSum"],

Cell["\<\
SpinPolarizationSum is an option for FermionSpinSum. The set (pure) function \
acts on the usual spin sum.\
\>", "Text",
 CellTags->"SpinPolarizationSum"],

Cell[TextData[{
 "See also:  ",
 ButtonBox["FermionSpinSum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FermionSpinSum",
  ButtonNote->"FermionSpinSum"],
 "."
}], "Text",
 CellTags->"SpinPolarizationSum"]
}, Open  ]],

Cell["SPL", "ObjectName",
 CellTags->"SPL"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SPL"],

Cell["SPL is an abbreviation for SimplifyPolyLog.", "Text",
 CellTags->"SPL"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["SimplifyPolyLog",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SimplifyPolyLog",
  ButtonNote->"SimplifyPolyLog"],
 "."
}], "Text",
 CellTags->"SPL"]
}, Open  ]],

Cell["SplittingFunction", "ObjectName",
 CellTags->"SplittingFunction"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SplittingFunction"],

Cell[TextData[{
 "SplittingFunction[pxy] is a database of splitting functions in the ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["MS", "_"], TraditionalForm]]],
 " scheme."
}], "Text",
 CellTags->"SplittingFunction"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "SplittingFunction", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1543]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"Polarization", "\[Rule]", "1"}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1543]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["AnomalousDimension",
  BaseStyle->"AddOnsLink",
  ButtonData:>"AnomalousDimension",
  ButtonNote->"AnomalousDimension"],
 "."
}], "Text",
 CellTags->"SplittingFunction"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SplittingFunction"],

Cell["Unpolarized case:", "Text",
 CellTags->"SplittingFunction"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"SplittingFunction", ",", 
    RowBox[{"Polarization", "\[Rule]", "0"}]}], "]"}], ";"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1544]:="],

Cell["\<\
In general the argument should be a string, but if the variables Pqq, etc. \
have no value, you can omit the \"\".\
\>", "Text",
 CellTags->"SplittingFunction"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "Pqq", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1545]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "F"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"6", " ", 
      RowBox[{"\[Delta]", "(", 
       FormBox[
        RowBox[{"1", "-", "x"}],
        TraditionalForm], ")"}]}], "-", 
     RowBox[{"4", " ", "x"}], "+", 
     RowBox[{"8", " ", 
      SubscriptBox[
       RowBox[{"(", 
        FractionBox["1", 
         RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "-", "4"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1545]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "Pqg", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1546]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"16", " ", 
      SuperscriptBox["x", "2"]}], "-", 
     RowBox[{"16", " ", "x"}], "+", "8"}], ")"}], " ", 
   SubscriptBox["T", "f"]}], TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1546]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "Pgq", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1547]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", "x"}], "+", 
     FractionBox["8", "x"], "-", "8"}], ")"}], " ", 
   SubscriptBox["C", "F"]}], TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1547]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "Pgg", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1548]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"8", " ", 
    SubscriptBox["C", "A"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{
       FractionBox["11", "12"], " ", 
       RowBox[{"\[Delta]", "(", 
        FormBox[
         RowBox[{"1", "-", "x"}],
         TraditionalForm], ")"}]}], "+", "x", "+", 
      SubscriptBox[
       RowBox[{"(", 
        FractionBox["1", 
         RowBox[{"1", "-", "x"}]], ")"}], "+"], "+", 
      FractionBox["1", "x"], "-", "2"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["8", "3"], " ", 
    SubscriptBox["N", "f"], " ", 
    SubscriptBox["T", "f"], " ", 
    RowBox[{"\[Delta]", "(", 
     FormBox[
      RowBox[{"1", "-", "x"}],
      TraditionalForm], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1548]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "aqq", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1549]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "F"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7", "-", 
        RowBox[{"4", " ", 
         RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], ")"}], " ", 
      RowBox[{"\[Delta]", "(", 
       FormBox[
        RowBox[{"1", "-", "x"}],
        TraditionalForm], ")"}]}], "+", 
     RowBox[{"2", " ", "x"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "x"}], "+", "2"}], ")"}], " ", 
      RowBox[{"log", "(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "-", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"log", "(", "x", ")"}], 
         RowBox[{"1", "-", "x"}]], "+", 
        SubscriptBox[
         RowBox[{"(", 
          FractionBox[
           RowBox[{"log", "(", 
            RowBox[{"1", "-", "x"}], ")"}], 
           RowBox[{"1", "-", "x"}]], ")"}], "+"]}], ")"}]}], "-", "4"}], 
    ")"}]}], TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1549]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "agq", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1550]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "F"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"2", " ", "x"}]}], "-", 
     FractionBox["4", "x"], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"2", " ", "x"}]}], "-", 
        FractionBox["4", "x"], "+", "4"}], ")"}], " ", 
      RowBox[{"log", "(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "+", "2"}], 
    ")"}]}], TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1550]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "aqg", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1551]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["T", "f"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"8", " ", 
          SuperscriptBox["x", "2"]}]}], "+", 
        RowBox[{"8", " ", "x"}], "-", "4"}], ")"}], " ", 
      RowBox[{"log", "(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "-", "4"}], 
    ")"}]}], TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1551]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "agg", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1552]:="],

Cell["Polarized case:", "Text",
 CellTags->"SplittingFunction"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"SplittingFunction", ",", 
    RowBox[{"Polarization", "\[Rule]", "1"}]}], "]"}], ";"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1553]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "Pqq", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1554]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "F"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"6", " ", 
      RowBox[{"\[Delta]", "(", 
       FormBox[
        RowBox[{"1", "-", "x"}],
        TraditionalForm], ")"}]}], "-", 
     RowBox[{"4", " ", "x"}], "+", 
     RowBox[{"8", " ", 
      SubscriptBox[
       RowBox[{"(", 
        FractionBox["1", 
         RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "-", "4"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1554]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "Pqg", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1555]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"16", " ", "x"}], "-", "8"}], ")"}], " ", 
   SubscriptBox["T", "f"]}], TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1555]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "Pgq", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1556]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"8", "-", 
     RowBox[{"4", " ", "x"}]}], ")"}], " ", 
   SubscriptBox["C", "F"]}], TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1556]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "Pgg", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1557]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "A"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["22", "3"], " ", 
       RowBox[{"\[Delta]", "(", 
        FormBox[
         RowBox[{"1", "-", "x"}],
         TraditionalForm], ")"}]}], "-", 
      RowBox[{"16", " ", "x"}], "+", 
      RowBox[{"8", " ", 
       SubscriptBox[
        RowBox[{"(", 
         FractionBox["1", 
          RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "+", "8"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["8", "3"], " ", 
    SubscriptBox["N", "f"], " ", 
    SubscriptBox["T", "f"], " ", 
    RowBox[{"\[Delta]", "(", 
     FormBox[
      RowBox[{"1", "-", "x"}],
      TraditionalForm], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1557]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "aqq", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1558]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "F"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7", "-", 
        RowBox[{"4", " ", 
         RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], ")"}], " ", 
      RowBox[{"\[Delta]", "(", 
       FormBox[
        RowBox[{"1", "-", "x"}],
        TraditionalForm], ")"}]}], "+", 
     RowBox[{"8", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "x"}], ")"}]}], "+", 
     RowBox[{"2", " ", "x"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "x"}], "+", "2"}], ")"}], " ", 
      RowBox[{"log", "(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "-", 
     RowBox[{"4", " ", 
      SubscriptBox[
       RowBox[{"(", 
        FractionBox["1", 
         RowBox[{"1", "-", "x"}]], ")"}], "+"], " ", 
      RowBox[{"log", "(", "x", ")"}]}], "-", 
     RowBox[{"4", " ", 
      SubscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"log", "(", 
          RowBox[{"1", "-", "x"}], ")"}], 
         RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "-", "4"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1558]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "agq", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1559]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "F"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"4", " ", "x"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "x"}], "-", "4"}], ")"}], " ", 
      RowBox[{"log", "(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "+", "2"}], 
    ")"}]}], TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1559]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "agqd", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1560]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "F"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "x"}], "-", "4"}], ")"}], " ", 
      RowBox[{"log", "(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "-", "2"}], 
    ")"}]}], TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1560]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "aqg", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1561]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["T", "f"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4", "-", 
        RowBox[{"8", " ", "x"}]}], ")"}], " ", 
      RowBox[{"log", "(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "-", "4"}], 
    ")"}]}], TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1561]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "aqgd", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1562]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["T", "f"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4", "-", 
        RowBox[{"8", " ", "x"}]}], ")"}], " ", 
      RowBox[{"log", "(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "-", "4"}], 
    ")"}]}], TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1562]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "agg", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1563]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "A"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["67", "9"], "-", 
         RowBox[{"4", " ", 
          RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], ")"}], " ", 
       RowBox[{"\[Delta]", "(", 
        FormBox[
         RowBox[{"1", "-", "x"}],
         TraditionalForm], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", "x"}], "-", "4"}], ")"}], " ", 
       RowBox[{"log", "(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"log", "(", "x", ")"}], 
          RowBox[{"1", "-", "x"}]], "+", 
         SubscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{"log", "(", 
             RowBox[{"1", "-", "x"}], ")"}], 
            RowBox[{"1", "-", "x"}]], ")"}], "+"]}], ")"}]}], "+", "2"}], 
     ")"}]}], "-", 
   RowBox[{
    FractionBox["20", "9"], " ", 
    SubscriptBox["T", "f"], " ", 
    RowBox[{"\[Delta]", "(", 
     FormBox[
      RowBox[{"1", "-", "x"}],
      TraditionalForm], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1563]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "aggd", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1564]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "A"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["67", "9"], "-", 
         RowBox[{"4", " ", 
          RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], ")"}], " ", 
       RowBox[{"\[Delta]", "(", 
        FormBox[
         RowBox[{"1", "-", "x"}],
         TraditionalForm], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", "x"}], "-", "4"}], ")"}], " ", 
       RowBox[{"log", "(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "x"}], ")"}], " ", "x"}], ")"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"log", "(", "x", ")"}], 
          RowBox[{"1", "-", "x"}]], "+", 
         SubscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{"log", "(", 
             RowBox[{"1", "-", "x"}], ")"}], 
            RowBox[{"1", "-", "x"}]], ")"}], "+"]}], ")"}]}], "+", "2"}], 
     ")"}]}], "-", 
   RowBox[{
    FractionBox["20", "9"], " ", 
    SubscriptBox["T", "f"], " ", 
    RowBox[{"\[Delta]", "(", 
     FormBox[
      RowBox[{"1", "-", "x"}],
      TraditionalForm], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1564]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "PQQS", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1565]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "F"], " ", 
   SubscriptBox["T", "f"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"16", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", "x"}], ")"}]}], "-", 
     RowBox[{"16", " ", 
      RowBox[{"(", 
       RowBox[{"x", "+", "1"}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"48", " ", "x"}], "-", "16"}], ")"}], " ", 
      RowBox[{"log", "(", "x", ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 CellTags->"SplittingFunction",
 CellLabel->"Out[1565]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "PQQNS", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1566]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "8"}], " ", 
    SubscriptBox["C", "F"], " ", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["C", "F"], "-", 
      FractionBox[
       SubscriptBox["C", "A"], "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", "1"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"2", " ", 
            RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], "-", 
          RowBox[{"4", " ", 
           TemplateBox[{"2",RowBox[{"-", "x"}]},
            "PolyLog"]}], "+", 
          RowBox[{
           SuperscriptBox["log", "2"], "(", "x", ")"}], "-", 
          RowBox[{"4", " ", 
           RowBox[{"log", "(", 
            RowBox[{"x", "+", "1"}], ")"}], " ", 
           RowBox[{"log", "(", "x", ")"}]}]}], ")"}]}], 
       RowBox[{"x", "+", "1"}]], "+", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "x"}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"x", "+", "1"}], ")"}], " ", 
       RowBox[{"log", "(", "x", ")"}]}]}], ")"}]}], "+", 
   RowBox[{
    SubscriptBox["C", "A"], " ", 
    SubscriptBox["C", "F"], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["x", "2"], "+", "1"}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["log", "2"], "(", "x", ")"}]}], 
       RowBox[{"1", "-", "x"}]], "+", 
      RowBox[{"8", " ", 
       RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"x", "+", "1"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["536", "9"], "-", 
         RowBox[{"16", " ", 
          RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], ")"}], " ", 
       SubscriptBox[
        RowBox[{"(", 
         FractionBox["1", 
          RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "+", 
      RowBox[{
       RowBox[{"\[Delta]", "(", 
        FormBox[
         RowBox[{"1", "-", "x"}],
         TraditionalForm], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"88", " ", 
           RowBox[{"\[Zeta]", "(", "2", ")"}]}], "3"], "-", 
         RowBox[{"24", " ", 
          TemplateBox[{"3"},
           "Zeta"]}], "+", 
         FractionBox["17", "3"]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["4", "9"], " ", 
       RowBox[{"(", 
        RowBox[{"53", "-", 
         RowBox[{"187", " ", "x"}]}], ")"}]}], "-", 
      RowBox[{
       FractionBox["4", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"5", " ", "x"}], "-", 
         FractionBox["22", 
          RowBox[{"1", "-", "x"}]], "+", "5"}], ")"}], " ", 
       RowBox[{"log", "(", "x", ")"}]}]}], ")"}]}], "+", 
   RowBox[{
    SubscriptBox["C", "F"], " ", 
    SubscriptBox["N", "f"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", "1"}], ")"}], " ", 
         RowBox[{"log", "(", "x", ")"}]}], 
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", "x"}], ")"}]}]]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", 
            RowBox[{"\[Zeta]", "(", "2", ")"}]}], "3"]}], "-", 
         FractionBox["2", "3"]}], ")"}], " ", 
       RowBox[{"\[Delta]", "(", 
        FormBox[
         RowBox[{"1", "-", "x"}],
         TraditionalForm], ")"}]}], "+", 
      FractionBox[
       RowBox[{"88", " ", "x"}], "9"], "-", 
      RowBox[{
       FractionBox["80", "9"], " ", 
       SubscriptBox[
        RowBox[{"(", 
         FractionBox["1", 
          RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "-", 
      FractionBox["8", "9"]}], ")"}]}], "+", 
   RowBox[{
    SubsuperscriptBox["C", "F", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"16", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["x", "2"], "+", "1"}], ")"}], " ", 
         RowBox[{"log", "(", 
          RowBox[{"1", "-", "x"}], ")"}], " ", 
         RowBox[{"log", "(", "x", ")"}]}], 
        RowBox[{"1", "-", "x"}]]}], "+", 
      RowBox[{
       RowBox[{"\[Delta]", "(", 
        FormBox[
         RowBox[{"1", "-", "x"}],
         TraditionalForm], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"24", " ", 
           RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], "+", 
         RowBox[{"48", " ", 
          TemplateBox[{"3"},
           "Zeta"]}], "+", "3"}], ")"}]}], "-", 
      RowBox[{"40", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "x"}], ")"}]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{"x", "+", "1"}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["log", "2"], "(", "x", ")"}]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "x"}], "+", 
         FractionBox["3", 
          RowBox[{"1", "-", "x"}]]}], ")"}], " ", 
       RowBox[{"log", "(", "x", ")"}]}]}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1566]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "PQG", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1567]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"4", " ", 
    SubscriptBox["C", "A"], " ", 
    SubscriptBox["T", "f"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"8", " ", 
        RowBox[{"\[Zeta]", "(", "2", ")"}]}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"16", " ", "x"}]}], "-", "8"}], ")"}], " ", 
       TemplateBox[{"2",RowBox[{"-", "x"}]},
        "PolyLog"]}], "-", 
      RowBox[{"44", " ", "x"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"4", "-", 
         RowBox[{"8", " ", "x"}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["log", "2"], "(", 
        RowBox[{"1", "-", "x"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"8", " ", "x"}]}], "-", "4"}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"16", " ", "x"}], "-", "16"}], ")"}], " ", 
       RowBox[{"log", "(", 
        RowBox[{"1", "-", "x"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"32", " ", "x"}], "+", "4"}], ")"}], " ", 
       RowBox[{"log", "(", "x", ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"16", " ", "x"}]}], "-", "8"}], ")"}], " ", 
       RowBox[{"log", "(", "x", ")"}], " ", 
       RowBox[{"log", "(", 
        RowBox[{"x", "+", "1"}], ")"}]}], "+", "48"}], ")"}]}], "+", 
   RowBox[{"4", " ", 
    SubscriptBox["C", "F"], " ", 
    SubscriptBox["T", "f"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"8", " ", 
       RowBox[{"\[Zeta]", "(", "2", ")"}]}], "-", 
      RowBox[{"16", " ", 
       RowBox[{"\[Zeta]", "(", "2", ")"}], " ", "x"}], "+", 
      RowBox[{"54", " ", "x"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", "x"}], "-", "4"}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["log", "2"], "(", 
        RowBox[{"1", "-", "x"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", "x"}], "-", "2"}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"16", "-", 
         RowBox[{"16", " ", "x"}]}], ")"}], " ", 
       RowBox[{"log", "(", 
        RowBox[{"1", "-", "x"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"8", "-", 
         RowBox[{"16", " ", "x"}]}], ")"}], " ", 
       RowBox[{"log", "(", "x", ")"}], " ", 
       RowBox[{"log", "(", 
        RowBox[{"1", "-", "x"}], ")"}]}], "-", 
      RowBox[{"18", " ", 
       RowBox[{"log", "(", "x", ")"}]}], "-", "44"}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1567]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "PGQ", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1568]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["C", "A"], " ", 
      SubscriptBox["C", "F"]}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"16", " ", "x"}], "+", "32"}], ")"}], " ", 
       TemplateBox[{"2",RowBox[{"-", "x"}]},
        "PolyLog"]}], "+", 
      RowBox[{"16", " ", 
       RowBox[{"\[Zeta]", "(", "2", ")"}], " ", "x"}], "+", 
      FractionBox[
       RowBox[{"280", " ", "x"}], "9"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"16", "-", 
         RowBox[{"8", " ", "x"}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["log", "2"], "(", 
        RowBox[{"1", "-", "x"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", "x"}], "+", "16"}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"8", " ", "x"}], "3"], "+", 
         FractionBox["80", "3"]}], ")"}], " ", 
       RowBox[{"log", "(", 
        RowBox[{"1", "-", "x"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"16", " ", "x"}], "-", "32"}], ")"}], " ", 
       RowBox[{"log", "(", "x", ")"}], " ", 
       RowBox[{"log", "(", 
        RowBox[{"1", "-", "x"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"32", "-", 
         RowBox[{"104", " ", "x"}]}], ")"}], " ", 
       RowBox[{"log", "(", "x", ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"16", " ", "x"}], "+", "32"}], ")"}], " ", 
       RowBox[{"log", "(", "x", ")"}], " ", 
       RowBox[{"log", "(", 
        RowBox[{"x", "+", "1"}], ")"}]}], "+", 
      FractionBox["328", "9"]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["C", "F"], " ", 
      SubscriptBox["T", "f"]}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"32", " ", "x"}], "9"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"32", " ", "x"}], "3"], "-", 
         FractionBox["64", "3"]}], ")"}], " ", 
       RowBox[{"log", "(", 
        RowBox[{"1", "-", "x"}], ")"}]}], "-", 
      FractionBox["128", "9"]}], ")"}]}], "+", 
   RowBox[{
    SubsuperscriptBox["C", "F", "2"], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"32", " ", "x"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", "x"}], "-", "16"}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["log", "2"], "(", 
        RowBox[{"1", "-", "x"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"8", "-", 
         RowBox[{"4", " ", "x"}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"8", " ", "x"}]}], "-", "16"}], ")"}], " ", 
       RowBox[{"log", "(", 
        RowBox[{"1", "-", "x"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"32", " ", "x"}], "+", "64"}], ")"}], " ", 
       RowBox[{"log", "(", "x", ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"36", " ", "x"}], "+", "48"}], ")"}], " ", 
       RowBox[{"log", "(", "x", ")"}]}], "-", "68"}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1568]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SplittingFunction", "[", "PGG", "]"}]], "Input",
 CellTags->"SplittingFunction",
 CellLabel->"In[1569]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["C", "A"], " ", 
    SubscriptBox["T", "f"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        FractionBox["32", "3"], " ", 
        RowBox[{"\[Delta]", "(", 
         FormBox[
          RowBox[{"1", "-", "x"}],
          TraditionalForm], ")"}]}]}], "+", 
      FractionBox[
       RowBox[{"608", " ", "x"}], "9"], "-", 
      RowBox[{
       FractionBox["160", "9"], " ", 
       SubscriptBox[
        RowBox[{"(", 
         FractionBox["1", 
          RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"32", " ", "x"}], "3"]}], "-", 
         FractionBox["32", "3"]}], ")"}], " ", 
       RowBox[{"log", "(", "x", ")"}]}], "-", 
      FractionBox["448", "9"]}], ")"}]}], "+", 
   RowBox[{
    SubsuperscriptBox["C", "A", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"64", " ", "x"}], "+", 
         FractionBox["32", 
          RowBox[{"x", "+", "1"}]], "+", "32"}], ")"}], " ", 
       TemplateBox[{"2",RowBox[{"-", "x"}]},
        "PolyLog"]}], "+", 
      RowBox[{
       FractionBox["64", "3"], " ", 
       RowBox[{"\[Delta]", "(", 
        FormBox[
         RowBox[{"1", "-", "x"}],
         TraditionalForm], ")"}]}], "+", 
      RowBox[{
       RowBox[{"\[Zeta]", "(", "2", ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"64", " ", "x"}], "-", 
         RowBox[{"16", " ", 
          SubscriptBox[
           RowBox[{"(", 
            FractionBox["1", 
             RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "+", 
         FractionBox["16", 
          RowBox[{"x", "+", "1"}]]}], ")"}]}], "+", 
      RowBox[{"24", " ", 
       TemplateBox[{"3"},
        "Zeta"], " ", 
       RowBox[{"\[Delta]", "(", 
        FormBox[
         RowBox[{"1", "-", "x"}],
         TraditionalForm], ")"}]}], "-", 
      FractionBox[
       RowBox[{"388", " ", "x"}], "9"], "+", 
      RowBox[{
       FractionBox["536", "9"], " ", 
       SubscriptBox[
        RowBox[{"(", 
         FractionBox["1", 
          RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["8", 
           RowBox[{"x", "+", "1"}]]}], "+", 
         FractionBox["8", 
          RowBox[{"1", "-", "x"}]], "+", "32"}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["232", "3"], "-", 
         FractionBox[
          RowBox[{"536", " ", "x"}], "3"]}], ")"}], " ", 
       RowBox[{"log", "(", "x", ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"64", " ", "x"}], "-", 
         FractionBox["32", 
          RowBox[{"1", "-", "x"}]], "-", "32"}], ")"}], " ", 
       RowBox[{"log", "(", 
        RowBox[{"1", "-", "x"}], ")"}], " ", 
       RowBox[{"log", "(", "x", ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"64", " ", "x"}], "+", 
         FractionBox["32", 
          RowBox[{"x", "+", "1"}]], "+", "32"}], ")"}], " ", 
       RowBox[{"log", "(", 
        RowBox[{"x", "+", "1"}], ")"}], " ", 
       RowBox[{"log", "(", "x", ")"}]}], "-", 
      FractionBox["148", "9"]}], ")"}]}], "+", 
   RowBox[{
    SubscriptBox["C", "F"], " ", 
    SubscriptBox["T", "f"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"8", " ", 
        RowBox[{"\[Delta]", "(", 
         FormBox[
          RowBox[{"1", "-", "x"}],
          TraditionalForm], ")"}]}]}], "+", 
      RowBox[{"80", " ", "x"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"16", " ", "x"}]}], "-", "16"}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["log", "2"], "(", "x", ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"16", " ", "x"}], "-", "80"}], ")"}], " ", 
       RowBox[{"log", "(", "x", ")"}]}], "-", "80"}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"SplittingFunction",
 CellLabel->"Out[1569]="]
}, Open  ]]
}, Open  ]],

Cell["StandardMatrixElement", "ObjectName",
 CellTags->"StandardMatrixElement"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"StandardMatrixElement"],

Cell["\<\
StandardMatrixElement[ ... ] is the head for matrix element abbreviations.\
\>", "Text",
 CellTags->"StandardMatrixElement"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OneLoop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoop",
  ButtonNote->"OneLoop"],
 "."
}], "Text",
 CellTags->"StandardMatrixElement"]
}, Open  ]],

Cell["SubContext", "ObjectName",
 CellTags->"SubContext"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SubContext"],

Cell["\<\
SubContext[fun] gives the sub-directory (context) in HighEnergyPhysics.\
\>", "Text",
 CellTags->"SubContext"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynCalc",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalc",
  ButtonNote->"FeynCalc"],
 ", ",
 ButtonBox["Load",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Load",
  ButtonNote->"Load"],
 "."
}], "Text",
 CellTags->"SubContext"]
}, Open  ]],

Cell["SubLoop", "ObjectName",
 CellTags->"SubLoop"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SubLoop"],

Cell["\<\
SubLoop is an option for OPE1Loop. If set to True, sub 1-loop tensorintegral \
decomposition is performed.\
\>", "Text",
 CellTags->"SubLoop"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OPE1Loop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OPE1Loop",
  ButtonNote->"OPE1Loop"],
 "."
}], "Text",
 CellTags->"SubLoop"]
}, Open  ]],

Cell["SumP", "ObjectName",
 CellTags->"SumP"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SumP"],

Cell[TextData[{
 "SumP[k, m] is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{
      StyleBox["k",
       FontSlant->"Plain"], "-", "1"}]], 
    RowBox[{
     SubsuperscriptBox["\[Sum]", 
      RowBox[{
       StyleBox["i",
        FontSlant->"Plain"], "=", "1"}], 
      RowBox[{"2", 
       StyleBox["m",
        FontSlant->"Plain"]}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], 
         StyleBox["i",
          FontSlant->"Plain"]]}], ")"}], "/", 
      SuperscriptBox[
       StyleBox["i",
        FontSlant->"Plain"], 
       StyleBox["k",
        FontSlant->"Plain"]]}]}]}], TraditionalForm]]]
}], "Text",
 CellTags->"SumP"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["SumS",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SumS",
  ButtonNote->"SumS"],
 ", ",
 ButtonBox["SumT",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SumT",
  ButtonNote->"SumT"],
 "."
}], "Text",
 CellTags->"SumP"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SumP"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumP", "[", 
  RowBox[{"1", ",", 
   RowBox[{"m", "-", "1"}]}], "]"}]], "Input",
 CellTags->"SumP",
 CellLabel->"In[1570]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubsuperscriptBox["S", "1", "'"], "\[NoBreak]", "(", "\[NoBreak]", 
   FormBox[
    RowBox[{"m", "-", "1"}],
    TraditionalForm], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
 CellTags->"SumP",
 CellLabel->"Out[1570]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumP", "[", 
  RowBox[{"2", ",", 
   RowBox[{"m", "-", "1"}]}], "]"}]], "Input",
 CellTags->"SumP",
 CellLabel->"In[1571]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubsuperscriptBox["S", "2", "'"], "\[NoBreak]", "(", "\[NoBreak]", 
   FormBox[
    RowBox[{"m", "-", "1"}],
    TraditionalForm], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
 CellTags->"SumP",
 CellLabel->"Out[1571]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumP", "[", 
  RowBox[{"1", ",", "m"}], "]"}]], "Input",
 CellTags->"SumP",
 CellLabel->"In[1572]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubsuperscriptBox["S", "1", "'"], "\[NoBreak]", "(", "\[NoBreak]", 
   FormBox["m",
    TraditionalForm], "\[NoBreak]", ")"}], TraditionalForm]], "Output",
 CellTags->"SumP",
 CellLabel->"Out[1572]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumP", "[", 
  RowBox[{"1", ",", "4"}], "]"}]], "Input",
 CellTags->"SumP",
 CellLabel->"In[1573]:="],

Cell[BoxData[
 FormBox[
  FractionBox["25", "12"], TraditionalForm]], "Output",
 CellTags->"SumP",
 CellLabel->"Out[1573]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  UnderoverscriptBox["\[Sum]", 
   RowBox[{"i", "=", "1"}], "8"], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "^", "i"}]}], ")"}], "/", "i"}]}]], "Input",\

 CellTags->"SumP",
 CellLabel->"In[1574]:="],

Cell[BoxData[
 FormBox[
  FractionBox["25", "12"], TraditionalForm]], "Output",
 CellTags->"SumP",
 CellLabel->"Out[1574]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Explicit", "[", 
  RowBox[{"SumP", "[", 
   RowBox[{"1", ",", 
    RowBox[{"n", "/", "2"}]}], "]"}], "]"}]], "Input",
 CellTags->"SumP",
 CellLabel->"In[1575]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"]}], ")"}], " ", 
    RowBox[{
     SubscriptBox["S", "1"], "(", 
     FormBox[
      FractionBox[
       RowBox[{"n", "-", "1"}], "2"],
      TraditionalForm], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "n"], "+", "1"}], ")"}], " ", 
    RowBox[{
     SubscriptBox["S", "1"], "(", 
     FormBox[
      FractionBox["n", "2"],
      TraditionalForm], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"SumP",
 CellLabel->"Out[1575]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"n", "\[Rule]", "8"}]}]], "Input",
 CellTags->"SumP",
 CellLabel->"In[1576]:="],

Cell[BoxData[
 FormBox[
  FractionBox["25", "12"], TraditionalForm]], "Output",
 CellTags->"SumP",
 CellLabel->"Out[1576]="]
}, Open  ]]
}, Open  ]],

Cell["SumS", "ObjectName",
 CellTags->"SumS"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SumS"],

Cell[TextData[{
 "SumS[1, m] is the harmonic number ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[Sum]", 
     RowBox[{
      StyleBox["i",
       FontSlant->"Italic"], "=", "1"}], 
     StyleBox["m",
      FontSlant->"Italic"]], 
    StyleBox[" ",
     FontSlant->"Italic"], 
    RowBox[{
     StyleBox["i",
      FontSlant->"Italic"], "^", 
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}]}]}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"=", 
      RowBox[{
       SubscriptBox["S", "1"], "(", "m", ")"}]}], " ", ")"}], "."}], 
   TraditionalForm]]],
 " SumS[1,1,m] is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[Sum]", 
     RowBox[{
      StyleBox["i",
       FontSlant->"Italic"], "=", "1"}], 
     StyleBox["m",
      FontSlant->"Italic"]], 
    SubscriptBox["S", "1"]}], TraditionalForm]]],
 "(",
 StyleBox["i",
  FontSlant->"Italic"],
 ")/",
 StyleBox["i",
  FontSlant->"Italic"],
 ". SumS[k,l,m] is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[Sum]", 
     RowBox[{"i", "=", "1"}], "m"], " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["S", "l"], "(", "i", ")"}], "/", 
     SuperscriptBox["i", "k"]}]}], TraditionalForm]]],
 ". SumS[r, n] represents Sum[Sign[r]^i/i^Abs[r], {i, 1, n}]. SumS[r,s, n] is \
Sum[Sign[r]^k/k^Abs[r] Sign[s]^j/j^Abs[s], {k, 1, n}, {j, 1, k}], etc."
}], "Text",
 CellTags->"SumS"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "SumS", "]"}]], "Input",
 CellTags->"SumS",
 CellLabel->"In[1577]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"Reduce", "\[Rule]", "False"}], "}"}], TraditionalForm]], "Output",\

 CellTags->"SumS",
 CellLabel->"Out[1577]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["SumP",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SumP",
  ButtonNote->"SumP"],
 ", ",
 ButtonBox["SumT",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SumT",
  ButtonNote->"SumT"],
 "."
}], "Text",
 CellTags->"SumS"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SumS"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumS", "[", 
  RowBox[{"1", ",", 
   RowBox[{"m", "-", "1"}]}], "]"}]], "Input",
 CellTags->"SumS",
 CellLabel->"In[1578]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["S", "1"], "(", 
   FormBox[
    RowBox[{"m", "-", "1"}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"SumS",
 CellLabel->"Out[1578]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumS", "[", 
  RowBox[{"2", ",", 
   RowBox[{"m", "-", "1"}]}], "]"}]], "Input",
 CellTags->"SumS",
 CellLabel->"In[1579]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["S", "2"], "(", 
   FormBox[
    RowBox[{"m", "-", "1"}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"SumS",
 CellLabel->"Out[1579]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumS", "[", 
  RowBox[{
   RowBox[{"-", "1"}], ",", "m"}], "]"}]], "Input",
 CellTags->"SumS",
 CellLabel->"In[1580]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["S", 
    RowBox[{"-", "1"}]], "(", "m", ")"}], TraditionalForm]], "Output",
 CellTags->"SumS",
 CellLabel->"Out[1580]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumS", "[", 
  RowBox[{"1", ",", "m", ",", 
   RowBox[{"Reduce", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"SumS",
 CellLabel->"In[1581]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["S", "1"], "(", 
    FormBox[
     RowBox[{"m", "-", "1"}],
     TraditionalForm], ")"}], "+", 
   FractionBox["1", "m"]}], TraditionalForm]], "Output",
 CellTags->"SumS",
 CellLabel->"Out[1581]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumS", "[", 
  RowBox[{"3", ",", 
   RowBox[{"m", "+", "2"}], ",", 
   RowBox[{"Reduce", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"SumS",
 CellLabel->"In[1582]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["S", "3"], "(", 
    FormBox[
     RowBox[{"m", "+", "1"}],
     TraditionalForm], ")"}], "+", 
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"m", "+", "2"}], ")"}], "3"]]}], TraditionalForm]], "Output",
 CellTags->"SumS",
 CellLabel->"Out[1582]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"SumS", ",", 
    RowBox[{"Reduce", "\[Rule]", "True"}]}], "]"}], ";"}]], "Input",
 CellTags->"SumS",
 CellLabel->"In[1583]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumS", "[", 
  RowBox[{"3", ",", 
   RowBox[{"m", "+", "2"}]}], "]"}]], "Input",
 CellTags->"SumS",
 CellLabel->"In[1584]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", 
    SuperscriptBox["m", "3"]], "+", 
   RowBox[{
    SubscriptBox["S", "3"], "(", 
    FormBox[
     RowBox[{"m", "-", "1"}],
     TraditionalForm], ")"}], "+", 
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"m", "+", "1"}], ")"}], "3"]], "+", 
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"m", "+", "2"}], ")"}], "3"]]}], TraditionalForm]], "Output",
 CellTags->"SumS",
 CellLabel->"Out[1584]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"SumS", ",", 
    RowBox[{"Reduce", "\[Rule]", "False"}]}], "]"}], ";"}]], "Input",
 CellTags->"SumS",
 CellLabel->"In[1585]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumS", "[", 
  RowBox[{"1", ",", "4"}], "]"}]], "Input",
 CellTags->"SumS",
 CellLabel->"In[1586]:="],

Cell[BoxData[
 FormBox[
  FractionBox["25", "12"], TraditionalForm]], "Output",
 CellTags->"SumS",
 CellLabel->"Out[1586]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  UnderoverscriptBox["\[Sum]", 
   RowBox[{"i", "=", "1"}], "4"], 
  RowBox[{"1", "/", "i"}]}]], "Input",
 CellTags->"SumS",
 CellLabel->"In[1587]:="],

Cell[BoxData[
 FormBox[
  FractionBox["25", "12"], TraditionalForm]], "Output",
 CellTags->"SumS",
 CellLabel->"Out[1587]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumS", "[", 
  RowBox[{"1", ",", "2", ",", 
   RowBox[{"m", "-", "1"}]}], "]"}]], "Input",
 CellTags->"SumS",
 CellLabel->"In[1588]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["S", "12"], "(", 
   FormBox[
    RowBox[{"m", "-", "1"}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"SumS",
 CellLabel->"Out[1588]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumS", "[", 
  RowBox[{"1", ",", "1", ",", "1", ",", "11"}], "]"}]], "Input",
 CellTags->"SumS",
 CellLabel->"In[1589]:="],

Cell[BoxData[
 FormBox[
  FractionBox["31276937512951", "4260000729600"], TraditionalForm]], "Output",\

 CellTags->"SumS",
 CellLabel->"Out[1589]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumS", "[", 
  RowBox[{
   RowBox[{"-", "1"}], ",", "4"}], "]"}]], "Input",
 CellTags->"SumS",
 CellLabel->"In[1590]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox["7", "12"]}], TraditionalForm]], "Output",
 CellTags->"SumS",
 CellLabel->"Out[1590]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumT", "[", 
  RowBox[{"1", ",", "4"}], "]"}]], "Input",
 CellTags->"SumS",
 CellLabel->"In[1591]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox["7", "12"]}], TraditionalForm]], "Output",
 CellTags->"SumS",
 CellLabel->"Out[1591]="]
}, Open  ]]
}, Open  ]],

Cell["SumT", "ObjectName",
 CellTags->"SumT"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SumT"],

Cell[TextData[{
 "SumT[1, m] is the alternative harmonic number ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[Sum]", 
     RowBox[{"i", "=", "1"}], "m"], " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "^", "i"}], "/", "i", " "}]}], 
   TraditionalForm]]],
 " SumT[r, n] represents Sum[(-1)^i/i^r, {i,1,n}], SumT[r,s, n] is Sum[1/k^r \
(-1)^j/j^s, {k, 1, n}, {j, 1, k}]."
}], "Text",
 CellTags->"SumT"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["SumP",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SumP",
  ButtonNote->"SumP"],
 ", ",
 ButtonBox["SumS",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SumS",
  ButtonNote->"SumS"],
 "."
}], "Text",
 CellTags->"SumT"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SumT"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumT", "[", 
  RowBox[{"1", ",", 
   RowBox[{"m", "-", "1"}]}], "]"}]], "Input",
 CellTags->"SumT",
 CellLabel->"In[1592]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox[
    OverscriptBox["S", "~"], "1"], "(", 
   FormBox[
    RowBox[{"m", "-", "1"}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"SumT",
 CellLabel->"Out[1592]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumT", "[", 
  RowBox[{"2", ",", 
   RowBox[{"m", "-", "1"}]}], "]"}]], "Input",
 CellTags->"SumT",
 CellLabel->"In[1593]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox[
    OverscriptBox["S", "~"], "2"], "(", 
   FormBox[
    RowBox[{"m", "-", "1"}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"SumT",
 CellLabel->"Out[1593]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumT", "[", 
  RowBox[{"1", ",", "m"}], "]"}]], "Input",
 CellTags->"SumT",
 CellLabel->"In[1594]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox[
    OverscriptBox["S", "~"], "1"], "(", "m", ")"}], 
  TraditionalForm]], "Output",
 CellTags->"SumT",
 CellLabel->"Out[1594]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumT", "[", 
  RowBox[{"1", ",", "m", ",", 
   RowBox[{"Reduce", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"SumT",
 CellLabel->"In[1595]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox[
     OverscriptBox["S", "~"], "1"], "(", 
    FormBox[
     RowBox[{"m", "-", "1"}],
     TraditionalForm], ")"}], "+", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "m"], "m"]}], TraditionalForm]], "Output",
 CellTags->"SumT",
 CellLabel->"Out[1595]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumT", "[", 
  RowBox[{"1", ",", "4"}], "]"}]], "Input",
 CellTags->"SumT",
 CellLabel->"In[1596]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox["7", "12"]}], TraditionalForm]], "Output",
 CellTags->"SumT",
 CellLabel->"Out[1596]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  UnderoverscriptBox["\[Sum]", 
   RowBox[{"i", "=", "1"}], "4"], 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", "i"}], "/", "i"}]}]], "Input",
 CellTags->"SumT",
 CellLabel->"In[1597]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox["7", "12"]}], TraditionalForm]], "Output",
 CellTags->"SumT",
 CellLabel->"Out[1597]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumT", "[", 
  RowBox[{"1", ",", "2", ",", 
   RowBox[{"m", "-", "1"}]}], "]"}]], "Input",
 CellTags->"SumT",
 CellLabel->"In[1598]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox[
    OverscriptBox["S", "~"], "12"], "(", 
   FormBox[
    RowBox[{"m", "-", "1"}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"SumT",
 CellLabel->"Out[1598]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumT", "[", 
  RowBox[{"1", ",", "2", ",", "42"}], "]"}]], "Input",
 CellTags->"SumT",
 CellLabel->"In[1599]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox["38987958697055013360489864298703621429610152138683927", 
    "10512121660702378405316004964483761080879190528000000"]}], 
  TraditionalForm]], "Output",
 CellTags->"SumT",
 CellLabel->"Out[1599]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumT", "[", 
  RowBox[{"1", ",", "4"}], "]"}]], "Input",
 CellTags->"SumT",
 CellLabel->"In[1600]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox["7", "12"]}], TraditionalForm]], "Output",
 CellTags->"SumT",
 CellLabel->"Out[1600]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumS", "[", 
  RowBox[{
   RowBox[{"-", "1"}], ",", "4"}], "]"}]], "Input",
 CellTags->"SumT",
 CellLabel->"In[1601]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox["7", "12"]}], TraditionalForm]], "Output",
 CellTags->"SumT",
 CellLabel->"Out[1601]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  UnderoverscriptBox["\[Sum]", 
   RowBox[{"i", "=", "1"}], 
   RowBox[{"m", "-", "1"}]], 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", "i"}], "/", "i"}]}]], "Input",
 CellTags->"SumT",
 CellLabel->"In[1602]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"]}], " ", 
    TemplateBox[{RowBox[{"-", "1"}],"1","m"},
     "LerchPhi"]}], "-", 
   RowBox[{"log", "(", "2", ")"}]}], TraditionalForm]], "Output",
 CellTags->"SumT",
 CellLabel->"Out[1602]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumT", "[", 
  RowBox[{"1", ",", "2", ",", "12"}], "]"}]], "Input",
 CellTags->"SumT",
 CellLabel->"In[1603]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox["57561743656913", "21300003648000"]}], 
  TraditionalForm]], "Output",
 CellTags->"SumT",
 CellLabel->"Out[1603]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SumS", "[", 
  RowBox[{"1", ",", 
   RowBox[{"-", "2"}], ",", "42"}], "]"}]], "Input",
 CellTags->"SumT",
 CellLabel->"In[1604]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox["38987958697055013360489864298703621429610152138683927", 
    "10512121660702378405316004964483761080879190528000000"]}], 
  TraditionalForm]], "Output",
 CellTags->"SumT",
 CellLabel->"Out[1604]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Array", "[", 
  RowBox[{"SumT", ",", "6"}], "]"}]], "Input",
 CellTags->"SumT",
 CellLabel->"In[1605]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "1"}], ",", 
    RowBox[{"-", 
     FractionBox["5", "8"]}], ",", 
    RowBox[{"-", 
     FractionBox["179", "216"]}], ",", 
    RowBox[{"-", 
     FractionBox["1207", "1728"]}], ",", 
    RowBox[{"-", 
     FractionBox["170603", "216000"]}], ",", 
    RowBox[{"-", 
     FractionBox["155903", "216000"]}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"SumT",
 CellLabel->"Out[1605]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Array", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"SumS", "[", 
     RowBox[{
      RowBox[{"-", "2"}], ",", "1", ",", "#1"}], "]"}], "&"}], ",", "6"}], 
  "]"}]], "Input",
 CellTags->"SumT",
 CellLabel->"In[1606]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "1"}], ",", 
    RowBox[{"-", 
     FractionBox["5", "8"]}], ",", 
    RowBox[{"-", 
     FractionBox["179", "216"]}], ",", 
    RowBox[{"-", 
     FractionBox["1207", "1728"]}], ",", 
    RowBox[{"-", 
     FractionBox["170603", "216000"]}], ",", 
    RowBox[{"-", 
     FractionBox["155903", "216000"]}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"SumT",
 CellLabel->"Out[1606]="]
}, Open  ]]
}, Open  ]],

Cell["SUND", "ObjectName",
 CellTags->"SUND"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SUND"],

Cell[TextData[{
 "SUND[a,b,c] are the symmetric SU(",
 StyleBox["N",
  FontSlant->"Italic"],
 ") ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["d", "abc"], "."}], TraditionalForm]]]
}], "Text",
 CellTags->"SUND"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["SUNDelta",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNDelta",
  ButtonNote->"SUNDelta"],
 ", ",
 ButtonBox["SUNF",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNF",
  ButtonNote->"SUNF"],
 ", ",
 ButtonBox["SUNSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNSimplify",
  ButtonNote->"SUNSimplify"],
 "."
}], "Text",
 CellTags->"SUND"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SUND"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUND", "[", 
  RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "Input",
 CellTags->"SUND",
 CellLabel->"In[1607]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["d", 
   RowBox[{"a", "b", "c"}]], TraditionalForm]], "Output",
 CellTags->"SUND",
 CellLabel->"Out[1607]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tt", "=", 
  RowBox[{"SUND", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", 
    RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellTags->"SUND",
 CellLabel->"In[1608]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{"tr", "(", 
     FormBox[
      RowBox[{
       SubscriptBox["T", 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], ".", 
       SubscriptBox["T", 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], ".", 
       SubscriptBox["T", 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]]}],
      TraditionalForm], ")"}]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"tr", "(", 
     FormBox[
      RowBox[{
       SubscriptBox["T", 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], ".", 
       SubscriptBox["T", 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], ".", 
       SubscriptBox["T", 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]]}],
      TraditionalForm], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"SUND",
 CellLabel->"Out[1608]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUND", "[", 
  RowBox[{"c", ",", "a", ",", "b"}], "]"}]], "Input",
 CellTags->"SUND",
 CellLabel->"In[1609]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["d", 
   RowBox[{"a", "b", "c"}]], TraditionalForm]], "Output",
 CellTags->"SUND",
 CellLabel->"Out[1609]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUND", "[", 
  RowBox[{"a", ",", "b", ",", "b"}], "]"}]], "Input",
 CellTags->"SUND",
 CellLabel->"In[1610]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["d", 
   RowBox[{"a", "b", "b"}]], TraditionalForm]], "Output",
 CellTags->"SUND",
 CellLabel->"Out[1610]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{
   RowBox[{"SUND", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
   RowBox[{"SUND", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}]}], "]"}]], "Input",
 CellTags->"SUND",
 CellLabel->"In[1611]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   RowBox[{"(", 
    RowBox[{"4", "-", 
     SubsuperscriptBox["C", "A", "2"]}], ")"}], " ", 
   SubscriptBox["C", "F"]}], TraditionalForm]], "Output",
 CellTags->"SUND",
 CellLabel->"Out[1611]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SUNSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"SUND", "[", 
      RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
     RowBox[{"SUND", "[", 
      RowBox[{"a", ",", "b", ",", "c"}], "]"}]}], ",", 
    RowBox[{"SUNNToCACF", "\[Rule]", "False"}]}], "]"}], "//", 
  "Factor2"}]], "Input",
 CellTags->"SUND",
 CellLabel->"In[1612]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SuperscriptBox["N", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"4", "-", 
      SuperscriptBox["N", "2"]}], ")"}]}], "N"], TraditionalForm]], "Output",
 CellTags->"SUND",
 CellLabel->"Out[1612]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SUNSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"SUND", "[", 
      RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
     RowBox[{"SUND", "[", 
      RowBox[{"e", ",", "b", ",", "c"}], "]"}]}], ",", 
    RowBox[{"SUNNToCACF", "\[Rule]", "False"}]}], "]"}], "//", 
  "Factor2"}]], "Input",
 CellTags->"SUND",
 CellLabel->"In[1613]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"4", "-", 
       SuperscriptBox["N", "2"]}], ")"}], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]}]]}], "N"]}], TraditionalForm]], "Output",
 CellTags->"SUND",
 CellLabel->"Out[1613]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SUND", "[", 
   RowBox[{"a", ",", "b", ",", "c"}], "]"}], "//", "StandardForm"}]], "Input",\

 CellTags->"SUND",
 CellLabel->"In[1614]:="],

Cell[BoxData[
 RowBox[{"SUND", "[", 
  RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "Output",
 CellTags->"SUND",
 CellLabel->"Out[1614]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SUND", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], "//", "FCI"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SUND",
 CellLabel->"In[1615]:="],

Cell[BoxData[
 RowBox[{"SUND", "[", 
  RowBox[{
   RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
   RowBox[{"SUNIndex", "[", "b", "]"}], ",", 
   RowBox[{"SUNIndex", "[", "c", "]"}]}], "]"}]], "Output",
 CellTags->"SUND",
 CellLabel->"Out[1615]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SUND", "[", 
     RowBox[{"a", ",", "b", ",", "c"}], "]"}], "//", "FCI"}], "//", "FCE"}], "//",
   "StandardForm"}]], "Input",
 CellTags->"SUND",
 CellLabel->"In[1616]:="],

Cell[BoxData[
 RowBox[{"SUND", "[", 
  RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "Output",
 CellTags->"SUND",
 CellLabel->"Out[1616]//StandardForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "tt", "]"}]], "Input",
 CellTags->"SUND",
 CellLabel->"In[1617]:="]
}, Open  ]],

Cell["SUNDelta", "ObjectName",
 CellTags->"SUNDelta"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SUNDelta"],

Cell[TextData[{
 "SUNDelta[a, b] is the Kronecker-delta for SU(",
 StyleBox["N",
  FontSlant->"Italic"],
 ") with color indices a and b."
}], "Text",
 CellTags->"SUNDelta"],

Cell[TextData[{
 "See also: ",
 ButtonBox["ExplicitSUNIndex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExplicitSUNIndex",
  ButtonNote->"ExplicitSUNIndex"],
 ", ",
 ButtonBox["SD",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SD",
  ButtonNote->"SD"],
 ", ",
 ButtonBox["SUNF",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNF",
  ButtonNote->"SUNF"],
 ", ",
 ButtonBox["SUNIndex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNIndex",
  ButtonNote->"SUNIndex"],
 ", ",
 ButtonBox["SUNSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNSimplify",
  ButtonNote->"SUNSimplify"],
 ", ",
 ButtonBox["Trick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Trick",
  ButtonNote->"Trick"],
 "."
}], "Text",
 CellTags->"SUNDelta"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SUNDelta"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNDelta", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Input",
 CellTags->"SUNDelta",
 CellLabel->"In[1618]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["\[Delta]", 
   RowBox[{"a", "b"}]], TraditionalForm]], "Output",
 CellTags->"SUNDelta",
 CellLabel->"Out[1618]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Trick", "[", " ", 
  RowBox[{
   RowBox[{"SUNDelta", "[", 
    RowBox[{"a", ",", "b"}], "]"}], " ", 
   RowBox[{"SUNDelta", "[", 
    RowBox[{"b", ",", "c"}], "]"}]}], " ", "]"}]], "Input",
 CellTags->"SUNDelta",
 CellLabel->"In[1619]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["\[Delta]", 
   RowBox[{
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["c",
      TraditionalForm],
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"SUNDelta",
 CellLabel->"Out[1619]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNDelta", "[", 
  RowBox[{
   RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
   RowBox[{"SUNIndex", "[", "b", "]"}]}], "]"}]], "Input",
 CellTags->"SUNDelta",
 CellLabel->"In[1620]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["\[Delta]", 
   RowBox[{
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["b",
      TraditionalForm],
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"SUNDelta",
 CellLabel->"Out[1620]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SUNDelta", "[", 
   RowBox[{"a", ",", "b"}], "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"SUNDelta",
 CellLabel->"In[1621]:="],

Cell[BoxData[
 RowBox[{"SUNDelta", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Output",
 CellTags->"SUNDelta",
 CellLabel->"Out[1621]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SUNDelta", "[", 
    RowBox[{"a", ",", "b"}], "]"}], "//", "FCI"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SUNDelta",
 CellLabel->"In[1622]:="],

Cell[BoxData[
 RowBox[{"SUNDelta", "[", 
  RowBox[{
   RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
   RowBox[{"SUNIndex", "[", "b", "]"}]}], "]"}]], "Output",
 CellTags->"SUNDelta",
 CellLabel->"Out[1622]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SUNDelta", "[", 
     RowBox[{"a", ",", "b"}], "]"}], "//", "FCI"}], "//", "FCE"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SUNDelta",
 CellLabel->"In[1623]:="],

Cell[BoxData[
 RowBox[{"SD", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Output",
 CellTags->"SUNDelta",
 CellLabel->"Out[1623]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SD", "[", 
    RowBox[{"a", ",", "b"}], "]"}], "//", "FCI"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SUNDelta",
 CellLabel->"In[1624]:="],

Cell[BoxData[
 RowBox[{"SUNDelta", "[", 
  RowBox[{
   RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
   RowBox[{"SUNIndex", "[", "b", "]"}]}], "]"}]], "Output",
 CellTags->"SUNDelta",
 CellLabel->"Out[1624]//StandardForm="]
}, Open  ]],

Cell["\<\
Symbolic arguments to SUNDelta are transformed into the data type SUNIndex \
and integer arguments are transformed to ExplicitSUNIndex. The difference is \
that SUNSimplify will only sum over symbolic indices.\
\>", "Text",
 CellTags->"SUNDelta"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SUNDelta", "[", 
    RowBox[{"a", ",", "2"}], "]"}], 
   RowBox[{"SUNDelta", "[", 
    RowBox[{"a", ",", "b"}], "]"}], 
   RowBox[{"SUNDelta", "[", 
    RowBox[{"c", ",", "2"}], "]"}]}], "//", "SUNSimplify"}]], "Input",
 CellTags->"SUNDelta",
 CellLabel->"In[1625]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"SUNDelta",
 CellLabel->"Out[1625]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"SUNDelta",
 CellLabel->"In[1626]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"SUNDelta", "[", 
   RowBox[{
    RowBox[{"ExplicitSUNIndex", "[", "2", "]"}], ",", 
    RowBox[{"SUNIndex", "[", "b", "]"}]}], "]"}], " ", 
  RowBox[{"SUNDelta", "[", 
   RowBox[{
    RowBox[{"ExplicitSUNIndex", "[", "2", "]"}], ",", 
    RowBox[{"SUNIndex", "[", "c", "]"}]}], "]"}]}]], "Output",
 CellTags->"SUNDelta",
 CellLabel->"Out[1626]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SUNDelta", "[", 
    RowBox[{"1", ",", "2"}], "]"}], "//", "FCI"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SUNDelta",
 CellLabel->"In[1627]:="],

Cell[BoxData[
 RowBox[{"SUNDelta", "[", 
  RowBox[{
   RowBox[{"ExplicitSUNIndex", "[", "1", "]"}], ",", 
   RowBox[{"ExplicitSUNIndex", "[", "2", "]"}]}], "]"}]], "Output",
 CellTags->"SUNDelta",
 CellLabel->"Out[1627]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["SUNDeltaContract", "ObjectName",
 CellTags->"SUNDeltaContract"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SUNDeltaContract"],

Cell[TextData[{
 "SUNDeltaContract[expr] substitues for all SUNDelta in expr \
SUNDeltaContract, contracts the SUN(N) indices and resubstitutes SUNDelta. \
SUNDeltaContract[i, j] is the Kronecker-delta for SU(",
 StyleBox["N",
  FontSlant->"Italic"],
 ") with contraction properties. SUNDeltaContract wraps also the head \
SUNIndex around its arguments."
}], "Text",
 CellTags->"SUNDeltaContract"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["SUNDelta",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNDelta",
  ButtonNote->"SUNDelta"],
 ", ",
 ButtonBox["SUNIndex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNIndex",
  ButtonNote->"SUNIndex"],
 "."
}], "Text",
 CellTags->"SUNDeltaContract"]
}, Open  ]],

Cell["SUNF", "ObjectName",
 CellTags->"SUNF"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SUNF"],

Cell[TextData[{
 "SUNF[a,b,c] are the structure constants of SU(",
 StyleBox["N",
  FontSlant->"Italic"],
 "). The arguments a,b,c should be of symbolic type."
}], "Text",
 CellTags->"SUNF"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "SUNF", "]"}]], "Input",
 CellTags->"SUNF",
 CellLabel->"In[1628]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"Explicit", "\[Rule]", "False"}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"SUNF",
 CellLabel->"Out[1628]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["SUND",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUND",
  ButtonNote->"SUND"],
 ", ",
 ButtonBox["SUNDelta",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNDelta",
  ButtonNote->"SUNDelta"],
 ", ",
 ButtonBox["SUNIndex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNIndex",
  ButtonNote->"SUNIndex"],
 ", ",
 ButtonBox["SUNSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNSimplify",
  ButtonNote->"SUNSimplify"],
 ", ",
 ButtonBox["SUNT",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNT",
  ButtonNote->"SUNT"],
 ", ",
 ButtonBox["Trick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Trick",
  ButtonNote->"Trick"],
 "."
}], "Text",
 CellTags->"SUNF"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SUNF"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"SUNF", "[", 
     RowBox[{"a", ",", "b", ",", "c"}], "]"}], "x"}], "+", 
   RowBox[{
    RowBox[{"SUNF", "[", 
     RowBox[{"b", ",", "a", ",", "c"}], "]"}], "y"}]}]}]], "Input",
 CellTags->"SUNF",
 CellLabel->"In[1629]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"x", " ", 
    SubscriptBox["f", 
     RowBox[{"a", "b", "c"}]]}], "+", 
   RowBox[{"y", " ", 
    SubscriptBox["f", 
     RowBox[{"b", "a", "c"}]]}]}], TraditionalForm]], "Output",
 CellTags->"SUNF",
 CellLabel->"Out[1629]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Calc", "[", "t1", "]"}]], "Input",
 CellTags->"SUNF",
 CellLabel->"In[1630]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"x", " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]}]]}], "-", 
   RowBox[{"y", " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]}]]}]}], TraditionalForm]], "Output",
 CellTags->"SUNF",
 CellLabel->"Out[1630]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", "t1", "]"}]], "Input",
 CellTags->"SUNF",
 CellLabel->"In[1631]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"x", "-", "y"}], ")"}], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"SUNF",
 CellLabel->"Out[1631]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNF", "[", 
  RowBox[{"a", ",", "a", ",", "b"}], "]"}]], "Input",
 CellTags->"SUNF",
 CellLabel->"In[1632]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["f", 
   RowBox[{"a", "a", "b"}]], TraditionalForm]], "Output",
 CellTags->"SUNF",
 CellLabel->"Out[1632]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SUNF", "[", 
   RowBox[{"a", ",", "a", ",", "b"}], "]"}], "//", "Calc"}]], "Input",
 CellTags->"SUNF",
 CellLabel->"In[1633]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"SUNF",
 CellLabel->"Out[1633]="]
}, Open  ]],

Cell[TextData[{
 "This is a consequence of the usual choice for the normalization of the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["T", "a"], " ", "generatorsin", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"see", "  ", "SUNT"}], ")"}], "."}]}], TraditionalForm]]]
}], "Text",
 CellTags->"SUNF"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNF", "[", 
  RowBox[{"a", ",", "b", ",", "c", ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"SUNF",
 CellLabel->"In[1634]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"tr", "(", 
      FormBox[
       RowBox[{
        SubscriptBox["T", 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}],
       TraditionalForm], ")"}], "-", 
     RowBox[{"tr", "(", 
      FormBox[
       RowBox[{
        SubscriptBox["T", 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]]}],
       TraditionalForm], ")"}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"SUNF",
 CellLabel->"Out[1634]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", "d"}], "]"}]}], "]"}]], "Input",
 CellTags->"SUNF",
 CellLabel->"In[1635]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "A"], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"SUNF",
 CellLabel->"Out[1635]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"SUNF",
 CellLabel->"In[1636]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"tr", "(", 
      FormBox[
       RowBox[{
        SubscriptBox["T", 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]]}],
       TraditionalForm], ")"}], "-", 
     RowBox[{"tr", "(", 
      FormBox[
       RowBox[{
        SubscriptBox["T", 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]]}],
       TraditionalForm], ")"}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"SUNF",
 CellLabel->"Out[1636]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SUNF", "[", 
   RowBox[{"a", ",", "b", ",", "c"}], "]"}], "//", "StandardForm"}]], "Input",\

 CellTags->"SUNF",
 CellLabel->"In[1637]:="],

Cell[BoxData[
 RowBox[{"SUNF", "[", 
  RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "Output",
 CellTags->"SUNF",
 CellLabel->"Out[1637]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], "//", "FCI"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SUNF",
 CellLabel->"In[1638]:="],

Cell[BoxData[
 RowBox[{"SUNF", "[", 
  RowBox[{
   RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
   RowBox[{"SUNIndex", "[", "b", "]"}], ",", 
   RowBox[{"SUNIndex", "[", "c", "]"}]}], "]"}]], "Output",
 CellTags->"SUNF",
 CellLabel->"Out[1638]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SUNF", "[", 
     RowBox[{"a", ",", "b", ",", "c"}], "]"}], "//", "FCI"}], "//", "FCE"}], "//",
   "StandardForm"}]], "Input",
 CellTags->"SUNF",
 CellLabel->"In[1639]:="],

Cell[BoxData[
 RowBox[{"SUNF", "[", 
  RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "Output",
 CellTags->"SUNF",
 CellLabel->"Out[1639]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNF", "[", 
  RowBox[{"b", ",", "a", ",", "c"}], "]"}]], "Input",
 CellTags->"SUNF",
 CellLabel->"In[1640]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["f", 
   RowBox[{"b", "a", "c"}]], TraditionalForm]], "Output",
 CellTags->"SUNF",
 CellLabel->"Out[1640]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SUNF", "[", 
   RowBox[{"b", ",", "a", ",", "c"}], "]"}], "//", "FCI"}]], "Input",
 CellTags->"SUNF",
 CellLabel->"In[1641]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"SUNF",
 CellLabel->"Out[1641]="]
}, Open  ]]
}, Open  ]],

Cell["SUNFJacobi", "ObjectName",
 CellTags->"SUNFJacobi"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SUNFJacobi"],

Cell["\<\
SUNFJacobi is an option for SUNSimplify, indicating whether the Jacobi \
identity should be used.\
\>", "Text",
 CellTags->"SUNFJacobi"],

Cell[TextData[{
 "See also:  ",
 ButtonBox["SUNF",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNF",
  ButtonNote->"SUNF"],
 ", ",
 ButtonBox["SUNSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNSimplify",
  ButtonNote->"SUNSimplify"],
 "."
}], "Text",
 CellTags->"SUNFJacobi"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SUNFJacobi"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], 
   RowBox[{"SUNF", "[", 
    RowBox[{"e", ",", "f", ",", "c"}], "]"}]}], "//", 
  RowBox[{
   RowBox[{"SUNSimplify", "[", 
    RowBox[{"#", ",", 
     RowBox[{"SUNFJacobi", "\[Rule]", "False"}]}], "]"}], "&"}]}]], "Input",
 CellTags->"SUNFJacobi",
 CellLabel->"In[1642]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"SUNFJacobi",
 CellLabel->"Out[1642]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], 
   RowBox[{"SUNF", "[", 
    RowBox[{"e", ",", "f", ",", "c"}], "]"}]}], "//", 
  RowBox[{
   RowBox[{"SUNSimplify", "[", 
    RowBox[{"#", ",", 
     RowBox[{"SUNFJacobi", "\[Rule]", "True"}]}], "]"}], "&"}]}]], "Input",
 CellTags->"SUNFJacobi",
 CellLabel->"In[1643]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]}]]}]}], TraditionalForm]], "Output",
 CellTags->"SUNFJacobi",
 CellLabel->"Out[1643]="]
}, Open  ]]
}, Open  ]],

Cell["SUNIndex", "ObjectName",
 CellTags->"SUNIndex"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SUNIndex"],

Cell[TextData[{
 "SUNIndex is the head of SU(",
 StyleBox["N",
  FontSlant->"Italic"],
 ") indices."
}], "Text",
 CellTags->"SUNIndex"],

Cell[TextData[{
 "See also: ",
 ButtonBox["ExplicitSUNIndex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ExplicitSUNIndex",
  ButtonNote->"ExplicitSUNIndex"],
 ", ",
 ButtonBox["SUNDelta",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNDelta",
  ButtonNote->"SUNDelta"],
 ", ",
 ButtonBox["SUNF",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNF",
  ButtonNote->"SUNF"],
 "."
}], "Text",
 CellTags->"SUNIndex"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SUNIndex"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNIndex", "[", "i", "]"}]], "Input",
 CellTags->"SUNIndex",
 CellLabel->"In[1644]:="],

Cell[BoxData[
 FormBox["i", TraditionalForm]], "Output",
 CellTags->"SUNIndex",
 CellLabel->"Out[1644]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"SUNIndex",
 CellLabel->"In[1645]:="],

Cell[BoxData[
 RowBox[{"SUNIndex", "[", "i", "]"}]], "Output",
 CellTags->"SUNIndex",
 CellLabel->"Out[1645]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SUNDelta", "[", 
    RowBox[{"i", ",", "j"}], "]"}], "//", "FCI"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SUNIndex",
 CellLabel->"In[1646]:="],

Cell[BoxData[
 RowBox[{"SUNDelta", "[", 
  RowBox[{
   RowBox[{"SUNIndex", "[", "i", "]"}], ",", 
   RowBox[{"SUNIndex", "[", "j", "]"}]}], "]"}]], "Output",
 CellTags->"SUNIndex",
 CellLabel->"Out[1646]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["SUNIndexRename", "ObjectName",
 CellTags->"SUNIndexRename"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SUNIndexRename"],

Cell["\<\
SUNIndexRename is an option of SUNSimplify. If set to False, no automatic \
renaming of dummy indices is done.\
\>", "Text",
 CellTags->"SUNIndexRename"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["SUNSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNSimplify",
  ButtonNote->"SUNSimplify"],
 ", ",
 ButtonBox["SUNIndex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNIndex",
  ButtonNote->"SUNIndex"],
 "."
}], "Text",
 CellTags->"SUNIndexRename"]
}, Open  ]],

Cell["SUNN", "ObjectName",
 CellTags->"SUNN"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SUNN"],

Cell[TextData[{
 "SUNN denotes the number of colors. Trick[SUNDelta[a, a]] yields (",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["SUNN", "2"], TraditionalForm]]],
 " -1)."
}], "Text",
 CellTags->"SUNN"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["SUNSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNSimplify",
  ButtonNote->"SUNSimplify"],
 ", ",
 ButtonBox["Trick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Trick",
  ButtonNote->"Trick"],
 ", ",
 ButtonBox["SUNIndex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNIndex",
  ButtonNote->"SUNIndex"],
 ", ",
 ButtonBox["CA",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CA",
  ButtonNote->"CA"],
 ", ",
 ButtonBox["CF",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CF",
  ButtonNote->"CF"],
 "."
}], "Text",
 CellTags->"SUNN"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SUNN"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{
   RowBox[{"SUNDelta", "[", 
    RowBox[{
     RowBox[{"SUNIndex", "[", "a", "]"}], ",", " ", 
     RowBox[{"SUNIndex", "[", "a", "]"}]}], "]"}], ",", 
   RowBox[{"SUNNToCACF", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"SUNN",
 CellLabel->"In[1647]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["N", "2"], "-", "1"}], TraditionalForm]], "Output",
 CellTags->"SUNN",
 CellLabel->"Out[1647]="]
}, Open  ]]
}, Open  ]],

Cell["SUNNToCACF", "ObjectName",
 CellTags->"SUNNToCACF"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SUNNToCACF"],

Cell["\<\
SUNNToCACF is an option of SUNSimplify. If set to True, the Casimir operator \
eigenvalues CA (=N) and CF (=(N^2-1)/(2 N)) are introduced.\
\>", "Text",
 CellTags->"SUNNToCACF"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["SUNSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNSimplify",
  ButtonNote->"SUNSimplify"],
 ", ",
 ButtonBox["Trick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Trick",
  ButtonNote->"Trick"],
 ", ",
 ButtonBox["SUNN",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNN",
  ButtonNote->"SUNN"],
 ", ",
 ButtonBox["CA",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CA",
  ButtonNote->"CA"],
 ", ",
 ButtonBox["CF",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CF",
  ButtonNote->"CF"],
 "."
}], "Text",
 CellTags->"SUNNToCACF"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SUNNToCACF"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{
   RowBox[{"SUNDelta", "[", 
    RowBox[{
     RowBox[{"SUNIndex", "[", "a", "]"}], ",", " ", 
     RowBox[{"SUNIndex", "[", "a", "]"}]}], "]"}], ",", 
   RowBox[{"SUNNToCACF", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"SUNNToCACF",
 CellLabel->"In[1648]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", 
   SubscriptBox["C", "A"], " ", 
   SubscriptBox["C", "F"]}], TraditionalForm]], "Output",
 CellTags->"SUNNToCACF",
 CellLabel->"Out[1648]="]
}, Open  ]]
}, Open  ]],

Cell["SUNSimplify", "ObjectName",
 CellTags->"SUNSimplify"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SUNSimplify"],

Cell["\<\
SUNSimplify simplifies products of SUNT (and complex conjugated) matrices. \
Basic renaming of dummy indices is done. If the option SUNTrace is set to \
False, then any SUNT-matrices are taken out of DiracTrace[...]; otherwise a \
color-trace is taken (by SUNTrace) before taking the SUN-objects in front of \
DiracTrace[...].\
\>", "Text",
 CellTags->"SUNSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "SUNSimplify", "]"}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1649]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Expanding", "\[Rule]", "False"}], ",", 
    RowBox[{"Explicit", "\[Rule]", "False"}], ",", 
    RowBox[{"Factoring", "\[Rule]", "False"}], ",", 
    RowBox[{"SUNIndexRename", "\[Rule]", "True"}], ",", 
    RowBox[{"SUNFJacobi", "\[Rule]", "False"}], ",", 
    RowBox[{"SUNNToCACF", "\[Rule]", "True"}], ",", 
    RowBox[{"SUNTrace", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1649]="]
}, Open  ]],

Cell[TextData[{
 "See also:  ",
 ButtonBox["Trick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Trick",
  ButtonNote->"Trick"],
 ", ",
 ButtonBox["CalcColorFactor",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CalcColorFactor",
  ButtonNote->"CalcColorFactor"],
 "."
}], "Text",
 CellTags->"SUNSimplify"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SUNSimplify"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{
   RowBox[{"SUNDelta", "[", 
    RowBox[{"a", ",", "b"}], "]"}], " ", 
   RowBox[{"SUNDelta", "[", 
    RowBox[{"b", ",", "c"}], "]"}]}]}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1650]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[Delta]", 
    RowBox[{"a", "b"}]], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{"b", "c"}]]}], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1650]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", "t1", "]"}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1651]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["\[Delta]", 
   RowBox[{
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["c",
      TraditionalForm],
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1651]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", "=", 
  RowBox[{
   RowBox[{"SUNT", "[", "a", "]"}], ".", 
   RowBox[{"SUNT", "[", "a", "]"}]}]}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1652]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["T", 
    FormBox["a",
     TraditionalForm]], ".", 
   SubscriptBox["T", 
    FormBox["a",
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1652]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", "t2", "]"}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1653]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["C", "F"], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1653]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{"t2", ",", 
   RowBox[{"SUNNToCACF", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1654]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["N", "2"], "-", "1"}], 
   RowBox[{"2", " ", "N"}]], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1654]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t3", "=", 
  RowBox[{
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "r", ",", "s"}], "]"}], 
   RowBox[{"SUNF", "[", 
    RowBox[{"b", ",", "r", ",", "s"}], "]"}]}]}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1655]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["f", 
    RowBox[{"a", "r", "s"}]], " ", 
   SubscriptBox["f", 
    RowBox[{"b", "r", "s"}]]}], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1655]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", "t3", "]"}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1656]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "A"], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1656]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t4", "=", 
  RowBox[{
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", ".", " ", 
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}]}]}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1657]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["f", 
    RowBox[{"a", "b", "c"}]], ".", 
   SubscriptBox["f", 
    RowBox[{"a", "b", "c"}]]}], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1657]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", "t4", "]"}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1658]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", 
   SubsuperscriptBox["C", "A", "2"], " ", 
   SubscriptBox["C", "F"]}], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1658]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t5", "=", 
  RowBox[{
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
   RowBox[{"SUNF", "[", 
    RowBox[{"d", ",", "b", ",", "c"}], "]"}]}]}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1659]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["f", 
    RowBox[{"a", "b", "c"}]], " ", 
   SubscriptBox["f", 
    RowBox[{"d", "b", "c"}]]}], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1659]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", "t5", "]"}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1660]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "A"], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1660]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t6", "=", 
  RowBox[{
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
   RowBox[{"SUND", "[", 
    RowBox[{"d", ",", "b", ",", "c"}], "]"}]}]}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1661]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["d", 
    RowBox[{"b", "c", "d"}]], " ", 
   SubscriptBox["f", 
    RowBox[{"a", "b", "c"}]]}], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1661]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{"t6", ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1662]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1662]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SUNSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"SUND", "[", 
      RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
     RowBox[{"SUND", "[", 
      RowBox[{"a", ",", "b", ",", "c"}], "]"}]}], ",", 
    RowBox[{"SUNNToCACF", "\[Rule]", "False"}]}], "]"}], "//", 
  "Factor2"}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1663]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SuperscriptBox["N", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"4", "-", 
      SuperscriptBox["N", "2"]}], ")"}]}], "N"], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1663]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SUNSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"SUND", "[", 
      RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
     RowBox[{"SUND", "[", 
      RowBox[{"e", ",", "b", ",", "c"}], "]"}]}], ",", 
    RowBox[{"SUNNToCACF", "\[Rule]", "False"}]}], "]"}], "//", 
  "FullSimplify"}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1664]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["N", "2"], "-", "4"}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]}]]}], "N"], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1664]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1665]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"tr", "(", 
      FormBox[
       RowBox[{
        SubscriptBox["T", 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]]}],
       TraditionalForm], ")"}], "-", 
     RowBox[{"tr", "(", 
      FormBox[
       RowBox[{
        SubscriptBox["T", 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]]}],
       TraditionalForm], ")"}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1665]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{
   RowBox[{"SUND", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1666]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"tr", "(", 
      FormBox[
       RowBox[{
        SubscriptBox["T", 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]]}],
       TraditionalForm], ")"}], "+", 
     RowBox[{"tr", "(", 
      FormBox[
       RowBox[{
        SubscriptBox["T", 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]]}],
       TraditionalForm], ")"}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1666]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
   RowBox[{"SUNT", "[", 
    RowBox[{"c", ",", "b", ",", "a"}], "]"}]}], "]"}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1667]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
   SubscriptBox["C", "A"], " ", 
   SubscriptBox["C", "F"]}], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1667]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t7", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"SUNF", "[", 
     RowBox[{"a", ",", "b", ",", "e"}], "]"}], 
    RowBox[{"SUNF", "[", 
     RowBox[{"c", ",", "d", ",", "e"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"SUNF", "[", 
     RowBox[{"a", ",", "b", ",", "z"}], "]"}], 
    RowBox[{"SUNF", "[", 
     RowBox[{"c", ",", "d", ",", "z"}], "]"}]}]}]}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1668]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["f", 
     RowBox[{"a", "b", "e"}]], " ", 
    SubscriptBox["f", 
     RowBox[{"c", "d", "e"}]]}], "+", 
   RowBox[{
    SubscriptBox["f", 
     RowBox[{"a", "b", "z"}]], " ", 
    SubscriptBox["f", 
     RowBox[{"c", "d", "z"}]]}]}], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1668]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{"t7", ",", 
   RowBox[{"Explicit", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1669]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1669]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{"t7", ",", 
   RowBox[{"Explicit", "\[Rule]", "False"}], ",", 
   RowBox[{"SUNIndexRename", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1670]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["z",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["z",
        TraditionalForm],
       TraditionalForm]}]]}]}], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1670]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{"1", "-", 
   RowBox[{"SUNDelta", "[", 
    RowBox[{"i", ",", "i"}], "]"}]}], "]"}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1671]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"2", "-", 
   SubsuperscriptBox["C", "A", "2"]}], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1671]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t8", "=", 
  RowBox[{"DiracTrace", "[", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"SUNIndex", "[", "a", "]"}], "]"}], 
    RowBox[{
     RowBox[{"DiracMatrix", "[", "\[Mu]", "]"}], ".", 
     RowBox[{"DiracMatrix", "[", "\[Nu]", "]"}]}]}], "]"}]}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1672]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"tr", "(", 
   FormBox[
    RowBox[{
     RowBox[{"f", "(", 
      FormBox["a",
       TraditionalForm], ")"}], " ", 
     RowBox[{
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]]}]}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1672]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{"t8", ",", 
   RowBox[{"SUNTrace", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1673]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"tr", "(", 
   FormBox[
    RowBox[{
     RowBox[{"f", "(", 
      FormBox["a",
       TraditionalForm], ")"}], " ", 
     RowBox[{
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]]}]}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1673]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{"t8", ",", 
   RowBox[{"SUNTrace", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1674]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"f", "(", 
    FormBox["a",
     TraditionalForm], ")"}], " ", 
   SubscriptBox["C", "A"], " ", 
   RowBox[{"tr", "(", 
    FormBox[
     RowBox[{
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], ".", 
      SuperscriptBox["\[Gamma]", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]]}],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellTags->"SUNSimplify",
 CellLabel->"Out[1674]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5", ",", "t6", ",", "t7", ",",
    "t8"}], "]"}]], "Input",
 CellTags->"SUNSimplify",
 CellLabel->"In[1675]:="]
}, Open  ]],

Cell["SUNT", "ObjectName",
 CellTags->"SUNT"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SUNT"],

Cell[TextData[{
 "SUNT[a] is the SU(",
 StyleBox["N",
  FontSlant->"Italic"],
 ") ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "a"], TraditionalForm]]],
 " generator in the fundamental representation."
}], "Text",
 CellTags->"SUNT"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["CA",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CA",
  ButtonNote->"CA"],
 ", ",
 ButtonBox["CF",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CF",
  ButtonNote->"CF"],
 ", ",
 ButtonBox["SUND",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUND",
  ButtonNote->"SUND"],
 ", ",
 ButtonBox["SUNDelta",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNDelta",
  ButtonNote->"SUNDelta"],
 ", ",
 ButtonBox["SUNF",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNF",
  ButtonNote->"SUNF"],
 ", ",
 ButtonBox["SUNSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNSimplify",
  ButtonNote->"SUNSimplify"],
 "."
}], "Text",
 CellTags->"SUNT"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SUNT"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNT", "[", "a", "]"}]], "Input",
 CellTags->"SUNT",
 CellLabel->"In[1676]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["T", 
   FormBox["a",
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"SUNT",
 CellLabel->"Out[1676]="]
}, Open  ]],

Cell[TextData[{
 "Since ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "a"], TraditionalForm]]],
 " is a noncommutative object, products have to separated by a dot (.)."
}], "Text",
 CellTags->"SUNT"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SUNT", "[", "a", "]"}], ".", " ", 
  RowBox[{"SUNT", "[", "b", "]"}], ".", " ", 
  RowBox[{"SUNT", "[", "c", "]"}]}]], "Input",
 CellTags->"SUNT",
 CellLabel->"In[1677]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["T", 
    FormBox["a",
     TraditionalForm]], ".", 
   SubscriptBox["T", 
    FormBox["b",
     TraditionalForm]], ".", 
   SubscriptBox["T", 
    FormBox["c",
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"SUNT",
 CellLabel->"Out[1677]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNT", "[", 
  RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}]], "Input",
 CellTags->"SUNT",
 CellLabel->"In[1678]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["T", 
    FormBox["a",
     TraditionalForm]], 
   SubscriptBox["T", 
    FormBox["b",
     TraditionalForm]], 
   SubscriptBox["T", 
    FormBox["c",
     TraditionalForm]], 
   SubscriptBox["T", 
    FormBox["d",
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"SUNT",
 CellLabel->"Out[1678]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{
   RowBox[{"SUNT", "[", 
    RowBox[{"a", ",", "b", ",", "a"}], "]"}], ",", 
   RowBox[{"SUNNToCACF", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"SUNT",
 CellLabel->"In[1679]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    SubscriptBox["T", 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], 
    RowBox[{"2", " ", "N"}]]}], TraditionalForm]], "Output",
 CellTags->"SUNT",
 CellLabel->"Out[1679]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{"SUNT", "[", 
   RowBox[{"a", ",", "b", ",", "b", ",", "a"}], "]"}], "]"}]], "Input",
 CellTags->"SUNT",
 CellLabel->"In[1680]:="],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox["C", "F", "2"], TraditionalForm]], "Output",
 CellTags->"SUNT",
 CellLabel->"Out[1680]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{"SUNT", "[", 
   RowBox[{"a", ",", "b", ",", "a"}], "]"}], "]"}]], "Input",
 CellTags->"SUNT",
 CellLabel->"In[1681]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", 
   SubscriptBox["T", 
    FormBox[
     FormBox["b",
      TraditionalForm],
     TraditionalForm]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["C", "A"], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["C", "F"]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"SUNT",
 CellLabel->"Out[1681]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{
   RowBox[{"SUNT", "[", 
    RowBox[{"a", ",", "b", ",", "a"}], "]"}], ",", 
   RowBox[{"SUNNToCACF", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"SUNT",
 CellLabel->"In[1682]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    SubscriptBox["T", 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], 
    RowBox[{"2", " ", "N"}]]}], TraditionalForm]], "Output",
 CellTags->"SUNT",
 CellLabel->"Out[1682]="]
}, Open  ]],

Cell[TextData[{
 "The normalizaton of the generators is chosen in the standard way, therefore \
",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"tr", "(", 
     RowBox[{
      SubscriptBox["T", "a"], 
      SubscriptBox["T", "b"]}], ")"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"1", "/", "2"}], " ", 
     RowBox[{
      SubscriptBox["\[Delta]", "ab"], "."}]}]}], TraditionalForm]]]
}], "Text",
 CellTags->"SUNT"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNTrace", "[", 
  RowBox[{"SUNT", "[", 
   RowBox[{"a", ",", "b"}], "]"}], "]"}]], "Input",
 CellTags->"SUNT",
 CellLabel->"In[1683]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]}]], "2"], TraditionalForm]], "Output",
 CellTags->"SUNT",
 CellLabel->"Out[1683]="]
}, Open  ]],

Cell[TextData[{
 "In case you want ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "f"], TraditionalForm]]],
 ", you need to include a factor 2Tf inside the trace."
}], "Text",
 CellTags->"SUNT"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNTrace", "[", 
  RowBox[{"2", " ", "Tf", " ", 
   RowBox[{"SUNT", "[", 
    RowBox[{"a", ",", "b"}], "]"}]}], "]"}]], "Input",
 CellTags->"SUNT",
 CellLabel->"In[1684]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["T", "f"], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"SUNT",
 CellLabel->"Out[1684]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SUNTrace", "[", 
   RowBox[{"SUNT", "[", 
    RowBox[{"a", ",", "b"}], "]"}], "]"}], "//", "StandardForm"}]], "Input",
 CellTags->"SUNT",
 CellLabel->"In[1685]:="],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"SUNDelta", "[", 
   RowBox[{
    RowBox[{"SUNIndex", "[", "a", "]"}], ",", 
    RowBox[{"SUNIndex", "[", "b", "]"}]}], "]"}]}]], "Output",
 CellTags->"SUNT",
 CellLabel->"Out[1685]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SUNT", "[", "a", "]"}], "//", "FCI"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SUNT",
 CellLabel->"In[1686]:="],

Cell[BoxData[
 RowBox[{"SUNT", "[", 
  RowBox[{"SUNIndex", "[", "a", "]"}], "]"}]], "Output",
 CellTags->"SUNT",
 CellLabel->"Out[1686]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SUNT", "[", "a", "]"}], "//", "FCI"}], "//", "FCE"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"SUNT",
 CellLabel->"In[1687]:="],

Cell[BoxData[
 RowBox[{"SUNT", "[", "a", "]"}]], "Output",
 CellTags->"SUNT",
 CellLabel->"Out[1687]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["SUNTrace", "ObjectName",
 CellTags->"SUNTrace"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SUNTrace"],

Cell["SUNTrace[expr] calculates the color-trace.", "Text",
 CellTags->"SUNTrace"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "SUNTrace", "]"}]], "Input",
 CellTags->"SUNTrace",
 CellLabel->"In[1688]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"Explicit", "\[Rule]", "False"}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"SUNTrace",
 CellLabel->"Out[1688]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["SUNSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNSimplify",
  ButtonNote->"SUNSimplify"],
 ", ",
 ButtonBox["Tr",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Tr",
  ButtonNote->"Tr"],
 "."
}], "Text",
 CellTags->"SUNTrace"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"SUNTrace"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNTrace", "[", 
  RowBox[{"SUNT", "[", 
   RowBox[{"a", ",", "b"}], "]"}], "]"}]], "Input",
 CellTags->"SUNTrace",
 CellLabel->"In[1689]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]}]], "2"], TraditionalForm]], "Output",
 CellTags->"SUNTrace",
 CellLabel->"Out[1689]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNTrace", "[", 
  RowBox[{"SUNT", "[", 
   RowBox[{"a", ",", "b", ",", "c"}], "]"}], "]"}]], "Input",
 CellTags->"SUNTrace",
 CellLabel->"In[1690]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"tr", "(", 
   FormBox[
    RowBox[{
     SubscriptBox["T", 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]]}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"SUNTrace",
 CellLabel->"Out[1690]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNTrace", "[", 
  RowBox[{
   RowBox[{"SUNT", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"SUNTrace",
 CellLabel->"In[1691]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    SubscriptBox["d", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]}]], "4"], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]}]]}]}], TraditionalForm]], "Output",
 CellTags->"SUNTrace",
 CellLabel->"Out[1691]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNTrace", "[", 
  RowBox[{"SUNT", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "]"}]], "Input",
 CellTags->"SUNTrace",
 CellLabel->"In[1692]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"tr", "(", 
   FormBox[
    RowBox[{
     SubscriptBox["T", 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"SUNTrace",
 CellLabel->"Out[1692]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{"SUNTrace", "[", 
   RowBox[{
    RowBox[{"SUNT", "[", 
     RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], ",", 
    RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellTags->"SUNTrace",
 CellLabel->"In[1693]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
     SubscriptBox["f", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm], "e"}]], " ", 
     SubscriptBox["d", 
      RowBox[{"e", 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]}]]}]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SubscriptBox["d", 
     RowBox[{"e", 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], "e"}]]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    SubscriptBox["d", 
     RowBox[{"e", 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["d", 
     RowBox[{"e", 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    SubscriptBox["d", 
     RowBox[{"e", 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["d", 
     RowBox[{"e", 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    SubscriptBox["d", 
     RowBox[{"e", 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["d", 
     RowBox[{"e", 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   FractionBox[
    RowBox[{
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]}]]}], 
    RowBox[{"4", " ", "N"}]], "-", 
   FractionBox[
    RowBox[{
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]}]]}], 
    RowBox[{"4", " ", "N"}]], "+", 
   FractionBox[
    RowBox[{
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]}]]}], 
    RowBox[{"4", " ", "N"}]]}], TraditionalForm]], "Output",
 CellTags->"SUNTrace",
 CellLabel->"Out[1693]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{"t1", ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"SUNTrace",
 CellLabel->"In[1694]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"tr", "(", 
   FormBox[
    RowBox[{
     SubscriptBox["T", 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"SUNTrace",
 CellLabel->"Out[1694]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", "=", 
  RowBox[{"SUNTrace", "[", 
   RowBox[{
    RowBox[{"SUNT", "[", 
     RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e"}], "]"}], ",", 
    RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellTags->"SUNTrace",
 CellLabel->"In[1695]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    SubscriptBox["d", 
     RowBox[{"c194", 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm], "c195"}]], " ", 
       SubscriptBox["d", 
        RowBox[{"c195", 
         FormBox[
          FormBox["c194",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["d", 
        RowBox[{"c195", 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox["c194",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm], "c195"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       SubscriptBox["d", 
        RowBox[{"c195", 
         FormBox[
          FormBox["c194",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       SubscriptBox["d", 
        RowBox[{"c195", 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       SubscriptBox["d", 
        RowBox[{"c195", 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       SubscriptBox["d", 
        RowBox[{"c195", 
         FormBox[
          FormBox["c194",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       SubscriptBox["d", 
        RowBox[{"c195", 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       SubscriptBox["d", 
        RowBox[{"c195", 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["c194",
           TraditionalForm],
          TraditionalForm]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["c",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["c194",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["d",
            TraditionalForm],
           TraditionalForm]}]]}], 
       RowBox[{"4", " ", "N"}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["c",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["d",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["c194",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]}]]}], 
       RowBox[{"4", " ", "N"}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["c",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["c194",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["d",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]}]]}], 
       RowBox[{"4", " ", "N"}]]}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], "c194"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm], "c196"}]], " ", 
       SubscriptBox["d", 
        RowBox[{"c196", 
         FormBox[
          FormBox["c194",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubscriptBox["d", 
        RowBox[{"c196", 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox["c194",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm], "c196"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       SubscriptBox["d", 
        RowBox[{"c196", 
         FormBox[
          FormBox["c194",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       SubscriptBox["d", 
        RowBox[{"c196", 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       SubscriptBox["d", 
        RowBox[{"c196", 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       SubscriptBox["d", 
        RowBox[{"c196", 
         FormBox[
          FormBox["c194",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       SubscriptBox["d", 
        RowBox[{"c196", 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       SubscriptBox["d", 
        RowBox[{"c196", 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["c194",
           TraditionalForm],
          TraditionalForm]}]]}], "-", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["c",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["c194",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["d",
            TraditionalForm],
           TraditionalForm]}]]}], 
       RowBox[{"4", " ", "N"}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["c",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["d",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["c194",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]}]]}], 
       RowBox[{"4", " ", "N"}]], "+", 
      FractionBox[
       RowBox[{
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["c",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["c194",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["d",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]}]]}], 
       RowBox[{"4", " ", "N"}]]}], ")"}]}], "+", 
   FractionBox[
    RowBox[{
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        SubscriptBox["d", 
         RowBox[{
          FormBox[
           FormBox["c",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["d",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]}]], "4"], "+", 
       RowBox[{
        FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
        SubscriptBox["f", 
         RowBox[{
          FormBox[
           FormBox["c",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["d",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]}]]}]}], ")"}]}], 
    RowBox[{"2", " ", "N"}]]}], TraditionalForm]], "Output",
 CellTags->"SUNTrace",
 CellLabel->"Out[1695]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{"t2", ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"SUNTrace",
 CellLabel->"In[1696]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"tr", "(", 
   FormBox[
    RowBox[{
     SubscriptBox["T", 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], ".", 
     SubscriptBox["T", 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}],
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"SUNTrace",
 CellLabel->"Out[1696]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
   RowBox[{"SUND", "[", 
    RowBox[{"d", ",", "b", ",", "c"}], "]"}]}], "]"}]], "Input",
 CellTags->"SUNTrace",
 CellLabel->"In[1697]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"SUNTrace",
 CellLabel->"Out[1697]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
   RowBox[{"SUND", "[", 
    RowBox[{"a", ",", "b", ",", "d"}], "]"}]}], "]"}]], "Input",
 CellTags->"SUNTrace",
 CellLabel->"In[1698]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"SUNTrace",
 CellLabel->"Out[1698]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{
   RowBox[{"SUNF", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
   RowBox[{"SUND", "[", 
    RowBox[{"a", ",", "d", ",", "c"}], "]"}]}], "]"}]], "Input",
 CellTags->"SUNTrace",
 CellLabel->"In[1699]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"SUNTrace",
 CellLabel->"Out[1699]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SUNSimplify", "[", 
  RowBox[{
   RowBox[{"SUND", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], " ", 
   RowBox[{"SUND", "[", 
    RowBox[{"d", ",", "b", ",", "c"}], "]"}]}], "]"}]], "Input",
 CellTags->"SUNTrace",
 CellLabel->"In[1700]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{"4", "-", 
      SubsuperscriptBox["C", "A", "2"]}], ")"}]}], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["C", "A"], "-", 
     RowBox[{"2", " ", 
      SubscriptBox["C", "F"]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"SUNTrace",
 CellLabel->"Out[1700]="]
}, Open  ]]
}, Open  ]],

Cell["SymbolicSum2", "ObjectName",
 CellTags->"SymbolicSum2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SymbolicSum2"],

Cell["\<\
SymbolicSum2 is similar to SymbolicSum (Algegra`SymbolicSum`SymbolicSum was a \
function to do symbolic summation. It was obsolete from version 3 - all \
functionality is now autoloaded by Sum), but extended to several double sums.\
\
\>", "Text",
 CellTags->"SymbolicSum2"]
}, Open  ]],

Cell["SymbolicSum3", "ObjectName",
 CellTags->"SymbolicSum3"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"SymbolicSum3"],

Cell["\<\
SymbolicSymbolicSum3 is similar to SymbolicSum \
(Algegra`SymbolicSum`SymbolicSum was a function to do symbolic summation. It \
was obsolete from version 3 - all functionality is now autoloaded by Sum), \
but extended to several double sums.\
\>", "Text",
 CellTags->"SymbolicSum3"]
}, Open  ]],

Cell["Symmetrize", "ObjectName",
 CellTags->"Symmetrize"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Symmetrize"],

Cell["\<\
Symmetrize[expr, {a1, a2, ...}] antisymmetrizes expr with respect to the \
variables a1,a2, ... \
\>", "Text",
 CellTags->"Symmetrize"],

Cell[TextData[{
 "See also: ",
 ButtonBox["AntiSymmetrize",
  BaseStyle->"AddOnsLink",
  ButtonData:>"AntiSymmetrize",
  ButtonNote->"AntiSymmetrize"],
 "."
}], "Text",
 CellTags->"Symmetrize"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Symmetrize"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Symmetrize", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"a", ",", "b"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b"}], "}"}]}], "]"}]], "Input",
 CellTags->"Symmetrize",
 CellLabel->"In[1701]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f", "(", 
      RowBox[{"a", ",", "b"}], ")"}], "+", 
     RowBox[{"f", "(", 
      RowBox[{"b", ",", "a"}], ")"}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Symmetrize",
 CellLabel->"Out[1701]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Symmetrize", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]], "Input",
 CellTags->"Symmetrize",
 CellLabel->"In[1702]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "6"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f", "(", 
      RowBox[{"x", ",", "y", ",", "z"}], ")"}], "+", 
     RowBox[{"f", "(", 
      RowBox[{"x", ",", "z", ",", "y"}], ")"}], "+", 
     RowBox[{"f", "(", 
      RowBox[{"y", ",", "x", ",", "z"}], ")"}], "+", 
     RowBox[{"f", "(", 
      RowBox[{"y", ",", "z", ",", "x"}], ")"}], "+", 
     RowBox[{"f", "(", 
      RowBox[{"z", ",", "x", ",", "y"}], ")"}], "+", 
     RowBox[{"f", "(", 
      RowBox[{"z", ",", "y", ",", "x"}], ")"}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"Symmetrize",
 CellLabel->"Out[1702]="]
}, Open  ]]
}, Open  ]],

Cell["TBox, Tbox", "ObjectName",
 CellTags->{"TBox", "Tbox"}],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->{"TBox", "Tbox"}],

Cell["\<\
TBox[a, b, ...] or Tbox[a, b, ...] produces a RowBox[{a,b, ...}] where a, b, \
... are boxed in TraditionalForm. TBox and Tbox are used internally by \
FeynCalc to produce the typeset output in TraditionalForm\
\>", "Text",
 CellTags->{"TBox", "Tbox"}]
}, Open  ]],

Cell["Tdec", "ObjectName",
 CellTags->"Tdec"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Tdec"],

Cell["\<\
Tdec[{q,mu}, {p}]; Tdec[{{qi, mu}, {qj, nu}, ...}, {p1, p2, ...}] or \
Tdec[exp, {{qi, mu}, {qj, nu}, ...}, {p1, p2, ...}] calculates the tensorial \
decomposition formulas. The more common ones are saved in TIDL.\
\>", "Text",
 CellTags->"Tdec"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Tdec", "]"}]], "Input",
 CellTags->"Tdec",
 CellLabel->"In[1703]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Factoring", "\[Rule]", "Factor2"}], ",", 
    RowBox[{"FeynCalcExternal", "\[Rule]", "True"}], ",", 
    RowBox[{"List", "\[Rule]", "True"}], ",", 
    RowBox[{"NumberOfMetricTensors", "\[Rule]", "\[Infinity]"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Tdec",
 CellLabel->"Out[1703]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["TID",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TID",
  ButtonNote->"TID"],
 ", ",
 ButtonBox["TIDL",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TIDL",
  ButtonNote->"TIDL"],
 ", ",
 ButtonBox["OneLoopSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoopSimplify",
  ButtonNote->"OneLoopSimplify"],
 "."
}], "Text",
 CellTags->"Tdec"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Tdec"],

Cell[TextData[{
 "Check that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Integral]", 
     RowBox[{
      SuperscriptBox["d", "D"], 
      RowBox[{"f", "(", 
       RowBox[{"p", ",", "q"}], ")"}], 
      SuperscriptBox["q", "\[Mu]"]}]}], "=", " ", 
    RowBox[{
     FractionBox[
      SuperscriptBox["p", "\[Mu]"], 
      SuperscriptBox["p", "2"]], 
     RowBox[{"\[Integral]", 
      RowBox[{
       SuperscriptBox["d", "D"], 
       RowBox[{"f", "(", 
        RowBox[{"p", ",", "q"}], ")"}], 
       RowBox[{"p", "\[CenterDot]", "q"}]}]}]}]}], TraditionalForm]]]
}], "Text",
 CellTags->"Tdec"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tdec", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
   RowBox[{"{", "p", "}"}]}], "]"}]], "Input",
 CellTags->"Tdec",
 CellLabel->"In[1704]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"X1", "\[Rule]", 
       SuperscriptBox["m", "2"]}], ",", 
      RowBox[{"X2", "\[Rule]", 
       FormBox[
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}],
        TraditionalForm]}]}], "}"}], ",", 
    FractionBox[
     RowBox[{"X2", " ", 
      SuperscriptBox["p", "\[Mu]"]}], "X1"]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Tdec",
 CellLabel->"Out[1704]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"%", "[", 
   RowBox[{"[", "2", "]"}], "]"}], "/.", 
  RowBox[{"%", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellTags->"Tdec",
 CellLabel->"In[1705]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["p", "\[Mu]"], " ", 
    FormBox[
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}],
     TraditionalForm]}], 
   SuperscriptBox["m", "2"]], TraditionalForm]], "Output",
 CellTags->"Tdec",
 CellLabel->"Out[1705]="]
}, Open  ]],

Cell[TextData[{
 "This calculates integral transformation for any ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Integral]", 
    RowBox[{
     SuperscriptBox["d", "D"], 
     SubscriptBox["q", "1"], 
     SuperscriptBox["d", "D"], 
     SubscriptBox["q", "2"], 
     SuperscriptBox["d", "D"], 
     SubscriptBox["q", "3"]}]}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", 
     RowBox[{"p", ",", 
      RowBox[{
       SubscriptBox["q", 
        RowBox[{"1", ","}]], 
       SubscriptBox["q", "2"]}], ",", 
      SubscriptBox["q", "3"]}], ")"}], " ", 
    SubsuperscriptBox["q", "1", "\[Mu]"], 
    SubsuperscriptBox["q", "2", "\[Nu]"], 
    SubsuperscriptBox["q", "3", "\[Rho]"]}], TraditionalForm]]],
 "."
}], "Text",
 CellTags->"Tdec"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t", "=", 
   RowBox[{"Tdec", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["q", "1"], ",", "\[Mu]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["q", "2"], ",", "\[Nu]"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["q", "3"], ",", "\[Rho]"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", "p", "}"}]}], "]"}]}], ";"}]], "Input",
 CellTags->"Tdec",
 CellLabel->"In[1706]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"t", "[", 
   RowBox[{"[", "2", "]"}], "]"}], "/.", 
  RowBox[{"t", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellTags->"Tdec",
 CellLabel->"In[1707]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["p", "\[Rho]"], " ", 
     SuperscriptBox["g", 
      RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["q", "3"],
        TraditionalForm]}],
      TraditionalForm], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "1"],
           TraditionalForm]}],
         TraditionalForm], " ", 
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "2"],
           TraditionalForm]}],
         TraditionalForm]}], "-", 
       RowBox[{
        SuperscriptBox["m", "2"], " ", 
        FormBox[
         RowBox[{
          FormBox[
           SubscriptBox["q", "1"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "2"],
           TraditionalForm]}],
         TraditionalForm]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "D"}], ")"}], " ", 
     SuperscriptBox["m", "4"]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["p", "\[Nu]"], " ", 
     SuperscriptBox["g", 
      RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["q", "2"],
        TraditionalForm]}],
      TraditionalForm], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "1"],
           TraditionalForm]}],
         TraditionalForm], " ", 
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "3"],
           TraditionalForm]}],
         TraditionalForm]}], "-", 
       RowBox[{
        SuperscriptBox["m", "2"], " ", 
        FormBox[
         RowBox[{
          FormBox[
           SubscriptBox["q", "1"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "3"],
           TraditionalForm]}],
         TraditionalForm]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "D"}], ")"}], " ", 
     SuperscriptBox["m", "4"]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["p", "\[Mu]"], " ", 
     SuperscriptBox["g", 
      RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["q", "1"],
        TraditionalForm]}],
      TraditionalForm], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "2"],
           TraditionalForm]}],
         TraditionalForm], " ", 
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "3"],
           TraditionalForm]}],
         TraditionalForm]}], "-", 
       RowBox[{
        SuperscriptBox["m", "2"], " ", 
        FormBox[
         RowBox[{
          FormBox[
           SubscriptBox["q", "2"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "3"],
           TraditionalForm]}],
         TraditionalForm]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "D"}], ")"}], " ", 
     SuperscriptBox["m", "4"]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["p", "\[Mu]"], " ", 
     SuperscriptBox["p", "\[Nu]"], " ", 
     SuperscriptBox["p", "\[Rho]"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"D", " ", 
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "1"],
           TraditionalForm]}],
         TraditionalForm], " ", 
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "2"],
           TraditionalForm]}],
         TraditionalForm], " ", 
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "3"],
           TraditionalForm]}],
         TraditionalForm]}], "+", 
       RowBox[{
        SuperscriptBox["m", "2"], " ", 
        FormBox[
         RowBox[{
          FormBox[
           SubscriptBox["q", "1"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "2"],
           TraditionalForm]}],
         TraditionalForm], " ", 
        RowBox[{"(", 
         RowBox[{"-", 
          RowBox[{"(", 
           FormBox[
            RowBox[{
             FormBox["p",
              TraditionalForm], "\[CenterDot]", 
             FormBox[
              SubscriptBox["q", "3"],
              TraditionalForm]}],
            TraditionalForm], ")"}]}], ")"}]}], "-", 
       RowBox[{
        SuperscriptBox["m", "2"], " ", 
        FormBox[
         RowBox[{
          FormBox[
           SubscriptBox["q", "1"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "3"],
           TraditionalForm]}],
         TraditionalForm], " ", 
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "2"],
           TraditionalForm]}],
         TraditionalForm]}], "-", 
       RowBox[{
        SuperscriptBox["m", "2"], " ", 
        FormBox[
         RowBox[{
          FormBox[
           SubscriptBox["q", "2"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "3"],
           TraditionalForm]}],
         TraditionalForm], " ", 
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "1"],
           TraditionalForm]}],
         TraditionalForm]}], "+", 
       RowBox[{"2", " ", 
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "1"],
           TraditionalForm]}],
         TraditionalForm], " ", 
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "2"],
           TraditionalForm]}],
         TraditionalForm], " ", 
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["q", "3"],
           TraditionalForm]}],
         TraditionalForm]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "D"}], ")"}], " ", 
     SuperscriptBox["m", "6"]}]]}], TraditionalForm]], "Output",
 CellTags->"Tdec",
 CellLabel->"Out[1707]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Contract", "[", 
   RowBox[{
    RowBox[{"%", " ", 
     RowBox[{"FVD", "[", 
      RowBox[{"p", ",", "\[Mu]"}], "]"}]}], 
    RowBox[{"FVD", "[", 
     RowBox[{"p", ",", "\[Nu]"}], "]"}], " ", 
    RowBox[{"FVD", "[", 
     RowBox[{"p", ",", "\[Rho]"}], "]"}]}], "]"}], "//", "Factor"}]], "Input",\

 CellTags->"Tdec",
 CellLabel->"In[1708]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "1"}], ")"}], " ", 
     SuperscriptBox["m", "6"]}]], 
   RowBox[{
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"D", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "1"],
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "2"],
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox["m", "4"], " ", 
       RowBox[{
        FormBox[
         SubscriptBox["q", "1"],
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "2"],
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox["m", "4"], " ", 
       RowBox[{
        FormBox[
         SubscriptBox["q", "1"],
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "3"],
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "2"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox["m", "4"], " ", 
       RowBox[{
        FormBox[
         SubscriptBox["q", "2"],
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "3"],
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "1"],
         TraditionalForm]}]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["m", "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "1"],
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "2"],
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["m", "2"], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"], " ", 
       RowBox[{
        FormBox[
         SubscriptBox["q", "1"],
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "2"],
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["m", "2"], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"], " ", 
       RowBox[{
        FormBox[
         SubscriptBox["q", "1"],
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "3"],
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "2"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["m", "2"], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"], " ", 
       RowBox[{
        FormBox[
         SubscriptBox["q", "2"],
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "3"],
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "1"],
         TraditionalForm]}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "1"],
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "2"],
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["q", "3"],
         TraditionalForm]}]}]}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Tdec",
 CellLabel->"Out[1708]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "t", "]"}], ";"}]], "Input",
 CellTags->"Tdec",
 CellLabel->"In[1709]:="]
}, Open  ]],

Cell["TensorFunction", "ObjectName",
 CellTags->"TensorFunction"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"TensorFunction"],

Cell["\<\
Tensorfunction[t, mu, nu, ...] transform into t[LorentzIndex[mu], \
LorentzIndex[nu], ...], i.e., it can be used as an unspecified tensoriell \
function t. A symmetric tensor can be obtained by Tensorfunction[{t, \"S\"}, \
mu, nu, ...], and an antisymmteric one by Tensorfunction[{t, \"A\"}, mu, nu, \
...].\
\>", "Text",
 CellTags->"TensorFunction"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Symmetrize",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Symmetrize",
  ButtonNote->"Symmetrize"],
 "."
}], "Text",
 CellTags->"TensorFunction"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"TensorFunction"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tensorfunction", "[", 
  RowBox[{"t", ",", "\[Mu]", ",", "\[Nu]", ",", "\[Tau]"}], "]"}]], "Input",
 CellTags->"TensorFunction",
 CellLabel->"In[1710]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"Tensorfunction", "(", 
   RowBox[{"t", ",", "\[Mu]", ",", "\[Nu]", ",", "\[Tau]"}], ")"}], 
  TraditionalForm]], "Output",
 CellTags->"TensorFunction",
 CellLabel->"Out[1710]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"TensorFunction",
 CellLabel->"In[1711]:="],

Cell[BoxData[
 RowBox[{"Tensorfunction", "[", 
  RowBox[{"t", ",", "\[Mu]", ",", "\[Nu]", ",", "\[Tau]"}], "]"}]], "Output",
 CellTags->"TensorFunction",
 CellLabel->"Out[1711]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", 
  RowBox[{
   RowBox[{"FV", "[", 
    RowBox[{"p", ",", "\[Mu]"}], "]"}], " ", "%"}], "]"}]], "Input",
 CellTags->"TensorFunction",
 CellLabel->"In[1712]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], " ", 
   RowBox[{"Tensorfunction", "(", 
    RowBox[{"t", ",", "\[Mu]", ",", "\[Nu]", ",", "\[Tau]"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"TensorFunction",
 CellLabel->"Out[1712]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"TensorFunction",
 CellLabel->"In[1713]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pair", "[", 
   RowBox[{
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
    RowBox[{"Momentum", "[", "p", "]"}]}], "]"}], " ", 
  RowBox[{"Tensorfunction", "[", 
   RowBox[{"t", ",", "\[Mu]", ",", "\[Nu]", ",", "\[Tau]"}], 
   "]"}]}]], "Output",
 CellTags->"TensorFunction",
 CellLabel->"Out[1713]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tensorfunction", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"f", ",", "\"\<S\>\""}], "}"}], ",", "\[Alpha]", ",", "\[Beta]"}],
   "]"}]], "Input",
 CellTags->"TensorFunction",
 CellLabel->"In[1714]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"Tensorfunction", "(", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"f", ",", "\<\"S\"\>"}], "}"}], ",", "\[Alpha]", ",", 
    "\[Beta]"}], ")"}], TraditionalForm]], "Output",
 CellTags->"TensorFunction",
 CellLabel->"Out[1714]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tensorfunction", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"f", ",", "\"\<S\>\""}], "}"}], ",", "\[Beta]", ",", "\[Alpha]"}],
   "]"}]], "Input",
 CellTags->"TensorFunction",
 CellLabel->"In[1715]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"Tensorfunction", "(", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"f", ",", "\<\"S\"\>"}], "}"}], ",", "\[Beta]", ",", 
    "\[Alpha]"}], ")"}], TraditionalForm]], "Output",
 CellTags->"TensorFunction",
 CellLabel->"Out[1715]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"TensorFunction",
 CellLabel->"In[1716]:="],

Cell[BoxData[
 RowBox[{"Tensorfunction", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"f", ",", "\<\"S\"\>"}], "}"}], ",", "\[Beta]", ",", "\[Alpha]"}],
   "]"}]], "Output",
 CellTags->"TensorFunction",
 CellLabel->"Out[1716]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Attributes", "[", "f", "]"}]], "Input",
 CellTags->"TensorFunction",
 CellLabel->"In[1717]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", "}"}], TraditionalForm]], "Output",
 CellTags->"TensorFunction",
 CellLabel->"Out[1717]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"ClearAttributes", "[", 
  RowBox[{"f", ",", "Orderless"}], "]"}]], "Input",
 CellTags->"TensorFunction",
 CellLabel->"In[1718]:="]
}, Open  ]],

Cell["Tf", "ObjectName",
 CellTags->"Tf"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Tf"],

Cell[TextData[{
 "Tf is the color factor ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "f"], TraditionalForm]]],
 ". It is 1/2 for SU(",
 StyleBox["N",
  FontSlant->"Italic"],
 ")."
}], "Text",
 CellTags->"Tf"],

Cell[TextData[{
 "See also: ",
 ButtonBox["Tr2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Tr2",
  ButtonNote->"Tr2"],
 ", ",
 ButtonBox["GluonPropagator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonPropagator",
  ButtonNote->"GluonPropagator"],
 ", ",
 ButtonBox["GluonSelfEnergy",
  BaseStyle->"AddOnsLink",
  ButtonData:>"GluonSelfEnergy",
  ButtonNote->"GluonSelfEnergy"],
 "."
}], "Text",
 CellTags->"Tf"]
}, Open  ]],

Cell["TFi", "ObjectName",
 CellTags->"TFi"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"TFi"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "TFi"}]], "Input",
 CellLabel->"In[1719]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   StyleBox[
    RowBox[{"Information", "::", "notfound"}], "MessageName"], 
   RowBox[{
   ":", " "}], "\<\"Symbol \[NoBreak]\\!\\(TraditionalForm\\`\\\"TFi\\\"\\)\
\[NoBreak] not found. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/Information\\\", ButtonNote -> \
\\\"Information::notfound\\\"]\\)\"\>"}], TraditionalForm]], "Message", "MSG"]
}, Open  ]],

Cell["\<\
TFi[d, pp, {{n1,m1},{n2,m2},{n3,m3},{n4,m4},{n5,m5}}] is the 2-loop \
d-dimensional integral 1/( (q1^2 - m1^2)^n1 (q2^2 - m2^2)^n2 ((q1-p)^2 - \
m3^2)^n3 *((q2-p)^2 - m4^2)^n4 * ((q1-q2)^2 - m5^2)^n5 ) . TFi[d, pp, \
{x,y,z,v,w}, {{n1,m1},{n2,m2},{n3,m3},{n4,m4},{n5,m5}}] has as additional \
factors in the numerator (q1^2)^x*(q2^2)^y*(q1.p)^z* (q2.p)^v*(q1.q2)^w. \
TFi[d, pp, dp, {a,b}, {{n1,m1},{n2,m2},{n3,m3},{n4,m4},{n5,m5}}] has as \
additional factors in the numerator (OPEDelta.q1)^a * (OPEDelta.q2)^b; dp is \
(OPEDelta.p).\
\>", "Text",
 CellTags->"TFi"],

Cell[TextData[{
 "TFi is similar to TFI from the TARCER package, see ",
 " ",
 ButtonBox["hep-ph/9801383.",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://xxx.lanl.gov/abs/hep-ph/9801383"], None}]
}], "Text",
 CellTags->"TFi"],

Cell["\<\
The function TarcerRecurse from the TARCER package recognize TFi (as well as \
TFI, which is defined in the HighEnergyPhysics`Tarcer` context).\
\>", "Text",
 CellTags->"TFi"],

Cell[TextData[{
 "See also: ",
 ButtonBox["ToTFi",
  BaseStyle->"AddOnsLink",
  ButtonData:>"ToTFi",
  ButtonNote->"ToTFi"],
 ", ",
 ButtonBox["FromTFi",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FromTFi",
  ButtonNote->"FromTFi"],
 "."
}], "Text",
 CellTags->"TFi"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"TFi"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TFi", "[", 
  RowBox[{"D", ",", 
   RowBox[{"M", "^", "2"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "m1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "m2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "m3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "m4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "m5"}], "}"}]}], "}"}]}], "]"}]], "Input",
 CellTags->"TFi",
 CellLabel->"In[1720]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"TFi", "(", 
   RowBox[{"D", ",", 
    SuperscriptBox["M", "2"], ",", 
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"2", "m1"},
       {"1", "m2"},
       {"3", "m3"},
       {"1", "m4"},
       {"1", "m5"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}]}], ")"}], 
  TraditionalForm]], "Output",
 CellTags->"TFi",
 CellLabel->"Out[1720]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TFi", "[", 
  RowBox[{"D", ",", 
   RowBox[{"M", "^", "2"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "M"}], "}"}], ",", "1", ",", "1", ",", "1", ",", 
     "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"TFi",
 CellLabel->"In[1721]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"TFi", "(", 
   RowBox[{"D", ",", 
    SuperscriptBox["M", "2"], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "M"}], "}"}], ",", "1", ",", "1", ",", "1", ",", 
      "1"}], "}"}]}], ")"}], TraditionalForm]], "Output",
 CellTags->"TFi",
 CellLabel->"Out[1721]="]
}, Open  ]]
}, Open  ]],

Cell["ThreeVector", "ObjectName",
 CellTags->"ThreeVector"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ThreeVector"],

Cell["ThreeVector[p] is the three dimensional vector p.", "Text",
 CellTags->"ThreeVector"],

Cell[TextData[{
 "See also: ",
 ButtonBox["DotProduct",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DotProduct",
  ButtonNote->"DotProduct"],
 ", ",
 ButtonBox["CrossProduct",
  BaseStyle->"AddOnsLink",
  ButtonData:>"CrossProduct",
  ButtonNote->"CrossProduct"],
 "."
}], "Text",
 CellTags->"ThreeVector"]
}, Open  ]],

Cell["TID", "ObjectName",
 CellTags->"TID"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"TID"],

Cell["TID[amp,q] performs a tensorial decomposition.", "Text",
 CellTags->"TID"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "TID", "]"}]], "Input",
 CellTags->"TID",
 CellLabel->"In[1722]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Collecting", "\[Rule]", "True"}], ",", 
    RowBox[{"Contract", "\[Rule]", "False"}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"ChangeDimension", "\[Rule]", "D"}], ",", 
    RowBox[{"DimensionalReduction", "\[Rule]", "False"}], ",", 
    RowBox[{"FeynAmpDenominatorCombine", "\[Rule]", "True"}], ",", 
    RowBox[{"FeynAmpDenominatorSimplify", "\[Rule]", "False"}], ",", 
    RowBox[{"Isolate", "\[Rule]", "False"}], ",", 
    RowBox[{"ScalarProductCancel", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"TID",
 CellLabel->"Out[1722]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OneLoopSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoopSimplify",
  ButtonNote->"OneLoopSimplify"],
 ", ",
 ButtonBox["TIDL",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TIDL",
  ButtonNote->"TIDL"],
 "."
}], "Text",
 CellTags->"TID"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"TID"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FAD", "[", 
    RowBox[{"k", ",", " ", 
     RowBox[{"k", " ", "-", " ", 
      SubscriptBox["p", "1"]}], ",", " ", 
     RowBox[{"k", " ", "-", " ", 
      SubscriptBox["p", "2"]}]}], "]"}], 
   RowBox[{"FVD", "[", 
    RowBox[{"k", ",", "\[Mu]"}], "]"}]}], "//", "FCI"}]], "Input",
 CellTags->"TID",
 CellLabel->"In[1723]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   SuperscriptBox[
    FormBox["k",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], 
   RowBox[{
    SuperscriptBox["k", "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", 
       SubscriptBox["p", "1"]}], ")"}], "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", 
       SubscriptBox["p", "2"]}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellTags->"TID",
 CellLabel->"Out[1723]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Factor", "/@", 
   RowBox[{"TID", "[", 
    RowBox[{"%", ",", "k"}], "]"}]}], "//", "FCE"}]], "Input",
 CellTags->"TID",
 CellLabel->"In[1724]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     FormBox[
      RowBox[{
       FormBox["k",
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm]}],
      TraditionalForm], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FormBox[
         SubsuperscriptBox["p", "1", "2"],
         TraditionalForm], " ", 
        SubsuperscriptBox["p", 
         FormBox["2",
          TraditionalForm], "\[Mu]"]}], "-", 
       FractionBox[
        RowBox[{"s", " ", 
         SubsuperscriptBox["p", 
          FormBox["1",
           TraditionalForm], "\[Mu]"]}], "2"]}], ")"}], " ", 
     FormBox[
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
           SuperscriptBox["k", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
          SequenceForm["[", $CellContext`k^2, "]"],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"k", "-", 
              SubscriptBox["p", "1"]}], ")"}], "2"], 
           "\[InvisibleSpace]", "\<\"]\"\>"}],
          SequenceForm[
          "[", ($CellContext`k - Subscript[$CellContext`p, 1])^2, "]"],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"k", "-", 
              SubscriptBox["p", "2"]}], ")"}], "2"], 
           "\[InvisibleSpace]", "\<\"]\"\>"}],
          SequenceForm[
          "[", ($CellContext`k - Subscript[$CellContext`p, 2])^2, "]"],
          Editable->False], ")"}]}]],
      TraditionalForm]}], 
    RowBox[{
     RowBox[{
      FormBox[
       SubsuperscriptBox["p", "1", "2"],
       TraditionalForm], " ", 
      FormBox[
       SubsuperscriptBox["p", "2", "2"],
       TraditionalForm]}], "-", 
     FractionBox[
      SuperscriptBox["s", "2"], "4"]}]], "+", 
   FractionBox[
    RowBox[{
     FormBox[
      RowBox[{
       FormBox["k",
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm]}],
      TraditionalForm], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"s", " ", 
         SubsuperscriptBox["p", 
          FormBox["2",
           TraditionalForm], "\[Mu]"]}], "2"], "-", 
       RowBox[{
        FormBox[
         SubsuperscriptBox["p", "2", "2"],
         TraditionalForm], " ", 
        SubsuperscriptBox["p", 
         FormBox["1",
          TraditionalForm], "\[Mu]"]}]}], ")"}], " ", 
     FormBox[
      FractionBox["1", 
       RowBox[{
        RowBox[{"(", 
         InterpretationBox[
          RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
           SuperscriptBox["k", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
          SequenceForm["[", $CellContext`k^2, "]"],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"k", "-", 
              SubscriptBox["p", "1"]}], ")"}], "2"], 
           "\[InvisibleSpace]", "\<\"]\"\>"}],
          SequenceForm[
          "[", ($CellContext`k - Subscript[$CellContext`p, 1])^2, "]"],
          Editable->False], ")"}], " ", 
        RowBox[{"(", 
         InterpretationBox[
          RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"k", "-", 
              SubscriptBox["p", "2"]}], ")"}], "2"], 
           "\[InvisibleSpace]", "\<\"]\"\>"}],
          SequenceForm[
          "[", ($CellContext`k - Subscript[$CellContext`p, 2])^2, "]"],
          Editable->False], ")"}]}]],
      TraditionalForm]}], 
    RowBox[{
     FractionBox[
      SuperscriptBox["s", "2"], "4"], "-", 
     RowBox[{
      FormBox[
       SubsuperscriptBox["p", "1", "2"],
       TraditionalForm], " ", 
      FormBox[
       SubsuperscriptBox["p", "2", "2"],
       TraditionalForm]}]}]]}], TraditionalForm]], "Output",
 CellTags->"TID",
 CellLabel->"Out[1724]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FAD", "[", 
    RowBox[{"k", ",", " ", 
     RowBox[{"k", " ", "-", " ", "p"}]}], "]"}], 
   RowBox[{"FVD", "[", 
    RowBox[{"k", ",", "\[Mu]"}], "]"}]}], "//", "FCI"}]], "Input",
 CellTags->"TID",
 CellLabel->"In[1725]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   SuperscriptBox[
    FormBox["k",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], 
   RowBox[{
    SuperscriptBox["k", "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"k", "-", "p"}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellTags->"TID",
 CellLabel->"Out[1725]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TID", "[", 
  RowBox[{"%", ",", "k"}], "]"}]], "Input",
 CellTags->"TID",
 CellLabel->"In[1726]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{
     FormBox["k",
      TraditionalForm], "\[CenterDot]", 
     FormBox["p",
      TraditionalForm]}]}], 
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    RowBox[{
     SuperscriptBox["k", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"k", "-", "p"}], ")"}], "2"]}]}]], TraditionalForm]], "Output",\

 CellTags->"TID",
 CellLabel->"Out[1726]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TID", "[", 
  RowBox[{"%%", ",", "k", ",", 
   RowBox[{"FeynAmpDenominatorSimplify", "\[Rule]", "True"}]}], 
  "]"}]], "Input",
 CellTags->"TID",
 CellLabel->"In[1727]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{
     FormBox["k",
      TraditionalForm], "\[CenterDot]", 
     FormBox["p",
      TraditionalForm]}]}], 
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    RowBox[{
     SuperscriptBox["k", "2"], ".", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"k", "-", "p"}], ")"}], "2"]}]}]], TraditionalForm]], "Output",\

 CellTags->"TID",
 CellLabel->"Out[1727]="]
}, Open  ]]
}, Open  ]],

Cell["TIDL", "ObjectName",
 CellTags->"TIDL"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"TIDL"],

Cell[" TIDL is a database of tensorial reduction formalae.", "Text",
 CellTags->"TIDL"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["TID",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TID",
  ButtonNote->"TID"]
}], "Text",
 CellTags->"TIDL"]
}, Open  ]],

Cell["Examples", "Subsubsection",
 CellTags->"TIDL"],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["B", "\[Mu]"], "-", "type"}], 
  TraditionalForm]]]], "Subsubsection",
 CellTags->"TIDL"],

Cell[TextData[{
 "In any n-dimensional integral ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Integral]", 
    RowBox[{
     SuperscriptBox["d", "n"], "\[NegativeVeryThinSpace]", 
     SuperscriptBox["q", "\[Mu]"], " ", 
     RowBox[{"f", "(", 
      RowBox[{"q", ",", "p"}], ")"}], " ", "the", " ", 
     SuperscriptBox["q", "\[Mu]"]}], " "}], TraditionalForm]]],
 "can be replaced by"
}], "Text",
 CellTags->"TIDL"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TIDL", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
   RowBox[{"{", "p", "}"}]}], "]"}]], "Input",
 CellTags->"TIDL",
 CellLabel->"In[1728]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]}], 
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], "2"]], TraditionalForm]], "Output",
 CellTags->"TIDL",
 CellLabel->"Out[1728]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["B", "\[Mu]\[Nu]"], "-", "type"}], 
  TraditionalForm]]]], "Subsubsection",
 CellTags->"TIDL"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TIDL", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"q", ",", "\[Nu]"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", "p", "}"}]}], "]"}]], "Input",
 CellTags->"TIDL",
 CellLabel->"In[1729]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"], "-", 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], "2"]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "D"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"D", " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["p",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}],
          TraditionalForm], "2"]}], "-", 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], "2"]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "D"}], ")"}], " ", 
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"]}]]}], TraditionalForm]], "Output",
 CellTags->"TIDL",
 CellLabel->"Out[1729]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "\[Mu]"], "-", "type"}], 
  TraditionalForm]]]], "Subsubsection",
 CellTags->"TIDL"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TIDL", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["p", "1"], ",", 
     SubscriptBox["p", "2"]}], "}"}]}], "]"}]], "Input",
 CellTags->"TIDL",
 CellLabel->"In[1730]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{
      SubsuperscriptBox["p", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox["q",
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{
       FormBox["q",
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm]}]}]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox[
         SubscriptBox["p", "1"],
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["p", "2"],
         TraditionalForm]}],
       TraditionalForm], "2"], "-", 
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"]}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{
      SubsuperscriptBox["p", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox["q",
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{
       FormBox["q",
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm]}]}]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox[
         SubscriptBox["p", "1"],
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["p", "2"],
         TraditionalForm]}],
       TraditionalForm], "2"], "-", 
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"]}]}]]}], TraditionalForm]], "Output",
 CellTags->"TIDL",
 CellLabel->"Out[1730]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "\[Mu]\[Nu]"], "-", "type"}], 
  TraditionalForm]]]], "Subsubsection",
 CellTags->"TIDL"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TIDL", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"q", ",", "\[Nu]"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["p", "1"], ",", 
     SubscriptBox["p", "2"]}], "}"}]}], "]"}]], "Input",
 CellTags->"TIDL",
 CellLabel->"In[1731]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["p", "2", "2"], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm]}],
          TraditionalForm], "2"]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], "2"], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SubsuperscriptBox["p", "1", "2"]}], "-", 
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], "2"], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox[
           SubscriptBox["p", "1"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["p", "2"],
           TraditionalForm]}],
         TraditionalForm], "2"], "-", 
       RowBox[{
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}]], "+", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"D", "-", "2"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          FormBox[
           RowBox[{
            FormBox[
             SubscriptBox["p", "1"],
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["p", "2"],
             TraditionalForm]}],
           TraditionalForm], "2"], "-", 
         RowBox[{
          SubsuperscriptBox["p", "1", "2"], " ", 
          SubsuperscriptBox["p", "2", "2"]}]}], ")"}], "2"]}]], 
    RowBox[{
     SubsuperscriptBox["p", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["p", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"D", " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm]}],
          TraditionalForm], "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm]}],
          TraditionalForm], "2"]}], "+", 
       RowBox[{
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm]}],
          TraditionalForm], "2"]}], "-", 
       RowBox[{"2", " ", "D", " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm]}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm]}]}], "+", 
       RowBox[{"D", " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SuperscriptBox[
         FormBox[
          SubsuperscriptBox["p", "1", "2"],
          TraditionalForm], "2"]}], "-", 
       RowBox[{
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SuperscriptBox[
         FormBox[
          SubsuperscriptBox["p", "1", "2"],
          TraditionalForm], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], "2"], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"]}], "-", 
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], "2"], " ", 
        SuperscriptBox[
         FormBox[
          SubsuperscriptBox["p", "1", "2"],
          TraditionalForm], "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}]}], "+", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"D", "-", "2"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          FormBox[
           RowBox[{
            FormBox[
             SubscriptBox["p", "1"],
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["p", "2"],
             TraditionalForm]}],
           TraditionalForm], "2"], "-", 
         RowBox[{
          SubsuperscriptBox["p", "1", "2"], " ", 
          SubsuperscriptBox["p", "2", "2"]}]}], ")"}], "2"]}]], 
    RowBox[{
     SubsuperscriptBox["p", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["p", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], "2"]}], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "3"]}], "+", 
       RowBox[{"D", " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"]}], "-", 
       RowBox[{"D", " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}]}], "-", 
       RowBox[{"D", " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SubsuperscriptBox["p", "2", "2"], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SubsuperscriptBox["p", "2", "2"], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], "2"], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}]}], "+", 
       RowBox[{"D", " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}]}], "+", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"D", "-", "2"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          FormBox[
           RowBox[{
            FormBox[
             SubscriptBox["p", "1"],
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["p", "2"],
             TraditionalForm]}],
           TraditionalForm], "2"], "-", 
         RowBox[{
          SubsuperscriptBox["p", "1", "2"], " ", 
          SubsuperscriptBox["p", "2", "2"]}]}], ")"}], "2"]}]], 
    RowBox[{
     SubsuperscriptBox["p", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["p", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], "2"]}], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "3"]}], "+", 
       RowBox[{"D", " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"]}], "-", 
       RowBox[{"D", " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}]}], "-", 
       RowBox[{"D", " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SubsuperscriptBox["p", "2", "2"], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SubsuperscriptBox["p", "2", "2"], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], "2"], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}]}], "+", 
       RowBox[{"D", " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}]}], "+", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"D", "-", "2"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          FormBox[
           RowBox[{
            FormBox[
             SubscriptBox["p", "1"],
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["p", "2"],
             TraditionalForm]}],
           TraditionalForm], "2"], "-", 
         RowBox[{
          SubsuperscriptBox["p", "1", "2"], " ", 
          SubsuperscriptBox["p", "2", "2"]}]}], ")"}], "2"]}]], 
    RowBox[{
     SubsuperscriptBox["p", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["p", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"D", " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"]}], "+", 
       RowBox[{
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"]}], "-", 
       RowBox[{"2", " ", "D", " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        SubsuperscriptBox["p", "2", "2"], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        SubsuperscriptBox["p", "2", "2"], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}]}], "+", 
       RowBox[{"D", " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SuperscriptBox[
         FormBox[
          SubsuperscriptBox["p", "2", "2"],
          TraditionalForm], "2"]}], "-", 
       RowBox[{
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SuperscriptBox[
         FormBox[
          SubsuperscriptBox["p", "2", "2"],
          TraditionalForm], "2"]}], "-", 
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], "2"], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SuperscriptBox[
         FormBox[
          SubsuperscriptBox["p", "2", "2"],
          TraditionalForm], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], "2"], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}]}], ")"}]}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"TIDL",
 CellLabel->"Out[1731]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "\[Mu]\[Nu]\[Rho]"], "-", "type"}], 
  TraditionalForm]]]], "Subsubsection",
 CellTags->"TIDL"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TIDL", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q", ",", "\[Rho]"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", ",", "k"}], "}"}]}], "]"}], ";"}]], "Input",
 CellTags->"TIDL",
 CellLabel->"In[1732]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["C", "\[Mu]\[Nu]\[Rho]\[Sigma]"], "-", "type"}], 
  TraditionalForm]]]], "Subsubsection",
 CellTags->"TIDL"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TIDL", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q", ",", "\[Rho]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q", ",", "\[Sigma]"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", ",", "k"}], "}"}]}], "]"}], ";"}]], "Input",
 CellTags->"TIDL",
 CellLabel->"In[1733]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["D", "\[Mu]"], "-", "type"}], 
  TraditionalForm]]]], "Subsubsection",
 CellTags->"TIDL"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TIDL", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["p", "1"], ",", 
     SubscriptBox["p", "2"], ",", 
     SubscriptBox["p", "3"]}], "}"}]}], "]"}]], "Input",
 CellTags->"TIDL",
 CellLabel->"In[1734]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SubsuperscriptBox["p", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}],
          TraditionalForm], "2"]}], "-", 
       RowBox[{
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "2", "2"]}], "+", 
       RowBox[{
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}], " ", 
        SubsuperscriptBox["p", "2", "2"]}], "+", 
       RowBox[{
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}]}]}], ")"}]}], 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["p", "3", "2"], " ", 
      SuperscriptBox[
       FormBox[
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}],
        TraditionalForm], "2"]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "3"],
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "3"],
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm]}]}], "+", 
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], " ", 
      SuperscriptBox[
       FormBox[
        RowBox[{
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}],
        TraditionalForm], "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox[
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}],
        TraditionalForm], "2"], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "-", 
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}]}]], "-", 
   FractionBox[
    RowBox[{
     SubsuperscriptBox["p", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm]}], ")"}]}], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox[
            SubscriptBox["p", "1"],
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "3"],
            TraditionalForm]}],
          TraditionalForm], "2"]}], "+", 
       RowBox[{
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        SubsuperscriptBox["p", "1", "2"], " ", 
        SubsuperscriptBox["p", "3", "2"]}], "-", 
       RowBox[{
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["p", "3", "2"], " ", 
      SuperscriptBox[
       FormBox[
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}],
        TraditionalForm], "2"]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "3"],
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "3"],
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm]}]}], "+", 
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], " ", 
      SuperscriptBox[
       FormBox[
        RowBox[{
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}],
        TraditionalForm], "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox[
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}],
        TraditionalForm], "2"], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "-", 
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}]}]], "+", 
   FractionBox[
    RowBox[{
     SubsuperscriptBox["p", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm]}], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox[
            SubscriptBox["p", "2"],
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["p", "3"],
            TraditionalForm]}],
          TraditionalForm], "2"]}], "-", 
       RowBox[{
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}], " ", 
        SubsuperscriptBox["p", "2", "2"]}], "+", 
       RowBox[{
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}], " ", 
        SubsuperscriptBox["p", "3", "2"]}], "-", 
       RowBox[{
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm]}], " ", 
        SubsuperscriptBox["p", "2", "2"], " ", 
        SubsuperscriptBox["p", "3", "2"]}]}], ")"}]}], 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["p", "3", "2"], " ", 
      SuperscriptBox[
       FormBox[
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm]}],
        TraditionalForm], "2"]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "3"],
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "3"],
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["p", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["p", "2"],
        TraditionalForm]}]}], "+", 
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], " ", 
      SuperscriptBox[
       FormBox[
        RowBox[{
         FormBox[
          SubscriptBox["p", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}],
        TraditionalForm], "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox[
        RowBox[{
         FormBox[
          SubscriptBox["p", "1"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["p", "3"],
          TraditionalForm]}],
        TraditionalForm], "2"], " ", 
      SubsuperscriptBox["p", "2", "2"]}], "-", 
     RowBox[{
      SubsuperscriptBox["p", "1", "2"], " ", 
      SubsuperscriptBox["p", "2", "2"], " ", 
      SubsuperscriptBox["p", "3", "2"]}]}]]}], TraditionalForm]], "Output",
 CellTags->"TIDL",
 CellLabel->"Out[1734]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["D", "\[Mu]\[Nu]"], "-", "type"}], 
  TraditionalForm]]]], "Subsubsection",
 CellTags->"TIDL"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TIDL", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q", ",", "\[Nu]"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", ",", "k", ",", "r"}], "}"}]}], "]"}], ";"}]], "Input",
 CellTags->"TIDL",
 CellLabel->"In[1735]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["D", "\[Mu]\[Nu]\[Rho]"], "-", "type"}], 
  TraditionalForm]]]], "Subsubsection",
 CellTags->"TIDL"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TIDL", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q", ",", "\[Rho]"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", ",", "k", ",", "r"}], "}"}]}], "]"}], ";"}]], "Input",
 CellTags->"TIDL",
 CellLabel->"In[1736]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["D", "\[Mu]\[Nu]\[Rho]\[Sigma]"], "-", "type"}], 
  TraditionalForm]]]], "Subsubsection",
 CellTags->"TIDL"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TIDL", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"q", ",", "\[Mu]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q", ",", "\[Rho]"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"q", ",", "\[Sigma]"}], "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", ",", "k", ",", "r", ",", "s"}], "}"}]}], "]"}], 
  ";"}]], "Input",
 CellTags->"TIDL",
 CellLabel->"In[1737]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Length", "[", "%", "]"}], ",", " ", 
   RowBox[{"LeafCount", "[", "%", "]"}], ",", 
   RowBox[{"ByteCount", "[", "%", "]"}]}], "}"}]], "Input",
 CellTags->"TIDL",
 CellLabel->"In[1738]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"4", ",", "29", ",", "744"}], "}"}], TraditionalForm]], "Output",
 CellTags->"TIDL",
 CellLabel->"Out[1738]="]
}, Open  ]]
}, Open  ]],

Cell["TimedIntegrate", "ObjectName",
 CellTags->"TimedIntegrate"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"TimedIntegrate"],

Cell["\<\
 TimedIntegrate[exp, vars] is like Integrate, but stops after the number of \
seconds specified by the option Timing. Options of Integrate can be given and \
are passed on.\
\>", "Text",
 CellTags->"TimedIntegrate"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "TimedIntegrate", "]"}]], "Input",
 CellTags->"TimedIntegrate",
 CellLabel->"In[1739]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Timing", "\[Rule]", "10"}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], ">", "0"}]}], ",", 
    RowBox[{"Integrate", "\[Rule]", "Integrate"}], ",", 
    RowBox[{"Expand", "\[Rule]", "True"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"TimedIntegrate",
 CellLabel->"Out[1739]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"TimedIntegrate"],

Cell["This should reach to be done", "Text",
 CellTags->"TimedIntegrate"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TimedIntegrate", "[", 
  RowBox[{
   RowBox[{"Log", "[", 
    RowBox[{"x", "^", "5"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"Timing", "\[Rule]", "1"}]}], "]"}]], "Input",
 CellTags->"TimedIntegrate",
 CellLabel->"In[1740]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", "5"}], TraditionalForm]], "Output",
 CellTags->"TimedIntegrate",
 CellLabel->"Out[1740]="]
}, Open  ]],

Cell["This shouldn't", "Text",
 CellTags->"TimedIntegrate"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TimedIntegrate", "[", 
  RowBox[{
   RowBox[{"Log", "[", 
    RowBox[{"Cos", "[", 
     RowBox[{"x", "^", "5"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"Timing", "\[Rule]", "10"}], ",", 
   RowBox[{"Integrate", "\[Rule]", "int"}]}], "]"}]], "Input",
 CellTags->"TimedIntegrate",
 CellLabel->"In[1741]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"int", "(", 
   RowBox[{
    RowBox[{"log", "(", 
     RowBox[{"cos", "(", 
      SuperscriptBox["x", "5"], ")"}], ")"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], ">", "0"}]}]}], ")"}], TraditionalForm]], "Output",
 CellTags->"TimedIntegrate",
 CellLabel->"Out[1741]="]
}, Open  ]]
}, Open  ]],

Cell["TLI  ***unfinished***", "ObjectName",
 CellTags->"TLI"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"TLI"],

Cell["\<\
TLI[{v,w,x,y,z},{a,b,c,d,e}, {al,be,ga,de,ep}].  The exponents of the \
numerator scalar product are (dl = OPEDelta):  v: k1.k1, w: k2.k2,  x: p.k1, \
y: p.k2, z: k1.k2.  a: dl.k1, b: dl.k2,  c: dl.(p-k1), d: dl.(p-k2), e: \
dl.(k1-k2).
TLI[{mu1, ...}, {nu1, ...}][{v,w,x,y,z},{a,b,c,d,e}, {al,be,ga,de,ep}] is a \
tensor integral, where mu1 belongs to k1 and nu1 to k2.
TLI[any___,{a,b,c,d,e,0,0}, {al,be,ga,de,ep}] simplifies to  TLI[any, \
{a,b,c,d,e}, {al,be,ga,de,ep}].
TLI[{0,0,0,0,0},{a,b,c,d,e}, {al,be,ga,de,ep}] simplifies to  \
TLI[{a,b,c,d,e}, {al,be,ga,de,ep}].\
\>", "Text",
 CellTags->"TLI"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "TLI", "]"}]], "Input",
 CellTags->"TLI",
 CellLabel->"In[1742]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"EpsilonOrder", "\[Rule]", "0"}], ",", 
    RowBox[{"Momentum", "\[Rule]", "p"}]}], "}"}], TraditionalForm]], "Output",\

 CellTags->"TLI",
 CellLabel->"Out[1742]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["TLI2FC",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TLI2FC",
  ButtonNote->"TLI2FC"],
 "."
}], "Text",
 CellTags->"TLI"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"TLI"],

Cell[BoxData[""], "Input",
 CellTags->"TLI",
 CellLabel->"In[1743]:="]
}, Open  ]],

Cell["TLIFP  ***unfinished***", "ObjectName",
 CellTags->"TLIFP"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"TLIFP"],

Cell["TLIFP[exp] does Feynman-Parametrizations of TLI's in exp.", "Text",
 CellTags->"TLIFP"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "TLIFP", "]"}]], "Input",
 CellTags->"TLIFP",
 CellLabel->"In[1744]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"FeynmanParameterNames", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"x", ",", "t", ",", "u", ",", "s", ",", "y"}], "}"}]}], ",", 
    RowBox[{"GammaExpand", "\[Rule]", "True"}], ",", 
    RowBox[{"Momentum", "\[Rule]", "p"}], ",", 
    RowBox[{"Print", "\[Rule]", "True"}]}], "}"}], TraditionalForm]], "Output",\

 CellTags->"TLIFP",
 CellLabel->"Out[1744]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["TLI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TLI",
  ButtonNote->"TLI"],
 "."
}], "Text",
 CellTags->"TLIFP"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"TLIFP"],

Cell[BoxData[""], "Input",
 CellTags->"TLIFP",
 CellLabel->"In[1745]:="]
}, Open  ]],

Cell["TLIHYP  ***unfinished***", "ObjectName",
 CellTags->"TLIHYP"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"TLIHYP"],

Cell["\<\
TLIHYP[exp] expresses TLI's in exp. in terms of hypergeometric functions, \
where possible.\
\>", "Text",
 CellTags->"TLIHYP"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "TLIHYP", "]"}]], "Input",
 CellTags->"TLIHYP",
 CellLabel->"In[1746]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"FeynmanParameterNames", "\[Rule]", "x"}], ",", 
    RowBox[{"Momentum", "\[Rule]", "p"}]}], "}"}], TraditionalForm]], "Output",\

 CellTags->"TLIHYP",
 CellLabel->"Out[1746]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["TLI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TLI",
  ButtonNote->"TLI"],
 "."
}], "Text",
 CellTags->"TLIHYP"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"TLIHYP"],

Cell[BoxData[""], "Input",
 CellTags->"TLIHYP",
 CellLabel->"In[1747]:="]
}, Open  ]],

Cell["TLI2", "ObjectName",
 CellTags->"TLI2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"TLI2"],

Cell["like TLI, but without any functional properties.", "Text",
 CellTags->"TLI2"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["TLI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TLI",
  ButtonNote->"TLI"],
 "."
}], "Text",
 CellTags->"TLI2"]
}, Open  ]],

Cell["TLI2FC  ***unfinished***", "ObjectName",
 CellTags->"TLI2FC"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"TLI2FC"],

Cell["\<\
TLI2FC[exp] transforms all TLI-integrals in exp to the FAD form.\
\>", "Text",
 CellTags->"TLI2FC"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "TLI2FC", "]"}]], "Input",
 CellTags->"TLI2FC",
 CellLabel->"In[1748]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"FeynCalcExternal", "\[Rule]", "False"}], ",", 
    RowBox[{"Momentum", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"q1", ",", "q2", ",", "p"}], "}"}]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"TLI2FC",
 CellLabel->"Out[1748]="]
}, Open  ]],

Cell[TextData[{
 "See also:  ",
 ButtonBox["TLI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TLI",
  ButtonNote->"TLI"],
 ".  ",
 ButtonBox["FC2TLI",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FC2TLI",
  ButtonNote->"FC2TLI"],
 "."
}], "Text",
 CellTags->"TLI2FC"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"TLI2FC"],

Cell[BoxData[""], "Input",
 CellTags->"TLI2FC",
 CellLabel->"In[1749]:="]
}, Open  ]],

Cell["ToDistribution", "ObjectName",
 CellTags->"ToDistribution"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ToDistribution"],

Cell["\<\
ToDistribution[exp,x] replaces (1-x)^(a Epsilon - 1) in exp by 1/(a Epsilon) \
DeltaFunction[1-x] + 1/(1-x) + a Epsilon Log[1-x]/(1-x) + 1/2 a^2 Epsilon^2 \
Log[1-x]^2/(1-x)] and (1-x)^(a Epsilon - 2) in exp by -1/(a Epsilon) \
DeltaFunctionPrime[1-x] + 1/(1-x)^2 + (a Epsilon) Log[1-x]/(1-x)^2 + a^2 \
Epsilon^2/2 Log[1-x]^2/(1-x)^2 + a^3 Epsilon^3/6 Log[1-x]^3/(1-x)^2.\
\>", "Text",
 CellTags->"ToDistribution"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "ToDistribution", "]"}]], "Input",
 CellTags->"ToDistribution",
 CellLabel->"In[1750]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"PlusDistribution", "\[Rule]", "Identity"}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"ToDistribution",
 CellLabel->"Out[1750]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["PlusDistribution",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PlusDistribution",
  ButtonNote->"PlusDistribution"],
 "."
}], "Text",
 CellTags->"ToDistribution"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ToDistribution"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetOptions", "[", 
  RowBox[{"ToDistribution", ",", 
   RowBox[{"PlusDistribution", "\[Rule]", "PlusDistribution"}]}], 
  "]"}]], "Input",
 CellTags->"ToDistribution",
 CellLabel->"In[1751]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"PlusDistribution", "\[Rule]", "PlusDistribution"}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"ToDistribution",
 CellLabel->"Out[1751]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ToDistribution", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "x"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"Epsilon", "-", "1"}], ")"}]}], ",", "x"}], "]"}]], "Input",
 CellTags->"ToDistribution",
 CellLabel->"In[1752]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"\[Delta]", "(", 
     FormBox[
      RowBox[{"1", "-", "x"}],
      TraditionalForm], ")"}], 
    TagBox["\[CurlyEpsilon]",
     TraditionalForm]], "+", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "3"], " ", 
    SubscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        SuperscriptBox["log", "3"], "(", 
        RowBox[{"1", "-", "x"}], ")"}], 
       RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "2"], " ", 
    SubscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        SuperscriptBox["log", "2"], "(", 
        RowBox[{"1", "-", "x"}], ")"}], 
       RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "+", 
   RowBox[{
    TagBox["\[CurlyEpsilon]",
     TraditionalForm], " ", 
    SubscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"log", "(", 
        RowBox[{"1", "-", "x"}], ")"}], 
       RowBox[{"1", "-", "x"}]], ")"}], "+"]}], "+", 
   SubscriptBox[
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{"1", "-", "x"}]], ")"}], "+"]}], TraditionalForm]], "Output",
 CellTags->"ToDistribution",
 CellLabel->"Out[1752]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetOptions", "[", 
  RowBox[{"ToDistribution", ",", 
   RowBox[{"PlusDistribution", "\[Rule]", "Identity"}]}], "]"}]], "Input",
 CellTags->"ToDistribution",
 CellLabel->"In[1753]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"PlusDistribution", "\[Rule]", "Identity"}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"ToDistribution",
 CellLabel->"Out[1753]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ToDistribution", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", "x"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"Epsilon", "-", "2"}], ")"}]}], ",", "x"}], "]"}]], "Input",
 CellTags->"ToDistribution",
 CellLabel->"In[1754]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[Delta]", "\[Prime]"], "(", 
      FormBox[
       RowBox[{"1", "-", "x"}],
       TraditionalForm], ")"}], 
     TagBox["\[CurlyEpsilon]",
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], "3"], " ", 
     RowBox[{
      SuperscriptBox["log", "3"], "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], 
    RowBox[{"6", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "x"}], ")"}], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], "2"], " ", 
     RowBox[{
      SuperscriptBox["log", "2"], "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "x"}], ")"}], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], " ", 
     RowBox[{"log", "(", 
      RowBox[{"1", "-", "x"}], ")"}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "x"}], ")"}], "2"]], "+", 
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "x"}], ")"}], "2"]]}], TraditionalForm]], "Output",
 CellTags->"ToDistribution",
 CellLabel->"Out[1754]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series2", "[", 
  RowBox[{
   RowBox[{"Integrate", "[", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "x"}], ")"}], 
      RowBox[{"Epsilon", "-", "2"}]], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"GenerateConditions", "\[Rule]", "False"}]}], "]"}], ",", 
   "Epsilon", ",", "3"}], "]"}]], "Input",
 CellTags->"ToDistribution",
 CellLabel->"In[1755]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "3"]}], "-", 
   SuperscriptBox[
    TagBox["\[CurlyEpsilon]",
     TraditionalForm], "2"], "-", 
   TagBox["\[CurlyEpsilon]",
    TraditionalForm], "-", "1"}], TraditionalForm]], "Output",
 CellTags->"ToDistribution",
 CellLabel->"Out[1755]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "@", "Integrate"}]], "Input",
 CellTags->"ToDistribution",
 CellLabel->"In[1756]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Assumptions", "\[RuleDelayed]", "$Assumptions"}], ",", 
    RowBox[{"GenerateConditions", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PrincipalValue", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"ToDistribution",
 CellLabel->"Out[1756]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate2", "[", 
  RowBox[{
   RowBox[{"ToDistribution", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "x"}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"Epsilon", "-", "2"}], ")"}]}], ",", "x"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellTags->"ToDistribution",
 CellLabel->"In[1757]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox[
     TagBox["\[CurlyEpsilon]",
      TraditionalForm], "3"]}], "-", 
   SuperscriptBox[
    TagBox["\[CurlyEpsilon]",
     TraditionalForm], "2"], "-", 
   TagBox["\[CurlyEpsilon]",
    TraditionalForm], "-", "1"}], TraditionalForm]], "Output",
 CellTags->"ToDistribution",
 CellLabel->"Out[1757]="]
}, Open  ]]
}, Open  ]],

Cell["ToHypergeometric", "ObjectName",
 CellTags->"ToHypergeometric"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ToHypergeometric"],

Cell[TextData[{
 "ToHypergeometric[",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     StyleBox["t",
      FontSlant->"Plain"], 
     StyleBox["b",
      FontSlant->"Plain"]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       StyleBox["t",
        FontSlant->"Plain"]}], ")"}], 
     StyleBox["c",
      FontSlant->"Plain"]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{
        StyleBox["t",
         FontSlant->"Plain"], " ", 
        StyleBox["z",
         FontSlant->"Plain"]}]}], ")"}], 
     StyleBox["a",
      FontSlant->"Plain"]]}], TraditionalForm]],
  FontVariations->{"CompatibilityType"->0}],
 ", ",
 "t",
 "] returns ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[CapitalGamma]", "(", 
     RowBox[{"b", "+", "1"}], ")"}], " ", 
    RowBox[{
     RowBox[{"\[CapitalGamma]", "(", 
      RowBox[{"c", "+", "1"}], ")"}], "/", 
     RowBox[{"\[CapitalGamma]", "(", 
      RowBox[{"b", "+", "c", "+", "2"}], ")"}]}], " ", 
    FormBox[
     RowBox[{
      SubscriptBox["\[Null]", "2"], 
      RowBox[{
       SubscriptBox["F", "1"], "(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], ",", 
         RowBox[{"b", "+", "1"}]}], ";", 
        RowBox[{"b", "+", "c", "+", "2"}], ";", 
        RowBox[{"-", "z"}]}], ")"}]}],
     TraditionalForm]}], TraditionalForm]]],
 ". Remember that Re ",
 StyleBox["b",
  FontSlant->"Italic"],
 " >0 and Re (",
 StyleBox["c",
  FontSlant->"Italic"],
 "-",
 StyleBox["b",
  FontSlant->"Italic"],
 ") > 0 should hold (need not be set in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ")."
}], "Text",
 CellTags->"ToHypergeometric"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["HypergeometricAC",
  BaseStyle->"AddOnsLink",
  ButtonData:>"HypergeometricAC",
  ButtonNote->"HypergeometricAC"],
 ", ",
 ButtonBox["HypergeometricIR",
  BaseStyle->"AddOnsLink",
  ButtonData:>"HypergeometricIR",
  ButtonNote->"HypergeometricIR"],
 ", ",
 ButtonBox["HypergeometricSE",
  BaseStyle->"AddOnsLink",
  ButtonData:>"HypergeometricSE",
  ButtonNote->"HypergeometricSE"],
 "."
}], "Text",
 CellTags->"ToHypergeometric"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ToHypergeometric"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ToHypergeometric", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["t", "b"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "t"}], ")"}], "c"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"t", " ", "z"}]}], ")"}], "a"]}], ",", "t"}], "]"}]], "Input",
 CellTags->"ToHypergeometric",
 CellLabel->"In[1758]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    TemplateBox[{RowBox[{"b", "+", "1"}]},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"c", "+", "1"}]},
     "Gamma"], " ", 
    TemplateBox[{
     RowBox[{"-", "a"}],RowBox[{"b", "+", "1"}],
      RowBox[{"b", "+", "c", "+", "2"}],RowBox[{"-", "z"}]},
     "Hypergeometric2F1"]}], 
   TemplateBox[{RowBox[{"b", "+", "c", "+", "2"}]},
    "Gamma"]], TraditionalForm]], "Output",
 CellTags->"ToHypergeometric",
 CellLabel->"Out[1758]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ToHypergeometric", "[", 
  RowBox[{
   RowBox[{"w", " ", 
    SuperscriptBox["t", 
     RowBox[{"b", "-", "1"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "t"}], ")"}], 
     RowBox[{"c", "-", "b", "-", "1"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"t", " ", "z"}]}], ")"}], 
     RowBox[{"-", "a"}]]}], ",", "t"}], "]"}]], "Input",
 CellTags->"ToHypergeometric",
 CellLabel->"In[1759]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"w", " ", 
    TemplateBox[{"b"},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"c", "-", "b"}]},
     "Gamma"], " ", 
    TemplateBox[{"a","b","c","z"},
     "Hypergeometric2F1"]}], 
   TemplateBox[{"c"},
    "Gamma"]], TraditionalForm]], "Output",
 CellTags->"ToHypergeometric",
 CellLabel->"Out[1759]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ToHypergeometric", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["t", "b"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "t"}], ")"}], "c"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"u", "+", 
       RowBox[{"t", " ", "z"}]}], ")"}], "a"]}], ",", "t"}], "]"}]], "Input",
 CellTags->"ToHypergeometric",
 CellLabel->"In[1760]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["u", "a"], " ", 
    TemplateBox[{RowBox[{"b", "+", "1"}]},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"c", "+", "1"}]},
     "Gamma"], " ", 
    TemplateBox[{
     RowBox[{"-", "a"}],RowBox[{"b", "+", "1"}],
      RowBox[{"b", "+", "c", "+", "2"}],RowBox[{"-", 
        FractionBox["z", "u"]}]},
     "Hypergeometric2F1"]}], 
   TemplateBox[{RowBox[{"b", "+", "c", "+", "2"}]},
    "Gamma"]], TraditionalForm]], "Output",
 CellTags->"ToHypergeometric",
 CellLabel->"Out[1760]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ToHypergeometric", "[", 
  RowBox[{
   RowBox[{"w", " ", 
    SuperscriptBox["t", 
     RowBox[{"b", "-", "1"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "t"}], ")"}], 
     RowBox[{"c", "-", "b", "-", "1"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"u", "-", 
       RowBox[{"t", " ", "z"}]}], ")"}], 
     RowBox[{"-", "a"}]]}], ",", "t"}], "]"}]], "Input",
 CellTags->"ToHypergeometric",
 CellLabel->"In[1761]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"w", " ", 
    SuperscriptBox["u", 
     RowBox[{"-", "a"}]], " ", 
    TemplateBox[{"b"},
     "Gamma"], " ", 
    TemplateBox[{RowBox[{"c", "-", "b"}]},
     "Gamma"], " ", 
    TemplateBox[{"a","b","c",FractionBox["z", "u"]},
     "Hypergeometric2F1"]}], 
   TemplateBox[{"c"},
    "Gamma"]], TraditionalForm]], "Output",
 CellTags->"ToHypergeometric",
 CellLabel->"Out[1761]="]
}, Open  ]]
}, Open  ]],

Cell["ToLarin", "ObjectName",
 CellTags->"ToLarin"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ToLarin"],

Cell[TextData[{
 "ToLarin[exp] translates all ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Gamma]", "\[Mu]"], " ", 
    SuperscriptBox["\[Gamma]", "5"]}], TraditionalForm]]],
 " in exp into ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], "/", "6"}], " ", 
    SuperscriptBox["\[CurlyEpsilon]", "\[Mu]\[Nu]\[Lambda]\[Sigma]"], 
    SuperscriptBox["\[Gamma]", "\[Nu]"], " ", 
    SuperscriptBox["\[Gamma]", "\[Lambda]"], " ", 
    RowBox[{
     SuperscriptBox["\[Gamma]", "\[Sigma]"], "."}]}], TraditionalForm]]]
}], "Text",
 CellTags->"ToLarin"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Eps",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Eps",
  ButtonNote->"Eps"],
 "."
}], "Text",
 CellTags->"ToLarin"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ToLarin"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracMatrix", "[", "\[Nu]", "]"}], ".", 
  RowBox[{"DiracMatrix", "[", "\[Mu]", "]"}], ".", 
  RowBox[{"DiracMatrix", "[", "5", "]"}]}]], "Input",
 CellTags->"ToLarin",
 CellLabel->"In[1762]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], ".", 
   SuperscriptBox["\[Gamma]", "5"]}], TraditionalForm]], "Output",
 CellTags->"ToLarin",
 CellLabel->"Out[1762]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ToLarin", "[", "%", "]"}]], "Input",
 CellTags->"ToLarin",
 CellLabel->"In[1763]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "6"]}], " ", "\[ImaginaryI]", " ", 
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], ".", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["du211",
       TraditionalForm],
      TraditionalForm]], ".", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["du212",
       TraditionalForm],
      TraditionalForm]], ".", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["du213",
       TraditionalForm],
      TraditionalForm]]}], " ", 
   SuperscriptBox["\[Epsilon]", 
    RowBox[{
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["du211",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["du212",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["du213",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"ToLarin",
 CellLabel->"Out[1763]="]
}, Open  ]]
}, Open  ]],

Cell["ToTFi", "ObjectName",
 CellTags->"ToTFi"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ToTFi"],

Cell["\<\
ToTFi[expr, q1, q2, p] translates FeynCalc 2-loop self energy type integrals \
into the TFi notatation, which can be used as input for the function \
TarcerRecurse from the TARCER package. See TFi for details on the conventions.\
\>", "Text",
 CellTags->"ToTFi"],

Cell[TextData[{
 "See also: ",
 ButtonBox["TFi",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TFi",
  ButtonNote->"TFi"],
 ", ",
 ButtonBox["FromTFi",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FromTFi",
  ButtonNote->"FromTFi"],
 "."
}], "Text",
 CellTags->"ToTFi"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"ToTFi"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FAD", "[", 
  RowBox[{"q1", ",", 
   RowBox[{"q1", "-", "p"}], ",", 
   RowBox[{"{", 
    RowBox[{"q2", ",", "M"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"q2", "-", "p"}], ",", "m"}], "}"}], ",", 
   RowBox[{"q1", "-", "q2"}]}], "]"}]], "Input",
 CellTags->"ToTFi",
 CellLabel->"In[1764]:="],

Cell[BoxData[
 FormBox[
  FractionBox["1", 
   RowBox[{
    RowBox[{"(", 
     InterpretationBox[
      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
       SuperscriptBox["q1", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
      SequenceForm["[", $CellContext`q1^2, "]"],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"q1", "-", "p"}], ")"}], "2"], 
       "\[InvisibleSpace]", "\<\"]\"\>"}],
      SequenceForm["[", (-$CellContext`p + $CellContext`q1)^2, "]"],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"q1", "-", "q2"}], ")"}], "2"], 
       "\[InvisibleSpace]", "\<\"]\"\>"}],
      SequenceForm["[", ($CellContext`q1 - $CellContext`q2)^2, "]"],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
       SuperscriptBox["q2", "2"], "\[InvisibleSpace]", "\<\"-\"\>", 
       "\[InvisibleSpace]", 
       SuperscriptBox["M", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
      SequenceForm["[", $CellContext`q2^2, "-", $CellContext`M^2, "]"],
      Editable->False], ")"}], " ", 
    RowBox[{"(", 
     InterpretationBox[
      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"q2", "-", "p"}], ")"}], "2"], 
       "\[InvisibleSpace]", "\<\"-\"\>", "\[InvisibleSpace]", 
       SuperscriptBox["m", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
      SequenceForm[
      "[", (-$CellContext`p + $CellContext`q2)^2, "-", $CellContext`m^2, "]"],
      
      Editable->False], ")"}]}]], TraditionalForm]], "Output",
 CellTags->"ToTFi",
 CellLabel->"Out[1764]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ToTFi", "[", 
  RowBox[{"%", ",", "q1", ",", "q2", ",", "p"}], "]"}]], "Input",
 CellTags->"ToTFi",
 CellLabel->"In[1765]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"ToTFi", "(", 
   RowBox[{
    FormBox[
     FractionBox["1", 
      RowBox[{
       RowBox[{"(", 
        InterpretationBox[
         RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
          SuperscriptBox["q1", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
         SequenceForm["[", $CellContext`q1^2, "]"],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"q1", "-", "p"}], ")"}], "2"], 
          "\[InvisibleSpace]", "\<\"]\"\>"}],
         SequenceForm["[", (-$CellContext`p + $CellContext`q1)^2, "]"],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"q1", "-", "q2"}], ")"}], "2"], 
          "\[InvisibleSpace]", "\<\"]\"\>"}],
         SequenceForm["[", ($CellContext`q1 - $CellContext`q2)^2, "]"],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
          SuperscriptBox["q2", "2"], "\[InvisibleSpace]", "\<\"-\"\>", 
          "\[InvisibleSpace]", 
          SuperscriptBox["M", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
         SequenceForm["[", $CellContext`q2^2, "-", $CellContext`M^2, "]"],
         Editable->False], ")"}], " ", 
       RowBox[{"(", 
        InterpretationBox[
         RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"q2", "-", "p"}], ")"}], "2"], 
          "\[InvisibleSpace]", "\<\"-\"\>", "\[InvisibleSpace]", 
          SuperscriptBox["m", "2"], "\[InvisibleSpace]", "\<\"]\"\>"}],
         SequenceForm[
         "[", (-$CellContext`p + $CellContext`q2)^2, "-", $CellContext`m^2, 
          "]"],
         Editable->False], ")"}]}]],
     TraditionalForm], ",", "q1", ",", "q2", ",", "p"}], ")"}], 
  TraditionalForm]], "Output",
 CellTags->"ToTFi",
 CellLabel->"Out[1765]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"ToTFi",
 CellLabel->"In[1766]:="],

Cell[BoxData[
 RowBox[{"ToTFi", "[", 
  RowBox[{
   RowBox[{"FAD", "[", 
    RowBox[{"q1", ",", 
     RowBox[{
      RowBox[{"-", "p"}], "+", "q1"}], ",", 
     RowBox[{"{", 
      RowBox[{"q2", ",", "M"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "p"}], "+", "q2"}], ",", "m"}], "}"}], ",", 
     RowBox[{"q1", "-", "q2"}]}], "]"}], ",", "q1", ",", "q2", ",", "p"}], 
  "]"}]], "Output",
 CellTags->"ToTFi",
 CellLabel->"Out[1766]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SOD", "[", "q1", "]"}], " ", 
   RowBox[{"SOD", "[", "q2", "]"}], 
   RowBox[{"FAD", "[", 
    RowBox[{"q1", ",", 
     RowBox[{"q1", "-", "p"}], ",", 
     RowBox[{"{", 
      RowBox[{"q2", ",", "M"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"q2", "-", "p"}], ",", "m"}], "}"}], ",", 
     RowBox[{"q1", "-", "q2"}]}], "]"}]}], "//", "FCI"}]], "Input",
 CellTags->"ToTFi",
 CellLabel->"In[1767]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{
     FormBox["\[CapitalDelta]",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q1",
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox["\[CapitalDelta]",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q2",
      TraditionalForm]}]}], 
   RowBox[{
    SuperscriptBox["q1", "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q1", "-", "p"}], ")"}], "2"], ".", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"q1", "-", "q2"}], ")"}], "2"], ".", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["q2", "2"], "-", 
      SuperscriptBox["M", "2"]}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"q2", "-", "p"}], ")"}], "2"], "-", 
      SuperscriptBox["m", "2"]}], ")"}]}]], TraditionalForm]], "Output",
 CellTags->"ToTFi",
 CellLabel->"Out[1767]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TR", "ObjectName",
 CellTags->"TR"],

Cell[BoxData[
 FormBox["TR", TraditionalForm]], "Output",
 CellTags->"TR",
 CellLabel->"Out[1959]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"TR"],

Cell[TextData[{
 "TR[exp] calculates the Dirac trace of exp. Depending on the setting of the \
option SUNTrace also a trace over SU(",
 StyleBox["N",
  FontSlant->"Italic"],
 ") objects is performed. The ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " build-in function Tr is overloaded to call TR if ",
 "any of DiracGamma, DiracSlash, GA, GAD, GS or GSD",
 " are in the expression."
}], "Text",
 CellTags->"TR"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "TR", "]"}]], "Input",
 CellTags->"TR",
 CellLabel->"In[1768]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"DiracTraceEvaluate", "\[Rule]", "True"}], ",", 
    RowBox[{"Explicit", "\[Rule]", "True"}], ",", 
    RowBox[{"Factoring", "\[Rule]", "False"}], ",", 
    RowBox[{"FeynCalcExternal", "\[Rule]", "False"}], ",", 
    RowBox[{"LeviCivitaSign", "\[RuleDelayed]", "$LeviCivitaSign"}], ",", 
    RowBox[{"Mandelstam", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"PairCollect", "\[Rule]", "False"}], ",", 
    RowBox[{"Schouten", "\[Rule]", "442"}], ",", 
    RowBox[{"SUNTrace", "\[Rule]", "False"}], ",", 
    RowBox[{"TraceOfOne", "\[Rule]", "4"}], ",", 
    RowBox[{"SUNNToCACF", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"TR",
 CellLabel->"Out[1768]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 ", ",
 ButtonBox["DiracTrace",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrace",
  ButtonNote->"DiracTrace"],
 ", ",
 ButtonBox["FermionSpinSum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FermionSpinSum",
  ButtonNote->"FermionSpinSum"],
 ", ",
 ButtonBox["SUNTrace",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNTrace",
  ButtonNote->"SUNTrace"],
 "."
}], "Text",
 CellTags->"TR"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"TR"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GA", "[", 
  RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]], "Input",
 CellTags->"TR",
 CellLabel->"In[1769]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"]}], TraditionalForm]], "Output",
 CellTags->"TR",
 CellLabel->"Out[1769]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TR", "[", "%", "]"}]], "Input",
 CellTags->"TR",
 CellLabel->"In[1770]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"4", " ", 
   SuperscriptBox["g", 
    RowBox[{"\[Mu]", "\[Nu]"}]]}], TraditionalForm]], "Output",
 CellTags->"TR",
 CellLabel->"Out[1770]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TR", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"GSD", "[", "p", "]"}], "+", "m"}], ")"}], ".", 
   RowBox[{"GAD", "[", "\[Mu]", "]"}], ".", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"GSD", "[", "q", "]"}], "-", "m"}], ")"}], ".", 
   RowBox[{"GAD", "[", "\[Nu]", "]"}]}], "]"}]], "Input",
 CellTags->"TR",
 CellLabel->"In[1771]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["m", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"-", 
        SuperscriptBox["g", 
         RowBox[{"\[Mu]", "\[Nu]"}]]}], ")"}]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"TR",
 CellLabel->"Out[1771]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TR", "[", 
  RowBox[{"GA", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]", ",", "5"}], 
   "]"}], "]"}]], "Input",
 CellTags->"TR",
 CellLabel->"In[1772]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
   SuperscriptBox["\[Epsilon]", 
    RowBox[{
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"TR",
 CellLabel->"Out[1772]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TR", "[", 
  RowBox[{"GAD", "[", 
   RowBox[{
   "\[Mu]", ",", "\[Nu]", ",", "\[Rho]", ",", "\[Sigma]", ",", "\[Tau]", ",", 
    "\[Xi]", ",", "5"}], "]"}], "]"}]], "Input",
 CellTags->"TR",
 CellLabel->"In[1773]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"4", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Xi]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Xi]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Xi]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Xi]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Tau]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Xi]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Xi]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Xi]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Sigma]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Xi]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Nu]", "\[Tau]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Xi]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Xi]", "\[Rho]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Xi]", "\[Sigma]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Xi]", "\[Tau]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Rho]", "\[Sigma]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Xi]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Tau]",
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Rho]", "\[Tau]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Xi]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Sigma]", "\[Tau]"}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Xi]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]}]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"TR",
 CellLabel->"Out[1773]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TR", "[", 
  RowBox[{
   RowBox[{"GAD", "[", 
    RowBox[{
     SubscriptBox["\[Nu]", "1"], ",", 
     SubscriptBox["\[Nu]", "2"], ",", 
     SubscriptBox["\[Nu]", "3"], ",", 
     SubscriptBox["\[Nu]", "4"], ",", 
     SubscriptBox["\[Nu]", "5"], ",", 
     SubscriptBox["\[Nu]", "6"]}], "]"}], ".", 
   RowBox[{"GA", "[", "5", "]"}]}], "]"}]], "Input",
 CellTags->"TR",
 CellLabel->"In[1774]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "4"}], " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{
        SubscriptBox["\[Nu]", "1"], 
        SubscriptBox["\[Nu]", "2"]}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "3"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "4"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "5"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "6"],
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{
        SubscriptBox["\[Nu]", "1"], 
        SubscriptBox["\[Nu]", "3"]}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "2"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "4"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "5"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "6"],
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{
        SubscriptBox["\[Nu]", "1"], 
        SubscriptBox["\[Nu]", "4"]}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "2"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "3"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "5"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "6"],
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{
        SubscriptBox["\[Nu]", "1"], 
        SubscriptBox["\[Nu]", "5"]}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "2"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "3"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "4"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "6"],
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{
        SubscriptBox["\[Nu]", "1"], 
        SubscriptBox["\[Nu]", "6"]}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "2"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "3"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "4"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "5"],
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{
        SubscriptBox["\[Nu]", "2"], 
        SubscriptBox["\[Nu]", "3"]}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "1"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "4"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "5"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "6"],
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{
        SubscriptBox["\[Nu]", "2"], 
        SubscriptBox["\[Nu]", "4"]}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "1"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "3"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "5"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "6"],
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{
        SubscriptBox["\[Nu]", "2"], 
        SubscriptBox["\[Nu]", "5"]}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "1"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "3"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "4"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "6"],
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{
        SubscriptBox["\[Nu]", "2"], 
        SubscriptBox["\[Nu]", "6"]}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "1"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "3"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "4"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "5"],
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{
        SubscriptBox["\[Nu]", "3"], 
        SubscriptBox["\[Nu]", "4"]}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "1"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "2"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "5"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "6"],
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{
        SubscriptBox["\[Nu]", "3"], 
        SubscriptBox["\[Nu]", "5"]}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "1"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "2"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "4"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "6"],
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{
        SubscriptBox["\[Nu]", "3"], 
        SubscriptBox["\[Nu]", "6"]}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "1"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "2"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "4"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "5"],
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{
        SubscriptBox["\[Nu]", "4"], 
        SubscriptBox["\[Nu]", "5"]}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "1"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "2"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "3"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "6"],
          TraditionalForm],
         TraditionalForm]}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{
        SubscriptBox["\[Nu]", "4"], 
        SubscriptBox["\[Nu]", "6"]}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "1"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "2"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "3"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "5"],
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{
        SubscriptBox["\[Nu]", "5"], 
        SubscriptBox["\[Nu]", "6"]}]], " ", 
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "1"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "2"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "3"],
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox[
          SubscriptBox["\[Nu]", "4"],
          TraditionalForm],
         TraditionalForm]}]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"TR",
 CellLabel->"Out[1774]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TR", "[", 
  RowBox[{"GS", "[", 
   RowBox[{"p", ",", "q", ",", "r", ",", "s"}], "]"}], "]"}]], "Input",
 CellTags->"TR",
 CellLabel->"In[1775]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["s",
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox["q",
        TraditionalForm], "\[CenterDot]", 
       FormBox["r",
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["r",
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox["q",
        TraditionalForm], "\[CenterDot]", 
       FormBox["s",
        TraditionalForm]}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox["r",
        TraditionalForm], "\[CenterDot]", 
       FormBox["s",
        TraditionalForm]}]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"TR",
 CellLabel->"Out[1775]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TR", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"GS", "[", "p", "]"}], "+", "m"}], ")"}], ".", 
    RowBox[{"GA", "[", "\[Mu]", "]"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"GS", "[", "q", "]"}], "+", "m"}], ")"}], ".", 
    RowBox[{"GA", "[", "\[Mu]", "]"}]}], ",", 
   RowBox[{"Factoring", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"TR",
 CellLabel->"In[1776]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"8", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["m", "2"]}], "-", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"TR",
 CellLabel->"Out[1776]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TR", "[", 
  RowBox[{
   RowBox[{"GA", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", 
   RowBox[{"FCE", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"TR",
 CellLabel->"In[1777]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"4", " ", 
   SuperscriptBox["g", 
    RowBox[{"\[Alpha]", "\[Beta]"}]]}], TraditionalForm]], "Output",
 CellTags->"TR",
 CellLabel->"Out[1777]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"TR",
 CellLabel->"In[1778]:="],

Cell[BoxData[
 RowBox[{"4", " ", 
  RowBox[{"MT", "[", 
   RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}]], "Output",
 CellTags->"TR",
 CellLabel->"Out[1778]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TR", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"GAD", "[", "\[Mu]", "]"}], ".", 
    RowBox[{"GA", "[", "\[Alpha]", "]"}], ".", 
    RowBox[{"GA", "[", "\[Beta]", "]"}], ".", 
    RowBox[{"GAD", "[", "\[Mu]", "]"}]}], ",", 
   RowBox[{"FCE", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"TR",
 CellLabel->"In[1779]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"4", " ", "D", " ", 
   SuperscriptBox["g", 
    RowBox[{"\[Alpha]", "\[Beta]"}]]}], TraditionalForm]], "Output",
 CellTags->"TR",
 CellLabel->"Out[1779]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"TR",
 CellLabel->"In[1780]:="],

Cell[BoxData[
 RowBox[{"4", " ", "D", " ", 
  RowBox[{"MT", "[", 
   RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}]], "Output",
 CellTags->"TR",
 CellLabel->"Out[1780]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{
   RowBox[{"GA", "[", 
    RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], " ", 
   RowBox[{
    RowBox[{"SUNT", "[", "b", "]"}], ".", 
    RowBox[{"SUNT", "[", "c", "]"}]}], " ", 
   RowBox[{"SUNDelta", "[", 
    RowBox[{"c", ",", "b"}], "]"}]}]}]], "Input",
 CellTags->"TR",
 CellLabel->"In[1781]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[Delta]", 
    RowBox[{"b", "c"}]], " ", 
   RowBox[{
    SubscriptBox["T", 
     FormBox["b",
      TraditionalForm]], ".", 
    SubscriptBox["T", 
     FormBox["c",
      TraditionalForm]]}], " ", 
   RowBox[{
    SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
    SuperscriptBox["\[Gamma]", "\[Nu]"]}]}], TraditionalForm]], "Output",
 CellTags->"TR",
 CellLabel->"Out[1781]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TR", "[", 
  RowBox[{"t", ",", 
   RowBox[{"SUNTrace", "\[Rule]", "False"}], ",", 
   RowBox[{"SUNNToCACF", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"TR",
 CellLabel->"In[1782]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"4", " ", 
   SubscriptBox["C", "F"], " ", 
   SuperscriptBox["g", 
    RowBox[{"\[Mu]", "\[Nu]"}]]}], TraditionalForm]], "Output",
 CellTags->"TR",
 CellLabel->"Out[1782]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TR", "[", 
  RowBox[{"t", ",", 
   RowBox[{"SUNTrace", "\[Rule]", "True"}], ",", 
   RowBox[{"SUNNToCACF", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"TR",
 CellLabel->"In[1783]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"4", " ", 
   SubscriptBox["C", "F"], " ", 
   SuperscriptBox["g", 
    RowBox[{"\[Mu]", "\[Nu]"}]]}], TraditionalForm]], "Output",
 CellTags->"TR",
 CellLabel->"Out[1783]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TR", "[", 
  RowBox[{"1", ",", 
   RowBox[{"SUNTrace", "\[Rule]", "False"}], ",", 
   RowBox[{"SUNNToCACF", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"TR",
 CellLabel->"In[1784]:="],

Cell[BoxData[
 FormBox["4", TraditionalForm]], "Output",
 CellTags->"TR",
 CellLabel->"Out[1784]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TR", "[", 
  RowBox[{"1", ",", 
   RowBox[{"SUNTrace", "\[Rule]", "True"}], ",", 
   RowBox[{"SUNNToCACF", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"TR",
 CellLabel->"In[1785]:="],

Cell[BoxData[
 FormBox["4", TraditionalForm]], "Output",
 CellTags->"TR",
 CellLabel->"Out[1785]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tr", "[", " ", 
  RowBox[{"GA", "[", 
   RowBox[{"m", ",", "n"}], "]"}], "]"}]], "Input",
 CellLabel->"In[1786]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"4", " ", 
   SuperscriptBox["g", 
    RowBox[{"m", "n"}]]}], TraditionalForm]], "Output",
 CellLabel->"Out[1786]="]
}, Open  ]],

Cell["\<\
Tr has been overloaded to use TR:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Tr"}]], "Input",
 CellLabel->"In[1787]:="],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"FeynCalc extension: Tr[list] finds the trace of the matrix or \
tensor list. Tr[list, f] finds a\\n   generalized trace, combining terms with \
f instead of Plus. Tr[list, f, n]\\n   goes down to level n in list. \\n \
\\n\\nTr[ expression ] calculates the DiracTrace, i.e.,  TR[ expression \
],\\nif any of DiracGamma, DiracSlash, GA, GAD, GS or GSD are present in \
expression.\"\>", "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Tr"]}]], "Print", "PrintUsage",
 CellTags->"Info3522766033-2743550"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"T", "[", "n_", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"gamma", ",", "calc"}], "}"}], ",", 
     RowBox[{
      RowBox[{"gamma", "=", 
       RowBox[{"Dot", "@@", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"DiracMatrix", "[", 
           RowBox[{
            RowBox[{"a", "[", "i", "]"}], ",", 
            RowBox[{"Dimension", "\[Rule]", 
             RowBox[{"(", 
              RowBox[{"d", "-", "4"}], ")"}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"calc", "=", 
       RowBox[{"Timing", "[", 
        RowBox[{
         RowBox[{"Tr", "[", 
          RowBox[{"gamma", ".", "gamma"}], "]"}], "//", "Factor"}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<Time=\>\"", ",", 
        RowBox[{
         RowBox[{"calc", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "//", "FeynCalcForm"}]}], "]"}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"calc", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[1788]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"T", "[", "3", "]"}]], "Input",
 CellLabel->"In[1789]:="],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Time=\"\>", "\[InvisibleSpace]", "0.030999999999998806`"}],
   SequenceForm["Time=", 0.030999999999998806`],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "4"}], " ", 
   RowBox[{"(", 
    RowBox[{"d", "-", "4"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["d", "2"], "-", 
     RowBox[{"14", " ", "d"}], "+", "44"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellLabel->"Out[1789]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"T", "[", "8", "]"}]], "Input",
 CellLabel->"In[1790]:="],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Time=\"\>", "\[InvisibleSpace]", "0.03200000000000358`"}],
   SequenceForm["Time=", 0.03200000000000358],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{"d", "-", "6"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"d", "-", "4"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["d", "6"], "-", 
     RowBox[{"78", " ", 
      SuperscriptBox["d", "5"]}], "+", 
     RowBox[{"2276", " ", 
      SuperscriptBox["d", "4"]}], "-", 
     RowBox[{"32264", " ", 
      SuperscriptBox["d", "3"]}], "+", 
     RowBox[{"238176", " ", 
      SuperscriptBox["d", "2"]}], "-", 
     RowBox[{"880384", " ", "d"}], "+", "1286144"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellLabel->"Out[1790]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"T", "[", "10", "]"}]], "Input",
 CellLabel->"In[1791]:="],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"Time=\"\>", "\[InvisibleSpace]", "0.29699999999999704`"}],
   SequenceForm["Time=", 0.29699999999999704`],
   Editable->False], TraditionalForm]], "Print"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "4"}], " ", 
   RowBox[{"(", 
    RowBox[{"d", "-", "6"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"d", "-", "4"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["d", "8"], "-", 
     RowBox[{"120", " ", 
      SuperscriptBox["d", "7"]}], "+", 
     RowBox[{"5736", " ", 
      SuperscriptBox["d", "6"]}], "-", 
     RowBox[{"144000", " ", 
      SuperscriptBox["d", "5"]}], "+", 
     RowBox[{"2099856", " ", 
      SuperscriptBox["d", "4"]}], "-", 
     RowBox[{"18411648", " ", 
      SuperscriptBox["d", "3"]}], "+", 
     RowBox[{"95670016", " ", 
      SuperscriptBox["d", "2"]}], "-", 
     RowBox[{"271300608", " ", "d"}], "+", "323158016"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellLabel->"Out[1791]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"t", ",", "T"}], "]"}], ";"}]], "Input",
 CellTags->"TR",
 CellLabel->"In[1792]:="]
}, Open  ]],

Cell["TraceDimension", "ObjectName",
 CellTags->"TraceDimension"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"TraceDimension"],

Cell["\<\
TraceDimension is an option for FeynCalc2FORM. If set to 4: trace, if set to \
n: tracen.\
\>", "Text",
 CellTags->"TraceDimension"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynCalc2FORM",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynCalc2FORM",
  ButtonNote->"FeynCalc2FORM"],
 "."
}], "Text",
 CellTags->"TraceDimension"]
}, Open  ]],

Cell["TraceOfOne", "ObjectName",
 CellTags->"TraceOfOne"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"TraceOfOne"],

Cell["\<\
TraceOfOne is an option for Tr and DiracTrace. Its setting determines the \
value of the unit trace.\
\>", "Text",
 CellTags->"TraceOfOne"],

Cell[TextData[{
 "See also: ",
 ButtonBox["TR",
  BaseStyle->"AddOnsLink",
  ButtonData:>"TR",
  ButtonNote->"Tr"],
 ", ",
 ButtonBox["DiracTrace",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrace",
  ButtonNote->"DiracTrace"],
 "."
}], "Text",
 CellTags->"TraceOfOne"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"TraceOfOne"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TR", "[", 
  RowBox[{"1", ",", 
   RowBox[{"SUNTrace", "\[Rule]", "False"}], ",", 
   RowBox[{"SUNNToCACF", "\[Rule]", "True"}], ",", 
   RowBox[{"TraceOfOne", "\[Rule]", "tr1"}]}], "]"}]], "Input",
 CellTags->"TraceOfOne",
 CellLabel->"In[1793]:="],

Cell[BoxData[
 FormBox["tr1", TraditionalForm]], "Output",
 CellTags->"TraceOfOne",
 CellLabel->"Out[1793]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TR", "[", 
  RowBox[{"1", ",", 
   RowBox[{"SUNTrace", "\[Rule]", "True"}], ",", 
   RowBox[{"SUNNToCACF", "\[Rule]", "True"}], ",", 
   RowBox[{"TraceOfOne", "\[Rule]", "tr2"}]}], "]"}]], "Input",
 CellTags->"TraceOfOne",
 CellLabel->"In[1794]:="],

Cell[BoxData[
 FormBox["tr2", TraditionalForm]], "Output",
 CellTags->"TraceOfOne",
 CellLabel->"Out[1794]="]
}, Open  ]]
}, Open  ]],

Cell["Trick", "ObjectName",
 CellTags->"Trick"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Trick"],

Cell["\<\
Trick[exp] performs several basic simplifications without expansion. \
Trick[exp] uses Contract, DotSimplify and SUNDeltaContract.\
\>", "Text",
 CellTags->"Trick"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Calc",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Calc",
  ButtonNote->"Calc"],
 ", ",
 ButtonBox["Contract",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Contract",
  ButtonNote->"Contract"],
 ", ",
 ButtonBox["DiracTrick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrick",
  ButtonNote->"DiracTrick"],
 ", ",
 ButtonBox["DotSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DotSimplify",
  ButtonNote->"DotSimplify"],
 ", ",
 ButtonBox["DiracTrick",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrick",
  ButtonNote->"DiracTrick"],
 "."
}], "Text",
 CellTags->"Trick"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["Examples"], "Subsubsection",
 CellTags->"Trick"],

Cell[TextData[{
 "This calculates ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"\[Mu]", " ", "\[Nu]"}]], 
    SubscriptBox["\[Gamma]", "\[Mu]"]}], TraditionalForm]]],
 "and ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["g", "\[Nu]", "\[Nu]"], TraditionalForm]]],
 " in D dimensions."
}], "Text",
 ZeroWidthTimes->True,
 CellTags->"Trick"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Trick", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"GA", "[", "\[Mu]", "]"}], " ", 
     RowBox[{"MT", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], ",", " ", 
    RowBox[{"MTD", "[", 
     RowBox[{"\[Nu]", ",", "\[Nu]"}], "]"}]}], "}"}], "]"}]], "Input",
 CellTags->"Trick",
 CellLabel->"In[1795]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], ",", "D"}], "}"}], TraditionalForm]], "Output",
 CellTags->"Trick",
 CellLabel->"Out[1795]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FV", "[", 
   RowBox[{
    RowBox[{"p", "+", "r"}], ",", "\[Mu]"}], "]"}], " ", 
  RowBox[{"MT", "[", 
   RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], " ", 
  RowBox[{"FV", "[", 
   RowBox[{
    RowBox[{"q", "-", "p"}], ",", "\[Nu]"}], "]"}]}]], "Input",
 CellTags->"Trick",
 CellLabel->"In[1796]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["g", 
    RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
   RowBox[{"(", 
    SuperscriptBox[
     FormBox[
      RowBox[{"q", "-", "p"}],
      TraditionalForm], "\[Nu]"], ")"}], " ", 
   RowBox[{"(", 
    SuperscriptBox[
     FormBox[
      RowBox[{"p", "+", "r"}],
      TraditionalForm], "\[Mu]"], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Trick",
 CellLabel->"Out[1796]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Trick", "[", "%", "]"}]], "Input",
 CellTags->"Trick",
 CellLabel->"In[1797]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FormBox["p",
     TraditionalForm], "\[CenterDot]", 
    FormBox["q",
     TraditionalForm]}], "-", 
   RowBox[{
    FormBox["p",
     TraditionalForm], "\[CenterDot]", 
    FormBox["r",
     TraditionalForm]}], "-", 
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], "2"], "+", 
   RowBox[{
    FormBox["q",
     TraditionalForm], "\[CenterDot]", 
    FormBox["r",
     TraditionalForm]}]}], TraditionalForm]], "Output",
 CellTags->"Trick",
 CellLabel->"Out[1797]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Trick", "[", 
  RowBox[{"c", ".", "b", ".", "a", " ", ".", " ", 
   RowBox[{"GA", "[", "d", "]"}], ".", 
   RowBox[{"GA", "[", "e", "]"}]}], "]"}]], "Input",
 CellTags->"Trick",
 CellLabel->"In[1798]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"a", " ", "b", " ", "c", " ", 
   RowBox[{
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], ".", 
    SuperscriptBox["\[Gamma]", 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellTags->"Trick",
 CellLabel->"Out[1798]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"%", "//", "FCE"}], "//", "StandardForm"}]], "Input",
 CellTags->"Trick",
 CellLabel->"In[1799]:="],

Cell[BoxData[
 RowBox[{"a", " ", "b", " ", "c", " ", 
  RowBox[{
   RowBox[{"GA", "[", "d", "]"}], ".", 
   RowBox[{"GA", "[", "e", "]"}]}]}]], "Output",
 CellTags->"Trick",
 CellLabel->"Out[1799]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell["TrickIntegrate", "ObjectName",
 CellTags->"TrickIntegrate"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"TrickIntegrate"],

Cell["\<\
 TrickIntegrate[(1-t)^(a Epsilon -1) g[t], t] does an integration trick for \
the definite integral of ((1-t)^(a Epsilon -1) g[t])  from 0 to 1. \
TrickIntegrate[(1-t)^(a Epsilon -1) g[t], t] gives  g[1]/a/Epsilon + \
Hold[Integrate][(1-t)^(a Epsilon-1) (g[t]-g[1]),{t,0,1}]. TrickIntegrate[t^(a \
Epsilon -1) f[t], t] gives f[0]/a/Epsilon + Hold[Integrate][t^(a Epsilon-1) \
(f[t]-f[0]),{t,0,1}], provided g[1] and f[0] do exist.\
\>", "Text",
 CellTags->"TrickIntegrate"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"TrickIntegrate"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrickIntegrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "t"}], ")"}], "^", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a", " ", "Epsilon"}], "-", "1"}], ")"}]}], " ", 
    RowBox[{"g", "[", "t", "]"}]}], ",", "t"}], "]"}]], "Input",
 CellTags->"TrickIntegrate",
 CellLabel->"In[1800]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Hold", "[", "Integrate", "]"}], "[", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "(", "t", ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "t"}], ")"}], 
      RowBox[{
       RowBox[{"a", " ", 
        TagBox["\[CurlyEpsilon]",
         TraditionalForm]}], "-", "1"}]]}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "1"}], "}"}]}], "]"}], 
  TraditionalForm]], "Output",
 CellTags->"TrickIntegrate",
 CellLabel->"Out[1800]="]
}, Open  ]]
}, Open  ]],

Cell["TrickMandelstam", "ObjectName",
 CellTags->"TrickMandelstam"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"TrickMandelstam"],

Cell[TextData[{
 "TrickMandelstam[expr, {s, t, u, ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox[
    StyleBox["m",
     FontSlant->"Plain"], "1", "2"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox[
    StyleBox["m",
     FontSlant->"Plain"], "2", "2"], TraditionalForm]]],
 "+ ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox[
    StyleBox["m",
     FontSlant->"Plain"], "3", "2"], TraditionalForm]]],
 "+ ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox[
    StyleBox["m",
     FontSlant->"Plain"], "4", "2"], TraditionalForm]]],
 "}] simplifies all sums in expr so that one of the Mandelstam variables s, t \
or u is eliminated by the relation ",
 StyleBox["s",
  FontSlant->"Italic"],
 " + ",
 StyleBox["t",
  FontSlant->"Italic"],
 " + ",
 StyleBox["u",
  FontSlant->"Italic"],
 " = ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox[
    StyleBox["m",
     FontSlant->"Italic"], "1", "2"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["m", "2", "2"], TraditionalForm]]],
 "+ ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["m", "3", "2"], TraditionalForm]]],
 "+ ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["m", "4", "2"], TraditionalForm]]],
 " . The trick is that the resulting sum has the most short number of terms."
}], "Text",
 CellTags->"TrickMandelstam"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"TrickMandelstam"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TrickMandelstam", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s", "+", "t", "-", "u"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", 
        SubsuperscriptBox["M", "W", "2"]}], "-", "t", "-", "u"}], ")"}]}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "t", ",", "u", ",", 
      RowBox[{"2", 
       SubsuperscriptBox["M", "W", "2"]}]}], "}"}]}], "]"}], "//", 
  "Factor2"}]], "Input",
 CellTags->"TrickMandelstam",
 CellLabel->"In[1801]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "2"}], " ", "s", " ", 
   RowBox[{"(", 
    RowBox[{"u", "-", 
     SubsuperscriptBox["M", "W", "2"]}], ")"}]}], TraditionalForm]], "Output",\

 CellTags->"TrickMandelstam",
 CellLabel->"Out[1801]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrickMandelstam", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"M", "^", "2"}], " ", "s"}], " ", "-", " ", 
    RowBox[{"s", "^", "2"}], " ", "+", " ", 
    RowBox[{
     RowBox[{"M", "^", "2"}], " ", "t"}], " ", "-", " ", "st", " ", "+", " ", 
    
    RowBox[{
     RowBox[{"M", "^", "2"}], " ", "u"}], " ", "-", " ", "su"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"s", ",", "t", ",", "u", ",", 
     RowBox[{"2", 
      RowBox[{"M", "^", "2"}]}]}], "}"}]}], "]"}]], "Input",
 CellTags->"TrickMandelstam",
 CellLabel->"In[1802]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["M", "4"]}], "-", 
   SuperscriptBox["s", "2"], "-", "st", "-", "su"}], 
  TraditionalForm]], "Output",
 CellTags->"TrickMandelstam",
 CellLabel->"Out[1802]="]
}, Open  ]]
}, Open  ]],

Cell["Tr2", "ObjectName",
 CellTags->"Tr2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Tr2"],

Cell["\<\
If exp contains DiracTrace's, Tr2[exp] simplifies exp and does the Dirac \
traces unless more that 4 gamma matrices and DiracGamma[5] occur. Tr2[exp] \
also separates the color-strucure, and takes the color trace if Tf occurs in \
exp. If exp does not contain DiracTrace's, Tr2[exp] takes the Dirac trace.\
\>", "Text",
 CellTags->"Tr2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Tr2", "]"}]], "Input",
 CellTags->"Tr2",
 CellLabel->"In[1803]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"Factoring", "\[Rule]", "False"}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Tr2",
 CellLabel->"Out[1803]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 ButtonBox["Tr",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Tr",
  ButtonNote->"Tr"],
 ", ",
 ButtonBox["Tf",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Tf",
  ButtonNote->"Tf"],
 ", ",
 ButtonBox["DiracTrace",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracTrace",
  ButtonNote->"DiracTrace"],
 ", ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 ", ",
 ButtonBox["SUNTrace",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SUNTrace",
  ButtonNote->"SUNTrace"],
 "."
}], "Text",
 CellTags->"Tr2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Tr2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tr2", "[", 
  RowBox[{"DiracMatrix", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "]"}], "]"}]], "Input",
 CellLabel->"In[1804]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"a", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "c"}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"a", "b"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "d"}]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellLabel->"Out[1804]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TR", "[", 
  RowBox[{
   RowBox[{"a", " ", "Tf"}], ",", 
   RowBox[{"SUNTrace", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"Tr2",
 CellLabel->"In[1805]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"4", " ", "a", " ", 
   SubscriptBox["T", "f"]}], TraditionalForm]], "Output",
 CellTags->"Tr2",
 CellLabel->"Out[1805]="]
}, Open  ]]
}, Open  ]],

Cell["Twist2AlienOperator  ***unfinished*** (unclear usage def.)", \
"ObjectName",
 CellTags->"Twist2AlienOperator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Twist2AlienOperator"],

Cell["\<\
Twist2AlienOperator[p, 0] : (7);   Twist2AlienOperator[p1,p2,{p3,mu,a}, 0] \
(p1: incoming quark momentum, p3: incoming gluon (count1)).\
\>", "Text",
 CellTags->"Twist2AlienOperator"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Twist2AlienOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2AlienOperator", "[", 
  RowBox[{"p", ",", " ", "0"}], "]"}]], "Input",
 CellTags->"Twist2AlienOperator",
 CellLabel->"In[1806]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["2", "m"], "-", 
      FractionBox["1", 
       RowBox[{"m", "+", "1"}]], "-", 
      FractionBox["2", 
       RowBox[{"m", "-", "1"}]]}], ")"}], " ", 
    SubscriptBox["C", "F"], " ", 
    SubsuperscriptBox["g", "s", "2"], " ", 
    SubscriptBox["S", "n"], " ", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["\[CapitalDelta]",
      TraditionalForm]}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}], ")"}], 
     RowBox[{"m", "-", "1"}]]}], 
   TagBox["\[CurlyEpsilon]",
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"Twist2AlienOperator",
 CellLabel->"Out[1806]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2AlienOperator", "[", 
  RowBox[{"p1", ",", "p2", ",", 
   RowBox[{"{", 
    RowBox[{"p3", ",", "mu", ",", "a"}], "}"}], ",", " ", "0"}], 
  "]"}]], "Input",
 CellTags->"Twist2AlienOperator",
 CellLabel->"In[1807]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "m"], "+", "1"}], ")"}], " ", 
    SubsuperscriptBox["g", "s", "3"], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["mu",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubscriptBox["S", "n"], " ", 
    RowBox[{
     SubscriptBox["T", 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], ".", 
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["\[CapitalDelta]",
        TraditionalForm]}], ")"}]}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["2", "m"], "-", 
         FractionBox["1", 
          RowBox[{"m", "+", "1"}]], "-", 
         FractionBox["2", 
          RowBox[{"m", "-", "1"}]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["p1",
              TraditionalForm]}], ")"}], 
           RowBox[{"m", "-", "1"}]], 
          RowBox[{
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["p1",
             TraditionalForm]}], "+", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["p3",
             TraditionalForm]}]}]], "-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["p3",
                TraditionalForm]}], ")"}]}], ")"}], 
           RowBox[{"m", "-", "1"}]], 
          RowBox[{
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["p1",
             TraditionalForm]}], "+", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["p3",
             TraditionalForm]}]}]]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", 
          RowBox[{"m", "-", "1"}]], "-", 
         FractionBox["1", "m"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["p3",
             TraditionalForm]}], ")"}]}], ")"}], 
        RowBox[{"m", "-", "2"}]]}]}], ")"}]}], 
   TagBox["\[CurlyEpsilon]",
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"Twist2AlienOperator",
 CellLabel->"Out[1807]="]
}, Open  ]]
}, Open  ]],

Cell["Twist2CounterOperator  ***unfinished*** (unclear usage def.)", \
"ObjectName",
 CellTags->"Twist2CounterOperator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Twist2CounterOperator"],

Cell["\<\
Twist2CounterOperator[p,mu,nu,a,b,5]; Twist2CounterOperator[p, 7] : (7);  \
Twist2CounterOperator[p1,p2,{p3,mu,a}, 1] (p1: incoming quark momentum, p3: \
incoming gluon (count1)).\
\>", "Text",
 CellTags->"Twist2CounterOperator"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Twist2CounterOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2CounterOperator", "[", 
  RowBox[{"p", ",", "mu", ",", "nu", ",", "a", ",", "b", ",", "5"}], 
  "]"}]], "Input",
 CellTags->"Twist2CounterOperator",
 CellLabel->"In[1808]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", 
      TagBox["\[CurlyEpsilon]",
       TraditionalForm]}]], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "m"], "+", "1"}], ")"}], " ", 
     SubscriptBox["C", "A"], " ", 
     SubsuperscriptBox["g", "s", "2"], " ", 
     SubscriptBox["S", "n"], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["8", "m"], "-", 
          FractionBox["12", 
           RowBox[{"m", "+", "1"}]], "+", 
          FractionBox["8", 
           RowBox[{"m", "+", "2"}]], "-", 
          FractionBox["8", 
           RowBox[{"m", "-", "1"}]]}], ")"}], " ", 
        SuperscriptBox["g", 
         RowBox[{"mu", "nu"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], ")"}], "m"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["8", "m"], "-", 
          FractionBox["24", 
           RowBox[{"m", "+", "1"}]], "+", 
          FractionBox["24", 
           RowBox[{"m", "+", "2"}]], "-", 
          FractionBox["4", 
           RowBox[{"m", "-", "1"}]]}], ")"}], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        SuperscriptBox[
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["mu",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["nu",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], ")"}], 
         RowBox[{"m", "-", "2"}]]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["6", "m"]}], "+", 
          FractionBox["16", 
           RowBox[{"m", "+", "1"}]], "-", 
          FractionBox["16", 
           RowBox[{"m", "+", "2"}]], "+", 
          FractionBox["6", 
           RowBox[{"m", "-", "1"}]]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], ")"}], 
         RowBox[{"m", "-", "1"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            FormBox["p",
             TraditionalForm], 
            FormBox[
             FormBox["mu",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox["\[CapitalDelta]",
             TraditionalForm], 
            FormBox[
             FormBox["nu",
              TraditionalForm],
             TraditionalForm]]}], "+", 
          RowBox[{
           SuperscriptBox[
            FormBox["\[CapitalDelta]",
             TraditionalForm], 
            FormBox[
             FormBox["mu",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox["p",
             TraditionalForm], 
            FormBox[
             FormBox["nu",
              TraditionalForm],
             TraditionalForm]]}]}], ")"}]}]}], ")"}]}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2CounterOperator",
 CellLabel->"Out[1808]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2CounterOperator", "[", 
  RowBox[{"p", ",", "7"}], "]"}]], "Input",
 CellTags->"Twist2CounterOperator",
 CellLabel->"In[1809]:="],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "m"], "+", "1"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["2", "m"], "-", 
      FractionBox["1", 
       RowBox[{"m", "+", "1"}]], "-", 
      FractionBox["2", 
       RowBox[{"m", "-", "1"}]]}], ")"}], " ", 
    SubscriptBox["C", "F"], " ", 
    SubsuperscriptBox["g", "s", "2"], " ", 
    SubscriptBox["S", "n"], " ", 
    RowBox[{
     FormBox["\<\"\[Gamma]\"\>",
      TraditionalForm], "\[CenterDot]", 
     FormBox["\[CapitalDelta]",
      TraditionalForm]}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}], ")"}], 
     RowBox[{"m", "-", "1"}]]}], 
   TagBox["\[CurlyEpsilon]",
    TraditionalForm]], TraditionalForm]], "Output",
 CellTags->"Twist2CounterOperator",
 CellLabel->"Out[1809]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2CounterOperator", "[", 
  RowBox[{"p1", ",", "p2", ",", 
   RowBox[{"{", 
    RowBox[{"p3", ",", "mu", ",", "a"}], "}"}], ",", "1"}], "]"}]], "Input",
 CellTags->"Twist2CounterOperator",
 CellLabel->"In[1810]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "m"], "+", "1"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["2", "m"], "-", 
       FractionBox["1", 
        RowBox[{"m", "+", "1"}]], "-", 
       FractionBox["2", 
        RowBox[{"m", "-", "1"}]]}], ")"}], " ", 
     SubscriptBox["T", 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["g", "s", "3"], " ", 
     SuperscriptBox[
      FormBox["\[CapitalDelta]",
       TraditionalForm], 
      FormBox[
       FormBox["mu",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubscriptBox["S", "n"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["C", "A"], "-", 
       RowBox[{"2", " ", 
        SubscriptBox["C", "F"]}]}], ")"}], " ", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p1",
            TraditionalForm]}], ")"}], 
         RowBox[{"m", "-", "1"}]], 
        RowBox[{
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], "\[CenterDot]", 
          FormBox["p1",
           TraditionalForm]}], "+", 
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], "\[CenterDot]", 
          FormBox["p2",
           TraditionalForm]}]}]], "-", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["p2",
              TraditionalForm]}], ")"}]}], ")"}], 
         RowBox[{"m", "-", "1"}]], 
        RowBox[{
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], "\[CenterDot]", 
          FormBox["p1",
           TraditionalForm]}], "+", 
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], "\[CenterDot]", 
          FormBox["p2",
           TraditionalForm]}]}]]}], ")"}]}], 
    RowBox[{"2", " ", 
     TagBox["\[CurlyEpsilon]",
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"Twist2CounterOperator",
 CellLabel->"Out[1810]="]
}, Open  ]]
}, Open  ]],

Cell["Twist2GluonOperator", "ObjectName",
 CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Twist2GluonOperator"],

Cell["\<\
Twist2GluonOperator[{p, mu, a}, {nu, b}] or Twist2GluonOperator[p, {mu, a}, \
{nu, b}] or Twist2GluonOperator[p, mu,a, nu,b] yields the 2-gluon operator (p \
is ingoing momentum corresponding to Lorentz index mu). \
Twist2GluonOperator[{p,mu,a}, {q,nu,b}, {k,la,c}] or Twist2GluonOperator[ \
p,mu,a , q,nu,b , k,la,c ] gives the 3-gluon operator. \
Twist2GluonOperator[{p,mu,a}, {q,nu,b}, {k,la,c}, {s,si,d}] or \
Twist2GluonOperator[p,mu,a , q,nu,b , k,la,c , s,si,d] yields the 4-Gluon \
operator. The dimension is determined by the option and Dimension. The \
setting of the option Polarization (unpolarized: 0; polarized: 1) determines \
whether the unpolarized or polarized feynman rule is returned. With the \
setting Explicit to False the color-structure and the (1+(-1)^OPEm) (for \
polarized: (1-(-1)^OPEm)) is extracted and the color indices are omitted in \
the arguments of Twist2GluonOperator.\
\>", "Text",
 CellTags->"Twist2GluonOperator"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Twist2QuarkOperator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Twist2QuarkOperator",
  ButtonNote->"Twist2QuarkOperator"],
 "."
}], "Text",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Polarized case, zero-momentum insertion ", "Subsubsection",
 CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetOptions", "[", 
  RowBox[{"Twist2GluonOperator", ",", " ", 
   RowBox[{"Polarization", " ", "\[Rule]", " ", "1"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "False"}], ",", " ", 
   RowBox[{"ZeroMomentumInsertion", " ", "\[Rule]", " ", "True"}]}], 
  "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1811]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
    RowBox[{"Explicit", "\[Rule]", "False"}], ",", 
    RowBox[{"ZeroMomentumInsertion", "\[Rule]", "True"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1811]="]
}, Open  ]],

Cell["2-gluon legs", "Text",
 CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{"p", ",", 
   RowBox[{"{", 
    RowBox[{"\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Nu]", ",", "b"}], "}"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1812]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FormBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "m"],
      TraditionalForm]}], ")"}], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["O", 
      RowBox[{
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm], "\[VeryThinSpace]", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]}], "G2"], "(", 
     FormBox["p",
      TraditionalForm], ")"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1812]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{"p", ",", 
   RowBox[{"{", 
    RowBox[{"\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1813]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FormBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "m"],
      TraditionalForm]}], ")"}], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   FormBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}], ")"}], 
     RowBox[{"m", "-", "1"}]],
    TraditionalForm], " ", 
   SuperscriptBox["\[Epsilon]", 
    RowBox[{
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox["p",
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1813]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{"p", ",", 
   RowBox[{"{", "\[Mu]", "}"}], ",", 
   RowBox[{"{", "\[Nu]", "}"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1814]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubsuperscriptBox["O", 
    RowBox[{
     FormBox["\[Mu]",
      TraditionalForm], "\[VeryThinSpace]", 
     FormBox["\[Nu]",
      TraditionalForm]}], "G2"], "(", 
   FormBox["p",
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1814]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{"p", ",", 
   RowBox[{"{", "\[Mu]", "}"}], ",", 
   RowBox[{"{", "\[Nu]", "}"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1815]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}], ")"}], 
     RowBox[{"m", "-", "1"}]],
    TraditionalForm], " ", 
   SuperscriptBox["\[Epsilon]", 
    RowBox[{
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox["p",
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1815]="]
}, Open  ]],

Cell["3-gluon legs", "Text",
 CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1816]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FormBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "m"],
      TraditionalForm]}], ")"}], " ", 
   SubscriptBox["g", "s"], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["O", 
      RowBox[{
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm], "\[VeryThinSpace]", 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm], "\[VeryThinSpace]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]}], "G3"], "(", 
     FormBox["q",
      TraditionalForm], ",", 
     FormBox["r",
      TraditionalForm], ",", 
     FormBox["p",
      TraditionalForm], ")"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1816]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]"}], "}"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1817]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubsuperscriptBox["O", 
    RowBox[{
     FormBox["\[Nu]",
      TraditionalForm], "\[VeryThinSpace]", 
     FormBox["\[Rho]",
      TraditionalForm], "\[VeryThinSpace]", 
     FormBox["\[Mu]",
      TraditionalForm]}], "G3"], "(", 
   FormBox["q",
    TraditionalForm], ",", 
   FormBox["r",
    TraditionalForm], ",", 
   FormBox["p",
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1817]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]"}], "}"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1818]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["p",
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["q",
          TraditionalForm]}]]}], "+", 
      RowBox[{
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}], " ", 
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["q",
          TraditionalForm]}]]}]}], ")"}], " ", 
    RowBox[{"(", 
     FormBox[
      TagBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "0"}], 
         RowBox[{
          RowBox[{"-", "3"}], "+", "m"}]], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "i"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["p",
             TraditionalForm]}], ")"}], "i"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q",
             TraditionalForm]}], ")"}], 
          RowBox[{
           RowBox[{"-", "3"}], "-", "i", "+", "m"}]]}]}],
       HoldForm],
      TraditionalForm], ")"}]}], "-", 
   RowBox[{
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["p",
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["r",
          TraditionalForm]}]]}], "+", 
      RowBox[{
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}], " ", 
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["r",
          TraditionalForm]}]]}]}], ")"}], " ", 
    RowBox[{"(", 
     FormBox[
      TagBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "0"}], 
         RowBox[{
          RowBox[{"-", "3"}], "+", "m"}]], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "i"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["p",
             TraditionalForm]}], ")"}], "i"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["r",
             TraditionalForm]}], ")"}], 
          RowBox[{
           RowBox[{"-", "3"}], "-", "i", "+", "m"}]]}]}],
       HoldForm],
      TraditionalForm], ")"}]}], "-", 
   RowBox[{
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["q",
          TraditionalForm], 
         FormBox["r",
          TraditionalForm]}]]}], "-", 
      RowBox[{
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}], " ", 
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["r",
          TraditionalForm]}]]}]}], ")"}], " ", 
    RowBox[{"(", 
     FormBox[
      TagBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "0"}], 
         RowBox[{
          RowBox[{"-", "3"}], "+", "m"}]], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "i"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q",
             TraditionalForm]}], ")"}], "i"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["r",
             TraditionalForm]}], ")"}], 
          RowBox[{
           RowBox[{"-", "3"}], "-", "i", "+", "m"}]]}]}],
       HoldForm],
      TraditionalForm], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}], ")"}], 
     RowBox[{"m", "-", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["\[Epsilon]", 
          RowBox[{
           FormBox[
            FormBox["\[Mu]",
             TraditionalForm],
            TraditionalForm], 
           FormBox[
            FormBox["\[Rho]",
             TraditionalForm],
            TraditionalForm], 
           FormBox["p",
            TraditionalForm], 
           FormBox["\[CapitalDelta]",
            TraditionalForm]}]]}], "-", 
        RowBox[{
         SuperscriptBox[
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox[
           FormBox["\[Rho]",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["\[Epsilon]", 
          RowBox[{
           FormBox[
            FormBox["\[Mu]",
             TraditionalForm],
            TraditionalForm], 
           FormBox[
            FormBox["\[Nu]",
             TraditionalForm],
            TraditionalForm], 
           FormBox["p",
            TraditionalForm], 
           FormBox["\[CapitalDelta]",
            TraditionalForm]}]]}]}], ")"}]}], ")"}]}], "-", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}], ")"}], 
     RowBox[{"m", "-", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["q",
          TraditionalForm]}]]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["q",
          TraditionalForm]}]]}]}], ")"}]}], "-", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["r",
        TraditionalForm]}], ")"}], 
     RowBox[{"m", "-", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["r",
          TraditionalForm]}]]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["r",
          TraditionalForm]}]]}]}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1818]="]
}, Open  ]],

Cell["4-gluon legs", "Text",
 CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "\[Sigma]", ",", "d"}], "}"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1819]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
   SubsuperscriptBox["g", "s", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["c220",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["c220",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["O", 
          RowBox[{
           FormBox[
            FormBox["\[Mu]",
             TraditionalForm],
            TraditionalForm], "\[VeryThinSpace]", 
           FormBox[
            FormBox["\[Nu]",
             TraditionalForm],
            TraditionalForm], "\[VeryThinSpace]", 
           FormBox[
            FormBox["\[Rho]",
             TraditionalForm],
            TraditionalForm], "\[VeryThinSpace]", 
           FormBox[
            FormBox["\[Sigma]",
             TraditionalForm],
            TraditionalForm]}], "G4"], "(", 
         FormBox["p",
          TraditionalForm], ",", 
         FormBox["q",
          TraditionalForm], ",", 
         FormBox["r",
          TraditionalForm], ",", 
         FormBox["s",
          TraditionalForm], ")"}], ")"}]}]}], "-", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c220",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c220",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["O", 
         RowBox[{
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Rho]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Sigma]",
            TraditionalForm],
           TraditionalForm]}], "G4"], "(", 
        FormBox["p",
         TraditionalForm], ",", 
        FormBox["r",
         TraditionalForm], ",", 
        FormBox["q",
         TraditionalForm], ",", 
        FormBox["s",
         TraditionalForm], ")"}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c220",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c220",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["O", 
         RowBox[{
          FormBox[
           FormBox["\[Rho]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Sigma]",
            TraditionalForm],
           TraditionalForm]}], "G4"], "(", 
        FormBox["r",
         TraditionalForm], ",", 
        FormBox["q",
         TraditionalForm], ",", 
        FormBox["p",
         TraditionalForm], ",", 
        FormBox["s",
         TraditionalForm], ")"}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1819]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "\[Sigma]"}], "}"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1820]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubsuperscriptBox["O", 
    RowBox[{
     FormBox["\[Mu]",
      TraditionalForm], "\[VeryThinSpace]", 
     FormBox["\[Nu]",
      TraditionalForm], "\[VeryThinSpace]", 
     FormBox["\[Rho]",
      TraditionalForm], "\[VeryThinSpace]", 
     FormBox["\[Sigma]",
      TraditionalForm]}], "G4"], "(", 
   FormBox["p",
    TraditionalForm], ",", 
   FormBox["q",
    TraditionalForm], ",", 
   FormBox["r",
    TraditionalForm], ",", 
   FormBox["s",
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1820]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "\[Sigma]"}], "}"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1821]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Sigma]",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Sigma]",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}], "+", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["s",
         TraditionalForm]}]}], ")"}], 
     RowBox[{"m", "-", "2"}]]}], "-", 
   RowBox[{
    RowBox[{"(", 
     FormBox[
      TagBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "0"}], 
         RowBox[{
          RowBox[{"-", "3"}], "+", "m"}]], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["p",
                TraditionalForm]}], ")"}]}], "-", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}]}], ")"}], "i"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["s",
             TraditionalForm]}], ")"}], 
          RowBox[{
           RowBox[{"-", "3"}], "-", "i", "+", "m"}]]}]}],
       HoldForm],
      TraditionalForm], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Sigma]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["s",
          TraditionalForm]}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Sigma]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["s",
          TraditionalForm]}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]]}]}], ")"}], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     FormBox[
      TagBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "0"}], 
         RowBox[{
          RowBox[{"-", "3"}], "+", "m"}]], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["p",
              TraditionalForm]}], "+", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}]}], ")"}], 
          RowBox[{
           RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["r",
               TraditionalForm]}], ")"}]}], ")"}], "i"]}]}],
       HoldForm],
      TraditionalForm], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["r",
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm]}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["r",
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm]}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]]}]}], ")"}], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    RowBox[{"(", 
     FormBox[
      TagBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "0"}], 
         RowBox[{
          RowBox[{"-", "3"}], "+", "m"}]], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["p",
               TraditionalForm]}], ")"}]}], ")"}], "i"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["r",
              TraditionalForm]}], "+", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["s",
              TraditionalForm]}]}], ")"}], 
          RowBox[{
           RowBox[{"-", "3"}], "-", "i", "+", "m"}]]}]}],
       HoldForm],
      TraditionalForm], ")"}], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Sigma]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["p",
          TraditionalForm]}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["p",
          TraditionalForm]}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]]}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     FormBox[
      TagBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "0"}], 
         RowBox[{
          RowBox[{"-", "3"}], "+", "m"}]], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], ")"}]}], ")"}], "i"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["r",
              TraditionalForm]}], "+", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["s",
              TraditionalForm]}]}], ")"}], 
          RowBox[{
           RowBox[{"-", "3"}], "-", "i", "+", "m"}]]}]}],
       HoldForm],
      TraditionalForm], ")"}], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Sigma]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["q",
          TraditionalForm]}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["q",
          TraditionalForm]}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]]}]}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox[
       TagBox[
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "0"}], 
          RowBox[{
           RowBox[{"-", "4"}], "+", "m"}]], "\<\"\"\>"}],
        HoldForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"\<\"\"\>", " ", 
        RowBox[{"(", 
         RowBox[{"j", "+", "1"}], ")"}]}],
       TraditionalForm], 
      FormBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], ")"}], 
         RowBox[{
          RowBox[{"-", "j"}], "+", "m", "-", "4"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["r",
               TraditionalForm]}], ")"}]}], "-", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["s",
             TraditionalForm]}]}], ")"}], 
         RowBox[{"j", "-", "i"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["s",
              TraditionalForm]}], ")"}]}], ")"}], "i"]}],
       TraditionalForm]}], ")"}], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Epsilon]", 
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox[
           FormBox["\[Sigma]",
            TraditionalForm],
           TraditionalForm], 
          FormBox["p",
           TraditionalForm], 
          FormBox["s",
           TraditionalForm]}]]}], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Sigma]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["s",
          TraditionalForm]}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}]}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox[
       TagBox[
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "0"}], 
          RowBox[{
           RowBox[{"-", "4"}], "+", "m"}]], "\<\"\"\>"}],
        HoldForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"\<\"\"\>", " ", 
        RowBox[{"(", 
         RowBox[{"j", "+", "1"}], ")"}]}],
       TraditionalForm], 
      FormBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}], ")"}], 
         RowBox[{
          RowBox[{"-", "j"}], "+", "m", "-", "4"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["r",
               TraditionalForm]}], ")"}]}], "-", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["s",
             TraditionalForm]}]}], ")"}], 
         RowBox[{"j", "-", "i"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["s",
              TraditionalForm]}], ")"}]}], ")"}], "i"]}],
       TraditionalForm]}], ")"}], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Epsilon]", 
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox[
           FormBox["\[Sigma]",
            TraditionalForm],
           TraditionalForm], 
          FormBox["q",
           TraditionalForm], 
          FormBox["s",
           TraditionalForm]}]]}], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Sigma]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["s",
          TraditionalForm]}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox[
       TagBox[
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "0"}], 
          RowBox[{
           RowBox[{"-", "4"}], "+", "m"}]], "\<\"\"\>"}],
        HoldForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"\<\"\"\>", " ", 
        RowBox[{"(", 
         RowBox[{"j", "+", "1"}], ")"}]}],
       TraditionalForm], 
      FormBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], ")"}], 
         RowBox[{
          RowBox[{"-", "j"}], "+", "m", "-", "4"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["r",
              TraditionalForm]}], ")"}]}], ")"}], "i"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["r",
               TraditionalForm]}], ")"}]}], "-", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["s",
             TraditionalForm]}]}], ")"}], 
         RowBox[{"j", "-", "i"}]]}],
       TraditionalForm]}], ")"}], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Epsilon]", 
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm], 
          FormBox["p",
           TraditionalForm], 
          FormBox["r",
           TraditionalForm]}]]}], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["p",
          TraditionalForm]}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}]}]}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox[
       TagBox[
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "0"}], 
          RowBox[{
           RowBox[{"-", "4"}], "+", "m"}]], "\<\"\"\>"}],
        HoldForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"\<\"\"\>", " ", 
        RowBox[{"(", 
         RowBox[{"j", "+", "1"}], ")"}]}],
       TraditionalForm], 
      FormBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}], ")"}], 
         RowBox[{
          RowBox[{"-", "j"}], "+", "m", "-", "4"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["r",
              TraditionalForm]}], ")"}]}], ")"}], "i"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["r",
               TraditionalForm]}], ")"}]}], "-", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["s",
             TraditionalForm]}]}], ")"}], 
         RowBox[{"j", "-", "i"}]]}],
       TraditionalForm]}], ")"}], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Epsilon]", 
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm], 
          FormBox["q",
           TraditionalForm], 
          FormBox["r",
           TraditionalForm]}]]}], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["q",
          TraditionalForm]}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}]}]}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1821]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Unpolarized case, zero-momentum insertion", "Subsubsection",
 CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetOptions", "[", 
  RowBox[{"Twist2GluonOperator", ",", 
   RowBox[{"Polarization", "\[Rule]", "0"}], ",", 
   RowBox[{"ZeroMomentumInsertion", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1822]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Polarization", "\[Rule]", "0"}], ",", 
    RowBox[{"Explicit", "\[Rule]", "False"}], ",", 
    RowBox[{"ZeroMomentumInsertion", "\[Rule]", "True"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1822]="]
}, Open  ]],

Cell["2-gluon legs", "Text",
 CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{"p", ",", 
   RowBox[{"{", 
    RowBox[{"\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Nu]", ",", "b"}], "}"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1823]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     FormBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "m"],
      TraditionalForm], "+", "1"}], ")"}], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["O", 
      RowBox[{
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm], "\[VeryThinSpace]", 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]}], "G2"], "(", 
     FormBox["p",
      TraditionalForm], ")"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1823]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{"p", ",", 
   RowBox[{"{", 
    RowBox[{"\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1824]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     FormBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "m"],
      TraditionalForm], "+", "1"}], ")"}], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   FormBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}], ")"}], 
     RowBox[{"m", "-", "2"}]],
    TraditionalForm], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
      SuperscriptBox[
       FormBox[
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["p",
          TraditionalForm]}],
        TraditionalForm], "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        RowBox[{
         SuperscriptBox[
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1824]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{"p", ",", 
   RowBox[{"{", "\[Mu]", "}"}], ",", 
   RowBox[{"{", "\[Nu]", "}"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1825]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubsuperscriptBox["O", 
    RowBox[{
     FormBox["\[Mu]",
      TraditionalForm], "\[VeryThinSpace]", 
     FormBox["\[Nu]",
      TraditionalForm]}], "G2"], "(", 
   FormBox["p",
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1825]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{"p", ",", 
   RowBox[{"{", "\[Mu]", "}"}], ",", 
   RowBox[{"{", "\[Nu]", "}"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1826]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}], ")"}], 
     RowBox[{"m", "-", "2"}]],
    TraditionalForm], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
      SuperscriptBox[
       FormBox[
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["p",
          TraditionalForm]}],
        TraditionalForm], "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        RowBox[{
         SuperscriptBox[
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1826]="]
}, Open  ]],

Cell["3-gluon legs", "Text",
 CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1827]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     FormBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], "m"],
      TraditionalForm], "+", "1"}], ")"}], " ", 
   SubscriptBox["g", "s"], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["O", 
      RowBox[{
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm], "\[VeryThinSpace]", 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm], "\[VeryThinSpace]", 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]}], "G3"], "(", 
     FormBox["q",
      TraditionalForm], ",", 
     FormBox["r",
      TraditionalForm], ",", 
     FormBox["p",
      TraditionalForm], ")"}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1827]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]"}], "}"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1828]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubsuperscriptBox["O", 
    RowBox[{
     FormBox["\[Nu]",
      TraditionalForm], "\[VeryThinSpace]", 
     FormBox["\[Rho]",
      TraditionalForm], "\[VeryThinSpace]", 
     FormBox["\[Mu]",
      TraditionalForm]}], "G3"], "(", 
   FormBox["q",
    TraditionalForm], ",", 
   FormBox["r",
    TraditionalForm], ",", 
   FormBox["p",
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1828]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]"}], "}"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1829]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["p",
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     FormBox[
      TagBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "0"}], 
         RowBox[{
          RowBox[{"-", "3"}], "+", "m"}]], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["p",
               TraditionalForm]}], ")"}]}], ")"}], "i"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q",
             TraditionalForm]}], ")"}], 
          RowBox[{
           RowBox[{"-", "3"}], "-", "i", "+", "m"}]]}]}],
       HoldForm],
      TraditionalForm], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["p",
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["r",
          TraditionalForm]}]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["r",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     FormBox[
      TagBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "0"}], 
         RowBox[{
          RowBox[{"-", "3"}], "+", "m"}]], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["p",
             TraditionalForm]}], ")"}], 
          RowBox[{
           RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["r",
               TraditionalForm]}], ")"}]}], ")"}], "i"]}]}],
       HoldForm],
      TraditionalForm], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["r",
          TraditionalForm]}]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["r",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     FormBox[
      TagBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "0"}], 
         RowBox[{
          RowBox[{"-", "3"}], "+", "m"}]], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], ")"}]}], ")"}], "i"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["r",
             TraditionalForm]}], ")"}], 
          RowBox[{
           RowBox[{"-", "3"}], "-", "i", "+", "m"}]]}]}],
       HoldForm],
      TraditionalForm], ")"}]}], "+", 
   RowBox[{
    FormBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}], ")"}], 
      RowBox[{"m", "-", "2"}]],
     TraditionalForm], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           FormBox["\[CapitalDelta]",
            TraditionalForm], 
           FormBox[
            FormBox["\[Nu]",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox["g", 
           RowBox[{"\[Mu]", "\[Rho]"}]]}], "-", 
         RowBox[{
          SuperscriptBox[
           FormBox["\[CapitalDelta]",
            TraditionalForm], 
           FormBox[
            FormBox["\[Rho]",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox["g", 
           RowBox[{"\[Mu]", "\[Nu]"}]]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           FormBox["\[CapitalDelta]",
            TraditionalForm], 
           FormBox[
            FormBox["\[Rho]",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], 
           FormBox[
            FormBox["\[Nu]",
             TraditionalForm],
            TraditionalForm]]}], "-", 
         RowBox[{
          SuperscriptBox[
           FormBox["\[CapitalDelta]",
            TraditionalForm], 
           FormBox[
            FormBox["\[Nu]",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], 
           FormBox[
            FormBox["\[Rho]",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}]}], ")"}]}], "+", 
   RowBox[{
    FormBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}], ")"}], 
      RowBox[{"m", "-", "2"}]],
     TraditionalForm], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           FormBox["\[CapitalDelta]",
            TraditionalForm], 
           FormBox[
            FormBox["\[Rho]",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox["g", 
           RowBox[{"\[Mu]", "\[Nu]"}]]}], "-", 
         RowBox[{
          SuperscriptBox[
           FormBox["\[CapitalDelta]",
            TraditionalForm], 
           FormBox[
            FormBox["\[Mu]",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox["g", 
           RowBox[{"\[Nu]", "\[Rho]"}]]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           FormBox["\[CapitalDelta]",
            TraditionalForm], 
           FormBox[
            FormBox["\[Mu]",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["\[Rho]",
             TraditionalForm],
            TraditionalForm]]}], "-", 
         RowBox[{
          SuperscriptBox[
           FormBox["\[CapitalDelta]",
            TraditionalForm], 
           FormBox[
            FormBox["\[Rho]",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["\[Mu]",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}]}], ")"}]}], "+", 
   RowBox[{
    FormBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}], ")"}], 
      RowBox[{"m", "-", "2"}]],
     TraditionalForm], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           FormBox["\[CapitalDelta]",
            TraditionalForm], 
           FormBox[
            FormBox["\[Mu]",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox["g", 
           RowBox[{"\[Nu]", "\[Rho]"}]]}], "-", 
         RowBox[{
          SuperscriptBox[
           FormBox["\[CapitalDelta]",
            TraditionalForm], 
           FormBox[
            FormBox["\[Nu]",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox["g", 
           RowBox[{"\[Mu]", "\[Rho]"}]]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           FormBox["\[CapitalDelta]",
            TraditionalForm], 
           FormBox[
            FormBox["\[Nu]",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["r",
            TraditionalForm], 
           FormBox[
            FormBox["\[Mu]",
             TraditionalForm],
            TraditionalForm]]}], "-", 
         RowBox[{
          SuperscriptBox[
           FormBox["\[CapitalDelta]",
            TraditionalForm], 
           FormBox[
            FormBox["\[Mu]",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["r",
            TraditionalForm], 
           FormBox[
            FormBox["\[Nu]",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}]}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1829]="]
}, Open  ]],

Cell["4-gluon legs", "Text",
 CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "\[Sigma]", ",", "d"}], "}"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1830]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], "+", "1"}], ")"}], " ", 
   SubsuperscriptBox["g", "s", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["c221",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["c221",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["O", 
          RowBox[{
           FormBox[
            FormBox["\[Mu]",
             TraditionalForm],
            TraditionalForm], "\[VeryThinSpace]", 
           FormBox[
            FormBox["\[Nu]",
             TraditionalForm],
            TraditionalForm], "\[VeryThinSpace]", 
           FormBox[
            FormBox["\[Rho]",
             TraditionalForm],
            TraditionalForm], "\[VeryThinSpace]", 
           FormBox[
            FormBox["\[Sigma]",
             TraditionalForm],
            TraditionalForm]}], "G4"], "(", 
         FormBox["p",
          TraditionalForm], ",", 
         FormBox["q",
          TraditionalForm], ",", 
         FormBox["r",
          TraditionalForm], ",", 
         FormBox["s",
          TraditionalForm], ")"}], ")"}]}]}], "-", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c221",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c221",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["O", 
         RowBox[{
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Rho]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Sigma]",
            TraditionalForm],
           TraditionalForm]}], "G4"], "(", 
        FormBox["p",
         TraditionalForm], ",", 
        FormBox["r",
         TraditionalForm], ",", 
        FormBox["q",
         TraditionalForm], ",", 
        FormBox["s",
         TraditionalForm], ")"}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c221",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c221",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["O", 
         RowBox[{
          FormBox[
           FormBox["\[Rho]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Sigma]",
            TraditionalForm],
           TraditionalForm]}], "G4"], "(", 
        FormBox["r",
         TraditionalForm], ",", 
        FormBox["q",
         TraditionalForm], ",", 
        FormBox["p",
         TraditionalForm], ",", 
        FormBox["s",
         TraditionalForm], ")"}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1830]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "\[Sigma]"}], "}"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1831]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubsuperscriptBox["O", 
    RowBox[{
     FormBox["\[Mu]",
      TraditionalForm], "\[VeryThinSpace]", 
     FormBox["\[Nu]",
      TraditionalForm], "\[VeryThinSpace]", 
     FormBox["\[Rho]",
      TraditionalForm], "\[VeryThinSpace]", 
     FormBox["\[Sigma]",
      TraditionalForm]}], "G4"], "(", 
   FormBox["p",
    TraditionalForm], ",", 
   FormBox["q",
    TraditionalForm], ",", 
   FormBox["r",
    TraditionalForm], ",", 
   FormBox["s",
    TraditionalForm], ")"}], TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1831]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "\[Sigma]"}], "}"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1832]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"\[Nu]", "\[Sigma]"}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}], "+", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["s",
         TraditionalForm]}]}], ")"}], 
     RowBox[{"m", "-", "2"}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     FormBox[
      TagBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "0"}], 
         RowBox[{
          RowBox[{"-", "3"}], "+", "m"}]], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["p",
               TraditionalForm]}], ")"}]}], ")"}], "i"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["r",
              TraditionalForm]}], "+", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["s",
              TraditionalForm]}]}], ")"}], 
          RowBox[{
           RowBox[{"-", "3"}], "-", "i", "+", "m"}]]}]}],
       HoldForm],
      TraditionalForm], ")"}], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}]}]}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     FormBox[
      TagBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "0"}], 
         RowBox[{
          RowBox[{"-", "3"}], "+", "m"}]], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], ")"}]}], ")"}], "i"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["r",
              TraditionalForm]}], "+", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["s",
              TraditionalForm]}]}], ")"}], 
          RowBox[{
           RowBox[{"-", "3"}], "-", "i", "+", "m"}]]}]}],
       HoldForm],
      TraditionalForm], ")"}], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Nu]", "\[Sigma]"}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     FormBox[
      TagBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "0"}], 
         RowBox[{
          RowBox[{"-", "3"}], "+", "m"}]], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["p",
              TraditionalForm]}], "+", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}]}], ")"}], 
          RowBox[{
           RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["r",
               TraditionalForm]}], ")"}]}], ")"}], "i"]}]}],
       HoldForm],
      TraditionalForm], ")"}], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["r",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["r",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}]}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     FormBox[
      TagBox[
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"i", "=", "0"}], 
         RowBox[{
          RowBox[{"-", "3"}], "+", "m"}]], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["p",
                TraditionalForm]}], ")"}]}], "-", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}]}], ")"}], "i"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["s",
             TraditionalForm]}], ")"}], 
          RowBox[{
           RowBox[{"-", "3"}], "-", "i", "+", "m"}]]}]}],
       HoldForm],
      TraditionalForm], ")"}], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["s",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["s",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"\[Nu]", "\[Sigma]"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["s",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["s",
         TraditionalForm]}]}]}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox[
       TagBox[
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "0"}], 
          RowBox[{
           RowBox[{"-", "4"}], "+", "m"}]], "\<\"\"\>"}],
        HoldForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"\<\"\"\>", " ", 
        RowBox[{"(", 
         RowBox[{"j", "+", "1"}], ")"}]}],
       TraditionalForm], 
      FormBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], ")"}], 
         RowBox[{
          RowBox[{"-", "j"}], "+", "m", "-", "4"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["r",
              TraditionalForm]}], ")"}]}], ")"}], "i"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["r",
               TraditionalForm]}], ")"}]}], "-", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["s",
             TraditionalForm]}]}], ")"}], 
         RowBox[{"j", "-", "i"}]]}],
       TraditionalForm]}], ")"}], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         FormBox["r",
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]]}], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}]}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox[
       TagBox[
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "0"}], 
          RowBox[{
           RowBox[{"-", "4"}], "+", "m"}]], "\<\"\"\>"}],
        HoldForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"\<\"\"\>", " ", 
        RowBox[{"(", 
         RowBox[{"j", "+", "1"}], ")"}]}],
       TraditionalForm], 
      FormBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], ")"}], 
         RowBox[{
          RowBox[{"-", "j"}], "+", "m", "-", "4"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["r",
               TraditionalForm]}], ")"}]}], "-", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["s",
             TraditionalForm]}]}], ")"}], 
         RowBox[{"j", "-", "i"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["s",
              TraditionalForm]}], ")"}]}], ")"}], "i"]}],
       TraditionalForm]}], ")"}], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         FormBox["s",
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]]}], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["s",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["s",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["s",
         TraditionalForm]}]}]}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox[
       TagBox[
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "0"}], 
          RowBox[{
           RowBox[{"-", "4"}], "+", "m"}]], "\<\"\"\>"}],
        HoldForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"\<\"\"\>", " ", 
        RowBox[{"(", 
         RowBox[{"j", "+", "1"}], ")"}]}],
       TraditionalForm], 
      FormBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}], ")"}], 
         RowBox[{
          RowBox[{"-", "j"}], "+", "m", "-", "4"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["r",
              TraditionalForm]}], ")"}]}], ")"}], "i"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["r",
               TraditionalForm]}], ")"}]}], "-", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["s",
             TraditionalForm]}]}], ")"}], 
         RowBox[{"j", "-", "i"}]]}],
       TraditionalForm]}], ")"}], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Sigma]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         FormBox["r",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]]}], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}]}]}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox[
       TagBox[
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "0"}], 
          RowBox[{
           RowBox[{"-", "4"}], "+", "m"}]], "\<\"\"\>"}],
        HoldForm],
       TraditionalForm], 
      FormBox[
       RowBox[{"\<\"\"\>", " ", 
        RowBox[{"(", 
         RowBox[{"j", "+", "1"}], ")"}]}],
       TraditionalForm], 
      FormBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}], ")"}], 
         RowBox[{
          RowBox[{"-", "j"}], "+", "m", "-", "4"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["r",
               TraditionalForm]}], ")"}]}], "-", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["s",
             TraditionalForm]}]}], ")"}], 
         RowBox[{"j", "-", "i"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["s",
              TraditionalForm]}], ")"}]}], ")"}], "i"]}],
       TraditionalForm]}], ")"}], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["\[CapitalDelta]",
      TraditionalForm], 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox[
         FormBox["s",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]]}], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Nu]", "\[Sigma]"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["s",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["s",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Sigma]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox["s",
         TraditionalForm]}]}]}], ")"}]}]}], TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1832]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Advanced Examples", "Subsubsection",
 CellTags->"Twist2GluonOperator"],

Cell["The setting All for Explicit performs the sums.", "Text",
 CellTags->"Twist2GluonOperator"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Twist2GluonOperator", ",", " ", 
    RowBox[{"Polarization", " ", "\[Rule]", " ", "1"}], ",", " ", 
    RowBox[{"Explicit", "\[Rule]", "All"}]}], "]"}], ";"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1833]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Twist2GluonOperator", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}]}], "]"}], ";"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1834]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Polarized case, non-zero-momentum insertion", "Subsubsection",
 CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetOptions", "[", 
  RowBox[{"Twist2GluonOperator", ",", " ", 
   RowBox[{"Polarization", " ", "\[Rule]", " ", "1"}], ",", 
   RowBox[{"ZeroMomentumInsertion", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1835]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
    RowBox[{"Explicit", "\[Rule]", "All"}], ",", 
    RowBox[{"ZeroMomentumInsertion", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1835]="]
}, Open  ]],

Cell["2-gluon legs", "Text",
 CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "q"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Nu]", ",", "b"}], "}"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1836]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FormBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], "\[CenterDot]", 
          FormBox["p",
           TraditionalForm]}], ")"}], 
        RowBox[{"m", "-", "2"}]],
       TraditionalForm], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["\[Epsilon]", 
          RowBox[{
           FormBox[
            FormBox["\[Nu]",
             TraditionalForm],
            TraditionalForm], 
           FormBox["\[CapitalDelta]",
            TraditionalForm], 
           FormBox["p",
            TraditionalForm], 
           FormBox["q",
            TraditionalForm]}]]}], "-", 
        RowBox[{
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], "\[CenterDot]", 
          FormBox["p",
           TraditionalForm]}], " ", 
         SuperscriptBox["\[Epsilon]", 
          RowBox[{
           FormBox[
            FormBox["\[Mu]",
             TraditionalForm],
            TraditionalForm], 
           FormBox[
            FormBox["\[Nu]",
             TraditionalForm],
            TraditionalForm], 
           FormBox["\[CapitalDelta]",
            TraditionalForm], 
           FormBox["q",
            TraditionalForm]}]]}]}], ")"}]}], "+", 
     RowBox[{
      FormBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}], ")"}], 
        RowBox[{"m", "-", "2"}]],
       TraditionalForm], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}], " ", 
         SuperscriptBox["\[Epsilon]", 
          RowBox[{
           FormBox[
            FormBox["\[Mu]",
             TraditionalForm],
            TraditionalForm], 
           FormBox[
            FormBox["\[Nu]",
             TraditionalForm],
            TraditionalForm], 
           FormBox["\[CapitalDelta]",
            TraditionalForm], 
           FormBox["p",
            TraditionalForm]}]]}], "-", 
        RowBox[{
         SuperscriptBox[
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["\[Epsilon]", 
          RowBox[{
           FormBox[
            FormBox["\[Mu]",
             TraditionalForm],
            TraditionalForm], 
           FormBox["\[CapitalDelta]",
            TraditionalForm], 
           FormBox["p",
            TraditionalForm], 
           FormBox["q",
            TraditionalForm]}]]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1836]="]
}, Open  ]],

Cell["3-gluon legs", "Text",
 CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1837]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["g", "s"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["p",
          TraditionalForm]}]]}], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["p",
          TraditionalForm]}], ")"}], 
       RowBox[{"m", "-", "2"}]]}], "+", 
     RowBox[{
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox["q",
         TraditionalForm]}]], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}], ")"}], 
       RowBox[{"m", "-", "2"}]]}], "-", 
     RowBox[{
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox["r",
         TraditionalForm]}]], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["r",
          TraditionalForm]}], ")"}], 
       RowBox[{"m", "-", "2"}]]}], "-", 
     RowBox[{
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox["p",
         TraditionalForm], 
        FormBox["r",
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       FormBox[
        TagBox[
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"i", "=", "0"}], 
           RowBox[{
            RowBox[{"-", "3"}], "+", "m"}]], 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["p",
               TraditionalForm]}], ")"}], 
            RowBox[{
             RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["p",
                TraditionalForm]}], "+", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["q",
                TraditionalForm]}]}], ")"}], "i"]}]}],
         HoldForm],
        TraditionalForm], ")"}], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm], 
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox["q",
         TraditionalForm], 
        FormBox["r",
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       FormBox[
        TagBox[
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"i", "=", "0"}], 
           RowBox[{
            RowBox[{"-", "3"}], "+", "m"}]], 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], ")"}], 
            RowBox[{
             RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["p",
                TraditionalForm]}], "+", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["q",
                TraditionalForm]}]}], ")"}], "i"]}]}],
         HoldForm],
        TraditionalForm], ")"}], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox["p",
         TraditionalForm], 
        FormBox["q",
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       FormBox[
        TagBox[
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"i", "=", "0"}], 
           RowBox[{
            RowBox[{"-", "3"}], "+", "m"}]], 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["p",
               TraditionalForm]}], ")"}], 
            RowBox[{
             RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["p",
                TraditionalForm]}], "+", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["r",
                TraditionalForm]}]}], ")"}], "i"]}]}],
         HoldForm],
        TraditionalForm], ")"}], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox["q",
         TraditionalForm], 
        FormBox["r",
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       FormBox[
        TagBox[
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"i", "=", "0"}], 
           RowBox[{
            RowBox[{"-", "3"}], "+", "m"}]], 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["r",
               TraditionalForm]}], ")"}], 
            RowBox[{
             RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["p",
                TraditionalForm]}], "+", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["r",
                TraditionalForm]}]}], ")"}], "i"]}]}],
         HoldForm],
        TraditionalForm], ")"}], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox["p",
         TraditionalForm], 
        FormBox["q",
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       FormBox[
        TagBox[
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"i", "=", "0"}], 
           RowBox[{
            RowBox[{"-", "3"}], "+", "m"}]], 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], ")"}], 
            RowBox[{
             RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["q",
                TraditionalForm]}], "+", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["r",
                TraditionalForm]}]}], ")"}], "i"]}]}],
         HoldForm],
        TraditionalForm], ")"}], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{
      SuperscriptBox["\[Epsilon]", 
       RowBox[{
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm], 
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox["p",
         TraditionalForm], 
        FormBox["r",
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       FormBox[
        TagBox[
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"i", "=", "0"}], 
           RowBox[{
            RowBox[{"-", "3"}], "+", "m"}]], 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["r",
               TraditionalForm]}], ")"}], 
            RowBox[{
             RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["q",
                TraditionalForm]}], "+", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["r",
                TraditionalForm]}]}], ")"}], "i"]}]}],
         HoldForm],
        TraditionalForm], ")"}], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Rho]",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], "+", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}]}], ")"}], "2"]], 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["r",
          TraditionalForm]}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["p",
              TraditionalForm]}], "+", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}]}], ")"}], "m"], "+", 
         RowBox[{
          RowBox[{"(", 
           FormBox[
            TagBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["p",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["p",
                    TraditionalForm]}], "+", 
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["q",
                    TraditionalForm]}]}], ")"}], "i"]}]}],
             HoldForm],
            TraditionalForm], ")"}], " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["p",
              TraditionalForm]}],
            TraditionalForm], "3"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           FormBox[
            TagBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["p",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["p",
                    TraditionalForm]}], "+", 
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["q",
                    TraditionalForm]}]}], ")"}], "i"]}]}],
             HoldForm],
            TraditionalForm], ")"}], " ", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}],
            TraditionalForm], "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           FormBox[
            TagBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["p",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["p",
                    TraditionalForm]}], "+", 
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["q",
                    TraditionalForm]}]}], ")"}], "i"]}]}],
             HoldForm],
            TraditionalForm], ")"}], " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["p",
              TraditionalForm]}],
            TraditionalForm], "2"], " ", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}]}]}], ")"}]}]}], "-", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], "+", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}]}], ")"}], "2"]], 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["r",
          TraditionalForm]}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["p",
              TraditionalForm]}], "+", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}]}], ")"}], "m"], "+", 
         RowBox[{
          RowBox[{"(", 
           FormBox[
            TagBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["q",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["p",
                    TraditionalForm]}], "+", 
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["q",
                    TraditionalForm]}]}], ")"}], "i"]}]}],
             HoldForm],
            TraditionalForm], ")"}], " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}],
            TraditionalForm], "3"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           FormBox[
            TagBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["q",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["p",
                    TraditionalForm]}], "+", 
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["q",
                    TraditionalForm]}]}], ")"}], "i"]}]}],
             HoldForm],
            TraditionalForm], ")"}], " ", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}],
            TraditionalForm], "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           FormBox[
            TagBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["q",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["p",
                    TraditionalForm]}], "+", 
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["q",
                    TraditionalForm]}]}], ")"}], "i"]}]}],
             HoldForm],
            TraditionalForm], ")"}], " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["p",
              TraditionalForm]}],
            TraditionalForm], "2"], " ", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}]}]}], ")"}]}]}], "-", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], "+", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["r",
            TraditionalForm]}]}], ")"}], "2"]], 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["q",
          TraditionalForm]}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["p",
              TraditionalForm]}], "+", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["r",
              TraditionalForm]}]}], ")"}], "m"], "+", 
         RowBox[{
          RowBox[{"(", 
           FormBox[
            TagBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["p",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["p",
                    TraditionalForm]}], "+", 
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["r",
                    TraditionalForm]}]}], ")"}], "i"]}]}],
             HoldForm],
            TraditionalForm], ")"}], " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["p",
              TraditionalForm]}],
            TraditionalForm], "3"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           FormBox[
            TagBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["p",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["p",
                    TraditionalForm]}], "+", 
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["r",
                    TraditionalForm]}]}], ")"}], "i"]}]}],
             HoldForm],
            TraditionalForm], ")"}], " ", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["r",
              TraditionalForm]}],
            TraditionalForm], "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           FormBox[
            TagBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["p",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["p",
                    TraditionalForm]}], "+", 
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["r",
                    TraditionalForm]}]}], ")"}], "i"]}]}],
             HoldForm],
            TraditionalForm], ")"}], " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["p",
              TraditionalForm]}],
            TraditionalForm], "2"], " ", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["r",
            TraditionalForm]}]}]}], ")"}]}]}], "-", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], "+", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["r",
            TraditionalForm]}]}], ")"}], "2"]], 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["q",
          TraditionalForm]}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["p",
              TraditionalForm]}], "+", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["r",
              TraditionalForm]}]}], ")"}], "m"], "+", 
         RowBox[{
          RowBox[{"(", 
           FormBox[
            TagBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["r",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["p",
                    TraditionalForm]}], "+", 
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["r",
                    TraditionalForm]}]}], ")"}], "i"]}]}],
             HoldForm],
            TraditionalForm], ")"}], " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["r",
              TraditionalForm]}],
            TraditionalForm], "3"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           FormBox[
            TagBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["r",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["p",
                    TraditionalForm]}], "+", 
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["r",
                    TraditionalForm]}]}], ")"}], "i"]}]}],
             HoldForm],
            TraditionalForm], ")"}], " ", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["r",
              TraditionalForm]}],
            TraditionalForm], "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           FormBox[
            TagBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["r",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["p",
                    TraditionalForm]}], "+", 
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["r",
                    TraditionalForm]}]}], ")"}], "i"]}]}],
             HoldForm],
            TraditionalForm], ")"}], " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["p",
              TraditionalForm]}],
            TraditionalForm], "2"], " ", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["r",
            TraditionalForm]}]}]}], ")"}]}]}], "-", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}], "+", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["r",
            TraditionalForm]}]}], ")"}], "2"]], 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["p",
          TraditionalForm]}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Rho]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}], "+", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["r",
              TraditionalForm]}]}], ")"}], "m"], "+", 
         RowBox[{
          RowBox[{"(", 
           FormBox[
            TagBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["q",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["q",
                    TraditionalForm]}], "+", 
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["r",
                    TraditionalForm]}]}], ")"}], "i"]}]}],
             HoldForm],
            TraditionalForm], ")"}], " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}],
            TraditionalForm], "3"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           FormBox[
            TagBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["q",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["q",
                    TraditionalForm]}], "+", 
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["r",
                    TraditionalForm]}]}], ")"}], "i"]}]}],
             HoldForm],
            TraditionalForm], ")"}], " ", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}], " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["r",
              TraditionalForm]}],
            TraditionalForm], "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           FormBox[
            TagBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["q",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["q",
                    TraditionalForm]}], "+", 
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["r",
                    TraditionalForm]}]}], ")"}], "i"]}]}],
             HoldForm],
            TraditionalForm], ")"}], " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}],
            TraditionalForm], "2"], " ", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["r",
            TraditionalForm]}]}]}], ")"}]}]}], "+", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}], "+", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["r",
            TraditionalForm]}]}], ")"}], "2"]], 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox["p",
          TraditionalForm]}]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}], "+", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["r",
              TraditionalForm]}]}], ")"}], "m"], "+", 
         RowBox[{
          RowBox[{"(", 
           FormBox[
            TagBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["r",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["q",
                    TraditionalForm]}], "+", 
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["r",
                    TraditionalForm]}]}], ")"}], "i"]}]}],
             HoldForm],
            TraditionalForm], ")"}], " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["r",
              TraditionalForm]}],
            TraditionalForm], "3"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           FormBox[
            TagBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["r",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["q",
                    TraditionalForm]}], "+", 
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["r",
                    TraditionalForm]}]}], ")"}], "i"]}]}],
             HoldForm],
            TraditionalForm], ")"}], " ", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}], " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["r",
              TraditionalForm]}],
            TraditionalForm], "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           FormBox[
            TagBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["r",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["q",
                    TraditionalForm]}], "+", 
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["r",
                    TraditionalForm]}]}], ")"}], "i"]}]}],
             HoldForm],
            TraditionalForm], ")"}], " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}],
            TraditionalForm], "2"], " ", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["r",
            TraditionalForm]}]}]}], ")"}]}]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm], 
         FormBox["\[CapitalDelta]",
          TraditionalForm]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}], " ", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["r",
            TraditionalForm]}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["p",
              TraditionalForm]}], ")"}], "m"]}], "+", 
         RowBox[{
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["r",
              TraditionalForm]}], ")"}], "m"], " ", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}], ")"}], "m"], " ", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["r",
            TraditionalForm]}], " ", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}]}]}], ")"}]}], 
      RowBox[{
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["r",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}]}]]}], ")"}], " ", 
   SubscriptBox["f", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1837]="]
}, Open  ]],

Cell["4-gluon legs", "Text",
 CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "\[Sigma]", ",", "d"}], "}"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1838]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"]}], ")"}], " ", 
   SubsuperscriptBox["g", "s", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["c222",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["c222",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["O", 
          RowBox[{
           FormBox[
            FormBox["\[Mu]",
             TraditionalForm],
            TraditionalForm], "\[VeryThinSpace]", 
           FormBox[
            FormBox["\[Nu]",
             TraditionalForm],
            TraditionalForm], "\[VeryThinSpace]", 
           FormBox[
            FormBox["\[Rho]",
             TraditionalForm],
            TraditionalForm], "\[VeryThinSpace]", 
           FormBox[
            FormBox["\[Sigma]",
             TraditionalForm],
            TraditionalForm]}], "G4"], "(", 
         FormBox["p",
          TraditionalForm], ",", 
         FormBox["q",
          TraditionalForm], ",", 
         FormBox["r",
          TraditionalForm], ",", 
         FormBox["s",
          TraditionalForm], ")"}], ")"}]}]}], "-", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c222",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c222",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["O", 
         RowBox[{
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Rho]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Sigma]",
            TraditionalForm],
           TraditionalForm]}], "G4"], "(", 
        FormBox["p",
         TraditionalForm], ",", 
        FormBox["r",
         TraditionalForm], ",", 
        FormBox["q",
         TraditionalForm], ",", 
        FormBox["s",
         TraditionalForm], ")"}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c222",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c222",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["O", 
         RowBox[{
          FormBox[
           FormBox["\[Rho]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Sigma]",
            TraditionalForm],
           TraditionalForm]}], "G4"], "(", 
        FormBox["r",
         TraditionalForm], ",", 
        FormBox["q",
         TraditionalForm], ",", 
        FormBox["p",
         TraditionalForm], ",", 
        FormBox["s",
         TraditionalForm], ")"}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1838]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Unpolarized case, non-zero-momentum insertion", "Subsubsection",
 CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetOptions", "[", 
  RowBox[{"Twist2GluonOperator", ",", " ", 
   RowBox[{"Polarization", " ", "\[Rule]", " ", "0"}], ",", 
   RowBox[{"ZeroMomentumInsertion", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1839]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Polarization", "\[Rule]", "0"}], ",", 
    RowBox[{"Explicit", "\[Rule]", "All"}], ",", 
    RowBox[{"ZeroMomentumInsertion", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1839]="]
}, Open  ]],

Cell["2-gluon legs", "Text",
 CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "q"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Nu]", ",", "b"}], "}"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1840]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], "+", "1"}], ")"}], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     FormBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["p",
          TraditionalForm]}], ")"}], 
       RowBox[{"m", "-", "2"}]],
      TraditionalForm], "+", 
     FormBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}], ")"}], 
       RowBox[{"m", "-", "2"}]],
      TraditionalForm]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"\[Mu]", "\[Nu]"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}]}], "-", 
        RowBox[{
         SuperscriptBox[
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]], " ", 
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1840]="]
}, Open  ]],

Cell["3-gluon legs", "Text",
 CellTags->"Twist2GluonOperator"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Twist2GluonOperator", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}]}], "]"}], ";"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1841]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]"}], "}"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1842]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], "+", "1"}], ")"}], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     FormBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["\[Mu]",
          TraditionalForm]}], ")"}], 
       RowBox[{"m", "-", "2"}]],
      TraditionalForm], "+", 
     FormBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["p",
          TraditionalForm]}], ")"}], 
       RowBox[{"m", "-", "2"}]],
      TraditionalForm]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["\[Mu]",
         TraditionalForm]}], " ", 
       SuperscriptBox["g", 
        RowBox[{"q", "r"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}]}]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["\[Mu]",
        TraditionalForm], 
       FormBox[
        FormBox["q",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["r",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["q",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["r",
            TraditionalForm],
           TraditionalForm]], " ", 
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], "\[CenterDot]", 
          FormBox["\[Mu]",
           TraditionalForm]}]}], "-", 
        RowBox[{
         SuperscriptBox[
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox[
           FormBox["r",
            TraditionalForm],
           TraditionalForm]], " ", 
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["\[Mu]",
           TraditionalForm]}]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1842]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]"}], "}"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1843]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], "+", "1"}], ")"}], " ", 
   SubscriptBox["\[Delta]", 
    RowBox[{
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Rho]",
       TraditionalForm],
      TraditionalForm]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     FormBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["\[Mu]",
          TraditionalForm]}], ")"}], 
       RowBox[{"m", "-", "2"}]],
      TraditionalForm], "+", 
     FormBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["p",
          TraditionalForm]}], ")"}], 
       RowBox[{"m", "-", "2"}]],
      TraditionalForm]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["\[Mu]",
         TraditionalForm]}], " ", 
       SuperscriptBox["g", 
        RowBox[{"q", "r"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}]}]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["\[Mu]",
        TraditionalForm], 
       FormBox[
        FormBox["q",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["r",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["\[CapitalDelta]",
        TraditionalForm], 
       FormBox[
        FormBox["q",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["r",
            TraditionalForm],
           TraditionalForm]], " ", 
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], "\[CenterDot]", 
          FormBox["\[Mu]",
           TraditionalForm]}]}], "-", 
        RowBox[{
         SuperscriptBox[
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox[
           FormBox["r",
            TraditionalForm],
           TraditionalForm]], " ", 
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["\[Mu]",
           TraditionalForm]}]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1843]="]
}, Open  ]],

Cell["4-gluon legs", "Text",
 CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "\[Sigma]", ",", "d"}], "}"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1844]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], "m"], "+", "1"}], ")"}], " ", 
   SubsuperscriptBox["g", "s", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["c223",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       SubscriptBox["f", 
        RowBox[{
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["c223",
           TraditionalForm],
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["O", 
          RowBox[{
           FormBox[
            FormBox["\[Mu]",
             TraditionalForm],
            TraditionalForm], "\[VeryThinSpace]", 
           FormBox[
            FormBox["\[Nu]",
             TraditionalForm],
            TraditionalForm], "\[VeryThinSpace]", 
           FormBox[
            FormBox["\[Rho]",
             TraditionalForm],
            TraditionalForm], "\[VeryThinSpace]", 
           FormBox[
            FormBox["\[Sigma]",
             TraditionalForm],
            TraditionalForm]}], "G4"], "(", 
         FormBox["p",
          TraditionalForm], ",", 
         FormBox["q",
          TraditionalForm], ",", 
         FormBox["r",
          TraditionalForm], ",", 
         FormBox["s",
          TraditionalForm], ")"}], ")"}]}]}], "-", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c223",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c223",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["O", 
         RowBox[{
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Rho]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Sigma]",
            TraditionalForm],
           TraditionalForm]}], "G4"], "(", 
        FormBox["p",
         TraditionalForm], ",", 
        FormBox["r",
         TraditionalForm], ",", 
        FormBox["q",
         TraditionalForm], ",", 
        FormBox["s",
         TraditionalForm], ")"}], ")"}]}], "+", 
     RowBox[{
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c223",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      SubscriptBox["f", 
       RowBox[{
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["c223",
          TraditionalForm],
         TraditionalForm]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["O", 
         RowBox[{
          FormBox[
           FormBox["\[Rho]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm], "\[VeryThinSpace]", 
          FormBox[
           FormBox["\[Sigma]",
            TraditionalForm],
           TraditionalForm]}], "G4"], "(", 
        FormBox["r",
         TraditionalForm], ",", 
        FormBox["q",
         TraditionalForm], ",", 
        FormBox["p",
         TraditionalForm], ",", 
        FormBox["s",
         TraditionalForm], ")"}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1844]="]
}, Open  ]],

Cell["Suppress the lengthy output.", "Text",
 CellTags->"Twist2GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{"Twist2GluonOperator", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p", ",", "\[Mu]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"q", ",", "\[Nu]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "\[Rho]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "\[Sigma]"}], "}"}], ",", 
     RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}], ",", "6"}], 
  "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1845]:="],

Cell[BoxData[
 FormBox[
  TagBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"\[Nu]", "\[Sigma]"}]], " ", 
        SuperscriptBox[
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"\[Mu]", "\[Sigma]"}]], " ", 
        SuperscriptBox[
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox[
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
        SuperscriptBox[
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["\[Sigma]",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"\[Mu]", "\[Rho]"}]], " ", 
        SuperscriptBox[
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["\[Sigma]",
           TraditionalForm],
          TraditionalForm]]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["r",
          TraditionalForm]}], "+", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["s",
          TraditionalForm]}]}], ")"}], 
      RowBox[{"m", "-", "2"}]]}], "+", 
    RowBox[{"\[LeftSkeleton]", "8", "\[RightSkeleton]"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FormBox[
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "0"}], 
          RowBox[{
           RowBox[{"-", "4"}], "+", "m"}]], "\<\"\"\>"}],
        TraditionalForm], 
       FormBox[
        RowBox[{"\<\"\"\>", " ", 
         RowBox[{"(", 
          RowBox[{"j", "+", "1"}], ")"}]}],
        TraditionalForm], 
       FormBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q",
             TraditionalForm]}], ")"}], 
          RowBox[{
           RowBox[{"-", "j"}], "+", "m", "-", "4"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["r",
               TraditionalForm]}], ")"}]}], ")"}], "i"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["r",
                TraditionalForm]}], ")"}]}], "-", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["s",
              TraditionalForm]}]}], ")"}], 
          RowBox[{"j", "-", "i"}]]}],
        TraditionalForm]}], ")"}], " ", 
     SuperscriptBox[
      FormBox["\[CapitalDelta]",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["\[CapitalDelta]",
       TraditionalForm], 
      FormBox[
       FormBox["\[Sigma]",
        TraditionalForm],
       TraditionalForm]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          FormBox["r",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]]}], " ", 
        SuperscriptBox[
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"\[Nu]", "\[Rho]"}]], " ", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["r",
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}], "-", 
       RowBox[{
        SuperscriptBox[
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["r",
          TraditionalForm]}]}], "+", 
       RowBox[{
        SuperscriptBox[
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["\[Rho]",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox["r",
          TraditionalForm]}]}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FormBox[
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "0"}], 
          RowBox[{
           RowBox[{"-", "4"}], "+", "m"}]], "\<\"\"\>"}],
        TraditionalForm], 
       FormBox[
        RowBox[{"\<\"\"\>", " ", 
         RowBox[{"(", 
          RowBox[{"j", "+", "1"}], ")"}]}],
        TraditionalForm], 
       FormBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q",
             TraditionalForm]}], ")"}], 
          RowBox[{
           RowBox[{"-", "j"}], "+", "m", "-", "4"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["r",
                TraditionalForm]}], ")"}]}], "-", 
            RowBox[{
             FormBox["\[CapitalDelta]",
              TraditionalForm], "\[CenterDot]", 
             FormBox["s",
              TraditionalForm]}]}], ")"}], 
          RowBox[{"j", "-", "i"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["s",
               TraditionalForm]}], ")"}]}], ")"}], "i"]}],
        TraditionalForm]}], ")"}], " ", 
     SuperscriptBox[
      FormBox["\[CapitalDelta]",
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["\[CapitalDelta]",
       TraditionalForm], 
      FormBox[
       FormBox["\[Rho]",
        TraditionalForm],
       TraditionalForm]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          FormBox["s",
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm]]}], " ", 
        SuperscriptBox[
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["\[Sigma]",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"\[Nu]", "\[Sigma]"}]], " ", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["s",
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}], "-", 
       RowBox[{
        SuperscriptBox[
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["\[Sigma]",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["s",
          TraditionalForm]}]}], "+", 
       RowBox[{
        SuperscriptBox[
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["\[CapitalDelta]",
          TraditionalForm], 
         FormBox[
          FormBox["\[Sigma]",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox["s",
          TraditionalForm]}]}]}], ")"}]}]}],
   Short[#, 6]& ], TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1845]//Short="]
}, Open  ]],

Cell["\<\
The setting Explicit \[Rule] All performs the sums.\
\>", "Text",
 CellTags->"Twist2GluonOperator"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Twist2GluonOperator", ",", " ", 
    RowBox[{"Polarization", " ", "\[Rule]", " ", "1"}], ",", " ", 
    RowBox[{"Explicit", "\[Rule]", "All"}]}], "]"}], ";"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1846]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{"Twist2GluonOperator", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"p", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"q", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "\[Rho]", ",", "c"}], "}"}]}], "]"}], ",", "5"}], 
  "]"}]], "Input",
 CellTags->"Twist2GluonOperator",
 CellLabel->"In[1847]:="],

Cell[BoxData[
 FormBox[
  TagBox[
   RowBox[{
    SubscriptBox["g", "s"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Epsilon]", 
         RowBox[{
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["\[Rho]",
            TraditionalForm],
           TraditionalForm], 
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox["p",
           TraditionalForm]}]]}], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], "\[CenterDot]", 
          FormBox["p",
           TraditionalForm]}], ")"}], 
        RowBox[{"m", "-", "2"}]]}], "+", 
      RowBox[{"\[LeftSkeleton]", "20", "\[RightSkeleton]"}], "+", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q",
             TraditionalForm]}], "+", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["r",
             TraditionalForm]}]}], ")"}], "2"]], 
       RowBox[{
        SuperscriptBox["\[Epsilon]", 
         RowBox[{
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["\[Rho]",
            TraditionalForm],
           TraditionalForm], 
          FormBox["\[CapitalDelta]",
           TraditionalForm], 
          FormBox["p",
           TraditionalForm]}]], " ", 
        RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], "+", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["r",
               TraditionalForm]}]}], ")"}], "m"], "+", 
          RowBox[{
           RowBox[{"(", 
            FormBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["r",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["q",
                    TraditionalForm]}], "+", 
                  RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}], 
                 ")"}], "i"]}]}],
             TraditionalForm], ")"}], " ", 
           SuperscriptBox[
            FormBox[
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["r",
               TraditionalForm]}],
             TraditionalForm], "3"]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            FormBox[
             RowBox[{
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}],
             TraditionalForm], ")"}], " ", 
           RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], " ", 
           SuperscriptBox[
            FormBox[
             RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
             TraditionalForm], "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            FormBox[
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "0"}], 
               RowBox[{
                RowBox[{"-", "3"}], "+", "m"}]], 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  FormBox["\[CapitalDelta]",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox["r",
                   TraditionalForm]}], ")"}], 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "i", "+", "m"}]], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["q",
                    TraditionalForm]}], "+", 
                  RowBox[{
                   FormBox["\[CapitalDelta]",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["r",
                    TraditionalForm]}]}], ")"}], "i"]}]}],
             TraditionalForm], ")"}], " ", 
           SuperscriptBox[
            FormBox[
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}],
             TraditionalForm], "2"], " ", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["r",
             TraditionalForm]}]}]}], ")"}]}]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[Epsilon]", 
         RowBox[{
          FormBox[
           FormBox["\[Mu]",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["\[Rho]",
            TraditionalForm],
           TraditionalForm], 
          FormBox["\[CapitalDelta]",
           TraditionalForm]}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q",
             TraditionalForm]}], " ", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["r",
             TraditionalForm]}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["p",
               TraditionalForm]}], ")"}], "m"]}], "+", 
          RowBox[{
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q",
             TraditionalForm]}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["r",
               TraditionalForm]}], ")"}], "m"], " ", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["p",
             TraditionalForm]}]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], ")"}], "m"], " ", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["r",
             TraditionalForm]}], " ", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["p",
             TraditionalForm]}]}]}], ")"}]}], 
       RowBox[{
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["r",
          TraditionalForm]}], " ", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["p",
          TraditionalForm]}]}]]}], ")"}], " ", 
    SubscriptBox["f", 
     RowBox[{
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]}]]}],
   Short[#, 5]& ], TraditionalForm]], "Output",
 CellTags->"Twist2GluonOperator",
 CellLabel->"Out[1847]//Short="]
}, Open  ]]
}, Open  ]],

Cell["Twist2QuarkOperator", "ObjectName",
 CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Twist2QuarkOperator"],

Cell["\<\
Twist2QuarkOperator[p] or Twist2QuarkOperator[p,_,_] yields the \
quark-antiquark operator (p is momentum in the direction of the incoming \
quark). Twist2QuarkOperator[{p,q}] yields the 2-quark operator for non-zero \
momentum insertion (p is momentum in the direction of the incoming quark). \
Twist2QuarkOperator[{p1,___}, {p2,___}, {p3, mu, a}] or \
Twist2QuarkOperator[p1,_,_, p2,_,_, p3,mu,a] is the quark-antiquark-gluon \
operator, where p1 is the incoming quark, p2 the incoming antiquark and p3 \
denotes the incoming gluon momentum. Twist2QuarkOperator[{p1}, {p2}, {p3, mu, \
a}, {p4, nu, b}] or Twist2QuarkOperator[{p1,___}, {p2,___}, {p3, mu, a}, {p4, \
nu, b}] or Twist2QuarkOperator[p1,_,_, p2,_,_, p3,mu,a, p4, nu, b] gives the \
Quark-Quark-Gluon-Gluon-operator. The setting of the option Polarization \
(unpolarized: 0; polarized: 1) determines whether the unpolarized or \
polarized operator is returned\
\>", "Text",
 CellTags->"Twist2QuarkOperator"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Twist2GluonOperator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Twist2GluonOperator",
  ButtonNote->"Twist2GluonOperator"],
 "."
}], "Text",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]],

Cell["Examples", "Subsubsection",
 CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell["Polarized case, zero-momentum insertion", "Subsubsection",
 CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetOptions", "[", 
  RowBox[{"Twist2QuarkOperator", ",", 
   RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
   RowBox[{"ZeroMomentumInsertion", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"In[1848]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Explicit", "\[Rule]", "True"}], ",", 
    RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
    RowBox[{"ZeroMomentumInsertion", "\[Rule]", "True"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"Out[1848]="]
}, Open  ]],

Cell["Quark-antiquark operator.", "Text",
 CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{"Twist2QuarkOperator", "[", "p", "]"}]}]], "Input",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"In[1849]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FormBox["\<\"\[Gamma]\"\>",
        TraditionalForm], "\[CenterDot]", 
       FormBox["\[CapitalDelta]",
        TraditionalForm]}], ")"}], ".", 
     SuperscriptBox["\[Gamma]", "5"]}]}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FormBox["\[CapitalDelta]",
       TraditionalForm], "\[CenterDot]", 
      FormBox["p",
       TraditionalForm]}], ")"}], 
    RowBox[{"m", "-", "1"}]]}], TraditionalForm]], "Output",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"Out[1849]="]
}, Open  ]],

Cell["Quark-antiquark-gluon operator.", "Text",
 CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", "=", 
  RowBox[{"Twist2QuarkOperator", "[", 
   RowBox[{
    RowBox[{"{", "p", "}"}], ",", 
    RowBox[{"{", "q", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "\[Mu]", ",", "a"}], "}"}]}], "]"}]}]], "Input",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"In[1850]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["\[CapitalDelta]",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], " ", 
   RowBox[{"(", 
    RowBox[{"-", 
     SubscriptBox["g", "s"]}], ")"}], " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], ")"}], ".", 
    SuperscriptBox["\[Gamma]", "5"], ".", 
    SubscriptBox["T", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]]}], " ", 
   RowBox[{"(", 
    FormBox[
     TagBox[
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "0"}], 
        RowBox[{
         RowBox[{"-", "2"}], "+", "m"}]], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "i"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], ")"}], 
         RowBox[{
          RowBox[{"-", "2"}], "-", "i", "+", "m"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}], ")"}], "i"]}]}],
      HoldForm],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"Out[1850]="]
}, Open  ]],

Cell["Quark-antiquark-gluon-gluon operator.", "Text",
 CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t3", "=", 
  RowBox[{"Twist2QuarkOperator", "[", 
   RowBox[{
    RowBox[{"{", "p", "}"}], ",", 
    RowBox[{"{", "q", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Nu]", ",", "b"}], "}"}]}], "]"}]}]], "Input",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"In[1851]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["\[CapitalDelta]",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox[
    FormBox["\[CapitalDelta]",
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]], " ", 
   RowBox[{"(", 
    RowBox[{"-", 
     SubsuperscriptBox["g", "s", "2"]}], ")"}], " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], ")"}], ".", 
    SuperscriptBox["\[Gamma]", "5"], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["T", 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]]}], " ", 
       RowBox[{"(", 
        RowBox[{
         FormBox[
          TagBox[
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"j", "=", "0"}], 
             RowBox[{
              RowBox[{"-", "3"}], "+", "m"}]], "\<\"\"\>"}],
           HoldForm],
          TraditionalForm], 
         FormBox[
          RowBox[{"\<\"\"\>", " ", 
           RowBox[{"(", 
            RowBox[{"j", "+", "1"}], ")"}]}],
          TraditionalForm], 
         FormBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "j"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["p",
               TraditionalForm]}], ")"}], "i"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], ")"}], 
            RowBox[{
             RowBox[{"-", "j"}], "+", "m", "-", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["p",
                TraditionalForm]}], "+", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["r",
                TraditionalForm]}]}], ")"}], 
            RowBox[{"j", "-", "i"}]]}],
          TraditionalForm]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "m"], " ", 
       RowBox[{
        SubscriptBox["T", 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], " ", 
       RowBox[{"(", 
        RowBox[{
         FormBox[
          TagBox[
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"j", "=", "0"}], 
             RowBox[{
              RowBox[{"-", "3"}], "+", "m"}]], "\<\"\"\>"}],
           HoldForm],
          TraditionalForm], 
         FormBox[
          RowBox[{"\<\"\"\>", " ", 
           RowBox[{"(", 
            RowBox[{"j", "+", "1"}], ")"}]}],
          TraditionalForm], 
         FormBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "j"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], ")"}], "i"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["p",
               TraditionalForm]}], ")"}], 
            RowBox[{
             RowBox[{"-", "j"}], "+", "m", "-", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["q",
                TraditionalForm]}], "+", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["r",
                TraditionalForm]}]}], ")"}], 
            RowBox[{"j", "-", "i"}]]}],
          TraditionalForm]}], ")"}]}]}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"Out[1851]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Unpolarized case, zero-momentum insertion", "Subsubsection",
 CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetOptions", "[", 
  RowBox[{"Twist2QuarkOperator", ",", " ", 
   RowBox[{"Polarization", "\[Rule]", "0"}], ",", 
   RowBox[{"ZeroMomentumInsertion", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"In[1852]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Explicit", "\[Rule]", "True"}], ",", 
    RowBox[{"Polarization", "\[Rule]", "0"}], ",", 
    RowBox[{"ZeroMomentumInsertion", "\[Rule]", "True"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"Out[1852]="]
}, Open  ]],

Cell["Quark-antiquark operator.", "Text",
 CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t4", "=", 
  RowBox[{"Twist2QuarkOperator", "[", "p", "]"}]}]], "Input",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"In[1853]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FormBox["\<\"\[Gamma]\"\>",
     TraditionalForm], "\[CenterDot]", 
    FormBox["\[CapitalDelta]",
     TraditionalForm]}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FormBox["\[CapitalDelta]",
       TraditionalForm], "\[CenterDot]", 
      FormBox["p",
       TraditionalForm]}], ")"}], 
    RowBox[{"m", "-", "1"}]]}], TraditionalForm]], "Output",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"Out[1853]="]
}, Open  ]],

Cell["Quark-antiquark-gluon operator.", "Text",
 CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t5", "=", 
  RowBox[{"Twist2QuarkOperator", "[", 
   RowBox[{
    RowBox[{"{", "p", "}"}], ",", 
    RowBox[{"{", "q", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "\[Mu]", ",", "a"}], "}"}]}], "]"}]}]], "Input",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"In[1854]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["\[CapitalDelta]",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubscriptBox["g", "s"], " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], ")"}], ".", 
    SubscriptBox["T", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]]}], " ", 
   RowBox[{"(", 
    FormBox[
     TagBox[
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "0"}], 
        RowBox[{
         RowBox[{"-", "2"}], "+", "m"}]], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "i"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["p",
            TraditionalForm]}], ")"}], 
         RowBox[{
          RowBox[{"-", "2"}], "-", "i", "+", "m"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           FormBox["\[CapitalDelta]",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}], ")"}], "i"]}]}],
      HoldForm],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"Out[1854]="]
}, Open  ]],

Cell["Quark-antiquark-gluon-gluon operator.", "Text",
 CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t6", "=", 
  RowBox[{"Twist2QuarkOperator", "[", 
   RowBox[{
    RowBox[{"{", "p", "}"}], ",", 
    RowBox[{"{", "q", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "\[Nu]", ",", "b"}], "}"}]}], "]"}]}]], "Input",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"In[1855]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "m"]}], " ", 
   SuperscriptBox[
    FormBox["\[CapitalDelta]",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox[
    FormBox["\[CapitalDelta]",
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["g", "s", "2"], " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["T", 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], " ", 
       RowBox[{"(", 
        RowBox[{
         FormBox[
          TagBox[
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"i", "=", "0"}], 
             RowBox[{
              RowBox[{"-", "3"}], "+", "m"}]], "\<\"\"\>"}],
           HoldForm],
          TraditionalForm], 
         FormBox[
          RowBox[{"\<\"\"\>", " ", 
           RowBox[{"(", 
            RowBox[{"i", "+", "1"}], ")"}]}],
          TraditionalForm], 
         FormBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], ")"}], "j"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                FormBox["\[CapitalDelta]",
                 TraditionalForm], "\[CenterDot]", 
                FormBox["p",
                 TraditionalForm]}], ")"}]}], ")"}], 
            RowBox[{
             RowBox[{"-", "i"}], "+", "m", "-", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FormBox["k",
                TraditionalForm], "\[CenterDot]", 
               FormBox["\[CapitalDelta]",
                TraditionalForm]}], "+", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["q",
                TraditionalForm]}]}], ")"}], 
            RowBox[{"i", "-", "j"}]]}],
          TraditionalForm]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SubscriptBox["T", 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]]}], " ", 
       RowBox[{"(", 
        RowBox[{
         FormBox[
          TagBox[
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"i", "=", "0"}], 
             RowBox[{
              RowBox[{"-", "3"}], "+", "m"}]], "\<\"\"\>"}],
           HoldForm],
          TraditionalForm], 
         FormBox[
          RowBox[{"\<\"\"\>", " ", 
           RowBox[{"(", 
            RowBox[{"i", "+", "1"}], ")"}]}],
          TraditionalForm], 
         FormBox[
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], ")"}], "j"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                FormBox["\[CapitalDelta]",
                 TraditionalForm], "\[CenterDot]", 
                FormBox["p",
                 TraditionalForm]}], ")"}]}], ")"}], 
            RowBox[{
             RowBox[{"-", "i"}], "+", "m", "-", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["q",
                TraditionalForm]}], "+", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["r",
                TraditionalForm]}]}], ")"}], 
            RowBox[{"i", "-", "j"}]]}],
          TraditionalForm]}], ")"}]}]}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"Out[1855]="]
}, Open  ]],

Cell["This shows the FeynCalcExternal (FCE) form.", "Text",
 CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Twist2QuarkOperator", "[", "p", "]"}], "//", "FCE"}], "//", 
  "StandardForm"}]], "Input",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"In[1856]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"GSD", "[", "OPEDelta", "]"}], " ", 
  SuperscriptBox[
   RowBox[{"SOD", "[", "p", "]"}], 
   RowBox[{
    RowBox[{"-", "1"}], "+", "OPEm"}]]}]], "Output",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"Out[1856]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2QuarkOperator", "[", 
  RowBox[{
   RowBox[{"{", "p", "}"}], ",", 
   RowBox[{"{", "q", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "All"}], ",", 
   RowBox[{"Polarization", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"In[1857]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["\[CapitalDelta]",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], " ", 
   RowBox[{"(", 
    RowBox[{"-", 
     SubscriptBox["g", "s"]}], ")"}], " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], ")"}], ".", 
    SubscriptBox["T", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]]}], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FormBox["\[CapitalDelta]",
          TraditionalForm], "\[CenterDot]", 
         FormBox["p",
          TraditionalForm]}], ")"}], 
       RowBox[{"m", "-", "1"}]], 
      RowBox[{
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}], "+", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "m"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          FormBox["\[CapitalDelta]",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}], ")"}], 
        RowBox[{"m", "-", "1"}]]}], 
      RowBox[{
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p",
         TraditionalForm]}], "+", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]]}], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"Out[1857]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist2QuarkOperator", "[", 
  RowBox[{
   RowBox[{"{", "p", "}"}], ",", 
   RowBox[{"{", "q", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "\[Mu]", ",", "a"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "\[Nu]", ",", "b"}], "}"}], ",", 
   RowBox[{"Explicit", "\[Rule]", "All"}], ",", 
   RowBox[{"Polarization", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"In[1858]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"-", "1"}], ")"}], "m"],
    TraditionalForm], " ", 
   SuperscriptBox[
    FormBox["\[CapitalDelta]",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox[
    FormBox["\[CapitalDelta]",
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]], " ", 
   RowBox[{"(", 
    RowBox[{"-", 
     SubsuperscriptBox["g", "s", "2"]}], ")"}], " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["T", 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           FormBox[
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{"m", "-", "1"}]],
            TraditionalForm], " ", 
           FormBox[
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["p",
                TraditionalForm]}], ")"}], 
             RowBox[{"m", "-", "1"}]],
            TraditionalForm]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["p",
               TraditionalForm]}], "+", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FormBox["k",
               TraditionalForm], "\[CenterDot]", 
              FormBox["\[CapitalDelta]",
               TraditionalForm]}], "+", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["p",
               TraditionalForm]}], "+", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}]}], ")"}]}]], "-", 
         FractionBox[
          FormBox[
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], ")"}], 
            RowBox[{"m", "-", "1"}]],
           TraditionalForm], 
          RowBox[{
           RowBox[{
            FormBox["k",
             TraditionalForm], "\[CenterDot]", 
            FormBox["\[CapitalDelta]",
             TraditionalForm]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["p",
               TraditionalForm]}], "+", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}]}], ")"}]}]], "+", 
         FractionBox[
          FormBox[
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FormBox["k",
                TraditionalForm], "\[CenterDot]", 
               FormBox["\[CapitalDelta]",
                TraditionalForm]}], "+", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["q",
                TraditionalForm]}]}], ")"}], 
            RowBox[{"m", "-", "1"}]],
           TraditionalForm], 
          RowBox[{
           RowBox[{
            FormBox["k",
             TraditionalForm], "\[CenterDot]", 
            FormBox["\[CapitalDelta]",
             TraditionalForm]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FormBox["k",
               TraditionalForm], "\[CenterDot]", 
              FormBox["\[CapitalDelta]",
               TraditionalForm]}], "+", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["p",
               TraditionalForm]}], "+", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}]}], ")"}]}]]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SubscriptBox["T", 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], ".", 
        SubscriptBox["T", 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]]}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           FormBox[
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"-", "1"}], ")"}], 
             RowBox[{"m", "-", "1"}]],
            TraditionalForm], " ", 
           FormBox[
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["p",
                TraditionalForm]}], ")"}], 
             RowBox[{"m", "-", "1"}]],
            TraditionalForm]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["p",
               TraditionalForm]}], "+", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["p",
               TraditionalForm]}], "+", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], "+", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["r",
               TraditionalForm]}]}], ")"}]}]], "-", 
         FractionBox[
          FormBox[
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], ")"}], 
            RowBox[{"m", "-", "1"}]],
           TraditionalForm], 
          RowBox[{
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["r",
             TraditionalForm]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["p",
               TraditionalForm]}], "+", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}]}], ")"}]}]], "+", 
         FractionBox[
          FormBox[
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["q",
                TraditionalForm]}], "+", 
              RowBox[{
               FormBox["\[CapitalDelta]",
                TraditionalForm], "\[CenterDot]", 
               FormBox["r",
                TraditionalForm]}]}], ")"}], 
            RowBox[{"m", "-", "1"}]],
           TraditionalForm], 
          RowBox[{
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["r",
             TraditionalForm]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["p",
               TraditionalForm]}], "+", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], "+", 
             RowBox[{
              FormBox["\[CapitalDelta]",
               TraditionalForm], "\[CenterDot]", 
              FormBox["r",
               TraditionalForm]}]}], ")"}]}]]}], ")"}]}]}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"Out[1858]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Polarized case, non-zero momentum insertion", "Subsubsection",
 CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetOptions", "[", 
  RowBox[{"Twist2QuarkOperator", ",", 
   RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
   RowBox[{"ZeroMomentumInsertion", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"In[1859]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Explicit", "\[Rule]", "True"}], ",", 
    RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
    RowBox[{"ZeroMomentumInsertion", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"Out[1859]="]
}, Open  ]],

Cell["\<\
With the setting ZeroMomentumInsertion \[Rule] False a non-zero momentum is \
assumed to flow into the operator vertex. \
\>", "Text",
 CellTags->"Twist2QuarkOperator"],

Cell["\<\
This is the Feynman rule associated with the quark-antiquark operator, where \
p is the momentum of the incoming quark and q the momentum of the antiquark. \
The momentum flowing into the operator vertex is thus -p-q.\
\>", "Text",
 CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", "=", 
  RowBox[{"Twist2QuarkOperator", "[", 
   RowBox[{"{", 
    RowBox[{"p", ",", "q"}], "}"}], "]"}]}]], "Input",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"In[1860]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["2", 
    RowBox[{"1", "-", "m"}]], " ", 
   RowBox[{
    SuperscriptBox["\[Gamma]", "5"], ".", 
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], ")"}]}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}], "-", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}]}], ")"}], 
    RowBox[{"m", "-", "1"}]]}], TraditionalForm]], "Output",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"Out[1860]="]
}, Open  ]],

Cell["This is the quark-antiquark-gluon operator vertex.", "Text",
 CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", "=", 
  RowBox[{"Twist2QuarkOperator", "[", 
   RowBox[{
    RowBox[{"{", "p", "}"}], ",", 
    RowBox[{"{", "q", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "\[Mu]", ",", "a"}], "}"}]}], "]"}]}]], "Input",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"In[1861]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["2", 
    RowBox[{"2", "-", "m"}]], " ", 
   SuperscriptBox[
    FormBox["\[CapitalDelta]",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubscriptBox["g", "s"], " ", 
   RowBox[{
    SubscriptBox["T", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], ".", 
    SuperscriptBox["\[Gamma]", "5"], ".", 
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], ")"}]}], " ", 
   RowBox[{"(", 
    FormBox[
     TagBox[
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "0"}], 
        RowBox[{
         RowBox[{"-", "2"}], "+", "m"}]], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["k",
               TraditionalForm], "\[CenterDot]", 
              FormBox["\[CapitalDelta]",
               TraditionalForm]}], ")"}]}], "+", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["p",
             TraditionalForm]}], "-", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q",
             TraditionalForm]}]}], ")"}], 
         RowBox[{
          RowBox[{"-", "2"}], "-", "i", "+", "m"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FormBox["k",
             TraditionalForm], "\[CenterDot]", 
            FormBox["\[CapitalDelta]",
             TraditionalForm]}], "+", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["p",
             TraditionalForm]}], "-", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q",
             TraditionalForm]}]}], ")"}], "i"]}]}],
      HoldForm],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"Out[1861]="]
}, Open  ]],

Cell["This shows the FeynCalcExternal form.", "Text",
 CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardForm", "[", 
  RowBox[{"FCE", "[", "t2", "]"}], "]"}]], "Input",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"In[1862]:="],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["2", 
   RowBox[{"2", "-", "OPEm"}]], " ", "Gstrong", " ", 
  RowBox[{
   RowBox[{"SUNT", "[", "a", "]"}], ".", 
   RowBox[{"GA", "[", "5", "]"}], ".", 
   RowBox[{"GSD", "[", "OPEDelta", "]"}]}], " ", 
  RowBox[{"FVD", "[", 
   RowBox[{"OPEDelta", ",", "\[Mu]"}], "]"}], " ", 
  RowBox[{"OPESum", "[", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"SOD", "[", "k", "]"}]}], "+", 
        RowBox[{"SOD", "[", "p", "]"}], "-", 
        RowBox[{"SOD", "[", "q", "]"}]}], ")"}], 
      RowBox[{
       RowBox[{"-", "2"}], "-", "OPEi", "+", "OPEm"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"SOD", "[", "k", "]"}], "+", 
        RowBox[{"SOD", "[", "p", "]"}], "-", 
        RowBox[{"SOD", "[", "q", "]"}]}], ")"}], "OPEi"]}], ",", 
    RowBox[{"{", 
     RowBox[{"OPEi", ",", "0", ",", 
      RowBox[{
       RowBox[{"-", "2"}], "+", "OPEm"}]}], "}"}]}], "]"}]}]], "Output",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"Out[1862]//StandardForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Unpolarized case, non-zero momentum insertion", "Subsubsection",
 CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetOptions", "[", 
  RowBox[{"Twist2QuarkOperator", ",", 
   RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
   RowBox[{"ZeroMomentumInsertion", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"In[1863]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Explicit", "\[Rule]", "True"}], ",", 
    RowBox[{"Polarization", "\[Rule]", "1"}], ",", 
    RowBox[{"ZeroMomentumInsertion", "\[Rule]", "False"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"Out[1863]="]
}, Open  ]],

Cell["Quark-antiquark operator.", "Text",
 CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t4", "=", 
  RowBox[{"Twist2QuarkOperator", "[", 
   RowBox[{"{", 
    RowBox[{"p", ",", "q"}], "}"}], "]"}]}]], "Input",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"In[1864]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["2", 
    RowBox[{"1", "-", "m"}]], " ", 
   RowBox[{
    SuperscriptBox["\[Gamma]", "5"], ".", 
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], ")"}]}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["p",
        TraditionalForm]}], "-", 
      RowBox[{
       FormBox["\[CapitalDelta]",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}]}], ")"}], 
    RowBox[{"m", "-", "1"}]]}], TraditionalForm]], "Output",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"Out[1864]="]
}, Open  ]],

Cell["Quark-antiquark-gluon operator.", "Text",
 CellTags->"Twist2QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t5", "=", 
  RowBox[{"Twist2QuarkOperator", "[", 
   RowBox[{
    RowBox[{"{", "p", "}"}], ",", 
    RowBox[{"{", "q", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "\[Mu]", ",", "a"}], "}"}]}], "]"}]}]], "Input",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"In[1865]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["2", 
    RowBox[{"2", "-", "m"}]], " ", 
   SuperscriptBox[
    FormBox["\[CapitalDelta]",
     TraditionalForm], 
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubscriptBox["g", "s"], " ", 
   RowBox[{
    SubscriptBox["T", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], ".", 
    SuperscriptBox["\[Gamma]", "5"], ".", 
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], ")"}]}], " ", 
   RowBox[{"(", 
    FormBox[
     TagBox[
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "0"}], 
        RowBox[{
         RowBox[{"-", "2"}], "+", "m"}]], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              FormBox["k",
               TraditionalForm], "\[CenterDot]", 
              FormBox["\[CapitalDelta]",
               TraditionalForm]}], ")"}]}], "+", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["p",
             TraditionalForm]}], "-", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q",
             TraditionalForm]}]}], ")"}], 
         RowBox[{
          RowBox[{"-", "2"}], "-", "i", "+", "m"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            FormBox["k",
             TraditionalForm], "\[CenterDot]", 
            FormBox["\[CapitalDelta]",
             TraditionalForm]}], "+", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["p",
             TraditionalForm]}], "-", 
           RowBox[{
            FormBox["\[CapitalDelta]",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q",
             TraditionalForm]}]}], ")"}], "i"]}]}],
      HoldForm],
     TraditionalForm], ")"}]}], TraditionalForm]], "Output",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"Out[1865]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5", ",", "t6"}], 
   "]"}], ";"}]], "Input",
 CellTags->"Twist2QuarkOperator",
 CellLabel->"In[1866]:="]
}, Open  ]],

Cell["Twist3QuarkOperator", "ObjectName",
 CellTags->"Twist3QuarkOperator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Twist3QuarkOperator"],

Cell["\<\
Twist3QuarkOperator[p] or  Twist3QuarkOperator[p,_,_]  yields the  2-quark \
operator (p is momentum in the direction of the fermion number flow). \
Twist3QuarkOperator[{p1,___}, {p2,___}, {p3, mu, a}] or \
Twist3QuarkOperator[p1,_,_,  p2,_,_,  p3,mu,a] Quark-Quark-Gluon-operator, \
where p1 is the incoming quark, p2 the incoming antiquark and p3 denotes the \
(incoming) gluon momentum.  Twist3QuarkOperator[{p1,___}, {p2,___}, {p3, mu, \
a}, {p4, nu, b}] or Twist3QuarkOperator[p1,_,_,  p2,_,_,  p3,mu,a, p4, nu, b] \
 gives the Quark-Quark-Gluon-Gluon-operator. The setting of the option \
Polarization (unpolarized: 0; polarized: 1) determines whether the \
uppolarized or polarized operator is returned.\
\>", "Text",
 CellTags->"Twist3QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist3QuarkOperator", "//", "Options"}]], "Input",
 CellTags->"Twist3QuarkOperator",
 CellLabel->"In[1867]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"CouplingConstant", "\[Rule]", 
     SubscriptBox["g", "s"]}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Polarization", "\[Rule]", "1"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Twist3QuarkOperator",
 CellLabel->"Out[1867]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Twist2QuarkOperator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Twist2QuarkOperator",
  ButtonNote->"Twist2QuarkOperator"],
 ", ",
 ButtonBox["Twist2GluonOperator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Twist2GluonOperator",
  ButtonNote->"Twist2GluonOperator"],
 "."
}], "Text",
 CellTags->"Twist3QuarkOperator"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Twist3QuarkOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist3QuarkOperator", "[", "p", "]"}]], "Input",
 CellTags->"Twist3QuarkOperator",
 CellLabel->"In[1868]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "m"], " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FormBox["\<\"\[Gamma]\"\>",
       TraditionalForm], "\[CenterDot]", 
      FormBox["\[CapitalDelta]",
       TraditionalForm]}], ")"}], ".", 
    SuperscriptBox["\[Gamma]", "5"]}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      FormBox["\[CapitalDelta]",
       TraditionalForm], "\[CenterDot]", 
      FormBox["p",
       TraditionalForm]}], ")"}], 
    RowBox[{"m", "-", "1"}]]}], TraditionalForm]], "Output",
 CellTags->"Twist3QuarkOperator",
 CellLabel->"Out[1868]="]
}, Open  ]]
}, Open  ]],

Cell["Twist4GluonOperator", "ObjectName",
 CellTags->"Twist4GluonOperator"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Twist4GluonOperator"],

Cell["\<\
Twist4GluonOperator[{oa, ob, oc, od}, {p1,la1,a1}, {p2,la2,a2}, {p3,la3,a3}, \
{p4,la4,a4}].\
\>", "Text",
 CellTags->"Twist4GluonOperator"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Twist2QuarkOperator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Twist2QuarkOperator",
  ButtonNote->"Twist2QuarkOperator"],
 ", ",
 ButtonBox["Twist3QuarkOperator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Twist3QuarkOperator",
  ButtonNote->"Twist3QuarkOperator"],
 ", ",
 ButtonBox["Twist2GluonOperator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Twist2GluonOperator",
  ButtonNote->"Twist2GluonOperator"],
 "."
}], "Text",
 CellTags->"Twist4GluonOperator"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Twist4GluonOperator"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Twist4GluonOperator", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"oa", ",", " ", "ob", ",", " ", "oc", ",", " ", "od"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"p1", ",", "la1", ",", "a1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"p2", ",", "la2", ",", "a2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"p3", ",", "la3", ",", "a3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"p4", ",", "la4", ",", "a4"}], "}"}]}], "]"}]], "Input",
 CellTags->"Twist4GluonOperator",
 CellLabel->"In[1869]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la2"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la3", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p3",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la2"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la3", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p3",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la3"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la2", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p2",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la3"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la2", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p2",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la2", "la3"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p2",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la2", "la3"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p2",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la2"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la3", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p3",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la2"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la3", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p3",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la2", "la3"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p2",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la2", "la3"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p2",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la3"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la2", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p2",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la3"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la2", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p2",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la3"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la2", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p2",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la3"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la2", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p2",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la2", "la3"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p2",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la2", "la3"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p2",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la2"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la3", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p3",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la2"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la3", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p3",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la2", "la3"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p2",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la2", "la3"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p2",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la3"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la2", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p2",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la3"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la2", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p2",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la2"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la3", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p3",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p2",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la1", "la2"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p1",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p1",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la1",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p1",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p2",
         TraditionalForm]}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p4",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"la3", "la4"}]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p3",
         TraditionalForm]}]}], "+", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p3",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["\[CapitalDelta]",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la3",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["\[CapitalDelta]",
         TraditionalForm], 
        FormBox[
         FormBox["la4",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["p3",
         TraditionalForm], "\[CenterDot]", 
        FormBox["p4",
         TraditionalForm]}]}]}], ")"}], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oa",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a2",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["ob",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a3",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["oc",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    SubscriptBox["\[Delta]", 
     RowBox[{
      FormBox[
       FormBox["a4",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["od",
        TraditionalForm],
       TraditionalForm]}]]}]}], TraditionalForm]], "Output",
 CellTags->"Twist4GluonOperator",
 CellLabel->"Out[1869]="]
}, Open  ]]
}, Open  ]],

Cell["TwoLoopSimplify  ***unfinished*** (examples missing)", "ObjectName",
 CellTags->"TwoLoopSimplify"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"TwoLoopSimplify"],

Cell["\<\
TwoLoopSimplify[amplitude,{qu1,qu2}] simplifies the 2-loop amplitude (qu1 and \
qu2 denote the integration momenta). TwoLoopSimplify[amplitude] transforms to \
TwoLoopSimplify[amplitude, {Global`q1, Global`q2}], i.e., the integration \
momenta in amplitude must be named q1 and q2.\
\>", "Text",
 CellTags->"TwoLoopSimplify"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OneLoopSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoopSimplify",
  ButtonNote->"OneLoopSimplify"],
 "."
}], "Text",
 CellTags->"TwoLoopSimplify"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"TwoLoopSimplify"],

Cell[BoxData[""], "Input",
 CellTags->"TwoLoopSimplify",
 CellLabel->"In[1870]:="]
}, Open  ]],

Cell["Uncontract", "ObjectName",
 CellTags->"Uncontract"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Uncontract"],

Cell["\<\
Uncontract[exp, q1, q2, ...] uncontracts Eps and DiracGamma. Uncontract[exp, \
q1, q2, Pair \[Rule] {p}] uncontracts also p.q1 and p.q2; the option Pair \
\[Rule] All uncontracts all momenta except OPEDelta.\
\>", "Text",
 CellTags->"Uncontract"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Uncontract", "]"}]], "Input",
 CellTags->"Uncontract",
 CellLabel->"In[1871]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Dimension", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"DimensionalReduction", "\[Rule]", "False"}], ",", 
    RowBox[{"Pair", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"Unique", "\[Rule]", "True"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Uncontract",
 CellLabel->"Out[1871]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Contract",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Contract",
  ButtonNote->"Contract"],
 "."
}], "Text",
 CellTags->"Uncontract"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Uncontract"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t1", " ", "=", " ", 
  RowBox[{
   RowBox[{"LeviCivita", "[", 
    RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], "[", 
   RowBox[{"p", ",", "q"}], "]"}]}]], "Input",
 CellTags->"Uncontract",
 CellLabel->"In[1872]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Epsilon]", 
   RowBox[{
    FormBox[
     FormBox["\[Mu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm], 
    FormBox["p",
     TraditionalForm], 
    FormBox["q",
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellTags->"Uncontract",
 CellLabel->"Out[1872]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Uncontract", "[", 
  RowBox[{"t1", ",", " ", "p"}], "]"}]], "Input",
 CellTags->"Uncontract",
 CellLabel->"In[1873]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], 
    FormBox[
     FormBox[
      RowBox[{"$AL$25262", "\[InvisibleApplication]", 
       RowBox[{"(", "1", ")"}]}],
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["\[Epsilon]", 
    RowBox[{
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox[
       RowBox[{"$AL$25262", "\[InvisibleApplication]", 
        RowBox[{"(", "1", ")"}]}],
       TraditionalForm],
      TraditionalForm], 
     FormBox["q",
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"Uncontract",
 CellLabel->"Out[1873]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", "=", 
  RowBox[{"DiracSlash", "[", "p", "]"}]}]], "Input",
 CellTags->"Uncontract",
 CellLabel->"In[1874]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["\<\"\[Gamma]\"\>",
    TraditionalForm], "\[CenterDot]", 
   FormBox["p",
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"Uncontract",
 CellLabel->"Out[1874]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Uncontract", "[", 
  RowBox[{"t2", ",", " ", "p"}], "]"}]], "Input",
 CellTags->"Uncontract",
 CellLabel->"In[1875]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["\<\"\[Gamma]\"\>",
    TraditionalForm], "\[CenterDot]", 
   FormBox["p",
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"Uncontract",
 CellLabel->"Out[1875]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Uncontract", "[", 
  RowBox[{"t1", ",", " ", "p", ",", "q"}], "]"}]], "Input",
 CellTags->"Uncontract",
 CellLabel->"In[1876]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], 
    FormBox[
     FormBox[
      RowBox[{"$AL$25272", "\[InvisibleApplication]", 
       RowBox[{"(", "1", ")"}]}],
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox[
    FormBox["q",
     TraditionalForm], 
    FormBox[
     FormBox[
      RowBox[{"$AL$25271", "\[InvisibleApplication]", 
       RowBox[{"(", "1", ")"}]}],
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["\[Epsilon]", 
    RowBox[{
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox["\[Nu]",
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox[
       RowBox[{"$AL$25272", "\[InvisibleApplication]", 
        RowBox[{"(", "1", ")"}]}],
       TraditionalForm],
      TraditionalForm], 
     FormBox[
      FormBox[
       RowBox[{"$AL$25271", "\[InvisibleApplication]", 
        RowBox[{"(", "1", ")"}]}],
       TraditionalForm],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"Uncontract",
 CellLabel->"Out[1876]="]
}, Open  ]],

Cell["By default scalar products are not uncontracted.", "Text",
 CellTags->"Uncontract"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Uncontract", "[", 
  RowBox[{
   RowBox[{"ScalarProduct", "[", 
    RowBox[{"p", ",", "q"}], "]"}], ",", " ", "q"}], "]"}]], "Input",
 CellTags->"Uncontract",
 CellLabel->"In[1877]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox["p",
    TraditionalForm], "\[CenterDot]", 
   FormBox["q",
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"Uncontract",
 CellLabel->"Out[1877]="]
}, Open  ]],

Cell["\<\
With the option Pair\[Rule]All they are \[OpenCurlyDoubleQuote]uncontracted \
\[CloseCurlyDoubleQuote].\
\>", "Text",
 CellTags->"Uncontract"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Uncontract", "[", 
  RowBox[{
   RowBox[{"ScalarProduct", "[", 
    RowBox[{"p", ",", "q"}], "]"}], ",", "q", ",", 
   RowBox[{"Pair", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellTags->"Uncontract",
 CellLabel->"In[1878]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], 
    FormBox[
     FormBox[
      RowBox[{"$AL$25279", "\[InvisibleApplication]", 
       RowBox[{"(", "1", ")"}]}],
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox[
    FormBox["q",
     TraditionalForm], 
    FormBox[
     FormBox[
      RowBox[{"$AL$25279", "\[InvisibleApplication]", 
       RowBox[{"(", "1", ")"}]}],
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"Uncontract",
 CellLabel->"Out[1878]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Uncontract", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"ScalarProduct", "[", 
     RowBox[{"p", ",", "q"}], "]"}], "^", "2"}], ",", "q", ",", 
   RowBox[{"Pair", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellTags->"Uncontract",
 CellLabel->"In[1879]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], 
    FormBox[
     FormBox[
      RowBox[{"$AL$25283", "\[InvisibleApplication]", 
       RowBox[{"(", "1", ")"}]}],
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], 
    FormBox[
     FormBox[
      RowBox[{"$AL$25283", "\[InvisibleApplication]", 
       RowBox[{"(", "2", ")"}]}],
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox[
    FormBox["q",
     TraditionalForm], 
    FormBox[
     FormBox[
      RowBox[{"$AL$25283", "\[InvisibleApplication]", 
       RowBox[{"(", "1", ")"}]}],
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox[
    FormBox["q",
     TraditionalForm], 
    FormBox[
     FormBox[
      RowBox[{"$AL$25283", "\[InvisibleApplication]", 
       RowBox[{"(", "2", ")"}]}],
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"Uncontract",
 CellLabel->"Out[1879]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"t1", ",", "t2"}], "]"}]], "Input",
 CellTags->"Uncontract",
 CellLabel->"In[1880]:="]
}, Open  ]],

Cell["UnDeclareNonCommutative", "ObjectName",
 CellTags->"UnDeclareNonCommutative"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"UnDeclareNonCommutative"],

Cell["\<\
UnDeclareNonCommutative[a, b, ...] undeclares a,b, ... to be noncommutative, \
i.e., DataType[a,b, ..., NonCommutative] is set to False.\
\>", "Text",
 CellTags->"UnDeclareNonCommutative"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DataType",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DataType",
  ButtonNote->"DataType"],
 ", ",
 ButtonBox["DeclareNonCommutative",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DeclareNonCommutative",
  ButtonNote->"DeclareNonCommutative"],
 "."
}], "Text",
 CellTags->"UnDeclareNonCommutative"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"UnDeclareNonCommutative"],

Cell[BoxData[
 RowBox[{"DeclareNonCommutative", "[", "x", "]"}]], "Input",
 CellTags->"UnDeclareNonCommutative",
 CellLabel->"In[1881]:="],

Cell["\<\
As a side-effect of DeclareNonCommutative x is declared to be of DataType \
NonCommutative.\
\>", "Text",
 CellTags->"UnDeclareNonCommutative"],

Cell[CellGroupData[{

Cell["DataType[x,NonCommutative]", "Input",
 CellTags->"UnDeclareNonCommutative",
 CellLabel->"In[1882]:="],

Cell[BoxData[
 FormBox["True", TraditionalForm]], "Output",
 CellTags->"UnDeclareNonCommutative",
 CellLabel->"Out[1882]="]
}, Open  ]],

Cell["The inverse operation is UnDeclareNonCommutative.", "Text",
 CellTags->"UnDeclareNonCommutative"],

Cell[BoxData[
 RowBox[{"UnDeclareNonCommutative", "[", "x", "]"}]], "Input",
 CellTags->"UnDeclareNonCommutative",
 CellLabel->"In[1883]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DataType", "[", 
  RowBox[{"x", ",", "NonCommutative"}], "]"}]], "Input",
 CellTags->"UnDeclareNonCommutative",
 CellLabel->"In[1884]:="],

Cell[BoxData[
 FormBox["True", TraditionalForm]], "Output",
 CellTags->"UnDeclareNonCommutative",
 CellLabel->"Out[1884]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"DeclareNonCommutative", "[", 
  RowBox[{"y", ",", "z"}], "]"}]], "Input",
 CellTags->"UnDeclareNonCommutative",
 CellLabel->"In[1885]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DataType", "[", 
  RowBox[{"y", ",", "z", ",", "NonCommutative"}], "]"}]], "Input",
 CellTags->"UnDeclareNonCommutative",
 CellLabel->"In[1886]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"True", ",", "True"}], "}"}], TraditionalForm]], "Output",
 CellTags->"UnDeclareNonCommutative",
 CellLabel->"Out[1886]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"UnDeclareNonCommutative", "[", 
  RowBox[{"y", ",", "z"}], "]"}]], "Input",
 CellTags->"UnDeclareNonCommutative",
 CellLabel->"In[1887]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DataType", "[", 
  RowBox[{"y", ",", "z", ",", "NonCommutative"}], "]"}]], "Input",
 CellTags->"UnDeclareNonCommutative",
 CellLabel->"In[1888]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"True", ",", "True"}], "}"}], TraditionalForm]], "Output",
 CellTags->"UnDeclareNonCommutative",
 CellLabel->"Out[1888]="]
}, Open  ]]
}, Open  ]],

Cell["Upper", "ObjectName",
 CellTags->"Upper"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Upper"],

Cell["\<\
Upper may be used inside LorentzIndex to indicate an contravariant \
LorentzIndex.\
\>", "Text",
 CellTags->"Upper"],

Cell[TextData[{
 "See also:  ",
 ButtonBox["LorentzIndex",
  BaseStyle->"AddOnsLink",
  ButtonData:>"LorentzIndex",
  ButtonNote->"LorentzIndex"],
 ", ",
 ButtonBox["Lower",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Lower",
  ButtonNote->"Lower"],
 ", ",
 ButtonBox["Contract1",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Contract1",
  ButtonNote->"Contract1"],
 "."
}], "Text",
 CellTags->"Upper"]
}, Open  ]],

Cell["UVPart  ***unfinished*** (examples missing)", "ObjectName",
 CellTags->"UVPart"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"UVPart"],

Cell["\<\
UVPart[exp, q] discards ultraviolet finite integrals  (q = integration \
momentum).\
\>", "Text",
 CellTags->"UVPart"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"UVPart"],

Cell[BoxData[""], "Input",
 CellTags->"UVPart",
 CellLabel->"In[1889]:="]
}, Open  ]],

Cell["Vectors", "ObjectName",
 CellTags->"Vectors"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Vectors"],

Cell["\<\
Vectors is an option for FORM2FeynCalc. Its default setting is Automatic. It \
may be set to a list, if the FORM-file does not contain a V(ectors) statement.\
\>", "Text",
 CellTags->"Vectors"],

Cell[TextData[{
 "See also:  ",
 ButtonBox["FORM2FeynCalc",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FORM2FeynCalc",
  ButtonNote->"FORM2FeynCalc"],
 "."
}], "Text",
 CellTags->"Vectors"]
}, Open  ]],

Cell["WriteOut", "ObjectName",
 CellTags->"WriteOut"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"WriteOut"],

Cell["\<\
WriteOut is an option for OneLoop.  If set to True, the result of OneLoop \
will be written to a file called \"name.res\", where name is the first \
argument of OneLoop.\
\>", "Text",
 CellTags->"WriteOut"],

Cell[TextData[{
 "See also:  ",
 ButtonBox["OneLoop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoop",
  ButtonNote->"OneLoop"],
 "."
}], "Text",
 CellTags->"WriteOut"]
}, Open  ]],

Cell["WriteOutPaVe", "ObjectName",
 CellTags->"WriteOutPaVe"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"WriteOutPaVe"],

Cell["\<\
WriteOutPaVe is an option for PaVeReduce and OneLoopSum. If set to a string, \
the results of all Passarino-Veltman PaVe's are stored in files with names \
generated from this string and the arguments of PaVe.\
\>", "Text",
 CellTags->"WriteOutPaVe"],

Cell[TextData[{
 "See also:  ",
 ButtonBox["PaVeReduce",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVeReduce",
  ButtonNote->"PaVeReduce"],
 ", ",
 ButtonBox["PaVe",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVe",
  ButtonNote->"PaVe"],
 ", ",
 ButtonBox["OneLoopSum",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoopSum",
  ButtonNote->"OneLoopSum"],
 "."
}], "Text",
 CellTags->"WriteOutPaVe"]
}, Open  ]],

Cell["Write2", "ObjectName",
 CellTags->"Write2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Write2"],

Cell["\<\
Write2[file, val1 = expr1, val2 = expr2, ...] writes the settings val1 = \
expr1, val2 = expr2 in sequence followed by a newline, to the specified \
output file. Setting the option FormatType of Write2 to FortranForm results \
in FORTRAN syntax output.\
\>", "Text",
 CellTags->"Write2"],

Cell["\<\
The continuation character for FORTRAN output can be controlled by changing \
$FortranContinuationCharacter.\
\>", "Text",
 CellTags->"Write2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullForm", "[", "$FortranContinuationCharacter", "]"}]], "Input",
 CellTags->"Write2",
 CellLabel->"In[1890]:="],

Cell[BoxData[
 FormBox[
  TagBox[
   StyleBox["\"\<&\>\"",
    ShowSpecialCharacters->False,
    ShowStringCharacters->True,
    NumberMarks->True],
   FullForm], TraditionalForm]], "Output",
 CellTags->"Write2",
 CellLabel->"Out[1890]//FullForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "Write2", "]"}]], "Input",
 CellTags->"Write2",
 CellLabel->"In[1891]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"D0Convention", "\[Rule]", "0"}], ",", 
    RowBox[{"FinalSubstitutions", "\[Rule]", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"FormatType", "\[Rule]", "InputForm"}], ",", 
    RowBox[{"FortranFormatDoublePrecision", "\[Rule]", "True"}], ",", 
    RowBox[{"PageWidth", "\[Rule]", "62"}], ",", 
    RowBox[{"PostFortranFile", "\[Rule]", "\<\"\"\>"}], ",", 
    RowBox[{"PreFortranFile", "\[Rule]", "\<\"\"\>"}], ",", 
    RowBox[{"StringReplace", "\[Rule]", 
     RowBox[{"{", "}"}]}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"Write2",
 CellLabel->"Out[1891]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Attributes", "[", "Write2", "]"}]], "Input",
 CellTags->"Write2",
 CellLabel->"In[1892]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", "HoldRest", "}"}], TraditionalForm]], "Output",
 CellTags->"Write2",
 CellLabel->"Out[1892]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Isolate",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Isolate",
  ButtonNote->"Isolate"],
 ", ",
 ButtonBox["PaVeReduce",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVeReduce",
  ButtonNote->"PaVeReduce"],
 "."
}], "Text",
 CellTags->"Write2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Write2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"a", "-", "b"}], ")"}], "2"]}], ")"}], "2"], ",", "a", ",", 
    "Factor"}], "]"}]}]], "Input",
 CellTags->"Write2",
 CellLabel->"In[1893]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["a", "4"]}], "-", 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "3"], " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", "c"}], ")"}]}], "+", 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      RowBox[{"b", " ", "c"}], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}], "-", 
   RowBox[{"4", " ", "a", " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", "c"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}], "+", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ")"}], "2"]}], TraditionalForm]], "Output",
 CellTags->"Write2",
 CellLabel->"Out[1893]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"tempfilename", "=", 
   RowBox[{
    RowBox[{"ToString", "[", "$SessionID", "]"}], "<>", "\"\<.s\>\""}]}], 
  ";"}]], "Input",
 CellTags->"Write2",
 CellLabel->"In[1894]:="],

Cell["This writes the assignment r=t to a file.", "Text",
 CellTags->"Write2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Write2", "[", 
   RowBox[{"tempfilename", ",", 
    RowBox[{"r", "=", "t"}]}], "]"}], ";"}]], "Input",
 CellTags->"Write2",
 CellLabel->"In[1895]:="],

Cell["This shows the contents of the file.", "Text",
 CellTags->"Write2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"ReadList", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", "\"\<:\>\"",
        ",", "\"\<\>\""}], "]"}], "<>", "tempfilename"}], ",", "String"}], 
   "]"}], "]"}]], "Input",
 CellTags->"Write2",
 CellLabel->"In[1896]:="],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {"\<\"r = ( 4*a^4 - 8*a^3*(b + c) - 4*a*(b + c)*(b^2 + c^2) + \"\>"},
      {"\<\" (b^2 + c^2)^2 + 8*a^2*(b^2 + b*c + c^2)\"\>"},
      {"\<\"       );\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellTags->"Write2",
 CellLabel->"Out[1896]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"DeleteFile", "[", 
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", "\"\<:\>\"", 
     ",", "\"\<\>\""}], "]"}], "<>", "tempfilename"}], "]"}]], "Input",
 CellTags->"Write2",
 CellLabel->"In[1897]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"t2", "=", 
  RowBox[{"x", "+", 
   RowBox[{"Isolate", "[", 
    RowBox[{"t", ",", "a", ",", 
     RowBox[{"IsolateNames", "\[Rule]", "W"}]}], "]"}]}]}]], "Input",
 CellTags->"Write2",
 CellLabel->"In[1898]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["a", "4"]}], "-", 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "3"], " ", 
    TagBox[
     RowBox[{"W", "(", "224", ")"}],
     HoldForm]}], "+", 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"], " ", 
    TagBox[
     RowBox[{"W", "(", "226", ")"}],
     HoldForm]}], "-", 
   RowBox[{"4", " ", "a", " ", 
    TagBox[
     RowBox[{"W", "(", "224", ")"}],
     HoldForm], " ", 
    TagBox[
     RowBox[{"W", "(", "225", ")"}],
     HoldForm]}], "+", 
   SuperscriptBox[
    TagBox[
     RowBox[{"W", "(", "225", ")"}],
     HoldForm], "2"], "+", "x"}], TraditionalForm]], "Output",
 CellTags->"Write2",
 CellLabel->"Out[1898]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Write2", "[", 
   RowBox[{"tempfilename", ",", 
    RowBox[{"r", "=", "t2"}]}], "]"}], ";"}]], "Input",
 CellTags->"Write2",
 CellLabel->"In[1899]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"ReadList", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", "\"\<:\>\"",
        ",", "\"\<\>\""}], "]"}], "<>", "tempfilename"}], ",", "String"}], 
   "]"}], "]"}]], "Input",
 CellTags->"Write2",
 CellLabel->"In[1900]:="],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {"\<\"W[224] = (b + c\"\>"},
      {"\<\"       );\"\>"},
      {"\<\"W[225] = (b^2 + c^2\"\>"},
      {"\<\"       );\"\>"},
      {"\<\"W[226] = (b^2 + b*c + c^2\"\>"},
      {"\<\"       );\"\>"},
      {"\<\"r = ( 4*a^4 + x - 8*a^3*HoldForm[W[224]] - \"\>"},
      {"\<\" 4*a*HoldForm[W[224]]*HoldForm[W[225]] + HoldForm[W[225]]^2 + \
\"\>"},
      {"\<\" 8*a^2*HoldForm[W[226]]\"\>"},
      {"\<\"       );\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellTags->"Write2",
 CellLabel->"Out[1900]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"DeleteFile", "[", 
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", "\"\<:\>\"", 
     ",", "\"\<\>\""}], "]"}], "<>", "tempfilename"}], "]"}]], "Input",
 CellTags->"Write2",
 CellLabel->"In[1901]:="],

Cell["\<\
This is how to write out the expression t2 in Fortran format.\
\>", "Text",
 CellTags->"Write2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Write2", "[", 
   RowBox[{"tempfilename", ",", 
    RowBox[{"r", "=", "t2"}], ",", 
    RowBox[{"FormatType", "\[Rule]", "FortranForm"}]}], "]"}], ";"}]], "Input",\

 CellTags->"Write2",
 CellLabel->"In[1902]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"ReadList", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", "\"\<:\>\"",
        ",", "\"\<\>\""}], "]"}], "<>", "tempfilename"}], ",", "String"}], 
   "]"}], "]"}]], "Input",
 CellTags->"Write2",
 CellLabel->"In[1903]:="],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {"\<\"        W(224D2)= W(224D2)\"\>"},
      {"\<\"        W(225D2)= W(225D2)\"\>"},
      {"\<\"        W(226D2)= W(226D2)\"\>"},
      {"\<\"        r = 4D0*a**4 + x - 8D0*a**3*W(224D2) - \"\>"},
      {"\<\"     &  4D0*a*W(224D2)*W(225D2) + W(225D2)**2 + \"\>"},
      {"\<\"     &  8D0*a**2*W(226D2)\"\>"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellTags->"Write2",
 CellLabel->"Out[1903]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"DeleteFile", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"$OperatingSystem", "===", "\"\<MacOS\>\""}], ",", "\"\<:\>\"", 
      ",", "\"\<\>\""}], "]"}], "<>", "tempfilename"}], "]"}], ";", 
  RowBox[{"Clear", "[", 
   RowBox[{"t", ",", "t2", ",", "tempfilename"}], "]"}], ";"}]], "Input",
 CellTags->"Write2",
 CellLabel->"In[1904]:="]
}, Open  ]],

Cell["XYT", "ObjectName",
 CellTags->"XYT"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"XYT"],

Cell[TextData[{
 "XYT[exp, x,y] transforms  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"x", " ", "y"}], ")"}], "m"], TraditionalForm]]],
 " away ..."
}], "Text",
 CellTags->"XYT"]
}, Open  ]],

Cell["ZeroMomentumInsertion", "ObjectName",
 CellTags->"ZeroMomentumInsertion"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"ZeroMomentumInsertion"],

Cell["\<\
ZeroMomentumInsertion is an option of FeynRule, Twist2GluonOperator and \
Twist2QuarkOperator.\
\>", "Text",
 CellTags->"ZeroMomentumInsertion"],

Cell[TextData[{
 "See also:  ",
 ButtonBox["FeynRule",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynRule",
  ButtonNote->"FeynRule"],
 ", ",
 ButtonBox["Twist2GluonOperator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Twist2GluonOperator",
  ButtonNote->"Twist2GluonOperator"],
 ", ",
 ButtonBox["Twist2QuarkOperator",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Twist2QuarkOperator",
  ButtonNote->"Twist2QuarkOperator"],
 "."
}], "Text",
 CellTags->"ZeroMomentumInsertion"]
}, Open  ]],

Cell["Zeta2", "ObjectName",
 CellTags->"Zeta2"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"Zeta2"],

Cell["Zeta2 denotes Zeta[2]. N[Zeta[2]] evaluates to N[Zeta[2]].", "Text",
 CellTags->"Zeta2"],

Cell[TextData[{
 "See also: ",
 ButtonBox["SimplifyPolyLog",
  BaseStyle->"AddOnsLink",
  ButtonData:>"SimplifyPolyLog",
  ButtonNote->"SimplifyPolyLog"],
 "."
}], "Text",
 CellTags->"Zeta2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"Zeta2"],

Cell[CellGroupData[{

Cell[BoxData["Zeta2"], "Input",
 CellTags->"Zeta2",
 CellLabel->"In[1905]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"\[Zeta]", "(", "2", ")"}], TraditionalForm]], "Output",
 CellTags->"Zeta2",
 CellLabel->"Out[1905]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", "Zeta2", "]"}]], "Input",
 CellTags->"Zeta2",
 CellLabel->"In[1906]:="],

Cell[BoxData[
 FormBox["1.6449340668482262`", TraditionalForm]], "Output",
 CellTags->"Zeta2",
 CellLabel->"Out[1906]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SimplifyPolyLog", "[", 
  RowBox[{"Pi", "^", "2"}], "]"}]], "Input",
 CellTags->"Zeta2",
 CellLabel->"In[1907]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"6", " ", 
   RowBox[{"\[Zeta]", "(", "2", ")"}]}], TraditionalForm]], "Output",
 CellTags->"Zeta2",
 CellLabel->"Out[1907]="]
}, Open  ]]
}, Open  ]],

Cell["$Abbreviations", "ObjectName",
 CellTags->"$Abbreviations"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$Abbreviations"],

Cell["\<\
$Abbreviations are a list of string substitution rules used when generating \
names for storing intermediate results. It is used by OneLoop and \
PaVeReduce.The elements of the list should be of the form \"name\" \[Rule] \
\"abbreviation\".\
\>", "Text",
 CellTags->"$Abbreviations"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"$Abbreviations", "//", "StandardForm"}]], "Input",
 CellTags->"$Abbreviations",
 CellLabel->"In[1908]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\", \"\>", "\[Rule]", "\<\"\"\>"}], ",", 
   RowBox[{"\<\"^\"\>", "\[Rule]", "\<\"\"\>"}], ",", 
   RowBox[{"\<\"{\"\>", "\[Rule]", "\<\"\"\>"}], ",", 
   RowBox[{"\<\"/\"\>", "\[Rule]", "\<\"\"\>"}], ",", 
   RowBox[{"\<\"Subscript\"\>", "\[Rule]", "\<\"su\"\>"}], ",", 
   RowBox[{"\<\"SmallVariable\"\>", "\[Rule]", "\<\"sma\"\>"}], ",", 
   RowBox[{"\<\"}\"\>", "\[Rule]", "\<\"\"\>"}], ",", 
   RowBox[{"\<\"[\"\>", "\[Rule]", "\<\"\"\>"}], ",", 
   RowBox[{"\<\"]\"\>", "\[Rule]", "\<\"\"\>"}], ",", 
   RowBox[{"\<\"*\"\>", "\[Rule]", "\<\"\"\>"}], ",", 
   RowBox[{"\<\" \"\>", "\[Rule]", "\<\"\"\>"}], ",", 
   RowBox[{"\<\"\\n\"\>", "\[Rule]", "\<\"\"\>"}], ",", 
   RowBox[{"\<\"\\r\"\>", "\[Rule]", "\<\"\"\>"}]}], "}"}]], "Output",
 CellTags->"$Abbreviations",
 CellLabel->"Out[1908]//StandardForm="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Abbreviation",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Abbreviation",
  ButtonNote->"Abbreviation"],
 ", ",
 ButtonBox["OneLoop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoop",
  ButtonNote->"OneLoop"],
 ", ",
 ButtonBox["PaVeReduce",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVeReduce",
  ButtonNote->"PaVeReduce"],
 ", ",
 ButtonBox["WriteOut",
  BaseStyle->"AddOnsLink",
  ButtonData:>"WriteOut",
  ButtonNote->"WriteOut"],
 ", ",
 ButtonBox["WriteOutPaVe",
  BaseStyle->"AddOnsLink",
  ButtonData:>"WriteOutPaVe",
  ButtonNote->"WriteOutPaVe"],
 "."
}], "Text",
 CellTags->"$Abbreviations"]
}, Open  ]],

Cell["$AL", "ObjectName",
 CellTags->"$AL"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$AL"],

Cell["\<\
$AL is the head for dummy indices which may be introduced by Uncontract.\
\>", "Text",
 CellTags->"$AL"],

Cell[CellGroupData[{

Cell[BoxData["$AL"], "Input",
 CellTags->"$AL",
 CellLabel->"In[1909]:="],

Cell[BoxData[
 FormBox["$AL", TraditionalForm]], "Output",
 CellTags->"$AL",
 CellLabel->"Out[1909]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Uncontract", "[", 
  RowBox[{
   RowBox[{"ScalarProduct", "[", 
    RowBox[{"p", ",", "q"}], "]"}], ",", "q", ",", 
   RowBox[{"Pair", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellTags->"$AL",
 CellLabel->"In[1910]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], 
    FormBox[
     FormBox[
      RowBox[{"$AL$25363", "\[InvisibleApplication]", 
       RowBox[{"(", "1", ")"}]}],
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox[
    FormBox["q",
     TraditionalForm], 
    FormBox[
     FormBox[
      RowBox[{"$AL$25363", "\[InvisibleApplication]", 
       RowBox[{"(", "1", ")"}]}],
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"$AL",
 CellLabel->"Out[1910]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"$AL", "=", "\[Mu]"}], ";"}]], "Input",
 CellTags->"$AL",
 CellLabel->"In[1911]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Uncontract", "[", 
  RowBox[{
   RowBox[{"ScalarProduct", "[", 
    RowBox[{"p", ",", "q"}], "]"}], ",", "q", ",", 
   RowBox[{"Pair", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellTags->"$AL",
 CellLabel->"In[1912]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], 
    FormBox[
     FormBox[
      RowBox[{"\[Mu]$25367", "(", "1", ")"}],
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox[
    FormBox["q",
     TraditionalForm], 
    FormBox[
     FormBox[
      RowBox[{"\[Mu]$25367", "(", "1", ")"}],
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellTags->"$AL",
 CellLabel->"Out[1912]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"$AL", "=."}], ";"}]], "Input",
 CellTags->"$AL",
 CellLabel->"In[1913]:="]
}, Open  ]],

Cell["$BreitMaison", "ObjectName",
 CellTags->"$BreitMaison"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$BreitMaison"],

Cell[TextData[{
 "The Breitenlohner-Maison ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", "5"], TraditionalForm]]],
 " scheme is currently not supported by the Dirac algebra functions.Use \
Tracer if you need it (PHI supplies the functions FCToTracer and \
TracerToFC)."
}], "Text",
 CellTags->"$BreitMaison"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Tr",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Tr",
  ButtonNote->"Tr"],
 ", ",
 ButtonBox["$Larin",
  BaseStyle->"AddOnsLink",
  ButtonData:>"$Larin",
  ButtonNote->"$Larin"],
 ", ",
 ButtonBox["$West",
  BaseStyle->"AddOnsLink",
  ButtonData:>"$West",
  ButtonNote->"$West"],
 "."
}], "Text",
 CellTags->"$BreitMaison"]
}, Open  ]],

Cell["$Color", "ObjectName",
 CellTags->"$Color"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$Color"],

Cell["\<\
$Color is False by default. If set to True, some special variables will be \
colored.\
\>", "Text",
 CellTags->"$Color"]
}, Open  ]],

Cell["$Covariant", "ObjectName",
 CellTags->"$Covariant"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$Covariant"],

Cell["\<\
The boolean setting of $Covariant determines whether lorentz indices are \
displayed as lower indices (True) or as upper ones (False).\
\>", "Text",
 CellTags->"$Covariant"],

Cell[CellGroupData[{

Cell[BoxData["$Covariant"], "Input",
 CellTags->"$Covariant",
 CellLabel->"In[1914]:="],

Cell[BoxData[
 FormBox["False", TraditionalForm]], "Output",
 CellTags->"$Covariant",
 CellLabel->"Out[1914]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GA", "[", "\[Mu]", "]"}]], "Input",
 CellTags->"$Covariant",
 CellLabel->"In[1915]:="],

Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Gamma]", "\[Mu]"], TraditionalForm]], "Output",
 CellTags->"$Covariant",
 CellLabel->"Out[1915]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Covariant", "=", "True"}], ";"}]], "Input",
 CellTags->"$Covariant",
 CellLabel->"In[1916]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GA", "[", "\[Mu]", "]"}]], "Input",
 CellTags->"$Covariant",
 CellLabel->"In[1917]:="],

Cell[BoxData[
 FormBox[
  SubscriptBox["\[Gamma]", "\[Mu]"], TraditionalForm]], "Output",
 CellTags->"$Covariant",
 CellLabel->"Out[1917]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Covariant", "=", "False"}], ";"}]], "Input",
 CellTags->"$Covariant",
 CellLabel->"In[1918]:="]
}, Open  ]],

Cell["$FCS", "ObjectName",
 CellTags->"$FCS"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$FCS"],

Cell["\<\
$FCS is a list of functions with a short name. E.g. GA[nu] can be used \
instead of DiracGamma[nu].\
\>", "Text",
 CellTags->"$FCS"],

Cell[CellGroupData[{

Cell[BoxData["$FCS"], "Input",
 CellTags->"$FCS",
 CellLabel->"In[1919]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"\<\"FAD\"\>", ",", "\<\"FV\"\>", ",", "\<\"FVD\"\>", 
    ",", "\<\"GA\"\>", ",", "\<\"GA5\"\>", ",", "\<\"GS\"\>", 
    ",", "\<\"GSD\"\>", ",", "\<\"LC\"\>", ",", "\<\"LCD\"\>", 
    ",", "\<\"MT\"\>", ",", "\<\"MTD\"\>", ",", "\<\"SD\"\>", 
    ",", "\<\"SOD\"\>", ",", "\<\"SP\"\>", ",", "\<\"SPC\"\>", 
    ",", "\<\"SPD\"\>", ",", "\<\"SPL\"\>", ",", "\<\"FCI\"\>", 
    ",", "\<\"FCE\"\>", ",", "\<\"FI\"\>", ",", "\<\"FC\"\>", 
    ",", "\<\"GGV\"\>", ",", "\<\"GP\"\>", ",", "\<\"QGV\"\>", 
    ",", "\<\"QO\"\>", ",", "\<\"FDr\"\>", ",", "\<\"CDr\"\>"}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"$FCS",
 CellLabel->"Out[1919]="]
}, Open  ]]
}, Open  ]],

Cell["$FCT", "ObjectName",
 CellTags->"$FCT"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$FCT"],

Cell["\<\
Setting the global variable $FCT to True changes the default typesetting \
rules for the noncommutative multiplication operator Dot[].\
\>", "Text",
 CellTags->"$FCT"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$FCT", " ", "=", " ", "True"}], ";"}]], "Input",
 CellTags->"$FCT",
 CellLabel->"In[1920]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GA", "[", "\[Mu]", "]"}], " ", ".", " ", 
  RowBox[{"GA", "[", "\[Nu]", "]"}]}]], "Input",
 CellTags->"$FCT",
 CellLabel->"In[1921]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], " ", 
   SuperscriptBox["\[Gamma]", "\[Nu]"]}], TraditionalForm]], "Output",
 CellTags->"$FCT",
 CellLabel->"Out[1921]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"$FCT", " ", "=", " ", "False"}], ";"}]], "Input",
 CellTags->"$FCT",
 CellLabel->"In[1922]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"GA", "[", "\[Mu]", "]"}], " ", ".", " ", 
  RowBox[{"GA", "[", "\[Nu]", "]"}]}]], "Input",
 CellTags->"$FCT",
 CellLabel->"In[1923]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", "\[Mu]"], ".", 
   SuperscriptBox["\[Gamma]", "\[Nu]"]}], TraditionalForm]], "Output",
 CellTags->"$FCT",
 CellLabel->"Out[1923]="]
}, Open  ]]
}, Open  ]],

Cell["$FeynCalcStuff", "ObjectName",
 CellTags->"$FeynCalcStuff"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$FeynCalcStuff"],

Cell["$FeynCalcStuff is the list of availabe stuff in FeynCalc.", "Text",
 CellTags->"$FeynCalcStuff"]
}, Open  ]],

Cell["$FeynCalcVersion", "ObjectName",
 CellTags->"$FeynCalcVersion"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$FeynCalcVersion"],

Cell["\<\
$FeynCalcVersion is a string that represents the version of FeynCalc.\
\>", "Text",
 CellTags->"$FeynCalcVersion"],

Cell[CellGroupData[{

Cell[BoxData["$FeynCalcVersion"], "Input",
 CellTags->"$FeynCalcVersion",
 CellLabel->"In[1924]:="],

Cell[BoxData[
 FormBox["\<\"8.0.2\"\>", TraditionalForm]], "Output",
 CellTags->"$FeynCalcVersion",
 CellLabel->"Out[1924]="]
}, Open  ]]
}, Open  ]],

Cell["$FortranContinuationCharacter", "ObjectName",
 CellTags->"$FortranContinuationCharacter"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$FortranContinuationCharacter"],

Cell["\<\
$FortranContinuationCharacter is the continuation character used in Write2.\
\>", "Text",
 CellTags->"$FortranContinuationCharacter"],

Cell[CellGroupData[{

Cell[BoxData["$FortranContinuationCharacter"], "Input",
 CellTags->"$FortranContinuationCharacter",
 CellLabel->"In[1925]:="],

Cell[BoxData[
 FormBox["\<\"&\"\>", TraditionalForm]], "Output",
 CellTags->"$FortranContinuationCharacter",
 CellLabel->"Out[1925]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Write2",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Write2",
  ButtonNote->"Write2"],
 "."
}], "Text",
 CellTags->"$FortranContinuationCharacter"]
}, Open  ]],

Cell["$Gauge", "ObjectName",
 CellTags->"$Gauge"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$Gauge"],

Cell["\<\
$Gauge(= 1/xi) is a constant specifying the gauge fixing parameter of QED in \
Lorentz gauge.  The usual choice is Feynman gauge, $Gauge=1. Notice that \
$Gauge is used by some functions, the option Gauge by others.\
\>", "Text",
 CellTags->"$Gauge"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Gauge",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Gauge",
  ButtonNote->"Gauge"],
 "."
}], "Text",
 CellTags->"$Gauge"]
}, Open  ]],

Cell["$Larin", "ObjectName",
 CellTags->"$Larin"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$Larin"],

Cell[TextData[{
 "If set to True, the Larin-Gorishny-Atkyampo-DelBurgo-scheme for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", "5"], TraditionalForm]]],
 " in ",
 StyleBox["D",
  FontSlant->"Italic"],
 "-dimensions is used, i.e. before evaluating traces (but after moving ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", "5"], TraditionalForm]]],
 " anticommuting in all dimensions to the right of the Dirac string) a \
product  gamma[mu].gamma5 is substituted to  -I/6 Eps[mu,al,be,si] \
gamma[al,be,si], where all indices live in ",
 StyleBox["D",
  FontSlant->"Italic"],
 "-dimensions now. Especially the Levic-Civita tensor is taken to be ",
 StyleBox["D",
  FontSlant->"Italic"],
 "-dimensional, i.e., contraction of two Eps's results in ",
 StyleBox["D",
  FontSlant->"Italic"],
 "'s. This has (FOR ONE AXIAL-VECTOR-CURRENT ONLY, it is not so clear if this \
scheme also works for more than one fermion line involving ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", "5"], TraditionalForm]]],
 ") the same effect as the Breitenlohner-Maison-'t Hooft-Veltman scheme."
}], "Text",
 CellTags->"$Larin"],

Cell[CellGroupData[{

Cell[BoxData["$Larin"], "Input",
 CellTags->"$Larin",
 CellLabel->"In[1926]:="],

Cell[BoxData[
 FormBox["False", TraditionalForm]], "Output",
 CellTags->"$Larin",
 CellLabel->"Out[1926]="]
}, Open  ]],

Cell[TextData[{
 "See also:  ",
 ButtonBox["Tr",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Tr",
  ButtonNote->"Tr"],
 ", ",
 ButtonBox["$BreitMaison",
  BaseStyle->"AddOnsLink",
  ButtonData:>"$BreitMaison",
  ButtonNote->"$BreitMaison"],
 ", ",
 ButtonBox["$West",
  BaseStyle->"AddOnsLink",
  ButtonData:>"$West",
  ButtonNote->"$West"],
 "."
}], "Text",
 CellTags->"$Larin"]
}, Open  ]],

Cell["$LimitTo4", "ObjectName",
 CellTags->"$LimitTo4"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$LimitTo4"],

Cell["\<\
$LimitTo4 is a global variable with default setting True. If set to False, no \
limit Dimension \[Rule] 4 is performed after tensor integral decomposition.\
\>", "Text",
 CellTags->"$LimitTo4"],

Cell[CellGroupData[{

Cell[BoxData["$LimitTo4"], "Input",
 CellTags->"$LimitTo4",
 CellLabel->"In[1927]:="],

Cell[BoxData[
 FormBox["True", TraditionalForm]], "Output",
 CellTags->"$LimitTo4",
 CellLabel->"Out[1927]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["PaVe",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVe",
  ButtonNote->"PaVe"],
 ", ",
 ButtonBox["PaVeReduce",
  BaseStyle->"AddOnsLink",
  ButtonData:>"PaVeReduce",
  ButtonNote->"PaVeReduce"],
 ", ",
 ButtonBox["OneLoop",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OneLoop",
  ButtonNote->"OneLoop"],
 "."
}], "Text",
 CellTags->"$LimitTo4"]
}, Open  ]],

Cell["$LorentzIndices", "ObjectName",
 CellTags->"$LorentzIndices"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$LorentzIndices"],

Cell["\<\
$LorentzIndices is a global variable. If set to True the dimension of \
LorentzIndex is displayed as an index.\
\>", "Text",
 CellTags->"$LorentzIndices"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$LorentzIndices", "=", "True"}], ";"}]], "Input",
 CellTags->"$LorentzIndices",
 CellLabel->"In[1928]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MetricTensor", "[", 
   RowBox[{"\[Alpha]", ",", "\[Beta]", ",", 
    RowBox[{"Dimension", "\[Rule]", "n"}]}], "]"}], 
  RowBox[{"DiracMatrix", "[", 
   RowBox[{"\[Alpha]", ",", 
    RowBox[{"Dimension", "\[Rule]", "n"}]}], "]"}]}]], "Input",
 CellTags->"$LorentzIndices",
 CellLabel->"In[1929]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", 
    FormBox[
     SubscriptBox[
      FormBox["\[Alpha]",
       TraditionalForm], 
      FormBox["n",
       TraditionalForm]],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{
     FormBox[
      SubscriptBox[
       FormBox["\[Alpha]",
        TraditionalForm], 
       FormBox["n",
        TraditionalForm]],
      TraditionalForm], 
     FormBox[
      SubscriptBox[
       FormBox["\[Beta]",
        TraditionalForm], 
       FormBox["n",
        TraditionalForm]],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"$LorentzIndices",
 CellLabel->"Out[1929]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"$LorentzIndices",
 CellLabel->"In[1930]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracGamma", "[", 
   RowBox[{
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Alpha]", ",", "n"}], "]"}], ",", "n"}], "]"}], " ", 
  RowBox[{"MetricTensor", "[", 
   RowBox[{"\[Alpha]", ",", "\[Beta]", ",", 
    RowBox[{"Dimension", "\[Rule]", "n"}]}], "]"}]}]], "Output",
 CellTags->"$LorentzIndices",
 CellLabel->"Out[1930]//StandardForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MTD", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], " ", 
   RowBox[{"FVD", "[", 
    RowBox[{"p", ",", "\[Beta]"}], "]"}], 
   RowBox[{"GAD", "[", "\[Mu]", "]"}]}], "//", "FCI"}]], "Input",
 CellTags->"$LorentzIndices",
 CellLabel->"In[1931]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["\[Gamma]", 
    FormBox[
     SubscriptBox[
      FormBox["\[Mu]",
       TraditionalForm], 
      FormBox["D",
       TraditionalForm]],
     TraditionalForm]], " ", 
   SuperscriptBox[
    FormBox["p",
     TraditionalForm], 
    FormBox[
     SubscriptBox[
      FormBox["\[Beta]",
       TraditionalForm], 
      FormBox["D",
       TraditionalForm]],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{
     FormBox[
      SubscriptBox[
       FormBox["\[Alpha]",
        TraditionalForm], 
       FormBox["D",
        TraditionalForm]],
      TraditionalForm], 
     FormBox[
      SubscriptBox[
       FormBox["\[Beta]",
        TraditionalForm], 
       FormBox["D",
        TraditionalForm]],
      TraditionalForm]}]]}], TraditionalForm]], "Output",
 CellTags->"$LorentzIndices",
 CellLabel->"Out[1931]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "StandardForm"}]], "Input",
 CellTags->"$LorentzIndices",
 CellLabel->"In[1932]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"DiracGamma", "[", 
   RowBox[{
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Mu]", ",", "D"}], "]"}], ",", "D"}], "]"}], " ", 
  RowBox[{"Pair", "[", 
   RowBox[{
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Alpha]", ",", "D"}], "]"}], ",", 
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Beta]", ",", "D"}], "]"}]}], "]"}], " ", 
  RowBox[{"Pair", "[", 
   RowBox[{
    RowBox[{"LorentzIndex", "[", 
     RowBox[{"\[Beta]", ",", "D"}], "]"}], ",", 
    RowBox[{"Momentum", "[", 
     RowBox[{"p", ",", "D"}], "]"}]}], "]"}]}]], "Output",
 CellTags->"$LorentzIndices",
 CellLabel->"Out[1932]//StandardForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"$LorentzIndices", "=", "False"}], ";"}]], "Input",
 CellTags->"$LorentzIndices",
 CellLabel->"In[1933]:="]
}, Open  ]],

Cell["$MIntegrate", "ObjectName",
 CellTags->"$MIntegrate"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$MIntegrate"],

Cell["\<\
$MIntegrate is a global list of integrations done by Mathematica inside \
OPEIntDelta.\
\>", "Text",
 CellTags->"$MIntegrate"],

Cell[CellGroupData[{

Cell[BoxData["$MIntegrate"], "Input",
 CellTags->"$MIntegrate",
 CellLabel->"In[1934]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", "}"}], TraditionalForm]], "Output",
 CellTags->"$MIntegrate",
 CellLabel->"Out[1934]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["OPEIntDelta",
  BaseStyle->"AddOnsLink",
  ButtonData:>"OPEIntDelta",
  ButtonNote->"OPEIntDelta"],
 "."
}], "Text",
 CellTags->"$MIntegrate"]
}, Open  ]],

Cell["$MU", "ObjectName",
 CellTags->"$MU"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$MU"],

Cell["\<\
$MU is the head for dummy indices which may be introduced by Chisholm (and \
evtl. Contract and DiracReduce).\
\>", "Text",
 CellTags->"$MU"],

Cell[CellGroupData[{

Cell[BoxData["$MU"], "Input",
 CellTags->"$MU",
 CellLabel->"In[1935]:="],

Cell[BoxData[
 FormBox["$MU", TraditionalForm]], "Output",
 CellTags->"$MU",
 CellLabel->"Out[1935]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Chisholm",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Chisholm",
  ButtonNote->"Chisholm"],
 "."
}], "Text",
 CellTags->"$MU"]
}, Open  ]],

Cell["$MemoryAvailable", "ObjectName",
 CellTags->"$MemoryAvailable"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$MemoryAvailable"],

Cell[TextData[{
 "$MemoryAvailable is  a global variable which is set to an integer ",
 StyleBox["n",
  FontSlant->"Italic"],
 ", where ",
 StyleBox["n",
  FontSlant->"Italic"],
 " is the available amount of main memory in MB. The default is 128. It \
should be increased if possible. The higher $MemoryAvailable can be, the more \
intermediate steps do not have to be repeated by FeynCalc."
}], "Text",
 CellTags->"$MemoryAvailable"],

Cell[CellGroupData[{

Cell[BoxData["$MemoryAvailable"], "Input",
 CellTags->"$MemoryAvailable",
 CellLabel->"In[1936]:="],

Cell[BoxData[
 FormBox["256", TraditionalForm]], "Output",
 CellTags->"$MemoryAvailable",
 CellLabel->"Out[1936]="]
}, Open  ]]
}, Open  ]],

Cell["$NonComm", "ObjectName",
 CellTags->"$NonComm"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$NonComm"],

Cell["\<\
$NonComm contains a list of all non-commutative heads present.\
\>", "Text",
 CellTags->"$NonComm"],

Cell[CellGroupData[{

Cell[BoxData["$NonComm"], "Input",
 CellTags->"$NonComm",
 CellLabel->"In[1937]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "ChiralityProjector", ",", "DiracGamma", ",", "DiracGammaT", ",", 
    "DiracMatrix", ",", "DiracSigma", ",", "DiracSlash", ",", "Spinor", ",", 
    "GAD", ",", "GA", ",", "GSD", ",", "GS", ",", "LeftPartialD", ",", 
    "LeftRightPartialD2", ",", "LeftRightPartialD", ",", "PartialD", ",", 
    "PauliSigma", ",", "QuantumField", ",", "RightPartialD", ",", 
    "SpinorUBar", ",", "SpinorU", ",", "SpinorVBar", ",", "SpinorV", ",", 
    "SUNT", ",", "FieldStrength", ",", "QuarkGluonVertex", ",", 
    "QuarkPropagator", ",", "C", ",", "Twist2QuarkOperator", ",", 
    "CovariantD", ",", "OPESum", ",", "Twist2AlienOperator", ",", 
    "Twist2CounterOperator"}], "}"}], TraditionalForm]], "Output",
 CellTags->"$NonComm",
 CellLabel->"Out[1937]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["NonCommQ",
  BaseStyle->"AddOnsLink",
  ButtonData:>"NonCommQ",
  ButtonNote->"NonCommQ"],
 ", ",
 ButtonBox["NonCommutative",
  BaseStyle->"AddOnsLink",
  ButtonData:>"NonCommutative",
  ButtonNote->"NonCommutative"],
 "."
}], "Text",
 CellTags->"$NonComm"]
}, Open  ]],

Cell["$PairBrackets", "ObjectName",
 CellTags->"$PairBrackets"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$PairBrackets"],

Cell["\<\
$PairBrackets determines whether brackets are drawn around scalar products in \
the notebook interface.\
\>", "Text",
 CellTags->"$PairBrackets"],

Cell[CellGroupData[{

Cell[BoxData["$PairBrackets"], "Input",
 CellTags->"$PairBrackets",
 CellLabel->"In[1938]:="],

Cell[BoxData[
 FormBox["False", TraditionalForm]], "Output",
 CellTags->"$PairBrackets",
 CellLabel->"Out[1938]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SP", "[", 
   RowBox[{"p", ",", "q"}], "]"}], 
  RowBox[{"SP", "[", 
   RowBox[{"r", ",", "s"}], "]"}]}]], "Input",
 CellTags->"$PairBrackets",
 CellLabel->"In[1939]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}],
    TraditionalForm], " ", 
   FormBox[
    RowBox[{
     FormBox["r",
      TraditionalForm], "\[CenterDot]", 
     FormBox["s",
      TraditionalForm]}],
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"$PairBrackets",
 CellLabel->"Out[1939]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"$PairBrackets", "=", "True"}]], "Input",
 CellTags->"$PairBrackets",
 CellLabel->"In[1940]:="],

Cell[BoxData[
 FormBox["True", TraditionalForm]], "Output",
 CellTags->"$PairBrackets",
 CellLabel->"Out[1940]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SP", "[", 
   RowBox[{"p", ",", "q"}], "]"}], 
  RowBox[{"SP", "[", 
   RowBox[{"r", ",", "s"}], "]"}]}]], "Input",
 CellTags->"$PairBrackets",
 CellLabel->"In[1941]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    RowBox[{"(", 
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm], ")"}],
    TraditionalForm], " ", 
   FormBox[
    RowBox[{"(", 
     FormBox["r",
      TraditionalForm], "\[CenterDot]", 
     FormBox["s",
      TraditionalForm], ")"}],
    TraditionalForm]}], TraditionalForm]], "Output",
 CellTags->"$PairBrackets",
 CellLabel->"Out[1941]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"$PairBrackets", "=", "False"}]], "Input",
 CellTags->"$PairBrackets",
 CellLabel->"In[1942]:="],

Cell[BoxData[
 FormBox["False", TraditionalForm]], "Output",
 CellTags->"$PairBrackets",
 CellLabel->"Out[1942]="]
}, Open  ]]
}, Open  ]],

Cell["$SpinorMinimal", "ObjectName",
 CellTags->"$SpinorMinimal"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$SpinorMinimal"],

Cell["\<\
$SpinorMinimal is a global switch for an additional simplification attempt in \
DiracSimplify for more than one Spinor-line. The default is False, since \
otherwise it costs too much time.\
\>", "Text",
 CellTags->"$SpinorMinimal"],

Cell[CellGroupData[{

Cell[BoxData["$SpinorMinimal"], "Input",
 CellTags->"$SpinorMinimal",
 CellLabel->"In[1943]:="],

Cell[BoxData[
 FormBox["False", TraditionalForm]], "Output",
 CellTags->"$SpinorMinimal",
 CellLabel->"Out[1943]="]
}, Open  ]],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["DiracSimplify",
  BaseStyle->"AddOnsLink",
  ButtonData:>"DiracSimplify",
  ButtonNote->"DiracSimplify"],
 "."
}], "Text",
 CellTags->"$SpinorMinimal"]
}, Open  ]],

Cell["$VeryVerbose", "ObjectName",
 CellTags->"$VeryVerbose"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$VeryVerbose"],

Cell["\<\
$VeryVerbose is a global variable with default setting 0. If set to 1, 2, \
..., less and more intermediate comments and informations are displayed \
during calculations.\
\>", "Text",
 CellTags->"$VeryVerbose"],

Cell[CellGroupData[{

Cell[BoxData["$VeryVerbose"], "Input",
 CellTags->"$VeryVerbose",
 CellLabel->"In[1944]:="],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellTags->"$VeryVerbose",
 CellLabel->"Out[1944]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"$VeryVerbose", " ", "=", " ", "3"}], ";"}]], "Input",
 CellTags->"$VeryVerbose",
 CellLabel->"In[1945]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Collect2", "[", 
   RowBox[{
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", "-", "y", "-", "z"}], ")"}], "^", "6"}], "]"}], ",", 
    "x"}], "]"}], ";"}]], "Input",
 CellTags->"$VeryVerbose",
 CellLabel->"In[1946]:="],

Cell["\<\
expanding. inhomogeneous part; LeafCount = 43; factored. #1#2#3#4#5#6\
\>", "Print",
 CellTags->"$VeryVerbose"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"length \"\>", "\[InvisibleSpace]", "21", 
    "\[InvisibleSpace]", "\<\".\"\>"}],
   SequenceForm["length ", 21, "."],
   Editable->False], TraditionalForm]], "Print",
 CellTags->"$VeryVerbose"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"collecting \"\>", "\[InvisibleSpace]", "6", 
    "\[InvisibleSpace]", "\<\" terms.\"\>"}],
   SequenceForm["collecting ", 6, " terms."],
   Editable->False], TraditionalForm]], "Print",
 CellTags->"$VeryVerbose"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"$VeryVerbose", "=", "0"}], ";"}]], "Input",
 CellTags->"$VeryVerbose",
 CellLabel->"In[1947]:="],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["$V0",
  BaseStyle->"AddOnsLink",
  ButtonData:>"$V0",
  ButtonNote->"$V0"],
 "."
}], "Text",
 CellTags->"$V0"]
}, Open  ]],

Cell["$West", "ObjectName",
 CellTags->"$West"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"$West"],

Cell[TextData[{
 "If $West is set to True (which is the default), traces involving more than \
4 Dirac matrices and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", "5"], TraditionalForm]]],
 " are calculated recursively according to formula (A.5) from Comp. Phys. \
Comm 77 (1993) 286-298, which is based on the Breitenlohner Maison ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", "5"], TraditionalForm]]],
 "-scheme.\nFrom FeynCalc 8.0.2 onwards this variable cannot be set to False \
(since it is not working at the moment)."
}], "Text",
 CellTags->"$West"],

Cell[TextData[{
 "See examples in ",
 ButtonBox["Tr",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Tr",
  ButtonNote->"Tr"],
 "."
}], "Text",
 CellTags->"$West"],

Cell["Evaluation time and memory usage", "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"AbsoluteTime", "[", "]"}], "-", "absolutestarttime"}]], "Input",
 CellLabel->"In[1948]:="],

Cell[BoxData[
 FormBox["168.1668`9.677285253685657", TraditionalForm]], "Output",
 CellLabel->"Out[1948]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MemoryInUse", "[", "]"}]], "Input",
 CellLabel->"In[1949]:="],

Cell[BoxData[
 FormBox["141458760", TraditionalForm]], "Output",
 CellLabel->"Out[1949]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MaxMemoryUsed", "[", "]"}]], "Input",
 CellLabel->"In[1950]:="],

Cell[BoxData[
 FormBox["141760168", TraditionalForm]], "Output",
 CellLabel->"Out[1950]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TimeUsed", "[", "]"}]], "Input",
 CellLabel->"In[1951]:="],

Cell[BoxData[
 FormBox["48.55500000000002`", TraditionalForm]], "Output",
 CellLabel->"Out[1951]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions (experimental)", "Section",
 CellTags->"Experimental"],

Cell["DoPolarizationSums", "ObjectName",
 CellTags->"DoPolarizationSums"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"DoPolarizationSums"],

Cell["\<\
***EXPERIMENTAL***
DoPolarizationSums[exp] sums over vector polarizations for expressions with a \
factor of the form
Pair[LorentzIndex[rho1_], Momentum[Polarization[p_, -I]]]*
Pair[LorentzIndex[rho2_], Momentum[Polarization[p_, I]]].\
\>", "Text",
 CellTags->"DoPolarizationSums"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["Polarization",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Polarization",
  ButtonNote->"Polarization"],
 ", ",
 ButtonBox["Uncontract",
  BaseStyle->"AddOnsLink",
  ButtonData:>"Uncontract",
  ButtonNote->"Uncontract"],
 "."
}], "Text",
 CellTags->"DoPolarizationSums"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"DoPolarizationSums"],

Cell["\<\
In the following (and indeed everywhere else within FeynCalc), notice that \
Lorentz indices written as super or subscripts are not to be taken as such. \
Instead, by convention, when two indices are contracted one is always lower \
and the other upper.\
\>", "Text",
 CellTags->"DoPolarizationSums"],

Cell["\<\
FeynCalc uses the following normalization of Polarization vectors:\
\>", "Text",
 CellTags->"DoPolarizationSums"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Pair", "[", 
   RowBox[{
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
    RowBox[{"Momentum", "[", 
     RowBox[{"Polarization", "[", 
      RowBox[{"p4", ",", 
       RowBox[{"-", "\[ImaginaryI]"}]}], "]"}], "]"}]}], "]"}], " ", 
  RowBox[{"Pair", "[", 
   RowBox[{
    RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
    RowBox[{"Momentum", "[", 
     RowBox[{"Polarization", "[", 
      RowBox[{"p4", ",", "\[ImaginaryI]"}], "]"}], "]"}]}], "]"}]}]], "Input",\

 CellTags->"DoPolarizationSums",
 CellLabel->"In[1952]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[CurlyEpsilon]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], "*"], "(", "p4", ")"}], " ", 
   RowBox[{
    SubscriptBox["\[CurlyEpsilon]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm]], "(", "p4", ")"}]}], TraditionalForm]], "Output",
 CellTags->"DoPolarizationSums",
 CellLabel->"Out[1952]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "Contract"}]], "Input",
 CellTags->"DoPolarizationSums",
 CellLabel->"In[1953]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", "1"}], TraditionalForm]], "Output",
 CellTags->"DoPolarizationSums",
 CellLabel->"Out[1953]="]
}, Open  ]],

Cell[TextData[{
 "DoPolarizationSums is chosen in such a way as to be consistent with this \
normalization and with ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox["\[Sum]", "Polarizations"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[CurlyEpsilon]", 
      FormBox[
       FormBox["\[Mu]",
        TraditionalForm],
       TraditionalForm]], "(", 
     FormBox[
      SubscriptBox[
       TagBox[
        StyleBox["\<\"p\"\>",
         FontSlant->"Italic"],
        StyleForm[#, FontSlant -> "Italic"]& ], "4"],
      TraditionalForm], ")"}], " ", 
    RowBox[{
     SubscriptBox[
      RowBox[{"(", 
       SuperscriptBox["\[CurlyEpsilon]", "\[Nu]"], ")"}], 
      FormBox["",
       TraditionalForm]], "(", 
     FormBox[
      SubscriptBox[
       TagBox[
        StyleBox["\<\"p\"\>",
         FontSlant->"Italic"],
        StyleForm[#, FontSlant -> "Italic"]& ], "4"],
      TraditionalForm], ")"}]}], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", 
    FormBox[
     SuperscriptBox[
      SubscriptBox["g", "\[Mu]"], 
      RowBox[{"\[NoBreak]", 
       FormBox["\[Nu]",
        TraditionalForm]}]],
     TraditionalForm]}], TraditionalForm]]],
 ":"
}], "Text",
 CellTags->"DoPolarizationSums"],

Cell[TextData[{
 "We can choose e.g. the following polarization vectors, labeled with a \
subscript, {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["e", "1"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["e", "2"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["e", "3"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   SubscriptBox["e", "4"], TraditionalForm]]],
 "} = {(\[ImaginaryI],0,0,0), (0,\[ImaginaryI],0,0), (0,0,\[ImaginaryI],0), \
(0,0,0,\[ImaginaryI])}."
}], "Text",
 CellTags->"DoPolarizationSums"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"ee", ",", "tt"}], "]"}]], "Input",
 CellTags->"DoPolarizationSums",
 CellLabel->"In[1954]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ev", "[", "i_", "]"}], ":=", 
   RowBox[{"ReplacePart", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", "I", ",", 
     "i"}], "]"}]}], ";"}]], "Input",
 CellTags->"DoPolarizationSums",
 CellLabel->"In[1955]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ev", "[", "1", "]"}], ",", 
   RowBox[{"ev", "[", "2", "]"}], ",", 
   RowBox[{"ev", "[", "3", "]"}], ",", 
   RowBox[{"ev", "[", "4", "]"}]}], "}"}]], "Input",
 CellTags->"DoPolarizationSums",
 CellLabel->"In[1956]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"\[ImaginaryI]", "0", "0", "0"},
     {"0", "\[ImaginaryI]", "0", "0"},
     {"0", "0", "\[ImaginaryI]", "0"},
     {"0", "0", "0", "\[ImaginaryI]"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 CellTags->"DoPolarizationSums",
 CellLabel->"Out[1956]="]
}, Open  ]],

Cell[TextData[{
 StyleBox["ee[i][\[Mu]]", "Input"],
 " is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["e", "i"], "\[Mu]"], TraditionalForm]]],
 ":"
}], "Text",
 CellTags->"DoPolarizationSums"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ee", "[", "i_", "]"}], "[", "mu_", "]"}], ":=", 
   RowBox[{
    RowBox[{"ev", "[", "i", "]"}], "[", 
    RowBox[{"[", "mu", "]"}], "]"}]}], ";"}]], "Input",
 CellTags->"DoPolarizationSums",
 CellLabel->"In[1957]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"tt", "[", 
   RowBox[{"i_", ",", "j_", ",", "mu_", ",", "nu_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"ee", "[", "i", "]"}], "[", "mu", "]"}], 
   RowBox[{
    RowBox[{"ee", "[", "j", "]"}], "[", "nu", "]"}]}]}]], "Input",
 CellTags->"DoPolarizationSums",
 CellLabel->"In[1958]:="],

Cell[TextData[{
 StyleBox["tt[i,j,\[Mu],\[Nu]]", "Input"],
 " is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["e", "i"], "\[Mu]"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["e", "j"], "\[Nu]"], TraditionalForm]]],
 ":"
}], "Text",
 CellTags->"DoPolarizationSums"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   UnderscriptBox["\[Sum]", 
    RowBox[{"i", ",", "j"}]], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     FormBox[
      SuperscriptBox[
       SubscriptBox["e", "i"], "\[Mu]"],
      TraditionalForm], 
     FormBox[
      SubscriptBox["e", 
       RowBox[{"j", ",", "\[Nu]"}]],
      TraditionalForm]}]}], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", 
    FormBox[
     SuperscriptBox[
      SubscriptBox["g", "\[Mu]"], 
      RowBox[{"\[NoBreak]", 
       FormBox["\[Nu]",
        TraditionalForm]}]],
     TraditionalForm]}], TraditionalForm]]],
 ":"
}], "Text",
 CellTags->"DoPolarizationSums"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"i", "=", "1"}], "4"], 
    RowBox[{"tt", "[", 
     RowBox[{"i", ",", "i", ",", "mu", ",", "nu"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"mu", ",", "1", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"nu", ",", "1", ",", "4"}], "}"}]}], "]"}]], "Input",
 CellTags->"DoPolarizationSums",
 CellLabel->"In[1959]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "1"}], "0", "0", "0"},
     {"0", 
      RowBox[{"-", "1"}], "0", "0"},
     {"0", "0", 
      RowBox[{"-", "1"}], "0"},
     {"0", "0", "0", 
      RowBox[{"-", "1"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 CellTags->"DoPolarizationSums",
 CellLabel->"Out[1959]="]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   UnderscriptBox["\[Sum]", 
    RowBox[{"\[Mu]", ",", "\[Nu]"}]], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     FormBox[
      SuperscriptBox[
       SubscriptBox["e", "i"], "\[Mu]"],
      TraditionalForm], 
     FormBox[
      SubscriptBox["e", 
       RowBox[{"j", ",", "\[Nu]"}]],
      TraditionalForm]}]}], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", 
    FormBox[
     SuperscriptBox[
      SubscriptBox["g", "i"], "j"],
     TraditionalForm]}], TraditionalForm]]],
 ":"
}], "Text",
 CellTags->"DoPolarizationSums"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"mu", "=", "1"}], "4"], 
    RowBox[{"tt", "[", 
     RowBox[{"i", ",", "j", ",", "mu", ",", "mu"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "1", ",", "4"}], "}"}]}], "]"}]], "Input",
 CellTags->"DoPolarizationSums",
 CellLabel->"In[1960]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "1"}], "0", "0", "0"},
     {"0", 
      RowBox[{"-", "1"}], "0", "0"},
     {"0", "0", 
      RowBox[{"-", "1"}], "0"},
     {"0", "0", "0", 
      RowBox[{"-", "1"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 CellTags->"DoPolarizationSums",
 CellLabel->"Out[1960]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptest", "=", 
  RowBox[{
   RowBox[{"Pair", "[", 
    RowBox[{
     RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
     RowBox[{"LorentzIndex", "[", 
      RowBox[{"ComplexIndex", "[", "\[Mu]", "]"}], "]"}]}], "]"}], " ", 
   RowBox[{"Pair", "[", 
    RowBox[{
     RowBox[{"LorentzIndex", "[", "\[Mu]", "]"}], ",", 
     RowBox[{"Momentum", "[", 
      RowBox[{"Polarization", "[", 
       RowBox[{"p4", ",", 
        RowBox[{"-", "\[ImaginaryI]"}]}], "]"}], "]"}]}], "]"}], " ", 
   RowBox[{"Pair", "[", 
    RowBox[{
     RowBox[{"LorentzIndex", "[", 
      RowBox[{"ComplexIndex", "[", "\[Mu]", "]"}], "]"}], ",", 
     RowBox[{"Momentum", "[", 
      RowBox[{"Polarization", "[", 
       RowBox[{"p4", ",", "\[ImaginaryI]"}], "]"}], "]"}]}], 
    "]"}]}]}]], "Input",
 CellTags->"DoPolarizationSums",
 CellLabel->"In[1961]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox["g", 
    RowBox[{"\[Mu]", 
     FormBox[
      SuperscriptBox["\[Mu]", "*"],
      TraditionalForm]}]], " ", 
   RowBox[{
    SubsuperscriptBox["\[CurlyEpsilon]", 
     FormBox[
      FormBox["\[Mu]",
       TraditionalForm],
      TraditionalForm], "*"], "(", "p4", ")"}], " ", 
   RowBox[{
    SubscriptBox["\[CurlyEpsilon]", 
     FormBox[
      FormBox[
       SuperscriptBox["\[Mu]", "*"],
       TraditionalForm],
      TraditionalForm]], "(", "p4", ")"}]}], TraditionalForm]], "Output",
 CellTags->"DoPolarizationSums",
 CellLabel->"Out[1961]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptest", "//", "DoPolarizationSums"}]], "Input",
 CellTags->"DoPolarizationSums",
 CellLabel->"In[1962]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   SuperscriptBox[
    FormBox[
     SuperscriptBox["g", 
      RowBox[{"\[Mu]", 
       FormBox[
        SuperscriptBox["\[Mu]", "*"],
        TraditionalForm]}]],
     TraditionalForm], "2"]}], TraditionalForm]], "Output",
 CellTags->"DoPolarizationSums",
 CellLabel->"Out[1962]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "Contract"}]], "Input",
 CellTags->"DoPolarizationSums",
 CellLabel->"In[1963]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", "4"}], TraditionalForm]], "Output",
 CellTags->"DoPolarizationSums",
 CellLabel->"Out[1963]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptest", "//", "Contract"}]], "Input",
 CellTags->"DoPolarizationSums",
 CellLabel->"In[1964]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", "1"}], TraditionalForm]], "Output",
 CellTags->"DoPolarizationSums",
 CellLabel->"Out[1964]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "DoPolarizationSums"}]], "Input",
 CellTags->"DoPolarizationSums",
 CellLabel->"In[1965]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"-", "4"}], TraditionalForm]], "Output",
 CellTags->"DoPolarizationSums",
 CellLabel->"Out[1965]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"ee", ",", "tt", ",", "ev", ",", "ptest"}], "]"}]], "Input",
 CellTags->"DoPolarizationSums",
 CellLabel->"In[1966]:="]
}, Open  ]],

Cell["FeynmanDoIntegrals ***unfinished***", "ObjectName",
 CellTags->"FeynmanDoIntegrals"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FeynmanDoIntegrals"],

Cell["\<\
***EXPERIMENTAL***
 FeynmanDoIntegrals[exp, moms, vars] attempts to evaluate integrals over \
Feynman parameters vars in an expression exp as produced e.g. with \
FeynmanReduce. The variables given must be atomic quantities (AtomQ). If vars \
is omitted all variables in the integrals will be integrated. If vars is \
given, only the variables in vars will be integrated. moms is a list of all \
external momenta. The integrals in exp must be given in the form \
Integratedx[x, low, up].int, where x is the integration variable, low and up \
are the integration limits and int the integrand. The interval [low,up] is \
assumed to include integration bounds put by possible DeltaFunctions and \
moreover it is assumed that up \[GreaterEqual] 0 and that up > low. The two \
options FCIntegrate and FCNIntegrate determine which integration will be \
applied to integrals judged respectively analytically and numerically doable. \
This judging is a very rough one. Using (TimedIntegrate[##, \
Integrate\[Rule]Integrate]&) or (TimedIntegrate[##, \
Integrate\[Rule]NIntegrate]&) as the setting of one or both allows for finer \
judging. Those that are judged neither analytically nor numerically doable \
are left unevaluated, but can of course be attempted evaluated by a simple \
sustitution. Beside the explicit options of FeynmanDoIntegrals options of the \
integration functions specified (FCIntegrate and FCNIntegrate) may be given \
and are passed on to these.\
\>", "Text",
 CellTags->"FeynmanDoIntegrals"],

Cell[TextData[{
 "See also: ",
 " ",
 ButtonBox["FeynmanReduce",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynmanReduce",
  ButtonNote->"FeynmanReduce"],
 ", ",
 ButtonBox["FeynmanParametrize1",
  BaseStyle->"AddOnsLink",
  ButtonData:>"FeynmanParametrize1",
  ButtonNote->"FeynmanParametrize1"],
 "."
}], "Text",
 CellTags->"FeynmanDoIntegrals"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "FeynmanDoIntegrals", "]"}]], "Input",
 CellTags->"FeynmanDoIntegrals",
 CellLabel->"In[1967]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"NIntegrate", "\[Rule]", "False"}], ",", 
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"EpsilonOrder", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", "0"}], "}"}]}], ",", 
    RowBox[{"FCIntegrate", "\[Rule]", "TimedIntegrate"}], ",", 
    RowBox[{"Simplify", "\[Rule]", "True"}], ",", 
    RowBox[{"Expand", "\[Rule]", "True"}], ",", 
    RowBox[{"Series", "\[Rule]", "True"}], ",", 
    RowBox[{"FCNIntegrate", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"DOT", "(", 
        RowBox[{
         RowBox[{"Sequence", "@@", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
             "HighEnergyPhysics`fcdevel`FeynmanDoIntegrals`Private`\
Integratedx", "@@", "#1"}], "&"}], ")"}], "/@", 
           RowBox[{"{", "##2", "}"}]}]}], ",", "#1"}], ")"}], "&"}], 
      ")"}]}]}], "}"}], TraditionalForm]], "Output",
 CellTags->"FeynmanDoIntegrals",
 CellLabel->"Out[1967]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FeynmanDoIntegrals"],

Cell[BoxData[""], "Input",
 CellTags->"FeynmanDoIntegrals",
 CellLabel->"In[1968]:="]
}, Open  ]],

Cell["FeynmanParametrize1 ***unfinished***", "ObjectName",
 CellTags->"FeynmanParametrize1"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FeynmanParametrize1"],

Cell["\<\
***EXPERIMENTAL***
 FeynmanParametrize1[exp,k,Method->Denominator] introduces Feynman parameters \
for all one-loop integrals in exp (k = integration momentum) using formula \
(11.A.1) from \"The Quantum Theory of Fields\" vol. 1 by Steven Weinberg.  \
FeynmanParametrize1[exp,k,Method->Exp] introduces Feynman parameters for all \
one-loop integrals in exp (k = integration momentum) using 1/(A-I eps) = I \
Integrate[Exp[-I x (A-I eps)],{x,0,Infinity}, \
Assumptions->{Arg[A]==0,Arg[eps]==0}]. In this case, when the option \
Integrate is set to True, odd factors of k-tensors are dropped and even \
factors are replaced according to Itzykson&Zuber (8-117).\
\>", "Text",
 CellTags->"FeynmanParametrize1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "FeynmanParametrize1", "]"}]], "Input",
 CellTags->"FeynmanParametrize1",
 CellLabel->"In[1969]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"FeynmanParameterNames", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e"}], "}"}]}], ",", 
    RowBox[{"Method", "\[Rule]", "Denominator"}], ",", 
    RowBox[{"Integrate", "\[Rule]", "True"}], ",", 
    RowBox[{"Flatten", "\[Rule]", "True"}], ",", 
    RowBox[{"CompleteSquare", "\[Rule]", "True"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"FeynmanParametrize1",
 CellLabel->"Out[1969]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FeynmanParametrize1"],

Cell[BoxData[""], "Input",
 CellTags->"FeynmanParametrize1",
 CellLabel->"In[1970]:="]
}, Open  ]],

Cell["FeynmanReduce ***unfinished***", "ObjectName",
 CellTags->"FeynmanReduce"],

Cell[CellGroupData[{

Cell["Description", "Subsubsection",
 CellTags->"FeynmanReduce"],

Cell["\<\
***EXPERIMENTAL***
 FeynmanReduce[exp,params] takes a Feynman parameterized expression exp (as \
e.g. generated with FeynmanParametrize1) and a list of Feynman parameters as \
input and attempts to simplify the expression. If no parameters are given, \
Integratedx variables in the expression will be used. Currently, reduction of \
exponentials is implemented. This will work on terms of the form \
E^p1[a,b,c,...]*p2[a,b,c,...], where p1 and p2 are fractions of polynomials \
in the Feynman parameters a,b,c,... If the option Expand is set to True, \
FeynmanReduce will attempt to bring the expression exp into a sum of such \
terms and operate on the terms one by one.\
\>", "Text",
 CellTags->"FeynmanReduce"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "FeynmanReduce", "]"}]], "Input",
 CellTags->"FeynmanReduce",
 CellLabel->"In[1971]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
    RowBox[{"Flatten", "\[Rule]", "True"}], ",", 
    RowBox[{"Expand", "\[Rule]", "True"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"FeynmanReduce",
 CellLabel->"Out[1971]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 CellTags->"FeynmanReduce"],

Cell[BoxData[""], "Input",
 CellTags->"FeynmanReduce",
 CellLabel->"In[1972]:="],

Cell["\<\
Other objects that are considered to be ok or under active development:\
\>", "Text",
 CellTags->"Experimental"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "ChargeConjugationMatrix", ",", " ", "DiracGammaT", ",", " ", 
   "SquareAmplitude"}], "}"}]], "Input",
 CellTags->"Experimental",
 CellLabel->"In[1973]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"C", ",", "DiracGammaT", ",", "SquareAmplitude"}], "}"}], 
  TraditionalForm]], "Output",
 CellTags->"Experimental",
 CellLabel->"Out[1973]="]
}, Open  ]],

Cell["Objects that are under consideration for being discarded:", "Text",
 CellTags->"Experimental"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "$OPEWard", ",", "$AchmedRoss", ",", "Contract2", ",", 
   "SpinSumExternalMomentum", ",", "SelectedGraphs"}], "}"}]], "Input",
 CellTags->"Experimental",
 CellLabel->"In[1974]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "False", ",", "False", ",", "Contract2", ",", "SpinSumExternalMomentum", 
    ",", "SelectedGraphs"}], "}"}], TraditionalForm]], "Output",
 CellTags->"Experimental",
 CellLabel->"Out[1974]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["AbsoluteTime[]-absolutestarttime", "Input",
 CellLabel->"In[1975]:="],

Cell[BoxData[
 FormBox["169.6508`9.6811009054274", TraditionalForm]], "Output",
 CellLabel->"Out[1975]="]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"AllBrackets",
WindowToolbars->"EditBar",
EvaluationCompletionAction->{},
WindowSize->{825, 679},
WindowMargins->{{16, Automatic}, {Automatic, 0}},
PrintingStartingPageNumber->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, 
   Cell[
    TextData[
     ValueBox["FileName"]], "Header"], Inherited}, {Inherited, 
   Cell[
    TextData[
     ValueBox["FileName"]], "Header"], Inherited}},
PageFooters->{{Inherited, 
   Cell[
    TextData[
     ValueBox["DateLong"]], "Footer"], Inherited}, {Inherited, 
   Cell[
    TextData[
     ValueBox["DateLong"]], "Footer"], Inherited}},
PrintingOptions->{"FacingPages"->True,
"FirstPageFace"->Left,
"FirstPageFooter"->True,
"FirstPageHeader"->False,
"GraphicsPrintingFormat"->"Automatic",
"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{597.5625, 842.375},
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->True,
"PrintSelectionHighlighting"->False,
"PrintingMargins"->{{54., 54.}, {72., 72.}}},
PrivateNotebookOptions->{"ShortBoxForm"->False},
ShowSelection->True,
TaggingRules:>{
 "MakeContentsNonDefaultOptions" -> {
   AutomaticCellTagging -> FromContent, PageNumbers -> False, SaveOptions -> 
    True, SelectCellStyles -> {"Section", "Subsection"}, 
    TOCCellStyles -> {"Contents", "Index"}}},
CellLabelAutoDelete->True,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "ClickSave"->{
  Cell[1210, 47, 799, 21, 29, NotebookDefault,
   CellTags->"ClickSave"]},
 "Functions"->{
  Cell[2571, 93, 52, 1, 63, "Section",
   CellTags->"Functions"]},
 "Abbreviation"->{
  Cell[4437, 164, 84, 2, 39, "ObjectName",
   PageBreakAbove->True,
   CellTags->"Abbreviation"],
  Cell[4546, 170, 63, 1, 33, "Subsubsection",
   CellTags->"Abbreviation"],
  Cell[4612, 173, 329, 6, 39, "Text",
   CellTags->"Abbreviation"],
  Cell[4944, 181, 1032, 43, 39, "Text",
   CellTags->"Abbreviation"],
  Cell[6013, 229, 60, 1, 33, "Subsubsection",
   CellTags->"Abbreviation"],
  Cell[6098, 234, 264, 8, 27, "Input",
   CellTags->"Abbreviation"],
  Cell[6365, 244, 228, 8, 28, "Output",
   CellTags->"Abbreviation"]},
 "Amplitude"->{
  Cell[6620, 256, 55, 1, 39, "ObjectName",
   CellTags->"Amplitude"],
  Cell[6700, 261, 60, 1, 33, "Subsubsection",
   CellTags->"Amplitude"],
  Cell[6763, 264, 529, 9, 71, "Text",
   CellTags->"Amplitude"],
  Cell[7317, 277, 115, 3, 27, "Input",
   CellTags->"Amplitude"],
  Cell[7435, 282, 328, 10, 25, "Output",
   CellTags->"Amplitude"],
  Cell[7778, 295, 177, 9, 23, "Text",
   CellTags->"Amplitude"],
  Cell[7992, 309, 57, 1, 33, "Subsubsection",
   CellTags->"Amplitude"],
  Cell[8074, 314, 133, 4, 27, "Input",
   CellTags->"Amplitude"],
  Cell[8210, 320, 104, 3, 25, "Output",
   CellTags->"Amplitude"],
  Cell[8329, 326, 93, 1, 23, "Text",
   CellTags->"Amplitude"],
  Cell[8447, 331, 121, 3, 27, "Input",
   CellTags->"Amplitude"],
  Cell[8571, 336, 2216, 95, 31, "Output",
   CellTags->"Amplitude"],
  Cell[10824, 436, 108, 3, 27, "Input",
   CellTags->"Amplitude"],
  Cell[10935, 441, 5133, 189, 71, "Output",
   CellTags->"Amplitude"],
  Cell[16083, 633, 211, 8, 23, "Text",
   CellTags->"Amplitude"],
  Cell[16319, 645, 306, 9, 27, "Input",
   CellTags->"Amplitude"],
  Cell[16628, 656, 13529, 441, 128, "Output",
   CellTags->"Amplitude"]},
 "Amputate"->{
  Cell[30184, 1101, 53, 1, 39, "ObjectName",
   CellTags->"Amputate"],
  Cell[30262, 1106, 59, 1, 33, "Subsubsection",
   CellTags->"Amputate"],
  Cell[30324, 1109, 215, 5, 39, "Text",
   CellTags->"Amputate"],
  Cell[30564, 1118, 114, 3, 27, "Input",
   CellTags->"Amputate"],
  Cell[30681, 1123, 296, 10, 25, "Output",
   CellTags->"Amputate"],
  Cell[30992, 1136, 656, 28, 23, "Text",
   CellTags->"Amputate"],
  Cell[31685, 1169, 56, 1, 33, "Subsubsection",
   CellTags->"Amputate"],
  Cell[31766, 1174, 170, 5, 27, "Input",
   CellTags->"Amputate"],
  Cell[31939, 1181, 428, 16, 25, "Output",
   CellTags->"Amputate"],
  Cell[32404, 1202, 131, 4, 27, "Input",
   CellTags->"Amputate"],
  Cell[32538, 1208, 721, 27, 27, "Output",
   CellTags->"Amputate"]},
 "AnomalousDimension"->{
  Cell[33286, 1239, 73, 1, 39, "ObjectName",
   CellTags->"AnomalousDimension"],
  Cell[33384, 1244, 69, 1, 33, "Subsubsection",
   CellTags->"AnomalousDimension"],
  Cell[33456, 1247, 143, 4, 23, "Text",
   CellTags->"AnomalousDimension"],
  Cell[33624, 1255, 134, 3, 27, "Input",
   CellTags->"AnomalousDimension"],
  Cell[33761, 1260, 254, 8, 25, "Output",
   CellTags->"AnomalousDimension"],
  Cell[34030, 1271, 406, 18, 23, "Text",
   CellTags->"AnomalousDimension"],
  Cell[34473, 1294, 66, 1, 33, "Subsubsection",
   CellTags->"AnomalousDimension"],
  Cell[34542, 1297, 63, 1, 23, "Text",
   CellTags->"AnomalousDimension"],
  Cell[34630, 1302, 206, 5, 27, "Input",
   CellTags->"AnomalousDimension"],
  Cell[34839, 1309, 254, 8, 25, "Output",
   CellTags->"AnomalousDimension"],
  Cell[35108, 1320, 241, 9, 30, "Text",
   CellTags->"AnomalousDimension"],
  Cell[35374, 1333, 133, 3, 27, "Input",
   CellTags->"AnomalousDimension"],
  Cell[35510, 1338, 462, 17, 43, "Output",
   CellTags->"AnomalousDimension"],
  Cell[35987, 1358, 240, 9, 30, "Text",
   CellTags->"AnomalousDimension"],
  Cell[36252, 1371, 132, 3, 27, "Input",
   CellTags->"AnomalousDimension"],
  Cell[36387, 1376, 284, 10, 43, "Output",
   CellTags->"AnomalousDimension"],
  Cell[36686, 1389, 240, 9, 30, "Text",
   CellTags->"AnomalousDimension"],
  Cell[36951, 1402, 132, 3, 27, "Input",
   CellTags->"AnomalousDimension"],
  Cell[37086, 1407, 283, 10, 43, "Output",
   CellTags->"AnomalousDimension"],
  Cell[37384, 1420, 240, 9, 30, "Text",
   CellTags->"AnomalousDimension"],
  Cell[37649, 1433, 132, 3, 27, "Input",
   CellTags->"AnomalousDimension"],
  Cell[37784, 1438, 594, 21, 45, "Output",
   CellTags->"AnomalousDimension"],
  Cell[38393, 1462, 241, 9, 30, "Text",
   CellTags->"AnomalousDimension"],
  Cell[38659, 1475, 133, 3, 27, "Input",
   CellTags->"AnomalousDimension"],
  Cell[38795, 1480, 689, 23, 47, "Output",
   CellTags->"AnomalousDimension"],
  Cell[39499, 1506, 241, 9, 30, "Text",
   CellTags->"AnomalousDimension"],
  Cell[39765, 1519, 133, 3, 27, "Input",
   CellTags->"AnomalousDimension"],
  Cell[39901, 1524, 6606, 218, 242, "Output",
   CellTags->"AnomalousDimension"],
  Cell[46522, 1745, 240, 9, 30, "Text",
   CellTags->"AnomalousDimension"],
  Cell[46787, 1758, 132, 3, 27, "Input",
   CellTags->"AnomalousDimension"],
  Cell[46922, 1763, 4116, 140, 151, "Output",
   CellTags->"AnomalousDimension"],
  Cell[51053, 1906, 240, 9, 30, "Text",
   CellTags->"AnomalousDimension"],
  Cell[51318, 1919, 132, 3, 27, "Input",
   CellTags->"AnomalousDimension"],
  Cell[51453, 1924, 6222, 212, 241, "Output",
   CellTags->"AnomalousDimension"],
  Cell[57690, 2139, 240, 9, 30, "Text",
   CellTags->"AnomalousDimension"],
  Cell[57955, 2152, 132, 3, 27, "Input",
   CellTags->"AnomalousDimension"],
  Cell[58090, 2157, 4910, 166, 187, "Output",
   CellTags->"AnomalousDimension"],
  Cell[63015, 2326, 267, 9, 30, "Text",
   CellTags->"AnomalousDimension"],
  Cell[63307, 2339, 132, 3, 27, "Input",
   CellTags->"AnomalousDimension"],
  Cell[63442, 2344, 4379, 139, 147, "Output",
   CellTags->"AnomalousDimension"],
  Cell[67836, 2486, 326, 10, 30, "Text",
   CellTags->"AnomalousDimension"],
  Cell[68187, 2500, 295, 9, 27, "Input",
   CellTags->"AnomalousDimension"],
  Cell[68485, 2511, 239, 7, 25, "Output",
   CellTags->"AnomalousDimension"]},
 "AntiCommutator"->{
  Cell[68751, 2522, 65, 1, 39, "ObjectName",
   CellTags->"AntiCommutator"],
  Cell[68841, 2527, 65, 1, 33, "Subsubsection",
   CellTags->"AntiCommutator"],
  Cell[68909, 2530, 145, 4, 23, "Text",
   CellTags->"AntiCommutator"],
  Cell[69057, 2536, 599, 24, 23, "Text",
   CellTags->"AntiCommutator"],
  Cell[69693, 2565, 62, 1, 33, "Subsubsection",
   CellTags->"AntiCommutator"],
  Cell[69758, 2568, 200, 9, 23, "Text",
   CellTags->"AntiCommutator"],
  Cell[69961, 2579, 150, 4, 27, "Input",
   CellTags->"AntiCommutator"],
  Cell[70136, 2587, 143, 4, 27, "Input",
   CellTags->"AntiCommutator"],
  Cell[70282, 2593, 163, 5, 25, "Output",
   CellTags->"AntiCommutator"],
  Cell[70482, 2603, 124, 3, 27, "Input",
   CellTags->"AntiCommutator"],
  Cell[70609, 2608, 180, 6, 25, "Output",
   CellTags->"AntiCommutator"],
  Cell[70826, 2619, 265, 8, 27, "Input",
   CellTags->"AntiCommutator"],
  Cell[71094, 2629, 438, 16, 25, "Output",
   CellTags->"AntiCommutator"],
  Cell[71569, 2650, 258, 8, 27, "Input",
   CellTags->"AntiCommutator"],
  Cell[71830, 2660, 318, 11, 25, "Output",
   CellTags->"AntiCommutator"],
  Cell[72163, 2674, 218, 6, 29, "Input",
   CellTags->"AntiCommutator"],
  Cell[72384, 2682, 104, 1, 23, "Text",
   CellTags->"AntiCommutator"],
  Cell[72513, 2687, 177, 5, 27, "Input",
   CellTags->"AntiCommutator"],
  Cell[72693, 2694, 109, 3, 25, "Output",
   CellTags->"AntiCommutator"],
  Cell[72839, 2702, 182, 5, 27, "Input",
   CellTags->"AntiCommutator"],
  Cell[73024, 2709, 190, 6, 25, "Output",
   CellTags->"AntiCommutator"],
  Cell[73251, 2720, 250, 8, 29, "Input",
   CellTags->"AntiCommutator"],
  Cell[73504, 2730, 132, 4, 25, "Output",
   CellTags->"AntiCommutator"],
  Cell[73673, 2739, 252, 7, 29, "Input",
   CellTags->"AntiCommutator"],
  Cell[73928, 2748, 315, 11, 27, "Output",
   CellTags->"AntiCommutator"],
  Cell[74258, 2762, 240, 6, 29, "Input",
   CellTags->"AntiCommutator"],
  Cell[74501, 2770, 176, 5, 27, "Input",
   CellTags->"AntiCommutator"],
  Cell[74680, 2777, 226, 7, 29, "Input",
   CellTags->"AntiCommutator"]},
 "AntiQuarkField"->{
  Cell[74921, 2787, 65, 1, 59, "ObjectName",
   CellTags->"AntiQuarkField"],
  Cell[75011, 2792, 65, 1, 49, "Subsubsection",
   CellTags->"AntiQuarkField"],
  Cell[75079, 2795, 197, 4, 34, "Text",
   CellTags->"AntiQuarkField"],
  Cell[75279, 2801, 313, 14, 23, "Text",
   CellTags->"AntiQuarkField"],
  Cell[75629, 2820, 62, 1, 33, "Subsubsection",
   CellTags->"AntiQuarkField"],
  Cell[75716, 2825, 93, 2, 27, "Input",
   CellTags->"AntiQuarkField"],
  Cell[75812, 2829, 137, 4, 25, "Output",
   CellTags->"AntiQuarkField"]},
 "AntiSymmetrize"->{
  Cell[75976, 2837, 65, 1, 39, "ObjectName",
   CellTags->"AntiSymmetrize"],
  Cell[76066, 2842, 65, 1, 33, "Subsubsection",
   CellTags->"AntiSymmetrize"],
  Cell[76134, 2845, 153, 4, 23, "Text",
   CellTags->"AntiSymmetrize"],
  Cell[76290, 2851, 185, 8, 23, "Text",
   CellTags->"AntiSymmetrize"],
  Cell[76512, 2864, 62, 1, 33, "Subsubsection",
   CellTags->"AntiSymmetrize"],
  Cell[76599, 2869, 246, 8, 27, "Input",
   CellTags->"AntiSymmetrize"],
  Cell[76848, 2879, 319, 11, 43, "Output",
   CellTags->"AntiSymmetrize"],
  Cell[77204, 2895, 266, 8, 27, "Input",
   CellTags->"AntiSymmetrize"],
  Cell[77473, 2905, 654, 20, 43, "Output",
   CellTags->"AntiSymmetrize"]},
 "Anti5"->{
  Cell[78154, 2929, 47, 1, 39, "ObjectName",
   CellTags->"Anti5"],
  Cell[78226, 2934, 56, 1, 33, "Subsubsection",
   CellTags->"Anti5"],
  Cell[78285, 2937, 487, 16, 39, "Text",
   CellTags->"Anti5"],
  Cell[78775, 2955, 163, 7, 23, "Text",
   CellTags->"Anti5"],
  Cell[78941, 2964, 423, 19, 23, "Text",
   CellTags->"Anti5"],
  Cell[79401, 2988, 53, 1, 33, "Subsubsection",
   CellTags->"Anti5"],
  Cell[79479, 2993, 154, 5, 27, "Input",
   CellTags->"Anti5"],
  Cell[79636, 3000, 186, 6, 27, "Output",
   CellTags->"Anti5"],
  Cell[79859, 3011, 102, 3, 27, "Input",
   CellTags->"Anti5"],
  Cell[79964, 3016, 290, 11, 27, "Output",
   CellTags->"Anti5"],
  Cell[80291, 3032, 144, 5, 27, "Input",
   CellTags->"Anti5"],
  Cell[80438, 3039, 265, 10, 27, "Output",
   CellTags->"Anti5"],
  Cell[80740, 3054, 194, 6, 27, "Input",
   CellTags->"Anti5"],
  Cell[80937, 3062, 320, 9, 27, "Output",
   CellTags->"Anti5"],
  Cell[81294, 3076, 125, 4, 27, "Input",
   CellTags->"Anti5"],
  Cell[81422, 3082, 320, 9, 27, "Output",
   CellTags->"Anti5"],
  Cell[81779, 3096, 133, 4, 27, "Input",
   CellTags->"Anti5"],
  Cell[81915, 3102, 320, 9, 27, "Output",
   CellTags->"Anti5"],
  Cell[82272, 3116, 151, 5, 27, "Input",
   CellTags->"Anti5"],
  Cell[82426, 3123, 320, 9, 27, "Output",
   CellTags->"Anti5"],
  Cell[82761, 3135, 351, 14, 23, "Text",
   CellTags->"Anti5"],
  Cell[83137, 3153, 127, 4, 27, "Input",
   CellTags->"Anti5"],
  Cell[83267, 3159, 191, 6, 27, "Output",
   CellTags->"Anti5"],
  Cell[83495, 3170, 102, 3, 27, "Input",
   CellTags->"Anti5"],
  Cell[83600, 3175, 290, 11, 27, "Output",
   CellTags->"Anti5"]},
 "Apart2"->{
  Cell[83917, 3190, 49, 1, 39, "ObjectName",
   CellTags->"Apart2"],
  Cell[83991, 3195, 57, 1, 33, "Subsubsection",
   CellTags->"Apart2"],
  Cell[84051, 3198, 108, 3, 23, "Text",
   CellTags->"Apart2"],
  Cell[84162, 3203, 302, 14, 23, "Text",
   CellTags->"Apart2"],
  Cell[84501, 3222, 54, 1, 33, "Subsubsection",
   CellTags->"Apart2"],
  Cell[84580, 3227, 256, 9, 27, "Input",
   CellTags->"Apart2"],
  Cell[84839, 3238, 1188, 30, 49, "Output",
   CellTags->"Apart2"],
  Cell[86064, 3273, 104, 3, 27, "Input",
   CellTags->"Apart2"],
  Cell[86171, 3278, 720, 26, 55, "Output",
   CellTags->"Apart2"],
  Cell[86928, 3309, 140, 4, 27, "Input",
   CellTags->"Apart2"],
  Cell[87071, 3315, 517, 19, 56, "Output",
   CellTags->"Apart2"]},
 "A0"->{
  Cell[87615, 3338, 64, 2, 39, "ObjectName",
   PageBreakAbove->True,
   CellTags->"A0"],
  Cell[87704, 3344, 53, 1, 33, "Subsubsection",
   CellTags->"A0"],
  Cell[87760, 3347, 291, 11, 25, "Text",
   CellTags->"A0"],
  Cell[88076, 3362, 107, 3, 27, "Input",
   CellTags->"A0"],
  Cell[88186, 3367, 161, 6, 25, "Output",
   CellTags->"A0"],
  Cell[88362, 3376, 437, 24, 23, "Text",
   CellTags->"A0"],
  Cell[88836, 3405, 50, 1, 33, "Subsubsection",
   CellTags->"A0"],
  Cell[88889, 3408, 246, 11, 23, "Text",
   CellTags->"A0"],
  Cell[89160, 3423, 120, 4, 29, "Input",
   CellTags->"A0"],
  Cell[89283, 3429, 259, 10, 29, "Output",
   CellTags->"A0"],
  Cell[89557, 3442, 186, 6, 27, "Input",
   CellTags->"A0"],
  Cell[89768, 3452, 120, 4, 29, "Input",
   CellTags->"A0"],
  Cell[89891, 3458, 324, 11, 29, "Output",
   CellTags->"A0"],
  Cell[90230, 3472, 187, 6, 27, "Input",
   CellTags->"A0"],
  Cell[90420, 3480, 222, 8, 23, "Text",
   CellTags->"A0"],
  Cell[90667, 3492, 96, 3, 27, "Input",
   CellTags->"A0"],
  Cell[90766, 3497, 97, 3, 25, "Output",
   CellTags->"A0"],
  Cell[90900, 3505, 160, 5, 27, "Input",
   CellTags->"A0"],
  Cell[91063, 3512, 97, 3, 25, "Output",
   CellTags->"A0"]},
 "A0ToB0"->{
  Cell[91187, 3519, 72, 2, 39, "ObjectName",
   PageBreakAbove->True,
   CellTags->"A0ToB0"],
  Cell[91284, 3525, 57, 1, 33, "Subsubsection",
   CellTags->"A0ToB0"],
  Cell[91344, 3528, 614, 27, 23, "Text",
   CellTags->"A0ToB0"],
  Cell[91983, 3559, 111, 3, 27, "Input",
   CellTags->"A0ToB0"],
  Cell[92097, 3564, 165, 6, 25, "Output",
   CellTags->"A0ToB0"],
  Cell[92277, 3573, 533, 29, 23, "Text",
   CellTags->"A0ToB0"]},
 "BackgroundGluonVertex"->{
  Cell[92825, 3605, 79, 1, 39, "ObjectName",
   CellTags->"BackgroundGluonVertex"],
  Cell[92929, 3610, 72, 1, 33, "Subsubsection",
   CellTags->"BackgroundGluonVertex"],
  Cell[93004, 3613, 1042, 19, 119, "Text",
   CellTags->"BackgroundGluonVertex"],
  Cell[94071, 3636, 140, 3, 27, "Input",
   CellTags->"BackgroundGluonVertex"],
  Cell[94214, 3641, 318, 9, 25, "Output",
   CellTags->"BackgroundGluonVertex"],
  Cell[94547, 3653, 201, 9, 23, "Text",
   CellTags->"BackgroundGluonVertex"],
  Cell[94785, 3667, 69, 1, 33, "Subsubsection",
   CellTags->"BackgroundGluonVertex"],
  Cell[94879, 3672, 360, 10, 27, "Input",
   CellTags->"BackgroundGluonVertex"],
  Cell[95242, 3684, 1486, 58, 27, "Output",
   CellTags->"BackgroundGluonVertex"],
  Cell[96765, 3747, 436, 12, 27, "Input",
   CellTags->"BackgroundGluonVertex"],
  Cell[97204, 3761, 3846, 142, 50, "Output",
   CellTags->"BackgroundGluonVertex"],
  Cell[101087, 3908, 411, 11, 27, "Input",
   CellTags->"BackgroundGluonVertex"],
  Cell[101501, 3921, 1559, 60, 45, "Output",
   CellTags->"BackgroundGluonVertex"],
  Cell[103097, 3986, 487, 13, 27, "Input",
   CellTags->"BackgroundGluonVertex"],
  Cell[103587, 4001, 3954, 145, 86, "Output",
   CellTags->"BackgroundGluonVertex"]},
 "Bracket"->{
  Cell[107568, 4150, 51, 1, 39, "ObjectName",
   CellTags->"Bracket"],
  Cell[107644, 4155, 58, 1, 33, "Subsubsection",
   CellTags->"Bracket"],
  Cell[107705, 4158, 72, 1, 23, "Text",
   CellTags->"Bracket"],
  Cell[107780, 4161, 181, 9, 23, "Text",
   CellTags->"Bracket"]},
 "BReduce"->{
  Cell[107976, 4173, 74, 2, 39, "ObjectName",
   PageBreakAbove->True,
   CellTags->"BReduce"],
  Cell[108075, 4179, 58, 1, 33, "Subsubsection",
   CellTags->"BReduce"],
  Cell[108136, 4182, 148, 4, 23, "Text",
   CellTags->"BReduce"],
  Cell[108287, 4188, 534, 29, 23, "Text",
   CellTags->"BReduce"],
  Cell[108858, 4222, 55, 1, 33, "Subsubsection",
   CellTags->"BReduce"],
  Cell[108916, 4225, 251, 11, 23, "Text",
   CellTags->"BReduce"],
  Cell[109192, 4240, 134, 4, 27, "Input",
   CellTags->"BReduce"],
  Cell[109329, 4246, 176, 6, 25, "Output",
   CellTags->"BReduce"],
  Cell[109904, 4272, 94, 3, 23, "Text",
   CellTags->"BReduce"],
  Cell[110023, 4279, 183, 5, 27, "Input",
   CellTags->"BReduce"],
  Cell[110209, 4286, 260, 10, 43, "Output",
   CellTags->"BReduce"]},
 "B0"->{
  Cell[110496, 4300, 41, 1, 39, "ObjectName",
   CellTags->"B0"],
  Cell[110562, 4305, 53, 1, 33, "Subsubsection",
   CellTags->"B0"],
  Cell[110618, 4308, 390, 9, 39, "Text",
   CellTags->"B0"],
  Cell[111033, 4321, 102, 3, 27, "Input",
   CellTags->"B0"],
  Cell[111138, 4326, 280, 9, 25, "Output",
   CellTags->"B0"],
  Cell[111433, 4338, 443, 24, 23, "Text",
   CellTags->"B0"],
  Cell[111913, 4367, 50, 1, 33, "Subsubsection",
   CellTags->"B0"],
  Cell[111988, 4372, 234, 8, 29, "Input",
   CellTags->"B0"],
  Cell[112225, 4382, 316, 12, 29, "Output",
   CellTags->"B0"],
  Cell[112556, 4397, 237, 7, 27, "Input",
   CellTags->"B0"],
  Cell[112818, 4408, 154, 5, 29, "Input",
   CellTags->"B0"],
  Cell[112975, 4415, 245, 8, 29, "Output",
   CellTags->"B0"],
  Cell[113257, 4428, 179, 6, 29, "Input",
   CellTags->"B0"],
  Cell[113439, 4436, 245, 8, 29, "Output",
   CellTags->"B0"],
  Cell[113721, 4449, 177, 6, 27, "Input",
   CellTags->"B0"],
  Cell[113901, 4457, 218, 7, 29, "Output",
   CellTags->"B0"]},
 "B0Real"->{
  Cell[114146, 4468, 72, 2, 39, "ObjectName",
   PageBreakAbove->True,
   CellTags->"B0Real"],
  Cell[114243, 4474, 57, 1, 33, "Subsubsection",
   CellTags->"B0Real"],
  Cell[114303, 4477, 186, 4, 23, "Text",
   CellTags->"B0Real"],
  Cell[114492, 4483, 153, 8, 23, "Text",
   CellTags->"B0Real"],
  Cell[114682, 4496, 54, 1, 33, "Subsubsection",
   CellTags->"B0Real"],
  Cell[114739, 4499, 83, 1, 23, "Text",
   CellTags->"B0Real"],
  Cell[114847, 4504, 133, 4, 27, "Input",
   CellTags->"B0Real"],
  Cell[114983, 4510, 200, 7, 25, "Output",
   CellTags->"B0Real"],
  Cell[115220, 4522, 102, 3, 27, "Input",
   CellTags->"B0Real"],
  Cell[115325, 4527, 282, 9, 25, "Output",
   CellTags->"B0Real"],
  Cell[115622, 4539, 92, 3, 23, "Text",
   CellTags->"B0Real"],
  Cell[115739, 4546, 181, 5, 27, "Input",
   CellTags->"B0Real"],
  Cell[115923, 4553, 200, 7, 25, "Output",
   CellTags->"B0Real"]},
 "B0Unique"->{
  Cell[116150, 4564, 76, 2, 58, "ObjectName",
   PageBreakAbove->True,
   CellTags->"B0Unique"],
  Cell[116251, 4570, 59, 1, 39, "Subsubsection",
   CellTags->"B0Unique"],
  Cell[116313, 4573, 184, 4, 54, "Text",
   CellTags->"B0Unique"],
  Cell[116500, 4579, 155, 8, 33, "Text",
   CellTags->"B0Unique"],
  Cell[116692, 4592, 56, 1, 48, "Subsubsection",
   CellTags->"B0Unique"],
  Cell[116751, 4595, 73, 1, 23, "Text",
   CellTags->"B0Unique"],
  Cell[116849, 4600, 135, 4, 27, "Input",
   CellTags->"B0Unique"],
  Cell[116987, 4606, 202, 7, 25, "Output",
   CellTags->"B0Unique"],
  Cell[117226, 4618, 104, 3, 27, "Input",
   CellTags->"B0Unique"],
  Cell[117333, 4623, 284, 9, 25, "Output",
   CellTags->"B0Unique"],
  Cell[117632, 4635, 88, 3, 23, "Text",
   CellTags->"B0Unique"],
  Cell[117745, 4642, 186, 5, 27, "Input",
   CellTags->"B0Unique"],
  Cell[117934, 4649, 177, 6, 25, "Output",
   CellTags->"B0Unique"]},
 "B00"->{
  Cell[118138, 4659, 43, 1, 39, "ObjectName",
   CellTags->"B00"],
  Cell[118206, 4664, 54, 1, 33, "Subsubsection",
   CellTags->"B00"],
  Cell[118263, 4667, 290, 8, 39, "Text",
   CellTags->"B00"],
  Cell[118578, 4679, 104, 3, 27, "Input",
   CellTags->"B00"],
  Cell[118685, 4684, 162, 6, 25, "Output",
   CellTags->"B00"],
  Cell[118862, 4693, 346, 19, 23, "Text",
   CellTags->"B00"],
  Cell[119245, 4717, 51, 1, 33, "Subsubsection",
   CellTags->"B00"],
  Cell[119299, 4720, 202, 7, 23, "Text",
   CellTags->"B00"],
  Cell[119526, 4731, 97, 3, 27, "Input",
   CellTags->"B00"],
  Cell[119626, 4736, 156, 6, 27, "Output",
   CellTags->"B00"],
  Cell[119819, 4747, 211, 7, 29, "Input",
   CellTags->"B00"],
  Cell[120033, 4756, 2675, 90, 92, "Output",
   CellTags->"B00"],
  Cell[122745, 4851, 211, 7, 29, "Input",
   CellTags->"B00"],
  Cell[122959, 4860, 1452, 54, 43, "Output",
   CellTags->"B00"],
  Cell[124448, 4919, 261, 8, 29, "Input",
   CellTags->"B00"],
  Cell[124712, 4929, 516, 22, 29, "Output",
   CellTags->"B00"],
  Cell[125265, 4956, 181, 6, 29, "Input",
   CellTags->"B00"],
  Cell[125449, 4964, 614, 22, 46, "Output",
   CellTags->"B00"],
  Cell[126100, 4991, 248, 8, 29, "Input",
   CellTags->"B00"],
  Cell[126351, 5001, 641, 23, 46, "Output",
   CellTags->"B00"]},
 "B1"->{
  Cell[127019, 5028, 41, 1, 39, "ObjectName",
   CellTags->"B1"],
  Cell[127085, 5033, 53, 1, 33, "Subsubsection",
   CellTags->"B1"],
  Cell[127141, 5036, 230, 7, 23, "Text",
   CellTags->"B1"],
  Cell[127396, 5047, 102, 3, 27, "Input",
   CellTags->"B1"],
  Cell[127501, 5052, 161, 6, 25, "Output",
   CellTags->"B1"],
  Cell[127677, 5061, 559, 29, 23, "Text",
   CellTags->"B1"],
  Cell[128273, 5095, 50, 1, 33, "Subsubsection",
   CellTags->"B1"],
  Cell[128348, 5100, 209, 7, 29, "Input",
   CellTags->"B1"],
  Cell[128560, 5109, 1153, 42, 50, "Output",
   CellTags->"B1"],
  Cell[129750, 5156, 259, 8, 29, "Input",
   CellTags->"B1"],
  Cell[130012, 5166, 316, 12, 29, "Output",
   CellTags->"B1"],
  Cell[130343, 5181, 187, 6, 27, "Input",
   CellTags->"B1"],
  Cell[130555, 5191, 209, 7, 29, "Input",
   CellTags->"B1"],
  Cell[130767, 5200, 390, 15, 43, "Output",
   CellTags->"B1"],
  Cell[131194, 5220, 179, 6, 29, "Input",
   CellTags->"B1"],
  Cell[131376, 5228, 403, 14, 43, "Output",
   CellTags->"B1"],
  Cell[131816, 5247, 154, 5, 29, "Input",
   CellTags->"B1"],
  Cell[131973, 5254, 403, 14, 43, "Output",
   CellTags->"B1"],
  Cell[132413, 5273, 238, 7, 29, "Input",
   CellTags->"B1"],
  Cell[132654, 5282, 791, 25, 50, "Output",
   CellTags->"B1"],
  Cell[133482, 5312, 279, 8, 29, "Input",
   CellTags->"B1"],
  Cell[133764, 5322, 419, 14, 43, "Output",
   CellTags->"B1"]},
 "B11"->{
  Cell[134210, 5340, 43, 1, 39, "ObjectName",
   CellTags->"B11"],
  Cell[134278, 5345, 54, 1, 33, "Subsubsection",
   CellTags->"B11"],
  Cell[134335, 5348, 495, 17, 39, "Text",
   CellTags->"B11"],
  Cell[134855, 5369, 104, 3, 27, "Input",
   CellTags->"B11"],
  Cell[134962, 5374, 162, 6, 25, "Output",
   CellTags->"B11"],
  Cell[135139, 5383, 441, 24, 23, "Text",
   CellTags->"B11"],
  Cell[135617, 5412, 51, 1, 33, "Subsubsection",
   CellTags->"B11"],
  Cell[135671, 5415, 215, 7, 23, "Text",
   CellTags->"B11"],
  Cell[135911, 5426, 97, 3, 27, "Input",
   CellTags->"B11"],
  Cell[136011, 5431, 156, 6, 27, "Output",
   CellTags->"B11"],
  Cell[136204, 5442, 212, 7, 29, "Input",
   CellTags->"B11"],
  Cell[136419, 5451, 2848, 97, 99, "Output",
   CellTags->"B11"],
  Cell[139304, 5553, 212, 7, 29, "Input",
   CellTags->"B11"],
  Cell[139519, 5562, 1206, 47, 54, "Output",
   CellTags->"B11"],
  Cell[140762, 5614, 171, 5, 27, "Input",
   CellTags->"B11"],
  Cell[140936, 5621, 164, 6, 25, "Output",
   CellTags->"B11"],
  Cell[141137, 5632, 212, 7, 29, "Input",
   CellTags->"B11"],
  Cell[141352, 5641, 517, 22, 29, "Output",
   CellTags->"B11"],
  Cell[141906, 5668, 170, 5, 27, "Input",
   CellTags->"B11"],
  Cell[142079, 5675, 163, 6, 25, "Output",
   CellTags->"B11"],
  Cell[142279, 5686, 182, 6, 29, "Input",
   CellTags->"B11"],
  Cell[142464, 5694, 269, 9, 43, "Output",
   CellTags->"B11"],
  Cell[142770, 5708, 249, 8, 29, "Input",
   CellTags->"B11"],
  Cell[143022, 5718, 295, 10, 43, "Output",
   CellTags->"B11"]},
 "CA"->{
  Cell[143344, 5732, 41, 1, 39, "ObjectName",
   CellTags->"CA"],
  Cell[143410, 5737, 53, 1, 33, "Subsubsection",
   CellTags->"CA"],
  Cell[143466, 5740, 198, 9, 23, "Text",
   CellTags->"CA"],
  Cell[143667, 5751, 274, 14, 23, "Text",
   CellTags->"CA"],
  Cell[143978, 5770, 50, 1, 33, "Subsubsection",
   CellTags->"CA"],
  Cell[144053, 5775, 70, 2, 27, "Input",
   CellTags->"CA"],
  Cell[144126, 5779, 120, 4, 25, "Output",
   CellTags->"CA"],
  Cell[144283, 5788, 173, 5, 27, "Input",
   CellTags->"CA"],
  Cell[144459, 5795, 98, 3, 25, "Output",
   CellTags->"CA"],
  Cell[144594, 5803, 72, 2, 27, "Input",
   CellTags->"CA"],
  Cell[144669, 5807, 98, 3, 25, "Output",
   CellTags->"CA"]},
 "Calc"->{
  Cell[144794, 5814, 45, 1, 39, "ObjectName",
   CellTags->"Calc"],
  Cell[144864, 5819, 55, 1, 33, "Subsubsection",
   CellTags->"Calc"],
  Cell[144922, 5822, 233, 5, 39, "Text",
   CellTags->"Calc"],
  Cell[145158, 5829, 407, 19, 23, "Text",
   CellTags->"Calc"],
  Cell[145602, 5853, 61, 1, 34, "Subsubsection",
   CellTags->"Calc"],
  Cell[145666, 5856, 346, 13, 26, "Text",
   CellTags->"Calc"],
  Cell[146037, 5873, 284, 9, 27, "Input",
   CellTags->"Calc"],
  Cell[146324, 5884, 147, 5, 25, "Output",
   CellTags->"Calc"],
  Cell[146486, 5892, 213, 9, 23, "Text",
   CellTags->"Calc"],
  Cell[146724, 5905, 258, 8, 27, "Input",
   CellTags->"Calc"],
  Cell[146985, 5915, 352, 15, 27, "Output",
   CellTags->"Calc"],
  Cell[147374, 5935, 328, 11, 27, "Input",
   CellTags->"Calc"],
  Cell[147705, 5948, 424, 16, 27, "Output",
   CellTags->"Calc"],
  Cell[148166, 5969, 101, 3, 27, "Input",
   CellTags->"Calc"],
  Cell[148270, 5974, 525, 22, 27, "Output",
   CellTags->"Calc"],
  Cell[148832, 6001, 215, 6, 27, "Input",
   CellTags->"Calc"],
  Cell[149050, 6009, 985, 44, 29, "Output",
   CellTags->"Calc"],
  Cell[150072, 6058, 382, 13, 27, "Input",
   CellTags->"Calc"],
  Cell[150457, 6073, 100, 3, 25, "Output",
   CellTags->"Calc"]},
 "CalcColorFactor"->{
  Cell[150584, 6080, 67, 1, 39, "ObjectName",
   CellTags->"CalcColorFactor"],
  Cell[150676, 6085, 66, 1, 33, "Subsubsection",
   CellTags->"CalcColorFactor"],
  Cell[150745, 6088, 470, 9, 103, "Text",
   CellTags->"CalcColorFactor"],
  Cell[151218, 6099, 195, 9, 23, "Text",
   CellTags->"CalcColorFactor"]},
 "Collecting"->{
  Cell[156322, 6289, 411, 18, 23, "Text",
   CellTags->"Collecting"],
  Cell[253372, 10160, 57, 1, 39, "ObjectName",
   CellTags->"Collecting"],
  Cell[253454, 10165, 61, 1, 33, "Subsubsection",
   CellTags->"Collecting"],
  Cell[253518, 10168, 207, 5, 23, "Text",
   CellTags->"Collecting"],
  Cell[253728, 10175, 411, 18, 23, "Text",
   CellTags->"Collecting"]},
 "CalculateCounterTerm"->{
  Cell[156748, 6310, 94, 1, 39, "ObjectName",
   CellTags->"CalculateCounterTerm"],
  Cell[156867, 6315, 71, 1, 33, "Subsubsection",
   CellTags->"CalculateCounterTerm"],
  Cell[156941, 6318, 110, 1, 23, "Text",
   CellTags->"CalculateCounterTerm"],
  Cell[157088, 6324, 77, 1, 34, "Subsubsection",
   CellTags->"CalculateCounterTerm"],
  Cell[157190, 6329, 123, 3, 27, "Input",
   CellTags->"CalculateCounterTerm"],
  Cell[157316, 6334, 191, 3, 38, "Print",
   CellTags->{"CalculateCounterTerm", "Info3522790126-4590919"}]},
 "Info3522790126-4590919"->{
  Cell[157316, 6334, 191, 3, 38, "Print",
   CellTags->{"CalculateCounterTerm", "Info3522790126-4590919"}]},
 "CancelQP"->{
  Cell[157534, 6341, 53, 1, 39, "ObjectName",
   CellTags->"CancelQP"],
  Cell[157612, 6346, 59, 1, 33, "Subsubsection",
   CellTags->"CancelQP"],
  Cell[157674, 6349, 314, 13, 23, "Text",
   CellTags->"CancelQP"],
  Cell[158025, 6367, 65, 1, 34, "Subsubsection",
   CellTags->"CancelQP"],
  Cell[158115, 6372, 549, 19, 27, "Input",
   CellTags->"CancelQP"],
  Cell[158667, 6393, 667, 24, 49, "Output",
   CellTags->"CancelQP"],
  Cell[159371, 6422, 182, 5, 27, "Input",
   CellTags->"CancelQP"],
  Cell[159556, 6429, 2183, 73, 51, "Output",
   CellTags->"CancelQP"],
  Cell[161776, 6507, 183, 5, 27, "Input",
   CellTags->"CancelQP"],
  Cell[161962, 6514, 6421, 209, 209, "Output",
   CellTags->"CancelQP"],
  Cell[168420, 6728, 555, 18, 27, "Input",
   CellTags->"CancelQP"],
  Cell[168978, 6748, 886, 33, 49, "Output",
   CellTags->"CancelQP"],
  Cell[169901, 6786, 182, 5, 27, "Input",
   CellTags->"CancelQP"],
  Cell[170086, 6793, 6471, 225, 100, "Output",
   CellTags->"CancelQP"],
  Cell[176594, 7023, 183, 5, 27, "Input",
   CellTags->"CancelQP"],
  Cell[176780, 7030, 3734, 126, 51, "Output",
   CellTags->"CancelQP"],
  Cell[180529, 7159, 106, 3, 27, "Input",
   CellTags->"CancelQP"]},
 "Cases2"->{
  Cell[180650, 7165, 49, 1, 39, "ObjectName",
   CellTags->"Cases2"],
  Cell[180724, 7170, 57, 1, 33, "Subsubsection",
   CellTags->"Cases2"],
  Cell[180784, 7173, 293, 6, 39, "Text",
   CellTags->"Cases2"],
  Cell[181114, 7184, 63, 1, 34, "Subsubsection",
   CellTags->"Cases2"],
  Cell[181202, 7189, 305, 10, 29, "Input",
   CellTags->"Cases2"],
  Cell[181510, 7201, 275, 9, 25, "Output",
   CellTags->"Cases2"],
  Cell[181822, 7215, 312, 10, 27, "Input",
   CellTags->"Cases2"],
  Cell[182137, 7227, 279, 9, 25, "Output",
   CellTags->"Cases2"],
  Cell[182453, 7241, 427, 14, 27, "Input",
   CellTags->"Cases2"],
  Cell[182883, 7257, 355, 11, 25, "Output",
   CellTags->"Cases2"],
  Cell[183275, 7273, 327, 10, 27, "Input",
   CellTags->"Cases2"],
  Cell[183605, 7285, 463, 17, 25, "Output",
   CellTags->"Cases2"]},
 "CF"->{
  Cell[184095, 7306, 41, 1, 39, "ObjectName",
   CellTags->"CF"],
  Cell[184161, 7311, 53, 1, 33, "Subsubsection",
   CellTags->"CF"],
  Cell[184217, 7314, 287, 13, 23, "Text",
   CellTags->"CF"],
  Cell[184507, 7329, 274, 14, 23, "Text",
   CellTags->"CF"],
  Cell[184818, 7348, 50, 1, 33, "Subsubsection",
   CellTags->"CF"],
  Cell[184893, 7353, 70, 2, 27, "Input",
   CellTags->"CF"],
  Cell[184966, 7357, 120, 4, 25, "Output",
   CellTags->"CF"],
  Cell[185123, 7366, 178, 5, 27, "Input",
   CellTags->"CF"],
  Cell[185304, 7373, 193, 7, 47, "Output",
   CellTags->"CF"],
  Cell[185733, 7395, 72, 2, 27, "Input",
   CellTags->"CF"],
  Cell[185808, 7399, 98, 3, 25, "Output",
   CellTags->"CF"],
  Cell[185943, 7407, 233, 7, 27, "Input",
   CellTags->"CF"],
  Cell[186179, 7416, 177, 6, 25, "Output",
   CellTags->"CF"]},
 "ChangeDimension"->{
  Cell[186383, 7426, 67, 1, 39, "ObjectName",
   CellTags->"ChangeDimension"],
  Cell[186475, 7431, 66, 1, 33, "Subsubsection",
   CellTags->"ChangeDimension"],
  Cell[186544, 7434, 210, 5, 39, "Text",
   CellTags->"ChangeDimension"],
  Cell[186757, 7441, 519, 24, 23, "Text",
   CellTags->"ChangeDimension"],
  Cell[187313, 7470, 63, 1, 33, "Subsubsection",
   CellTags->"ChangeDimension"],
  Cell[187379, 7473, 219, 5, 39, "Text",
   CellTags->"ChangeDimension"],
  Cell[187623, 7482, 212, 6, 27, "Input",
   CellTags->"ChangeDimension"],
  Cell[187838, 7490, 198, 7, 25, "Output",
   CellTags->"ChangeDimension"],
  Cell[188073, 7502, 151, 4, 27, "Input",
   CellTags->"ChangeDimension"],
  Cell[188227, 7508, 198, 7, 25, "Output",
   CellTags->"ChangeDimension"],
  Cell[188462, 7520, 116, 3, 27, "Input",
   CellTags->"ChangeDimension"],
  Cell[188581, 7525, 272, 8, 39, "Output",
   CellTags->"ChangeDimension"],
  Cell[188868, 7536, 119, 3, 23, "Text",
   CellTags->"ChangeDimension"],
  Cell[189012, 7543, 201, 6, 27, "Input",
   CellTags->"ChangeDimension"],
  Cell[189216, 7551, 222, 6, 39, "Output",
   CellTags->"ChangeDimension"],
  Cell[189453, 7560, 105, 1, 23, "Text",
   CellTags->"ChangeDimension"],
  Cell[189583, 7565, 482, 15, 27, "Input",
   CellTags->"ChangeDimension"],
  Cell[190068, 7582, 571, 18, 27, "Output",
   CellTags->"ChangeDimension"],
  Cell[190676, 7605, 153, 4, 27, "Input",
   CellTags->"ChangeDimension"],
  Cell[190832, 7611, 755, 29, 27, "Output",
   CellTags->"ChangeDimension"],
  Cell[191624, 7645, 222, 6, 27, "Input",
   CellTags->"ChangeDimension"],
  Cell[191849, 7653, 755, 29, 27, "Output",
   CellTags->"ChangeDimension"],
  Cell[192619, 7685, 132, 3, 23, "Text",
   CellTags->"ChangeDimension"],
  Cell[192754, 7690, 208, 6, 27, "Input",
   CellTags->"ChangeDimension"],
  Cell[192965, 7698, 219, 5, 39, "Text",
   CellTags->"ChangeDimension"],
  Cell[193187, 7705, 201, 6, 27, "Input",
   CellTags->"ChangeDimension"],
  Cell[193413, 7715, 220, 6, 27, "Input",
   CellTags->"ChangeDimension"],
  Cell[193636, 7723, 489, 21, 25, "Output",
   CellTags->"ChangeDimension"],
  Cell[194162, 7749, 182, 5, 27, "Input",
   CellTags->"ChangeDimension"],
  Cell[194347, 7756, 489, 21, 25, "Output",
   CellTags->"ChangeDimension"],
  Cell[194873, 7782, 176, 5, 29, "Input",
   CellTags->"ChangeDimension"],
  Cell[195052, 7789, 301, 10, 25, "Output",
   CellTags->"ChangeDimension"],
  Cell[195390, 7804, 141, 4, 29, "Input",
   CellTags->"ChangeDimension"],
  Cell[195534, 7810, 130, 4, 25, "Output",
   CellTags->"ChangeDimension"],
  Cell[195679, 7817, 201, 6, 27, "Input",
   CellTags->"ChangeDimension"],
  Cell[195883, 7825, 157, 5, 27, "Input",
   CellTags->"ChangeDimension"]},
 "ChargeConjugationMatrix"->{
  Cell[196055, 7833, 83, 1, 39, "ObjectName",
   CellTags->"ChargeConjugationMatrix"],
  Cell[196163, 7838, 74, 1, 33, "Subsubsection",
   CellTags->"ChargeConjugationMatrix"],
  Cell[196240, 7841, 176, 6, 23, "Text",
   CellTags->"ChargeConjugationMatrix"],
  Cell[196419, 7849, 248, 9, 23, "Text",
   CellTags->"ChargeConjugationMatrix"],
  Cell[196704, 7863, 71, 1, 33, "Subsubsection",
   CellTags->"ChargeConjugationMatrix"],
  Cell[196800, 7868, 214, 5, 27, "Input",
   CellTags->"ChargeConjugationMatrix"],
  Cell[197017, 7875, 306, 11, 25, "Output",
   CellTags->"ChargeConjugationMatrix"],
  Cell[197360, 7891, 120, 3, 27, "Input",
   CellTags->"ChargeConjugationMatrix"],
  Cell[197483, 7896, 255, 9, 31, "Output",
   CellTags->"ChargeConjugationMatrix"],
  Cell[197775, 7910, 209, 5, 27, "Input",
   CellTags->"ChargeConjugationMatrix"],
  Cell[197987, 7917, 228, 7, 27, "Output",
   CellTags->"ChargeConjugationMatrix"],
  Cell[198252, 7929, 120, 3, 27, "Input",
   CellTags->"ChargeConjugationMatrix"],
  Cell[198375, 7934, 192, 6, 29, "Output",
   CellTags->"ChargeConjugationMatrix"],
  Cell[198604, 7945, 134, 3, 27, "Input",
   CellTags->"ChargeConjugationMatrix"],
  Cell[198741, 7950, 137, 4, 25, "Output",
   CellTags->"ChargeConjugationMatrix"]},
 "ChargeConjugationMatrixInv"->{
  Cell[198905, 7958, 89, 1, 39, "ObjectName",
   CellTags->"ChargeConjugationMatrixInv"],
  Cell[199019, 7963, 77, 1, 33, "Subsubsection",
   CellTags->"ChargeConjugationMatrixInv"],
  Cell[199099, 7966, 195, 4, 23, "Text",
   CellTags->"ChargeConjugationMatrixInv"],
  Cell[199297, 7972, 242, 9, 23, "Text",
   CellTags->"ChargeConjugationMatrixInv"],
  Cell[199576, 7986, 74, 1, 33, "Subsubsection",
   CellTags->"ChargeConjugationMatrixInv"],
  Cell[199675, 7991, 217, 5, 27, "Input",
   CellTags->"ChargeConjugationMatrixInv"],
  Cell[199895, 7998, 309, 11, 25, "Output",
   CellTags->"ChargeConjugationMatrixInv"],
  Cell[200241, 8014, 123, 3, 27, "Input",
   CellTags->"ChargeConjugationMatrixInv"],
  Cell[200367, 8019, 258, 9, 31, "Output",
   CellTags->"ChargeConjugationMatrixInv"],
  Cell[200662, 8033, 212, 5, 27, "Input",
   CellTags->"ChargeConjugationMatrixInv"],
  Cell[200877, 8040, 231, 7, 27, "Output",
   CellTags->"ChargeConjugationMatrixInv"],
  Cell[201145, 8052, 123, 3, 27, "Input",
   CellTags->"ChargeConjugationMatrixInv"],
  Cell[201271, 8057, 195, 6, 29, "Output",
   CellTags->"ChargeConjugationMatrixInv"],
  Cell[201503, 8068, 165, 4, 27, "Input",
   CellTags->"ChargeConjugationMatrixInv"],
  Cell[201671, 8074, 189, 6, 25, "Output",
   CellTags->"ChargeConjugationMatrixInv"],
  Cell[201897, 8085, 119, 3, 27, "Input",
   CellTags->"ChargeConjugationMatrixInv"],
  Cell[202019, 8090, 164, 5, 25, "Output",
   CellTags->"ChargeConjugationMatrixInv"],
  Cell[202220, 8100, 140, 3, 27, "Input",
   CellTags->"ChargeConjugationMatrixInv"],
  Cell[202363, 8105, 140, 4, 25, "Output",
   CellTags->"ChargeConjugationMatrixInv"]},
 "CheckContext"->{
  Cell[202530, 8113, 61, 1, 39, "ObjectName",
   CellTags->"CheckContext"],
  Cell[202616, 8118, 63, 1, 33, "Subsubsection",
   CellTags->"CheckContext"],
  Cell[202682, 8121, 164, 4, 23, "Text",
   CellTags->"CheckContext"],
  Cell[202849, 8127, 320, 14, 23, "Text",
   CellTags->"CheckContext"],
  Cell[203206, 8146, 60, 1, 33, "Subsubsection",
   CellTags->"CheckContext"],
  Cell[203269, 8149, 142, 4, 23, "Text",
   CellTags->"CheckContext"],
  Cell[203436, 8157, 138, 3, 27, "Input",
   CellTags->"CheckContext"],
  Cell[203577, 8162, 112, 3, 25, "Output",
   CellTags->"CheckContext"],
  Cell[203704, 8168, 87, 1, 23, "Text",
   CellTags->"CheckContext"],
  Cell[203816, 8173, 92, 2, 27, "Input",
   CellTags->"CheckContext"],
  Cell[203911, 8177, 121, 3, 25, "Output",
   CellTags->"CheckContext"],
  Cell[204069, 8185, 138, 3, 27, "Input",
   CellTags->"CheckContext"],
  Cell[204210, 8190, 111, 3, 25, "Output",
   CellTags->"CheckContext"]},
 "CheckDB"->{
  Cell[204348, 8197, 51, 1, 39, "ObjectName",
   CellTags->"CheckDB"],
  Cell[204424, 8202, 106, 3, 33, "Subsubsection",
   CellTags->"CheckDB"],
  Cell[205639, 8226, 113, 3, 27, "Input",
   CellTags->"CheckDB"],
  Cell[205755, 8231, 471, 14, 25, "Output",
   CellTags->"CheckDB"],
  Cell[206263, 8250, 116, 3, 27, "Input",
   CellTags->"CheckDB"],
  Cell[206382, 8255, 134, 4, 25, "Output",
   CellTags->"CheckDB"],
  Cell[207674, 8310, 383, 13, 27, "Input",
   CellTags->"CheckDB"],
  Cell[208060, 8325, 150, 5, 25, "Output",
   CellTags->"CheckDB"],
  Cell[208310, 8337, 303, 9, 27, "Input",
   CellTags->"CheckDB"],
  Cell[208616, 8348, 116, 3, 25, "Output",
   CellTags->"CheckDB"],
  Cell[208747, 8354, 268, 8, 27, "Input",
   CellTags->"CheckDB"]},
 "ChiralityProjector"->{
  Cell[209030, 8365, 73, 1, 39, "ObjectName",
   CellTags->"ChiralityProjector"],
  Cell[209128, 8370, 69, 1, 33, "Subsubsection",
   CellTags->"ChiralityProjector"],
  Cell[209200, 8373, 499, 19, 25, "Text",
   CellTags->"ChiralityProjector"],
  Cell[209702, 8394, 409, 19, 23, "Text",
   CellTags->"ChiralityProjector"],
  Cell[210148, 8418, 66, 1, 33, "Subsubsection",
   CellTags->"ChiralityProjector"],
  Cell[210239, 8423, 262, 8, 27, "Input",
   CellTags->"ChiralityProjector"],
  Cell[210504, 8433, 227, 7, 29, "Output",
   CellTags->"ChiralityProjector"],
  Cell[210768, 8445, 114, 3, 27, "Input",
   CellTags->"ChiralityProjector"],
  Cell[210885, 8450, 227, 7, 29, "Output",
   CellTags->"ChiralityProjector"],
  Cell[211149, 8462, 196, 5, 27, "Input",
   CellTags->"ChiralityProjector"],
  Cell[211348, 8469, 380, 14, 46, "Output",
   CellTags->"ChiralityProjector"]},
 "Chisholm"->{
  Cell[211755, 8487, 53, 1, 39, "ObjectName",
   CellTags->"Chisholm"],
  Cell[211833, 8492, 59, 1, 33, "Subsubsection",
   CellTags->"Chisholm"],
  Cell[211895, 8495, 142, 4, 23, "Text",
   CellTags->"Chisholm"],
  Cell[212040, 8501, 316, 14, 23, "Text",
   CellTags->"Chisholm"],
  Cell[212393, 8520, 56, 1, 33, "Subsubsection",
   CellTags->"Chisholm"],
  Cell[212474, 8525, 206, 6, 27, "Input",
   CellTags->"Chisholm"],
  Cell[212683, 8533, 2020, 78, 27, "Output",
   CellTags->"Chisholm"],
  Cell[214740, 8616, 183, 5, 27, "Input",
   CellTags->"Chisholm"],
  Cell[214926, 8623, 236, 7, 25, "Output",
   CellTags->"Chisholm"],
  Cell[215199, 8635, 139, 4, 27, "Input",
   CellTags->"Chisholm"],
  Cell[215341, 8641, 1374, 54, 27, "Output",
   CellTags->"Chisholm"],
  Cell[216730, 8698, 77, 1, 23, "Text",
   CellTags->"Chisholm"],
  Cell[216832, 8703, 130, 4, 27, "Input",
   CellTags->"Chisholm"],
  Cell[216965, 8709, 105, 3, 25, "Output",
   CellTags->"Chisholm"],
  Cell[217107, 8717, 139, 4, 27, "Input",
   CellTags->"Chisholm"],
  Cell[217249, 8723, 1374, 54, 27, "Output",
   CellTags->"Chisholm"],
  Cell[218660, 8782, 130, 4, 27, "Input",
   CellTags->"Chisholm"],
  Cell[218793, 8788, 105, 3, 25, "Output",
   CellTags->"Chisholm"],
  Cell[218935, 8796, 169, 5, 27, "Input",
   CellTags->"Chisholm"],
  Cell[219107, 8803, 590, 22, 25, "Output",
   CellTags->"Chisholm"],
  Cell[219734, 8830, 110, 3, 27, "Input",
   CellTags->"Chisholm"],
  Cell[219847, 8835, 1439, 57, 27, "Output",
   CellTags->"Chisholm"],
  Cell[221323, 8897, 232, 7, 27, "Input",
   CellTags->"Chisholm"],
  Cell[221558, 8906, 391, 10, 25, "Output",
   CellTags->"Chisholm"],
  Cell[221986, 8921, 139, 4, 27, "Input",
   CellTags->"Chisholm"],
  Cell[222128, 8927, 11544, 439, 87, "Output",
   CellTags->"Chisholm"],
  Cell[233709, 9371, 139, 4, 27, "Input",
   CellTags->"Chisholm"],
  Cell[233851, 9377, 11544, 439, 87, "Output",
   CellTags->"Chisholm"],
  Cell[245410, 9819, 85, 1, 23, "Text",
   CellTags->"Chisholm"],
  Cell[245520, 9824, 130, 4, 27, "Input",
   CellTags->"Chisholm"],
  Cell[245653, 9830, 125, 4, 25, "Output",
   CellTags->"Chisholm"],
  Cell[245815, 9839, 130, 4, 27, "Input",
   CellTags->"Chisholm"],
  Cell[245948, 9845, 125, 4, 25, "Output",
   CellTags->"Chisholm"],
  Cell[246088, 9852, 192, 6, 27, "Input",
   CellTags->"Chisholm"]},
 "ChisholmSpinor"->{
  Cell[246295, 9861, 65, 1, 39, "ObjectName",
   CellTags->"ChisholmSpinor"],
  Cell[246385, 9866, 65, 1, 33, "Subsubsection",
   CellTags->"ChisholmSpinor"],
  Cell[246453, 9869, 296, 6, 39, "Text",
   CellTags->"ChisholmSpinor"],
  Cell[246752, 9877, 304, 14, 23, "Text",
   CellTags->"ChisholmSpinor"],
  Cell[247093, 9896, 62, 1, 33, "Subsubsection",
   CellTags->"ChisholmSpinor"],
  Cell[247180, 9901, 312, 9, 27, "Input",
   CellTags->"ChisholmSpinor"],
  Cell[247495, 9912, 427, 15, 25, "Output",
   CellTags->"ChisholmSpinor"],
  Cell[247959, 9932, 117, 3, 27, "Input",
   CellTags->"ChisholmSpinor"],
  Cell[248079, 9937, 2686, 99, 93, "Output",
   CellTags->"ChisholmSpinor"]},
 "ClearScalarProducts"->{
  Cell[250792, 10040, 75, 1, 39, "ObjectName",
   CellTags->"ClearScalarProducts"],
  Cell[250892, 10045, 70, 1, 33, "Subsubsection",
   CellTags->"ClearScalarProducts"],
  Cell[250965, 10048, 145, 4, 23, "Text",
   CellTags->"ClearScalarProducts"],
  Cell[251113, 10054, 484, 23, 23, "Text",
   CellTags->"ClearScalarProducts"],
  Cell[251634, 10082, 67, 1, 33, "Subsubsection",
   CellTags->"ClearScalarProducts"],
  Cell[251726, 10087, 195, 6, 27, "Input",
   CellTags->"ClearScalarProducts"],
  Cell[251924, 10095, 139, 4, 27, "Output",
   CellTags->"ClearScalarProducts"],
  Cell[252100, 10104, 211, 6, 27, "Input",
   CellTags->"ClearScalarProducts"],
  Cell[252314, 10112, 139, 4, 27, "Output",
   CellTags->"ClearScalarProducts"],
  Cell[252468, 10119, 104, 2, 27, "Input",
   CellTags->"ClearScalarProducts"],
  Cell[252597, 10125, 211, 6, 27, "Input",
   CellTags->"ClearScalarProducts"],
  Cell[252811, 10133, 173, 6, 27, "Output",
   CellTags->"ClearScalarProducts"],
  Cell[253021, 10144, 148, 4, 27, "Input",
   CellTags->"ClearScalarProducts"],
  Cell[253172, 10150, 173, 6, 27, "Output",
   CellTags->"ClearScalarProducts"]},
 "Collect2"->{
  Cell[254154, 10196, 53, 1, 39, "ObjectName",
   CellTags->"Collect2"],
  Cell[254232, 10201, 59, 1, 33, "Subsubsection",
   CellTags->"Collect2"],
  Cell[254294, 10204, 613, 10, 71, "Text",
   CellTags->"Collect2"],
  Cell[254932, 10218, 115, 3, 27, "Input",
   CellTags->"Collect2"],
  Cell[255050, 10223, 398, 11, 25, "Output",
   CellTags->"Collect2"],
  Cell[255463, 10237, 176, 9, 23, "Text",
   CellTags->"Collect2"],
  Cell[255676, 10251, 56, 1, 33, "Subsubsection",
   CellTags->"Collect2"],
  Cell[255757, 10256, 440, 14, 40, "Input",
   CellTags->"Collect2"],
  Cell[256200, 10272, 451, 16, 44, "Output",
   CellTags->"Collect2"],
  Cell[256688, 10293, 185, 5, 27, "Input",
   CellTags->"Collect2"],
  Cell[256876, 10300, 399, 14, 40, "Output",
   CellTags->"Collect2"],
  Cell[257312, 10319, 186, 5, 27, "Input",
   CellTags->"Collect2"],
  Cell[257501, 10326, 451, 16, 44, "Output",
   CellTags->"Collect2"],
  Cell[257989, 10347, 525, 18, 29, "Input",
   CellTags->"Collect2"],
  Cell[258517, 10367, 537, 18, 27, "Output",
   CellTags->"Collect2"],
  Cell[259091, 10390, 320, 10, 29, "Input",
   CellTags->"Collect2"],
  Cell[259414, 10402, 820, 31, 27, "Output",
   CellTags->"Collect2"],
  Cell[260271, 10438, 112, 3, 27, "Input",
   CellTags->"Collect2"],
  Cell[260386, 10443, 825, 27, 27, "Output",
   CellTags->"Collect2"],
  Cell[261226, 10473, 130, 4, 27, "Input",
   CellTags->"Collect2"],
  Cell[261381, 10481, 305, 9, 29, "Input",
   CellTags->"Collect2"],
  Cell[261689, 10492, 935, 31, 29, "Output",
   CellTags->"Collect2"],
  Cell[262661, 10528, 149, 4, 27, "Input",
   CellTags->"Collect2"],
  Cell[262813, 10534, 671, 21, 29, "Output",
   CellTags->"Collect2"]},
 "Collect3"->{
  Cell[263511, 10559, 53, 1, 39, "ObjectName",
   CellTags->"Collect3"],
  Cell[263589, 10564, 59, 1, 33, "Subsubsection",
   CellTags->"Collect3"],
  Cell[263651, 10567, 719, 23, 39, "Text",
   CellTags->"Collect3"],
  Cell[264395, 10594, 115, 3, 27, "Input",
   CellTags->"Collect3"],
  Cell[264513, 10599, 233, 8, 25, "Output",
   CellTags->"Collect3"],
  Cell[264761, 10610, 286, 14, 23, "Text",
   CellTags->"Collect3"],
  Cell[265084, 10629, 56, 1, 33, "Subsubsection",
   CellTags->"Collect3"],
  Cell[265165, 10634, 525, 18, 29, "Input",
   CellTags->"Collect3"],
  Cell[265693, 10654, 548, 19, 27, "Output",
   CellTags->"Collect3"],
  Cell[266278, 10678, 289, 9, 29, "Input",
   CellTags->"Collect3"],
  Cell[266570, 10689, 4614, 134, 136, "Output",
   CellTags->"Collect3"]},
 "Combine"->{
  Cell[272367, 10869, 51, 1, 39, "ObjectName",
   CellTags->"Combine"],
  Cell[272443, 10874, 58, 1, 33, "Subsubsection",
   CellTags->"Combine"],
  Cell[272504, 10877, 315, 6, 39, "Text",
   CellTags->"Combine"],
  Cell[272844, 10887, 113, 3, 27, "Input",
   CellTags->"Combine"],
  Cell[272960, 10892, 171, 6, 25, "Output",
   CellTags->"Combine"],
  Cell[273146, 10901, 175, 9, 23, "Text",
   CellTags->"Combine"],
  Cell[273358, 10915, 55, 1, 33, "Subsubsection",
   CellTags->"Combine"],
  Cell[273438, 10920, 283, 10, 42, "Input",
   CellTags->"Combine"],
  Cell[273724, 10932, 304, 11, 43, "Output",
   CellTags->"Combine"],
  Cell[274043, 10946, 122, 3, 23, "Text",
   CellTags->"Combine"],
  Cell[274190, 10953, 284, 10, 42, "Input",
   CellTags->"Combine"],
  Cell[274477, 10965, 303, 10, 43, "Output",
   CellTags->"Combine"],
  Cell[274795, 10978, 175, 4, 23, "Text",
   CellTags->"Combine"],
  Cell[274995, 10986, 354, 12, 42, "Input",
   CellTags->"Combine"],
  Cell[275352, 11000, 303, 10, 43, "Output",
   CellTags->"Combine"]},
 "CombineGraphs"->{
  Cell[275682, 11014, 63, 1, 39, "ObjectName",
   CellTags->"CombineGraphs"],
  Cell[275770, 11019, 64, 1, 33, "Subsubsection",
   CellTags->"CombineGraphs"],
  Cell[275837, 11022, 86, 1, 23, "Text",
   CellTags->"CombineGraphs"],
  Cell[275926, 11025, 185, 8, 23, "Text",
   CellTags->"CombineGraphs"]},
 "Commutator"->{
  Cell[276126, 11036, 57, 1, 39, "ObjectName",
   CellTags->"Commutator"],
  Cell[276208, 11041, 61, 1, 33, "Subsubsection",
   CellTags->"Commutator"],
  Cell[276272, 11044, 138, 4, 23, "Text",
   CellTags->"Commutator"],
  Cell[276413, 11050, 607, 24, 23, "Text",
   CellTags->"Commutator"],
  Cell[277057, 11079, 58, 1, 33, "Subsubsection",
   CellTags->"Commutator"],
  Cell[277118, 11082, 167, 4, 27, "Input",
   CellTags->"Commutator"],
  Cell[277310, 11090, 136, 4, 27, "Input",
   CellTags->"Commutator"],
  Cell[277449, 11096, 184, 5, 25, "Output",
   CellTags->"Commutator"],
  Cell[277670, 11106, 121, 3, 27, "Input",
   CellTags->"Commutator"],
  Cell[277794, 11111, 177, 6, 25, "Output",
   CellTags->"Commutator"],
  Cell[278008, 11122, 247, 8, 27, "Input",
   CellTags->"Commutator"],
  Cell[278258, 11132, 381, 12, 25, "Output",
   CellTags->"Commutator"],
  Cell[278654, 11147, 169, 4, 27, "Input",
   CellTags->"Commutator"],
  Cell[278826, 11153, 68, 1, 23, "Text",
   CellTags->"Commutator"],
  Cell[278897, 11156, 228, 6, 27, "Input",
   CellTags->"Commutator"],
  Cell[279150, 11166, 463, 15, 27, "Input",
   CellTags->"Commutator"],
  Cell[279616, 11183, 727, 19, 25, "Output",
   CellTags->"Commutator"],
  Cell[280380, 11207, 114, 3, 27, "Input",
   CellTags->"Commutator"],
  Cell[280497, 11212, 106, 3, 25, "Output",
   CellTags->"Commutator"],
  Cell[280618, 11218, 113, 3, 27, "Input",
   CellTags->"Commutator"],
  Cell[280734, 11223, 159, 4, 27, "Input",
   CellTags->"Commutator"]},
 "CommutatorExplicit"->{
  Cell[280908, 11230, 73, 1, 39, "ObjectName",
   CellTags->"CommutatorExplicit"],
  Cell[281006, 11235, 69, 1, 33, "Subsubsection",
   CellTags->"CommutatorExplicit"],
  Cell[281078, 11238, 157, 4, 23, "Text",
   CellTags->"CommutatorExplicit"],
  Cell[281238, 11244, 296, 14, 23, "Text",
   CellTags->"CommutatorExplicit"],
  Cell[281571, 11263, 66, 1, 33, "Subsubsection",
   CellTags->"CommutatorExplicit"],
  Cell[281640, 11266, 175, 4, 27, "Input",
   CellTags->"CommutatorExplicit"],
  Cell[281840, 11274, 144, 4, 27, "Input",
   CellTags->"CommutatorExplicit"],
  Cell[281987, 11280, 192, 5, 25, "Output",
   CellTags->"CommutatorExplicit"],
  Cell[282216, 11290, 129, 3, 27, "Input",
   CellTags->"CommutatorExplicit"],
  Cell[282348, 11295, 185, 6, 25, "Output",
   CellTags->"CommutatorExplicit"],
  Cell[282570, 11306, 196, 6, 27, "Input",
   CellTags->"CommutatorExplicit"],
  Cell[282769, 11314, 283, 10, 25, "Output",
   CellTags->"CommutatorExplicit"],
  Cell[283089, 11329, 129, 3, 27, "Input",
   CellTags->"CommutatorExplicit"],
  Cell[283221, 11334, 389, 14, 25, "Output",
   CellTags->"CommutatorExplicit"],
  Cell[283647, 11353, 167, 5, 27, "Input",
   CellTags->"CommutatorExplicit"],
  Cell[283817, 11360, 389, 12, 25, "Output",
   CellTags->"CommutatorExplicit"],
  Cell[284221, 11375, 177, 4, 27, "Input",
   CellTags->"CommutatorExplicit"]},
 "CompleteSquare"->{
  Cell[284413, 11382, 65, 1, 39, "ObjectName",
   CellTags->"CompleteSquare"],
  Cell[284503, 11387, 65, 1, 33, "Subsubsection",
   CellTags->"CompleteSquare"],
  Cell[284571, 11390, 1107, 82, 39, "Text",
   CellTags->"CompleteSquare"],
  Cell[285715, 11477, 62, 1, 33, "Subsubsection",
   CellTags->"CompleteSquare"],
  Cell[286456, 11511, 170, 5, 27, "Input",
   CellTags->"CompleteSquare"],
  Cell[286629, 11518, 685, 27, 46, "Output",
   CellTags->"CompleteSquare"],
  Cell[287351, 11550, 180, 6, 27, "Input",
   CellTags->"CompleteSquare"],
  Cell[287534, 11558, 110, 3, 25, "Output",
   CellTags->"CompleteSquare"],
  Cell[287681, 11566, 155, 4, 27, "Input",
   CellTags->"CompleteSquare"],
  Cell[287839, 11572, 515, 20, 46, "Output",
   CellTags->"CompleteSquare"],
  Cell[288369, 11595, 137, 4, 27, "Input",
   CellTags->"CompleteSquare"]},
 "ComplexConjugate"->{
  Cell[288521, 11602, 69, 1, 39, "ObjectName",
   CellTags->"ComplexConjugate"],
  Cell[288615, 11607, 67, 1, 33, "Subsubsection",
   CellTags->"ComplexConjugate"],
  Cell[288685, 11610, 414, 7, 55, "Text",
   CellTags->"ComplexConjugate"],
  Cell[289102, 11619, 449, 19, 23, "Text",
   CellTags->"ComplexConjugate"],
  Cell[289588, 11643, 64, 1, 33, "Subsubsection",
   CellTags->"ComplexConjugate"],
  Cell[289677, 11648, 196, 5, 27, "Input",
   CellTags->"ComplexConjugate"],
  Cell[289876, 11655, 163, 5, 25, "Output",
   CellTags->"ComplexConjugate"],
  Cell[290076, 11665, 121, 3, 27, "Input",
   CellTags->"ComplexConjugate"],
  Cell[290200, 11670, 239, 6, 39, "Output",
   CellTags->"ComplexConjugate"],
  Cell[290476, 11681, 152, 4, 27, "Input",
   CellTags->"ComplexConjugate"],
  Cell[290631, 11687, 249, 7, 27, "Output",
   CellTags->"ComplexConjugate"],
  Cell[290917, 11699, 125, 3, 27, "Input",
   CellTags->"ComplexConjugate"],
  Cell[291045, 11704, 427, 16, 27, "Output",
   CellTags->"ComplexConjugate"],
  Cell[291509, 11725, 182, 5, 27, "Input",
   CellTags->"ComplexConjugate"],
  Cell[291694, 11732, 531, 22, 25, "Output",
   CellTags->"ComplexConjugate"],
  Cell[292262, 11759, 125, 3, 27, "Input",
   CellTags->"ComplexConjugate"],
  Cell[292390, 11764, 531, 22, 25, "Output",
   CellTags->"ComplexConjugate"],
  Cell[292958, 11791, 190, 5, 27, "Input",
   CellTags->"ComplexConjugate"],
  Cell[293151, 11798, 380, 17, 27, "Output",
   CellTags->"ComplexConjugate"],
  Cell[293568, 11820, 270, 7, 27, "Input",
   CellTags->"ComplexConjugate"],
  Cell[293841, 11829, 157, 4, 39, "Output",
   CellTags->"ComplexConjugate"],
  Cell[294035, 11838, 273, 8, 27, "Input",
   CellTags->"ComplexConjugate"],
  Cell[294311, 11848, 335, 10, 25, "Output",
   CellTags->"ComplexConjugate"],
  Cell[294683, 11863, 125, 3, 27, "Input",
   CellTags->"ComplexConjugate"],
  Cell[294811, 11868, 431, 15, 25, "Output",
   CellTags->"ComplexConjugate"],
  Cell[295257, 11886, 166, 4, 23, "Text",
   CellTags->"ComplexConjugate"]},
 "Contract"->{
  Cell[295438, 11893, 53, 1, 39, "ObjectName",
   CellTags->"Contract"],
  Cell[295516, 11898, 59, 1, 33, "Subsubsection",
   CellTags->"Contract"],
  Cell[295578, 11901, 411, 7, 55, "Text",
   CellTags->"Contract"],
  Cell[296014, 11912, 115, 3, 27, "Input",
   CellTags->"Contract"],
  Cell[296132, 11917, 612, 15, 45, "Output",
   CellTags->"Contract"],
  Cell[296900, 11940, 423, 19, 23, "Text",
   CellTags->"Contract"],
  Cell[297360, 11964, 56, 1, 33, "Subsubsection",
   CellTags->"Contract"],
  Cell[297441, 11969, 233, 7, 27, "Input",
   CellTags->"Contract"],
  Cell[297677, 11978, 207, 7, 28, "Output",
   CellTags->"Contract"],
  Cell[297921, 11990, 109, 3, 27, "Input",
   CellTags->"Contract"],
  Cell[298033, 11995, 236, 10, 25, "Output",
   CellTags->"Contract"],
  Cell[298306, 12010, 199, 6, 27, "Input",
   CellTags->"Contract"],
  Cell[298508, 12018, 264, 10, 28, "Output",
   CellTags->"Contract"],
  Cell[298809, 12033, 109, 3, 27, "Input",
   CellTags->"Contract"],
  Cell[298921, 12038, 221, 8, 25, "Output",
   CellTags->"Contract"],
  Cell[299179, 12051, 144, 4, 27, "Input",
   CellTags->"Contract"],
  Cell[299326, 12057, 155, 5, 25, "Output",
   CellTags->"Contract"],
  Cell[299496, 12065, 83, 1, 23, "Text",
   CellTags->"Contract"],
  Cell[299604, 12070, 109, 3, 27, "Input",
   CellTags->"Contract"],
  Cell[299716, 12075, 104, 3, 25, "Output",
   CellTags->"Contract"],
  Cell[299835, 12081, 208, 5, 39, "Text",
   CellTags->"Contract"],
  Cell[300068, 12090, 231, 7, 27, "Input",
   CellTags->"Contract"],
  Cell[300302, 12099, 233, 8, 25, "Output",
   CellTags->"Contract"],
  Cell[300572, 12112, 109, 3, 27, "Input",
   CellTags->"Contract"],
  Cell[300684, 12117, 104, 3, 25, "Output",
   CellTags->"Contract"],
  Cell[300825, 12125, 231, 7, 27, "Input",
   CellTags->"Contract"],
  Cell[301059, 12134, 233, 8, 25, "Output",
   CellTags->"Contract"],
  Cell[301329, 12147, 227, 7, 27, "Input",
   CellTags->"Contract"],
  Cell[301559, 12156, 181, 6, 28, "Output",
   CellTags->"Contract"],
  Cell[301777, 12167, 114, 3, 27, "Input",
   CellTags->"Contract"],
  Cell[301894, 12172, 206, 8, 25, "Output",
   CellTags->"Contract"],
  Cell[302137, 12185, 277, 9, 27, "Input",
   CellTags->"Contract"],
  Cell[302417, 12196, 427, 18, 28, "Output",
   CellTags->"Contract"],
  Cell[302881, 12219, 109, 3, 27, "Input",
   CellTags->"Contract"],
  Cell[302993, 12224, 575, 24, 25, "Output",
   CellTags->"Contract"],
  Cell[303605, 12253, 271, 8, 27, "Input",
   CellTags->"Contract"],
  Cell[303879, 12263, 555, 23, 25, "Output",
   CellTags->"Contract"],
  Cell[304471, 12291, 109, 3, 27, "Input",
   CellTags->"Contract"],
  Cell[304583, 12296, 439, 19, 25, "Output",
   CellTags->"Contract"],
  Cell[305059, 12320, 313, 9, 27, "Input",
   CellTags->"Contract"],
  Cell[305375, 12331, 922, 40, 25, "Output",
   CellTags->"Contract"],
  Cell[306334, 12376, 109, 3, 27, "Input",
   CellTags->"Contract"],
  Cell[306446, 12381, 204, 7, 25, "Output",
   CellTags->"Contract"],
  Cell[306687, 12393, 426, 13, 27, "Input",
   CellTags->"Contract"],
  Cell[307116, 12408, 301, 9, 25, "Output",
   CellTags->"Contract"],
  Cell[307454, 12422, 139, 4, 27, "Input",
   CellTags->"Contract"],
  Cell[307596, 12428, 352, 12, 25, "Output",
   CellTags->"Contract"],
  Cell[307963, 12443, 194, 6, 27, "Input",
   CellTags->"Contract"]},
 "Contract1"->{
  Cell[308172, 12452, 55, 1, 39, "ObjectName",
   CellTags->"Contract1"],
  Cell[308252, 12457, 60, 1, 33, "Subsubsection",
   CellTags->"Contract1"],
  Cell[308315, 12460, 459, 8, 95, "Text",
   CellTags->"Contract1"],
  Cell[308777, 12470, 389, 18, 23, "Text",
   CellTags->"Contract1"],
  Cell[309203, 12493, 57, 1, 33, "Subsubsection",
   CellTags->"Contract1"],
  Cell[309285, 12498, 349, 12, 27, "Input",
   CellTags->"Contract1"],
  Cell[309637, 12512, 207, 8, 25, "Output",
   CellTags->"Contract1"],
  Cell[309881, 12525, 349, 12, 27, "Input",
   CellTags->"Contract1"],
  Cell[310233, 12539, 478, 20, 27, "Output",
   CellTags->"Contract1"],
  Cell[310748, 12564, 269, 9, 27, "Input",
   CellTags->"Contract1"],
  Cell[311020, 12575, 105, 3, 25, "Output",
   CellTags->"Contract1"],
  Cell[311162, 12583, 269, 9, 27, "Input",
   CellTags->"Contract1"],
  Cell[311434, 12594, 298, 11, 27, "Output",
   CellTags->"Contract1"]},
 "Convolute"->{
  Cell[311759, 12609, 55, 1, 39, "ObjectName",
   CellTags->"Convolute"],
  Cell[311839, 12614, 60, 1, 33, "Subsubsection",
   CellTags->"Convolute"],
  Cell[311902, 12617, 1363, 49, 61, "Text",
   CellTags->"Convolute"],
  Cell[313290, 12670, 117, 3, 27, "Input",
   CellTags->"Convolute"],
  Cell[313410, 12675, 400, 13, 25, "Output",
   CellTags->"Convolute"],
  Cell[313825, 12691, 332, 14, 23, "Text",
   CellTags->"Convolute"],
  Cell[314194, 12710, 57, 1, 33, "Subsubsection",
   CellTags->"Convolute"],
  Cell[314276, 12715, 134, 4, 27, "Input",
   CellTags->"Convolute"],
  Cell[314413, 12721, 154, 5, 25, "Output",
   CellTags->"Convolute"],
  Cell[314604, 12731, 134, 4, 27, "Input",
   CellTags->"Convolute"],
  Cell[314741, 12737, 178, 6, 25, "Output",
   CellTags->"Convolute"],
  Cell[314956, 12748, 134, 4, 27, "Input",
   CellTags->"Convolute"],
  Cell[315093, 12754, 128, 4, 25, "Output",
   CellTags->"Convolute"],
  Cell[315258, 12763, 181, 6, 42, "Input",
   CellTags->"Convolute"],
  Cell[315442, 12771, 215, 7, 25, "Output",
   CellTags->"Convolute"],
  Cell[315694, 12783, 227, 7, 42, "Input",
   CellTags->"Convolute"],
  Cell[315924, 12792, 215, 7, 25, "Output",
   CellTags->"Convolute"],
  Cell[316176, 12804, 181, 6, 42, "Input",
   CellTags->"Convolute"],
  Cell[316360, 12812, 307, 11, 25, "Output",
   CellTags->"Convolute"],
  Cell[316704, 12828, 228, 8, 42, "Input",
   CellTags->"Convolute"],
  Cell[316935, 12838, 536, 19, 43, "Output",
   CellTags->"Convolute"],
  Cell[317508, 12862, 190, 6, 27, "Input",
   CellTags->"Convolute"],
  Cell[317701, 12870, 321, 11, 25, "Output",
   CellTags->"Convolute"],
  Cell[318059, 12886, 216, 7, 27, "Input",
   CellTags->"Convolute"],
  Cell[318278, 12895, 273, 10, 25, "Output",
   CellTags->"Convolute"],
  Cell[318588, 12910, 237, 8, 42, "Input",
   CellTags->"Convolute"],
  Cell[318828, 12920, 389, 13, 27, "Output",
   CellTags->"Convolute"],
  Cell[319254, 12938, 263, 9, 42, "Input",
   CellTags->"Convolute"],
  Cell[319520, 12949, 617, 21, 27, "Output",
   CellTags->"Convolute"],
  Cell[320174, 12975, 239, 8, 42, "Input",
   CellTags->"Convolute"],
  Cell[320416, 12985, 717, 24, 43, "Output",
   CellTags->"Convolute"],
  Cell[321170, 13014, 190, 6, 27, "Input",
   CellTags->"Convolute"],
  Cell[321363, 13022, 245, 9, 25, "Output",
   CellTags->"Convolute"],
  Cell[321645, 13036, 190, 6, 27, "Input",
   CellTags->"Convolute"],
  Cell[321838, 13044, 317, 11, 25, "Output",
   CellTags->"Convolute"],
  Cell[322192, 13060, 260, 9, 42, "Input",
   CellTags->"Convolute"],
  Cell[322455, 13071, 452, 16, 48, "Output",
   CellTags->"Convolute"],
  Cell[322944, 13092, 165, 5, 27, "Input",
   CellTags->"Convolute"],
  Cell[323112, 13099, 229, 9, 43, "Output",
   CellTags->"Convolute"],
  Cell[323378, 13113, 195, 6, 27, "Input",
   CellTags->"Convolute"],
  Cell[323576, 13121, 239, 9, 43, "Output",
   CellTags->"Convolute"],
  Cell[323852, 13135, 212, 7, 42, "Input",
   CellTags->"Convolute"],
  Cell[324067, 13144, 416, 14, 43, "Output",
   CellTags->"Convolute"],
  Cell[324520, 13163, 213, 7, 42, "Input",
   CellTags->"Convolute"],
  Cell[324736, 13172, 316, 12, 43, "Output",
   CellTags->"Convolute"],
  Cell[325089, 13189, 237, 8, 42, "Input",
   CellTags->"Convolute"],
  Cell[325329, 13199, 550, 18, 43, "Output",
   CellTags->"Convolute"],
  Cell[325916, 13222, 213, 7, 42, "Input",
   CellTags->"Convolute"],
  Cell[326132, 13231, 409, 13, 43, "Output",
   CellTags->"Convolute"],
  Cell[326578, 13249, 190, 6, 27, "Input",
   CellTags->"Convolute"],
  Cell[326771, 13257, 245, 9, 25, "Output",
   CellTags->"Convolute"],
  Cell[327053, 13271, 165, 5, 27, "Input",
   CellTags->"Convolute"],
  Cell[327221, 13278, 188, 6, 25, "Output",
   CellTags->"Convolute"],
  Cell[327446, 13289, 286, 10, 42, "Input",
   CellTags->"Convolute"],
  Cell[327735, 13301, 790, 29, 48, "Output",
   CellTags->"Convolute"],
  Cell[328562, 13335, 295, 10, 42, "Input",
   CellTags->"Convolute"],
  Cell[328860, 13347, 1193, 41, 64, "Output",
   CellTags->"Convolute"],
  Cell[332434, 13501, 244, 8, 42, "Input",
   CellTags->"Convolute"],
  Cell[332681, 13511, 463, 16, 43, "Output",
   CellTags->"Convolute"]},
 "ConvoluteTable"->{
  Cell[330080, 13392, 66, 1, 39, "ObjectName",
   CellTags->"ConvoluteTable"],
  Cell[330171, 13397, 65, 1, 33, "Subsubsection",
   CellTags->"ConvoluteTable"],
  Cell[330239, 13400, 152, 4, 23, "Text",
   CellTags->"ConvoluteTable"],
  Cell[330416, 13408, 122, 3, 27, "Input",
   CellTags->"ConvoluteTable"],
  Cell[330541, 13413, 405, 13, 25, "Output",
   CellTags->"ConvoluteTable"],
  Cell[330961, 13429, 322, 14, 23, "Text",
   CellTags->"ConvoluteTable"],
  Cell[331320, 13448, 62, 1, 33, "Subsubsection",
   CellTags->"ConvoluteTable"],
  Cell[331407, 13453, 144, 4, 27, "Input",
   CellTags->"ConvoluteTable"],
  Cell[331554, 13459, 159, 5, 25, "Output",
   CellTags->"ConvoluteTable"],
  Cell[331750, 13469, 144, 4, 27, "Input",
   CellTags->"ConvoluteTable"],
  Cell[331897, 13475, 183, 6, 25, "Output",
   CellTags->"ConvoluteTable"],
  Cell[332117, 13486, 144, 4, 27, "Input",
   CellTags->"ConvoluteTable"],
  Cell[332264, 13492, 133, 4, 25, "Output",
   CellTags->"ConvoluteTable"]},
 "CovariantFieldDerivative"->{
  Cell[333171, 13531, 85, 1, 39, "ObjectName",
   CellTags->"CovariantFieldDerivative"],
  Cell[333281, 13536, 75, 1, 33, "Subsubsection",
   CellTags->"CovariantFieldDerivative"],
  Cell[333359, 13539, 372, 6, 39, "Text",
   CellTags->"CovariantFieldDerivative"],
  Cell[333734, 13547, 460, 19, 23, "Text",
   CellTags->"CovariantFieldDerivative"],
  Cell[334231, 13571, 72, 1, 33, "Subsubsection",
   CellTags->"CovariantFieldDerivative"],
  Cell[334328, 13576, 329, 9, 27, "Input",
   CellTags->"CovariantFieldDerivative"],
  Cell[334660, 13587, 543, 21, 28, "Output",
   CellTags->"CovariantFieldDerivative"]},
 "CounterT"->{
  Cell[335230, 13612, 53, 1, 39, "ObjectName",
   CellTags->"CounterT"],
  Cell[335308, 13617, 59, 1, 33, "Subsubsection",
   CellTags->"CounterT"],
  Cell[335370, 13620, 146, 4, 23, "Text",
   CellTags->"CounterT"],
  Cell[335519, 13626, 450, 19, 23, "Text",
   CellTags->"CounterT"],
  Cell[336006, 13650, 56, 1, 33, "Subsubsection",
   CellTags->"CounterT"],
  Cell[336087, 13655, 284, 6, 27, "Input",
   CellTags->"CounterT"],
  Cell[336374, 13663, 3127, 106, 59, "Output",
   CellTags->"CounterT"]},
 "CounterTerm"->{
  Cell[339528, 13773, 59, 1, 39, "ObjectName",
   CellTags->"CounterTerm"],
  Cell[339612, 13778, 62, 1, 33, "Subsubsection",
   CellTags->"CounterTerm"],
  Cell[339677, 13781, 216, 5, 39, "Text",
   CellTags->"CounterTerm"],
  Cell[339896, 13788, 578, 24, 23, "Text",
   CellTags->"CounterTerm"],
  Cell[340511, 13817, 59, 1, 33, "Subsubsection",
   CellTags->"CounterTerm"],
  Cell[340595, 13822, 116, 3, 27, "Input",
   CellTags->"CounterTerm"],
  Cell[340714, 13827, 1632, 52, 63, "Output",
   CellTags->"CounterTerm"]},
 "CouplingConstant"->{
  Cell[342373, 13883, 69, 1, 39, "ObjectName",
   CellTags->"CouplingConstant"],
  Cell[342467, 13888, 67, 1, 33, "Subsubsection",
   CellTags->"CouplingConstant"],
  Cell[342537, 13891, 657, 11, 95, "Text",
   CellTags->"CouplingConstant"],
  Cell[343197, 13904, 318, 14, 23, "Text",
   CellTags->"CouplingConstant"]},
 "CovariantD"->{
  Cell[343530, 13921, 57, 1, 39, "ObjectName",
   CellTags->"CovariantD"],
  Cell[343612, 13926, 61, 1, 33, "Subsubsection",
   CellTags->"CovariantD"],
  Cell[343676, 13929, 1210, 18, 175, "Text",
   CellTags->"CovariantD"],
  Cell[344911, 13951, 119, 3, 27, "Input",
   CellTags->"CovariantD"],
  Cell[345033, 13956, 439, 12, 25, "Output",
   CellTags->"CovariantD"],
  Cell[345487, 13971, 185, 4, 23, "Text",
   CellTags->"CovariantD"],
  Cell[345675, 13977, 455, 19, 23, "Text",
   CellTags->"CovariantD"],
  Cell[346167, 14001, 58, 1, 33, "Subsubsection",
   CellTags->"CovariantD"],
  Cell[346250, 14006, 117, 3, 27, "Input",
   CellTags->"CovariantD"],
  Cell[346370, 14011, 132, 4, 28, "Output",
   CellTags->"CovariantD"],
  Cell[346539, 14020, 150, 4, 27, "Input",
   CellTags->"CovariantD"],
  Cell[346692, 14026, 161, 5, 31, "Output",
   CellTags->"CovariantD"],
  Cell[346890, 14036, 180, 5, 27, "Input",
   CellTags->"CovariantD"],
  Cell[347073, 14043, 992, 39, 33, "Output",
   CellTags->"CovariantD"],
  Cell[348080, 14085, 164, 4, 23, "Text",
   CellTags->"CovariantD"],
  Cell[348269, 14093, 120, 3, 27, "Input",
   CellTags->"CovariantD"],
  Cell[348392, 14098, 176, 6, 25, "Output",
   CellTags->"CovariantD"],
  Cell[348605, 14109, 153, 4, 27, "Input",
   CellTags->"CovariantD"],
  Cell[348761, 14115, 205, 7, 29, "Output",
   CellTags->"CovariantD"],
  Cell[349003, 14127, 203, 5, 27, "Input",
   CellTags->"CovariantD"],
  Cell[349209, 14134, 939, 36, 32, "Output",
   CellTags->"CovariantD"],
  Cell[350185, 14175, 183, 5, 27, "Input",
   CellTags->"CovariantD"],
  Cell[350371, 14182, 932, 35, 32, "Output",
   CellTags->"CovariantD"],
  Cell[351340, 14222, 187, 5, 27, "Input",
   CellTags->"CovariantD"],
  Cell[351530, 14229, 1345, 49, 34, "Output",
   CellTags->"CovariantD"],
  Cell[352890, 14281, 602, 22, 30, "Text",
   CellTags->"CovariantD"],
  Cell[353517, 14307, 215, 6, 27, "Input",
   CellTags->"CovariantD"],
  Cell[353735, 14315, 513, 20, 31, "Output",
   CellTags->"CovariantD"],
  Cell[354263, 14338, 285, 10, 23, "Text",
   CellTags->"CovariantD"],
  Cell[354573, 14352, 215, 6, 27, "Input",
   CellTags->"CovariantD"],
  Cell[354791, 14360, 2287, 81, 53, "Output",
   CellTags->"CovariantD"],
  Cell[357093, 14444, 189, 7, 23, "Text",
   CellTags->"CovariantD"],
  Cell[357307, 14455, 215, 6, 27, "Input",
   CellTags->"CovariantD"],
  Cell[357525, 14463, 6316, 201, 55, "Output",
   CellTags->"CovariantD"],
  Cell[363878, 14669, 181, 5, 27, "Input",
   CellTags->"CovariantD"],
  Cell[364062, 14676, 261, 9, 29, "Output",
   CellTags->"CovariantD"],
  Cell[364360, 14690, 195, 6, 27, "Input",
   CellTags->"CovariantD"],
  Cell[364558, 14698, 4816, 151, 55, "Output",
   CellTags->"CovariantD"],
  Cell[369411, 14854, 223, 7, 27, "Input",
   CellTags->"CovariantD"],
  Cell[369637, 14863, 788, 24, 59, "Output",
   CellTags->"CovariantD"],
  Cell[370462, 14892, 240, 7, 27, "Input",
   CellTags->"CovariantD"],
  Cell[370705, 14901, 803, 25, 59, "Output",
   CellTags->"CovariantD"]},
 "CrossProduct"->{
  Cell[371535, 14930, 61, 1, 39, "ObjectName",
   CellTags->"CrossProduct"],
  Cell[371621, 14935, 63, 1, 33, "Subsubsection",
   CellTags->"CrossProduct"],
  Cell[371687, 14938, 145, 4, 23, "Text",
   CellTags->"CrossProduct"],
  Cell[371835, 14944, 308, 14, 23, "Text",
   CellTags->"CrossProduct"],
  Cell[372180, 14963, 60, 1, 33, "Subsubsection",
   CellTags->"CrossProduct"],
  Cell[372265, 14968, 326, 9, 27, "Input",
   CellTags->"CrossProduct"],
  Cell[372594, 14979, 639, 22, 28, "Output",
   CellTags->"CrossProduct"]},
 "C0"->{
  Cell[373260, 15005, 41, 1, 39, "ObjectName",
   CellTags->"C0"],
  Cell[373326, 15010, 53, 1, 33, "Subsubsection",
   CellTags->"C0"],
  Cell[373382, 15013, 448, 10, 55, "Text",
   CellTags->"C0"],
  Cell[373833, 15025, 458, 24, 23, "Text",
   CellTags->"C0"],
  Cell[374328, 15054, 50, 1, 33, "Subsubsection",
   CellTags->"C0"],
  Cell[374403, 15059, 174, 5, 27, "Input",
   CellTags->"C0"],
  Cell[374580, 15066, 260, 8, 25, "Output",
   CellTags->"C0"],
  Cell[374877, 15079, 203, 6, 27, "Input",
   CellTags->"C0"],
  Cell[375083, 15087, 260, 8, 25, "Output",
   CellTags->"C0"],
  Cell[375380, 15100, 326, 10, 27, "Input",
   CellTags->"C0"],
  Cell[375709, 15112, 260, 8, 25, "Output",
   CellTags->"C0"]},
 "DataType"->{
  Cell[375996, 15124, 53, 1, 39, "ObjectName",
   CellTags->"DataType"],
  Cell[376074, 15129, 59, 1, 33, "Subsubsection",
   CellTags->"DataType"],
  Cell[376136, 15132, 344, 6, 39, "Text",
   CellTags->"DataType"],
  Cell[376483, 15140, 835, 32, 39, "Text",
   CellTags->"DataType"],
  Cell[377321, 15174, 291, 13, 23, "Text",
   CellTags->"DataType"],
  Cell[377615, 15189, 218, 9, 23, "Text",
   CellTags->"DataType"],
  Cell[377870, 15203, 56, 1, 33, "Subsubsection",
   CellTags->"DataType"],
  Cell[377929, 15206, 74, 1, 23, "Text",
   CellTags->"DataType"],
  Cell[378006, 15209, 221, 7, 27, "Input",
   CellTags->"DataType"],
  Cell[378252, 15220, 224, 8, 27, "Input",
   CellTags->"DataType"],
  Cell[378479, 15230, 238, 9, 25, "Output",
   CellTags->"DataType"],
  Cell[378732, 15242, 179, 4, 23, "Text",
   CellTags->"DataType"],
  Cell[378936, 15250, 112, 3, 27, "Input",
   CellTags->"DataType"],
  Cell[379051, 15255, 210, 7, 25, "Output",
   CellTags->"DataType"],
  Cell[379276, 15265, 271, 9, 27, "Input",
   CellTags->"DataType"],
  Cell[379550, 15276, 412, 14, 27, "Input",
   CellTags->"DataType"],
  Cell[379965, 15292, 395, 14, 27, "Input",
   CellTags->"DataType"],
  Cell[380385, 15310, 340, 13, 27, "Input",
   CellTags->"DataType"],
  Cell[380728, 15325, 350, 13, 25, "Output",
   CellTags->"DataType"],
  Cell[381115, 15343, 107, 3, 27, "Input",
   CellTags->"DataType"],
  Cell[381225, 15348, 281, 11, 25, "Output",
   CellTags->"DataType"],
  Cell[381543, 15364, 107, 3, 27, "Input",
   CellTags->"DataType"],
  Cell[381653, 15369, 172, 6, 25, "Output",
   CellTags->"DataType"],
  Cell[381840, 15378, 191, 6, 27, "Input",
   CellTags->"DataType"],
  Cell[382034, 15386, 187, 6, 27, "Input",
   CellTags->"DataType"],
  Cell[382224, 15394, 429, 15, 27, "Input",
   CellTags->"DataType"],
  Cell[382678, 15413, 290, 11, 27, "Input",
   CellTags->"DataType"],
  Cell[382971, 15426, 299, 12, 25, "Output",
   CellTags->"DataType"],
  Cell[383307, 15443, 105, 3, 27, "Input",
   CellTags->"DataType"],
  Cell[383415, 15448, 228, 9, 25, "Output",
   CellTags->"DataType"],
  Cell[383658, 15460, 151, 5, 27, "Input",
   CellTags->"DataType"],
  Cell[383812, 15467, 222, 7, 27, "Input",
   CellTags->"DataType"],
  Cell[384037, 15476, 272, 9, 27, "Input",
   CellTags->"DataType"],
  Cell[384312, 15487, 114, 3, 23, "Text",
   CellTags->"DataType"],
  Cell[384451, 15494, 149, 4, 27, "Input",
   CellTags->"DataType"],
  Cell[384603, 15500, 107, 3, 25, "Output",
   CellTags->"DataType"],
  Cell[384725, 15506, 83, 1, 23, "Text",
   CellTags->"DataType"],
  Cell[384833, 15511, 233, 8, 27, "Input",
   CellTags->"DataType"],
  Cell[385069, 15521, 104, 3, 25, "Output",
   CellTags->"DataType"],
  Cell[385210, 15529, 226, 7, 27, "Input",
   CellTags->"DataType"],
  Cell[385439, 15538, 435, 16, 25, "Output",
   CellTags->"DataType"]},
 "DB0"->{
  Cell[385901, 15558, 43, 1, 39, "ObjectName",
   CellTags->"DB0"],
  Cell[385969, 15563, 54, 1, 33, "Subsubsection",
   CellTags->"DB0"],
  Cell[386026, 15566, 146, 4, 23, "Text",
   CellTags->"DB0"],
  Cell[386175, 15572, 156, 9, 23, "Text",
   CellTags->"DB0"],
  Cell[386368, 15586, 51, 1, 33, "Subsubsection",
   CellTags->"DB0"],
  Cell[386444, 15591, 339, 12, 29, "Input",
   CellTags->"DB0"],
  Cell[386786, 15605, 255, 8, 29, "Output",
   CellTags->"DB0"]},
 "DB1"->{
  Cell[387068, 15617, 43, 1, 39, "ObjectName",
   CellTags->"DB1"],
  Cell[387136, 15622, 54, 1, 33, "Subsubsection",
   CellTags->"DB1"],
  Cell[387193, 15625, 117, 3, 23, "Text",
   CellTags->"DB1"],
  Cell[387313, 15630, 156, 9, 23, "Text",
   CellTags->"DB1"],
  Cell[387506, 15644, 51, 1, 33, "Subsubsection",
   CellTags->"DB1"],
  Cell[387582, 15649, 339, 12, 29, "Input",
   CellTags->"DB1"],
  Cell[387924, 15663, 1410, 45, 51, "Output",
   CellTags->"DB1"]},
 "DeclareNonCommutative"->{
  Cell[389361, 15712, 79, 1, 39, "ObjectName",
   CellTags->"DeclareNonCommutative"],
  Cell[389465, 15717, 72, 1, 33, "Subsubsection",
   CellTags->"DeclareNonCommutative"],
  Cell[389540, 15720, 192, 4, 23, "Text",
   CellTags->"DeclareNonCommutative"],
  Cell[389735, 15726, 347, 14, 23, "Text",
   CellTags->"DeclareNonCommutative"],
  Cell[390119, 15745, 69, 1, 33, "Subsubsection",
   CellTags->"DeclareNonCommutative"],
  Cell[390191, 15748, 135, 3, 27, "Input",
   CellTags->"DeclareNonCommutative"],
  Cell[390329, 15753, 152, 4, 23, "Text",
   CellTags->"DeclareNonCommutative"],
  Cell[390506, 15761, 158, 4, 27, "Input",
   CellTags->"DeclareNonCommutative"],
  Cell[390667, 15767, 120, 3, 25, "Output",
   CellTags->"DeclareNonCommutative"],
  Cell[390802, 15773, 158, 4, 27, "Input",
   CellTags->"DeclareNonCommutative"],
  Cell[390985, 15781, 191, 5, 27, "Input",
   CellTags->"DeclareNonCommutative"],
  Cell[391179, 15788, 199, 6, 25, "Output",
   CellTags->"DeclareNonCommutative"],
  Cell[391393, 15797, 170, 4, 27, "Input",
   CellTags->"DeclareNonCommutative"],
  Cell[391588, 15805, 191, 5, 27, "Input",
   CellTags->"DeclareNonCommutative"],
  Cell[391782, 15812, 199, 6, 25, "Output",
   CellTags->"DeclareNonCommutative"]},
 "DeltaFunction"->{
  Cell[392008, 15822, 63, 1, 39, "ObjectName",
   CellTags->"DeltaFunction"],
  Cell[392096, 15827, 64, 1, 33, "Subsubsection",
   CellTags->"DeltaFunction"],
  Cell[392163, 15830, 353, 11, 47, "Text",
   CellTags->"DeltaFunction"],
  Cell[392519, 15843, 592, 24, 23, "Text",
   CellTags->"DeltaFunction"],
  Cell[393148, 15872, 61, 1, 33, "Subsubsection",
   CellTags->"DeltaFunction"],
  Cell[393234, 15877, 142, 4, 27, "Input",
   CellTags->"DeltaFunction"],
  Cell[393379, 15883, 203, 7, 25, "Output",
   CellTags->"DeltaFunction"],
  Cell[393619, 15895, 320, 10, 27, "Input",
   CellTags->"DeltaFunction"],
  Cell[393942, 15907, 137, 4, 25, "Output",
   CellTags->"DeltaFunction"],
  Cell[394116, 15916, 294, 9, 27, "Input",
   CellTags->"DeltaFunction"],
  Cell[394413, 15927, 137, 4, 25, "Output",
   CellTags->"DeltaFunction"],
  Cell[394587, 15936, 320, 10, 27, "Input",
   CellTags->"DeltaFunction"],
  Cell[394910, 15948, 137, 4, 25, "Output",
   CellTags->"DeltaFunction"],
  Cell[395084, 15957, 204, 6, 27, "Input",
   CellTags->"DeltaFunction"],
  Cell[395291, 15965, 109, 3, 25, "Output",
   CellTags->"DeltaFunction"]},
 "DeltaFunctionDoublePrime"->{
  Cell[395427, 15972, 85, 1, 39, "ObjectName",
   CellTags->"DeltaFunctionDoublePrime"],
  Cell[395537, 15977, 75, 1, 33, "Subsubsection",
   CellTags->"DeltaFunctionDoublePrime"],
  Cell[395615, 15980, 248, 8, 23, "Text",
   CellTags->"DeltaFunctionDoublePrime"],
  Cell[395866, 15990, 219, 8, 23, "Text",
   CellTags->"DeltaFunctionDoublePrime"]},
 "DeltaFunctionPrime"->{
  Cell[396100, 16001, 73, 1, 39, "ObjectName",
   CellTags->"DeltaFunctionPrime"],
  Cell[396198, 16006, 69, 1, 33, "Subsubsection",
   CellTags->"DeltaFunctionPrime"],
  Cell[396270, 16009, 227, 7, 23, "Text",
   CellTags->"DeltaFunctionPrime"],
  Cell[396500, 16018, 576, 23, 23, "Text",
   CellTags->"DeltaFunctionPrime"],
  Cell[397113, 16046, 66, 1, 33, "Subsubsection",
   CellTags->"DeltaFunctionPrime"],
  Cell[397204, 16051, 152, 4, 27, "Input",
   CellTags->"DeltaFunctionPrime"],
  Cell[397359, 16057, 240, 8, 25, "Output",
   CellTags->"DeltaFunctionPrime"],
  Cell[397636, 16070, 330, 10, 27, "Input",
   CellTags->"DeltaFunctionPrime"],
  Cell[397969, 16082, 203, 6, 25, "Output",
   CellTags->"DeltaFunctionPrime"],
  Cell[398209, 16093, 326, 10, 29, "Input",
   CellTags->"DeltaFunctionPrime"],
  Cell[398538, 16105, 114, 3, 25, "Output",
   CellTags->"DeltaFunctionPrime"]},
 "DenominatorOrder"->{
  Cell[398679, 16112, 69, 1, 39, "ObjectName",
   CellTags->"DenominatorOrder"],
  Cell[398773, 16117, 67, 1, 33, "Subsubsection",
   CellTags->"DenominatorOrder"],
  Cell[398843, 16120, 175, 4, 23, "Text",
   CellTags->"DenominatorOrder"],
  Cell[399021, 16126, 327, 13, 23, "Text",
   CellTags->"DenominatorOrder"]},
 "Dimension"->{
  Cell[399363, 16142, 55, 1, 39, "ObjectName",
   CellTags->"Dimension"],
  Cell[399443, 16147, 60, 1, 33, "Subsubsection",
   CellTags->"Dimension"],
  Cell[399506, 16150, 246, 5, 39, "Text",
   CellTags->"Dimension"],
  Cell[399777, 16159, 120, 3, 27, "Input",
   CellTags->"Dimension"],
  Cell[399900, 16164, 244, 8, 25, "Output",
   CellTags->"Dimension"],
  Cell[400181, 16177, 313, 9, 27, "Input",
   CellTags->"Dimension"],
  Cell[400497, 16188, 286, 11, 25, "Output",
   CellTags->"Dimension"],
  Cell[400798, 16202, 131, 4, 23, "Text",
   CellTags->"Dimension"],
  Cell[400954, 16210, 357, 11, 27, "Input",
   CellTags->"Dimension"],
  Cell[401314, 16223, 360, 10, 39, "Output",
   CellTags->"Dimension"],
  Cell[401689, 16236, 166, 4, 23, "Text",
   CellTags->"Dimension"],
  Cell[401858, 16242, 133, 4, 27, "Input",
   CellTags->"Dimension"],
  Cell[402016, 16250, 326, 9, 27, "Input",
   CellTags->"Dimension"],
  Cell[402345, 16261, 662, 28, 25, "Output",
   CellTags->"Dimension"],
  Cell[403044, 16294, 110, 3, 27, "Input",
   CellTags->"Dimension"],
  Cell[403157, 16299, 373, 10, 39, "Output",
   CellTags->"Dimension"],
  Cell[403545, 16312, 134, 4, 27, "Input",
   CellTags->"Dimension"]},
 "DimensionalReduction"->{
  Cell[403694, 16319, 77, 1, 39, "ObjectName",
   CellTags->"DimensionalReduction"],
  Cell[403796, 16324, 71, 1, 33, "Subsubsection",
   CellTags->"DimensionalReduction"],
  Cell[403870, 16327, 121, 3, 23, "Text",
   CellTags->"DimensionalReduction"],
  Cell[403994, 16332, 301, 13, 23, "Text",
   CellTags->"DimensionalReduction"]},
 "DiracBasis"->{
  Cell[404310, 16348, 57, 1, 39, "ObjectName",
   CellTags->"DiracBasis"],
  Cell[404392, 16353, 61, 1, 33, "Subsubsection",
   CellTags->"DiracBasis"],
  Cell[404456, 16356, 299, 6, 39, "Text",
   CellTags->"DiracBasis"],
  Cell[404758, 16364, 184, 8, 23, "Text",
   CellTags->"DiracBasis"]},
 "DiracCanonical"->{
  Cell[404957, 16375, 65, 1, 39, "ObjectName",
   CellTags->"DiracCanonical"],
  Cell[405047, 16380, 65, 1, 33, "Subsubsection",
   CellTags->"DiracCanonical"],
  Cell[405115, 16383, 171, 4, 23, "Text",
   CellTags->"DiracCanonical"],
  Cell[405289, 16389, 194, 8, 23, "Text",
   CellTags->"DiracCanonical"]},
 "DiracEquation"->{
  Cell[405498, 16400, 63, 1, 39, "ObjectName",
   CellTags->"DiracEquation"],
  Cell[405586, 16405, 64, 1, 33, "Subsubsection",
   CellTags->"DiracEquation"],
  Cell[405653, 16408, 160, 4, 23, "Text",
   CellTags->"DiracEquation"],
  Cell[405816, 16414, 199, 9, 23, "Text",
   CellTags->"DiracEquation"],
  Cell[406052, 16428, 61, 1, 33, "Subsubsection",
   CellTags->"DiracEquation"],
  Cell[406138, 16433, 279, 8, 27, "Input",
   CellTags->"DiracEquation"],
  Cell[406420, 16443, 368, 13, 25, "Output",
   CellTags->"DiracEquation"],
  Cell[406825, 16461, 119, 3, 27, "Input",
   CellTags->"DiracEquation"],
  Cell[406947, 16466, 217, 7, 25, "Output",
   CellTags->"DiracEquation"]},
 "DiracGamma"->{
  Cell[407191, 16477, 57, 1, 39, "ObjectName",
   CellTags->"DiracGamma"],
  Cell[407273, 16482, 61, 1, 33, "Subsubsection",
   CellTags->"DiracGamma"],
  Cell[407337, 16485, 762, 24, 59, "Text",
   CellTags->"DiracGamma"],
  Cell[408102, 16511, 681, 29, 23, "Text",
   CellTags->"DiracGamma"],
  Cell[408820, 16545, 58, 1, 33, "Subsubsection",
   CellTags->"DiracGamma"],
  Cell[408903, 16550, 113, 3, 27, "Input",
   CellTags->"DiracGamma"],
  Cell[409019, 16555, 137, 4, 27, "Output",
   CellTags->"DiracGamma"],
  Cell[409193, 16564, 159, 4, 27, "Input",
   CellTags->"DiracGamma"],
  Cell[409355, 16570, 214, 8, 25, "Output",
   CellTags->"DiracGamma"],
  Cell[409584, 16581, 332, 13, 26, "Text",
   CellTags->"DiracGamma"],
  Cell[409941, 16598, 167, 5, 27, "Input",
   CellTags->"DiracGamma"],
  Cell[410111, 16605, 223, 8, 25, "Output",
   CellTags->"DiracGamma"],
  Cell[410371, 16618, 280, 8, 27, "Input",
   CellTags->"DiracGamma"],
  Cell[410654, 16628, 468, 17, 25, "Output",
   CellTags->"DiracGamma"],
  Cell[411159, 16650, 218, 7, 27, "Input",
   CellTags->"DiracGamma"],
  Cell[411380, 16659, 223, 8, 25, "Output",
   CellTags->"DiracGamma"],
  Cell[411640, 16672, 208, 7, 27, "Input",
   CellTags->"DiracGamma"],
  Cell[411851, 16681, 341, 12, 25, "Output",
   CellTags->"DiracGamma"],
  Cell[412229, 16698, 144, 4, 27, "Input",
   CellTags->"DiracGamma"],
  Cell[412376, 16704, 593, 22, 25, "Output",
   CellTags->"DiracGamma"],
  Cell[413006, 16731, 300, 9, 27, "Input",
   CellTags->"DiracGamma"],
  Cell[413309, 16742, 430, 13, 25, "Output",
   CellTags->"DiracGamma"],
  Cell[413776, 16760, 138, 4, 27, "Input",
   CellTags->"DiracGamma"],
  Cell[413917, 16766, 430, 13, 25, "Output",
   CellTags->"DiracGamma"],
  Cell[414384, 16784, 141, 4, 27, "Input",
   CellTags->"DiracGamma"],
  Cell[414528, 16790, 1123, 42, 27, "Output",
   CellTags->"DiracGamma"],
  Cell[415666, 16835, 168, 5, 27, "Input",
   CellTags->"DiracGamma"]},
 "DiracGammaCombine"->{
  Cell[415849, 16843, 71, 1, 39, "ObjectName",
   CellTags->"DiracGammaCombine"],
  Cell[415945, 16848, 68, 1, 33, "Subsubsection",
   CellTags->"DiracGammaCombine"],
  Cell[416016, 16851, 135, 4, 23, "Text",
   CellTags->"DiracGammaCombine"],
  Cell[416154, 16857, 804, 34, 23, "Text",
   CellTags->"DiracGammaCombine"],
  Cell[416995, 16896, 65, 1, 33, "Subsubsection",
   CellTags->"DiracGammaCombine"],
  Cell[417085, 16901, 220, 6, 27, "Input",
   CellTags->"DiracGammaCombine"],
  Cell[417308, 16909, 265, 9, 25, "Output",
   CellTags->"DiracGammaCombine"],
  Cell[417610, 16923, 122, 3, 27, "Input",
   CellTags->"DiracGammaCombine"],
  Cell[417735, 16928, 194, 5, 39, "Output",
   CellTags->"DiracGammaCombine"],
  Cell[417966, 16938, 270, 8, 27, "Input",
   CellTags->"DiracGammaCombine"],
  Cell[418239, 16948, 317, 11, 25, "Output",
   CellTags->"DiracGammaCombine"],
  Cell[418593, 16964, 122, 3, 27, "Input",
   CellTags->"DiracGammaCombine"],
  Cell[418718, 16969, 244, 7, 39, "Output",
   CellTags->"DiracGammaCombine"],
  Cell[418999, 16981, 127, 3, 27, "Input",
   CellTags->"DiracGammaCombine"],
  Cell[419129, 16986, 438, 16, 25, "Output",
   CellTags->"DiracGammaCombine"]},
 "DiracGammaExpand"->{
  Cell[419594, 17006, 69, 1, 39, "ObjectName",
   CellTags->"DiracGammaExpand"],
  Cell[419688, 17011, 67, 1, 33, "Subsubsection",
   CellTags->"DiracGammaExpand"],
  Cell[419758, 17014, 190, 4, 39, "Text",
   CellTags->"DiracGammaExpand"],
  Cell[419951, 17020, 806, 34, 23, "Text",
   CellTags->"DiracGammaExpand"],
  Cell[420794, 17059, 64, 1, 33, "Subsubsection",
   CellTags->"DiracGammaExpand"],
  Cell[420883, 17064, 314, 9, 27, "Input",
   CellTags->"DiracGammaExpand"],
  Cell[421200, 17075, 474, 17, 25, "Output",
   CellTags->"DiracGammaExpand"],
  Cell[421689, 17095, 125, 3, 23, "Text",
   CellTags->"DiracGammaExpand"],
  Cell[421839, 17102, 121, 3, 27, "Input",
   CellTags->"DiracGammaExpand"],
  Cell[421963, 17107, 291, 8, 39, "Output",
   CellTags->"DiracGammaExpand"],
  Cell[422269, 17118, 101, 1, 23, "Text",
   CellTags->"DiracGammaExpand"],
  Cell[422395, 17123, 125, 3, 27, "Input",
   CellTags->"DiracGammaExpand"],
  Cell[422523, 17128, 599, 22, 25, "Output",
   CellTags->"DiracGammaExpand"],
  Cell[423137, 17153, 90, 1, 23, "Text",
   CellTags->"DiracGammaExpand"],
  Cell[423252, 17158, 209, 5, 27, "Input",
   CellTags->"DiracGammaExpand"],
  Cell[423464, 17165, 291, 8, 39, "Output",
   CellTags->"DiracGammaExpand"],
  Cell[423792, 17178, 164, 4, 27, "Input",
   CellTags->"DiracGammaExpand"],
  Cell[423959, 17184, 394, 11, 39, "Output",
   CellTags->"DiracGammaExpand"],
  Cell[424368, 17198, 106, 1, 23, "Text",
   CellTags->"DiracGammaExpand"],
  Cell[424499, 17203, 122, 3, 27, "Input",
   CellTags->"DiracGammaExpand"],
  Cell[424624, 17208, 534, 20, 27, "Output",
   CellTags->"DiracGammaExpand"],
  Cell[425173, 17231, 114, 3, 27, "Input",
   CellTags->"DiracGammaExpand"]},
 "DiracGammaT"->{
  Cell[425302, 17237, 59, 1, 39, "ObjectName",
   CellTags->"DiracGammaT"],
  Cell[425386, 17242, 62, 1, 33, "Subsubsection",
   CellTags->"DiracGammaT"],
  Cell[425451, 17245, 208, 5, 39, "Text",
   CellTags->"DiracGammaT"],
  Cell[425662, 17252, 188, 9, 23, "Text",
   CellTags->"DiracGammaT"],
  Cell[425887, 17266, 59, 1, 33, "Subsubsection",
   CellTags->"DiracGammaT"],
  Cell[425971, 17271, 158, 4, 27, "Input",
   CellTags->"DiracGammaT"],
  Cell[426132, 17277, 220, 8, 31, "Output",
   CellTags->"DiracGammaT"],
  Cell[426389, 17290, 113, 3, 27, "Input",
   CellTags->"DiracGammaT"],
  Cell[426505, 17295, 212, 8, 25, "Output",
   CellTags->"DiracGammaT"],
  Cell[426754, 17308, 167, 6, 27, "Input",
   CellTags->"DiracGammaT"],
  Cell[426924, 17316, 219, 7, 27, "Output",
   CellTags->"DiracGammaT"]},
 "DiracMatrix"->{
  Cell[427170, 17327, 59, 1, 39, "ObjectName",
   CellTags->"DiracMatrix"],
  Cell[427254, 17332, 62, 1, 33, "Subsubsection",
   CellTags->"DiracMatrix"],
  Cell[427319, 17335, 1220, 46, 41, "Text",
   CellTags->"DiracMatrix"],
  Cell[428542, 17383, 1053, 49, 23, "Text",
   CellTags->"DiracMatrix"],
  Cell[429632, 17437, 59, 1, 33, "Subsubsection",
   CellTags->"DiracMatrix"],
  Cell[429716, 17442, 119, 3, 27, "Input",
   CellTags->"DiracMatrix"],
  Cell[429838, 17447, 212, 8, 25, "Output",
   CellTags->"DiracMatrix"],
  Cell[430065, 17458, 539, 20, 23, "Text",
   CellTags->"DiracMatrix"],
  Cell[430629, 17482, 184, 5, 27, "Input",
   CellTags->"DiracMatrix"],
  Cell[430816, 17489, 350, 14, 25, "Output",
   CellTags->"DiracMatrix"],
  Cell[431203, 17508, 160, 5, 27, "Input",
   CellTags->"DiracMatrix"],
  Cell[431366, 17515, 175, 4, 39, "Output",
   CellTags->"DiracMatrix"],
  Cell[431578, 17524, 145, 4, 27, "Input",
   CellTags->"DiracMatrix"],
  Cell[431726, 17530, 142, 4, 25, "Output",
   CellTags->"DiracMatrix"],
  Cell[431905, 17539, 112, 3, 27, "Input",
   CellTags->"DiracMatrix"],
  Cell[432020, 17544, 125, 3, 39, "Output",
   CellTags->"DiracMatrix"],
  Cell[432182, 17552, 111, 3, 27, "Input",
   CellTags->"DiracMatrix"],
  Cell[432296, 17557, 142, 4, 25, "Output",
   CellTags->"DiracMatrix"],
  Cell[432475, 17566, 138, 4, 27, "Input",
   CellTags->"DiracMatrix"],
  Cell[432616, 17572, 221, 6, 39, "Output",
   CellTags->"DiracMatrix"],
  Cell[432874, 17583, 152, 4, 27, "Input",
   CellTags->"DiracMatrix"],
  Cell[433029, 17589, 249, 7, 25, "Output",
   CellTags->"DiracMatrix"],
  Cell[433315, 17601, 166, 5, 27, "Input",
   CellTags->"DiracMatrix"],
  Cell[433484, 17608, 342, 14, 27, "Output",
   CellTags->"DiracMatrix"],
  Cell[433863, 17627, 112, 3, 27, "Input",
   CellTags->"DiracMatrix"],
  Cell[433978, 17632, 269, 7, 39, "Output",
   CellTags->"DiracMatrix"]},
 "DiracOrder"->{
  Cell[434274, 17643, 57, 1, 39, "ObjectName",
   CellTags->"DiracOrder"],
  Cell[434356, 17648, 61, 1, 33, "Subsubsection",
   CellTags->"DiracOrder"],
  Cell[434420, 17651, 204, 5, 23, "Text",
   CellTags->"DiracOrder"],
  Cell[434627, 17658, 312, 14, 23, "Text",
   CellTags->"DiracOrder"],
  Cell[434976, 17677, 58, 1, 33, "Subsubsection",
   CellTags->"DiracOrder"],
  Cell[435059, 17682, 176, 5, 27, "Input",
   CellTags->"DiracOrder"],
  Cell[435238, 17689, 206, 6, 25, "Output",
   CellTags->"DiracOrder"],
  Cell[435481, 17700, 114, 3, 27, "Input",
   CellTags->"DiracOrder"],
  Cell[435598, 17705, 472, 18, 25, "Output",
   CellTags->"DiracOrder"],
  Cell[436085, 17726, 93, 1, 23, "Text",
   CellTags->"DiracOrder"],
  Cell[436203, 17731, 176, 5, 27, "Input",
   CellTags->"DiracOrder"],
  Cell[436382, 17738, 247, 7, 25, "Output",
   CellTags->"DiracOrder"],
  Cell[436666, 17750, 114, 3, 27, "Input",
   CellTags->"DiracOrder"],
  Cell[436783, 17755, 472, 18, 25, "Output",
   CellTags->"DiracOrder"],
  Cell[437292, 17778, 171, 5, 27, "Input",
   CellTags->"DiracOrder"],
  Cell[437466, 17785, 243, 7, 27, "Output",
   CellTags->"DiracOrder"],
  Cell[437724, 17795, 196, 8, 23, "Text",
   CellTags->"DiracOrder"],
  Cell[437945, 17807, 114, 3, 27, "Input",
   CellTags->"DiracOrder"],
  Cell[438062, 17812, 391, 15, 27, "Output",
   CellTags->"DiracOrder"],
  Cell[438490, 17832, 167, 5, 27, "Input",
   CellTags->"DiracOrder"],
  Cell[438660, 17839, 239, 7, 27, "Output",
   CellTags->"DiracOrder"],
  Cell[438936, 17851, 114, 3, 27, "Input",
   CellTags->"DiracOrder"],
  Cell[439053, 17856, 271, 10, 27, "Output",
   CellTags->"DiracOrder"],
  Cell[439361, 17871, 183, 5, 27, "Input",
   CellTags->"DiracOrder"],
  Cell[439547, 17878, 255, 7, 25, "Output",
   CellTags->"DiracOrder"],
  Cell[439817, 17888, 288, 10, 23, "Text",
   CellTags->"DiracOrder"],
  Cell[440130, 17902, 219, 7, 27, "Input",
   CellTags->"DiracOrder"],
  Cell[440352, 17911, 1207, 45, 25, "Output",
   CellTags->"DiracOrder"],
  Cell[441596, 17961, 113, 3, 27, "Input",
   CellTags->"DiracOrder"],
  Cell[441712, 17966, 477, 19, 25, "Output",
   CellTags->"DiracOrder"],
  Cell[442204, 17988, 188, 6, 27, "Input",
   CellTags->"DiracOrder"]},
 "DiracReduce"->{
  Cell[442407, 17997, 59, 1, 39, "ObjectName",
   CellTags->"DiracReduce"],
  Cell[442491, 18002, 62, 1, 33, "Subsubsection",
   CellTags->"DiracReduce"],
  Cell[442556, 18005, 662, 11, 87, "Text",
   CellTags->"DiracReduce"],
  Cell[443243, 18020, 121, 3, 27, "Input",
   CellTags->"DiracReduce"],
  Cell[443367, 18025, 323, 10, 25, "Output",
   CellTags->"DiracReduce"],
  Cell[443705, 18038, 197, 9, 23, "Text",
   CellTags->"DiracReduce"],
  Cell[443939, 18052, 59, 1, 33, "Subsubsection",
   CellTags->"DiracReduce"],
  Cell[444023, 18057, 172, 5, 27, "Input",
   CellTags->"DiracReduce"],
  Cell[444198, 18064, 202, 6, 25, "Output",
   CellTags->"DiracReduce"],
  Cell[444437, 18075, 116, 3, 27, "Input",
   CellTags->"DiracReduce"],
  Cell[444556, 18080, 281, 9, 25, "Output",
   CellTags->"DiracReduce"],
  Cell[444874, 18094, 186, 5, 27, "Input",
   CellTags->"DiracReduce"],
  Cell[445063, 18101, 239, 7, 25, "Output",
   CellTags->"DiracReduce"],
  Cell[445339, 18113, 116, 3, 27, "Input",
   CellTags->"DiracReduce"],
  Cell[445458, 18118, 919, 28, 27, "Output",
   CellTags->"DiracReduce"],
  Cell[446414, 18151, 207, 6, 27, "Input",
   CellTags->"DiracReduce"],
  Cell[446624, 18159, 283, 8, 25, "Output",
   CellTags->"DiracReduce"],
  Cell[446944, 18172, 140, 4, 27, "Input",
   CellTags->"DiracReduce"],
  Cell[447087, 18178, 1814, 54, 27, "Output",
   CellTags->"DiracReduce"],
  Cell[448938, 18237, 253, 7, 27, "Input",
   CellTags->"DiracReduce"],
  Cell[449194, 18246, 127, 4, 25, "Output",
   CellTags->"DiracReduce"],
  Cell[449358, 18255, 133, 4, 27, "Input",
   CellTags->"DiracReduce"],
  Cell[449494, 18261, 127, 4, 25, "Output",
   CellTags->"DiracReduce"],
  Cell[449636, 18268, 156, 4, 27, "Input",
   CellTags->"DiracReduce"]},
 "DiracSigma"->{
  Cell[449807, 18275, 57, 1, 39, "ObjectName",
   CellTags->"DiracSigma"],
  Cell[449889, 18280, 61, 1, 33, "Subsubsection",
   CellTags->"DiracSigma"],
  Cell[449953, 18283, 213, 5, 39, "Text",
   CellTags->"DiracSigma"],
  Cell[450169, 18290, 211, 9, 23, "Text",
   CellTags->"DiracSigma"],
  Cell[450417, 18304, 58, 1, 33, "Subsubsection",
   CellTags->"DiracSigma"],
  Cell[450500, 18309, 236, 7, 27, "Input",
   CellTags->"DiracSigma"],
  Cell[450739, 18318, 169, 5, 25, "Output",
   CellTags->"DiracSigma"],
  Cell[450945, 18328, 122, 3, 27, "Input",
   CellTags->"DiracSigma"],
  Cell[451070, 18333, 784, 29, 43, "Output",
   CellTags->"DiracSigma"],
  Cell[451891, 18367, 236, 7, 27, "Input",
   CellTags->"DiracSigma"],
  Cell[452130, 18376, 189, 6, 25, "Output",
   CellTags->"DiracSigma"],
  Cell[452356, 18387, 223, 7, 27, "Input",
   CellTags->"DiracSigma"],
  Cell[452582, 18396, 156, 5, 25, "Output",
   CellTags->"DiracSigma"],
  Cell[452775, 18406, 122, 3, 27, "Input",
   CellTags->"DiracSigma"],
  Cell[452900, 18411, 950, 33, 43, "Output",
   CellTags->"DiracSigma"],
  Cell[453865, 18447, 144, 4, 27, "Input",
   CellTags->"DiracSigma"]},
 "DiracSigmaExplicit"->{
  Cell[454024, 18454, 73, 1, 39, "ObjectName",
   CellTags->"DiracSigmaExplicit"],
  Cell[454122, 18459, 69, 1, 33, "Subsubsection",
   CellTags->"DiracSigmaExplicit"],
  Cell[454194, 18462, 186, 4, 23, "Text",
   CellTags->"DiracSigmaExplicit"],
  Cell[454383, 18468, 195, 9, 23, "Text",
   CellTags->"DiracSigmaExplicit"],
  Cell[454615, 18482, 66, 1, 33, "Subsubsection",
   CellTags->"DiracSigmaExplicit"],
  Cell[454706, 18487, 217, 6, 27, "Input",
   CellTags->"DiracSigmaExplicit"],
  Cell[454926, 18495, 177, 5, 25, "Output",
   CellTags->"DiracSigmaExplicit"],
  Cell[455140, 18505, 129, 3, 27, "Input",
   CellTags->"DiracSigmaExplicit"],
  Cell[455272, 18510, 792, 29, 43, "Output",
   CellTags->"DiracSigmaExplicit"]},
 "DiracSimpCombine"->{
  Cell[456091, 18543, 69, 1, 39, "ObjectName",
   CellTags->"DiracSimpCombine"],
  Cell[456185, 18548, 67, 1, 33, "Subsubsection",
   CellTags->"DiracSimpCombine"],
  Cell[456255, 18551, 209, 5, 39, "Text",
   CellTags->"DiracSimpCombine"],
  Cell[456467, 18558, 196, 8, 23, "Text",
   CellTags->"DiracSimpCombine"]},
 "DiracSimplify"->{
  Cell[456678, 18569, 63, 1, 39, "ObjectName",
   CellTags->"DiracSimplify"],
  Cell[456766, 18574, 64, 1, 33, "Subsubsection",
   CellTags->"DiracSimplify"],
  Cell[456833, 18577, 382, 7, 55, "Text",
   CellTags->"DiracSimplify"],
  Cell[457240, 18588, 125, 3, 27, "Input",
   CellTags->"DiracSimplify"],
  Cell[457368, 18593, 604, 14, 45, "Output",
   CellTags->"DiracSimplify"],
  Cell[457987, 18610, 422, 19, 23, "Text",
   CellTags->"DiracSimplify"],
  Cell[458446, 18634, 61, 1, 33, "Subsubsection",
   CellTags->"DiracSimplify"],
  Cell[458510, 18637, 99, 1, 23, "Text",
   CellTags->"DiracSimplify"],
  Cell[458634, 18642, 178, 5, 27, "Input",
   CellTags->"DiracSimplify"],
  Cell[458815, 18649, 250, 7, 25, "Output",
   CellTags->"DiracSimplify"],
  Cell[459102, 18661, 120, 3, 27, "Input",
   CellTags->"DiracSimplify"],
  Cell[459225, 18666, 261, 10, 25, "Output",
   CellTags->"DiracSimplify"],
  Cell[459501, 18679, 96, 1, 23, "Text",
   CellTags->"DiracSimplify"],
  Cell[459622, 18684, 179, 5, 27, "Input",
   CellTags->"DiracSimplify"],
  Cell[459804, 18691, 250, 7, 25, "Output",
   CellTags->"DiracSimplify"],
  Cell[460091, 18703, 120, 3, 27, "Input",
   CellTags->"DiracSimplify"],
  Cell[460214, 18708, 261, 10, 25, "Output",
   CellTags->"DiracSimplify"],
  Cell[460512, 18723, 174, 5, 27, "Input",
   CellTags->"DiracSimplify"],
  Cell[460689, 18730, 246, 7, 27, "Output",
   CellTags->"DiracSimplify"],
  Cell[460950, 18740, 179, 7, 23, "Text",
   CellTags->"DiracSimplify"],
  Cell[461154, 18751, 120, 3, 27, "Input",
   CellTags->"DiracSimplify"],
  Cell[461277, 18756, 394, 15, 27, "Output",
   CellTags->"DiracSimplify"],
  Cell[461708, 18776, 170, 5, 27, "Input",
   CellTags->"DiracSimplify"],
  Cell[461881, 18783, 242, 7, 27, "Output",
   CellTags->"DiracSimplify"],
  Cell[462160, 18795, 120, 3, 27, "Input",
   CellTags->"DiracSimplify"],
  Cell[462283, 18800, 274, 10, 27, "Output",
   CellTags->"DiracSimplify"],
  Cell[462594, 18815, 326, 10, 27, "Input",
   CellTags->"DiracSimplify"],
  Cell[462923, 18827, 570, 18, 25, "Output",
   CellTags->"DiracSimplify"],
  Cell[463508, 18848, 120, 3, 23, "Text",
   CellTags->"DiracSimplify"],
  Cell[463653, 18855, 120, 3, 27, "Input",
   CellTags->"DiracSimplify"],
  Cell[463776, 18860, 1908, 72, 27, "Output",
   CellTags->"DiracSimplify"],
  Cell[465721, 18937, 117, 3, 27, "Input",
   CellTags->"DiracSimplify"],
  Cell[465841, 18942, 570, 18, 25, "Output",
   CellTags->"DiracSimplify"],
  Cell[466448, 18965, 272, 7, 27, "Input",
   CellTags->"DiracSimplify"],
  Cell[466723, 18974, 407, 14, 25, "Output",
   CellTags->"DiracSimplify"],
  Cell[467167, 18993, 120, 3, 27, "Input",
   CellTags->"DiracSimplify"],
  Cell[467290, 18998, 109, 3, 25, "Output",
   CellTags->"DiracSimplify"],
  Cell[467436, 19006, 373, 12, 27, "Input",
   CellTags->"DiracSimplify"],
  Cell[467812, 19020, 624, 18, 25, "Output",
   CellTags->"DiracSimplify"],
  Cell[468473, 19043, 119, 3, 27, "Input",
   CellTags->"DiracSimplify"],
  Cell[468595, 19048, 13964, 531, 83, "Output",
   CellTags->"DiracSimplify"],
  Cell[482574, 19582, 115, 3, 23, "Text",
   CellTags->"DiracSimplify"],
  Cell[482714, 19589, 251, 7, 27, "Input",
   CellTags->"DiracSimplify"],
  Cell[482968, 19598, 465, 18, 25, "Output",
   CellTags->"DiracSimplify"],
  Cell[483448, 19619, 141, 4, 23, "Text",
   CellTags->"DiracSimplify"],
  Cell[483614, 19627, 289, 8, 27, "Input",
   CellTags->"DiracSimplify"],
  Cell[483906, 19637, 556, 19, 25, "Output",
   CellTags->"DiracSimplify"],
  Cell[484499, 19661, 268, 7, 27, "Input",
   CellTags->"DiracSimplify"],
  Cell[484770, 19670, 109, 3, 25, "Output",
   CellTags->"DiracSimplify"],
  Cell[484894, 19676, 183, 5, 27, "Input",
   CellTags->"DiracSimplify"]},
 "DiracSimplify2"->{
  Cell[485092, 19684, 65, 1, 39, "ObjectName",
   CellTags->"DiracSimplify2"],
  Cell[485182, 19689, 65, 1, 33, "Subsubsection",
   CellTags->"DiracSimplify2"],
  Cell[485250, 19692, 224, 7, 23, "Text",
   CellTags->"DiracSimplify2"],
  Cell[485477, 19701, 200, 9, 23, "Text",
   CellTags->"DiracSimplify2"],
  Cell[485714, 19715, 62, 1, 33, "Subsubsection",
   CellTags->"DiracSimplify2"],
  Cell[485801, 19720, 222, 6, 27, "Input",
   CellTags->"DiracSimplify2"],
  Cell[486026, 19728, 439, 11, 27, "Output",
   CellTags->"DiracSimplify2"],
  Cell[486502, 19744, 121, 3, 27, "Input",
   CellTags->"DiracSimplify2"],
  Cell[486626, 19749, 883, 35, 27, "Output",
   CellTags->"DiracSimplify2"]},
 "DiracSlash"->{
  Cell[487536, 19788, 57, 1, 39, "ObjectName",
   CellTags->"DiracSlash"],
  Cell[487618, 19793, 61, 1, 33, "Subsubsection",
   CellTags->"DiracSlash"],
  Cell[487682, 19796, 469, 16, 26, "Text",
   CellTags->"DiracSlash"],
  Cell[488176, 19816, 119, 3, 27, "Input",
   CellTags->"DiracSlash"],
  Cell[488298, 19821, 245, 8, 25, "Output",
   CellTags->"DiracSlash"],
  Cell[488558, 19832, 868, 39, 23, "Text",
   CellTags->"DiracSlash"],
  Cell[489463, 19876, 58, 1, 33, "Subsubsection",
   CellTags->"DiracSlash"],
  Cell[489524, 19879, 234, 9, 26, "Text",
   CellTags->"DiracSlash"],
  Cell[489783, 19892, 113, 3, 27, "Input",
   CellTags->"DiracSlash"],
  Cell[489899, 19897, 223, 8, 25, "Output",
   CellTags->"DiracSlash"],
  Cell[490159, 19910, 173, 5, 27, "Input",
   CellTags->"DiracSlash"],
  Cell[490335, 19917, 431, 16, 25, "Output",
   CellTags->"DiracSlash"],
  Cell[490803, 19938, 136, 4, 27, "Input",
   CellTags->"DiracSlash"],
  Cell[490942, 19944, 431, 16, 25, "Output",
   CellTags->"DiracSlash"],
  Cell[491410, 19965, 105, 3, 27, "Input",
   CellTags->"DiracSlash"],
  Cell[491518, 19970, 147, 4, 25, "Output",
   CellTags->"DiracSlash"],
  Cell[491702, 19979, 148, 4, 27, "Input",
   CellTags->"DiracSlash"],
  Cell[491853, 19985, 128, 3, 39, "Output",
   CellTags->"DiracSlash"],
  Cell[492018, 19993, 214, 7, 27, "Input",
   CellTags->"DiracSlash"],
  Cell[492235, 20002, 189, 5, 39, "Output",
   CellTags->"DiracSlash"]},
 "DiracSpinor"->{
  Cell[492451, 20011, 59, 1, 39, "ObjectName",
   CellTags->"DiracSpinor"],
  Cell[492535, 20016, 62, 1, 33, "Subsubsection",
   CellTags->"DiracSpinor"],
  Cell[492600, 20019, 288, 6, 39, "Text",
   CellTags->"DiracSpinor"],
  Cell[492891, 20027, 170, 8, 23, "Text",
   CellTags->"DiracSpinor"]},
 "DiracSubstitute67"->{
  Cell[493076, 20038, 71, 1, 39, "ObjectName",
   CellTags->"DiracSubstitute67"],
  Cell[493172, 20043, 68, 1, 33, "Subsubsection",
   CellTags->"DiracSubstitute67"],
  Cell[493243, 20046, 219, 5, 39, "Text",
   CellTags->"DiracSubstitute67"],
  Cell[493465, 20053, 313, 13, 23, "Text",
   CellTags->"DiracSubstitute67"]},
 "DiracTrace"->{
  Cell[493793, 20069, 57, 1, 39, "ObjectName",
   CellTags->"DiracTrace"],
  Cell[493875, 20074, 61, 1, 33, "Subsubsection",
   CellTags->"DiracTrace"],
  Cell[493939, 20077, 336, 6, 39, "Text",
   CellTags->"DiracTrace"],
  Cell[494300, 20087, 119, 3, 27, "Input",
   CellTags->"DiracTrace"],
  Cell[494422, 20092, 668, 16, 45, "Output",
   CellTags->"DiracTrace"],
  Cell[495105, 20111, 283, 12, 23, "Text",
   CellTags->"DiracTrace"],
  Cell[495391, 20125, 163, 9, 23, "Text",
   CellTags->"DiracTrace"],
  Cell[495591, 20139, 58, 1, 33, "Subsubsection",
   CellTags->"DiracTrace"],
  Cell[495674, 20144, 174, 5, 27, "Input",
   CellTags->"DiracTrace"],
  Cell[495851, 20151, 270, 9, 27, "Output",
   CellTags->"DiracTrace"],
  Cell[496158, 20165, 209, 6, 27, "Input",
   CellTags->"DiracTrace"],
  Cell[496370, 20173, 370, 11, 27, "Output",
   CellTags->"DiracTrace"],
  Cell[496777, 20189, 149, 4, 27, "Input",
   CellTags->"DiracTrace"],
  Cell[496929, 20195, 635, 22, 27, "Output",
   CellTags->"DiracTrace"],
  Cell[497601, 20222, 296, 8, 27, "Input",
   CellTags->"DiracTrace"],
  Cell[497900, 20232, 566, 23, 25, "Output",
   CellTags->"DiracTrace"],
  Cell[498503, 20260, 334, 9, 27, "Input",
   CellTags->"DiracTrace"],
  Cell[498840, 20271, 8415, 321, 47, "Output",
   CellTags->"DiracTrace"],
  Cell[507292, 20597, 186, 5, 27, "Input",
   CellTags->"DiracTrace"],
  Cell[507481, 20604, 498, 15, 25, "Output",
   CellTags->"DiracTrace"],
  Cell[508016, 20624, 294, 8, 27, "Input",
   CellTags->"DiracTrace"],
  Cell[508313, 20634, 182, 6, 25, "Output",
   CellTags->"DiracTrace"],
  Cell[508532, 20645, 111, 3, 27, "Input",
   CellTags->"DiracTrace"],
  Cell[508646, 20650, 175, 5, 39, "Output",
   CellTags->"DiracTrace"]},
 "DiracTraceEvaluate"->{
  Cell[508848, 20659, 73, 1, 39, "ObjectName",
   CellTags->"DiracTraceEvaluate"],
  Cell[508946, 20664, 69, 1, 33, "Subsubsection",
   CellTags->"DiracTraceEvaluate"],
  Cell[509018, 20667, 162, 4, 23, "Text",
   CellTags->"DiracTraceEvaluate"],
  Cell[509183, 20673, 281, 13, 23, "Text",
   CellTags->"DiracTraceEvaluate"]},
 "DiracTrick"->{
  Cell[509479, 20689, 57, 1, 39, "ObjectName",
   CellTags->"DiracTrick"],
  Cell[509561, 20694, 61, 1, 33, "Subsubsection",
   CellTags->"DiracTrick"],
  Cell[509625, 20697, 222, 5, 39, "Text",
   CellTags->"DiracTrick"],
  Cell[509872, 20706, 119, 3, 27, "Input",
   CellTags->"DiracTrick"],
  Cell[509994, 20711, 174, 6, 25, "Output",
   CellTags->"DiracTrick"],
  Cell[510183, 20720, 428, 19, 23, "Text",
   CellTags->"DiracTrick"],
  Cell[510648, 20744, 58, 1, 33, "Subsubsection",
   CellTags->"DiracTrick"],
  Cell[510709, 20747, 96, 1, 23, "Text",
   CellTags->"DiracTrick"],
  Cell[510830, 20752, 175, 5, 27, "Input",
   CellTags->"DiracTrick"],
  Cell[511008, 20759, 247, 7, 25, "Output",
   CellTags->"DiracTrick"],
  Cell[511292, 20771, 114, 3, 27, "Input",
   CellTags->"DiracTrick"],
  Cell[511409, 20776, 247, 7, 25, "Output",
   CellTags->"DiracTrick"],
  Cell[511671, 20786, 93, 1, 23, "Text",
   CellTags->"DiracTrick"],
  Cell[511789, 20791, 176, 5, 27, "Input",
   CellTags->"DiracTrick"],
  Cell[511968, 20798, 247, 7, 25, "Output",
   CellTags->"DiracTrick"],
  Cell[512252, 20810, 114, 3, 27, "Input",
   CellTags->"DiracTrick"],
  Cell[512369, 20815, 247, 7, 25, "Output",
   CellTags->"DiracTrick"],
  Cell[512653, 20827, 171, 5, 27, "Input",
   CellTags->"DiracTrick"],
  Cell[512827, 20834, 243, 7, 27, "Output",
   CellTags->"DiracTrick"],
  Cell[513085, 20844, 176, 7, 23, "Text",
   CellTags->"DiracTrick"],
  Cell[513286, 20855, 114, 3, 27, "Input",
   CellTags->"DiracTrick"],
  Cell[513403, 20860, 243, 7, 27, "Output",
   CellTags->"DiracTrick"],
  Cell[513683, 20872, 167, 5, 27, "Input",
   CellTags->"DiracTrick"],
  Cell[513853, 20879, 239, 7, 27, "Output",
   CellTags->"DiracTrick"],
  Cell[514129, 20891, 114, 3, 27, "Input",
   CellTags->"DiracTrick"],
  Cell[514246, 20896, 239, 7, 27, "Output",
   CellTags->"DiracTrick"],
  Cell[514522, 20908, 323, 10, 27, "Input",
   CellTags->"DiracTrick"],
  Cell[514848, 20920, 567, 18, 25, "Output",
   CellTags->"DiracTrick"],
  Cell[515452, 20943, 114, 3, 27, "Input",
   CellTags->"DiracTrick"],
  Cell[515569, 20948, 567, 18, 25, "Output",
   CellTags->"DiracTrick"],
  Cell[516173, 20971, 108, 3, 27, "Input",
   CellTags->"DiracTrick"],
  Cell[516284, 20976, 1905, 72, 27, "Output",
   CellTags->"DiracTrick"],
  Cell[518226, 21053, 370, 12, 27, "Input",
   CellTags->"DiracTrick"],
  Cell[518599, 21067, 621, 18, 25, "Output",
   CellTags->"DiracTrick"],
  Cell[519257, 21090, 113, 3, 27, "Input",
   CellTags->"DiracTrick"],
  Cell[519373, 21095, 621, 18, 25, "Output",
   CellTags->"DiracTrick"]},
 "Divideout"->{
  Cell[520021, 21117, 55, 1, 39, "ObjectName",
   CellTags->"Divideout"],
  Cell[520101, 21122, 60, 1, 33, "Subsubsection",
   CellTags->"Divideout"],
  Cell[520164, 21125, 137, 4, 23, "Text",
   CellTags->"Divideout"],
  Cell[520304, 21131, 281, 13, 23, "Text",
   CellTags->"Divideout"]},
 "DOT"->{
  Cell[520600, 21147, 43, 1, 39, "ObjectName",
   CellTags->"DOT"],
  Cell[520668, 21152, 54, 1, 33, "Subsubsection",
   CellTags->"DOT"],
  Cell[520725, 21155, 348, 8, 87, "Text",
   CellTags->"DOT"],
  Cell[521076, 21165, 177, 8, 23, "Text",
   CellTags->"DOT"]},
 "DotExpand"->{
  Cell[521268, 21176, 55, 1, 39, "ObjectName",
   CellTags->"DotExpand"],
  Cell[521348, 21181, 60, 1, 33, "Subsubsection",
   CellTags->"DotExpand"],
  Cell[521411, 21184, 85, 1, 23, "Text",
   CellTags->"DotExpand"],
  Cell[521499, 21187, 582, 23, 23, "Text",
   CellTags->"DotExpand"],
  Cell[522118, 21215, 57, 1, 33, "Subsubsection",
   CellTags->"DotExpand"],
  Cell[522200, 21220, 313, 10, 27, "Input",
   CellTags->"DotExpand"],
  Cell[522516, 21232, 504, 13, 25, "Output",
   CellTags->"DotExpand"],
  Cell[523035, 21248, 229, 7, 27, "Input",
   CellTags->"DotExpand"],
  Cell[523289, 21259, 313, 10, 27, "Input",
   CellTags->"DotExpand"],
  Cell[523605, 21271, 639, 22, 25, "Output",
   CellTags->"DotExpand"],
  Cell[524259, 21296, 231, 7, 27, "Input",
   CellTags->"DotExpand"],
  Cell[524515, 21307, 313, 10, 27, "Input",
   CellTags->"DotExpand"],
  Cell[524831, 21319, 504, 13, 25, "Output",
   CellTags->"DotExpand"]},
 "DotPower"->{
  Cell[525362, 21336, 53, 1, 39, "ObjectName",
   CellTags->"DotPower"],
  Cell[525440, 21341, 59, 1, 33, "Subsubsection",
   CellTags->"DotPower"],
  Cell[525502, 21344, 189, 4, 23, "Text",
   CellTags->"DotPower"],
  Cell[525694, 21350, 182, 8, 23, "Text",
   CellTags->"DotPower"]},
 "DotProduct"->{
  Cell[525891, 21361, 57, 1, 39, "ObjectName",
   CellTags->"DotProduct"],
  Cell[525973, 21366, 61, 1, 33, "Subsubsection",
   CellTags->"DotProduct"],
  Cell[526037, 21369, 219, 5, 39, "Text",
   CellTags->"DotProduct"],
  Cell[526259, 21376, 312, 14, 23, "Text",
   CellTags->"DotProduct"],
  Cell[526608, 21395, 58, 1, 33, "Subsubsection",
   CellTags->"DotProduct"],
  Cell[526691, 21400, 234, 7, 27, "Input",
   CellTags->"DotProduct"],
  Cell[526928, 21409, 314, 11, 28, "Output",
   CellTags->"DotProduct"]},
 "DotSimplifyRelations"->{
  Cell[527269, 21424, 77, 1, 39, "ObjectName",
   CellTags->"DotSimplifyRelations"],
  Cell[527371, 21429, 71, 1, 33, "Subsubsection",
   CellTags->"DotSimplifyRelations"],
  Cell[527445, 21432, 241, 5, 39, "Text",
   CellTags->"DotSimplifyRelations"],
  Cell[527689, 21439, 194, 8, 23, "Text",
   CellTags->"DotSimplifyRelations"]},
 "DotSimplify"->{
  Cell[527898, 21450, 59, 1, 39, "ObjectName",
   CellTags->"DotSimplify"],
  Cell[527982, 21455, 62, 1, 33, "Subsubsection",
   CellTags->"DotSimplify"],
  Cell[528047, 21458, 322, 6, 39, "Text",
   CellTags->"DotSimplify"],
  Cell[528394, 21468, 121, 3, 27, "Input",
   CellTags->"DotSimplify"],
  Cell[528518, 21473, 381, 11, 25, "Output",
   CellTags->"DotSimplify"],
  Cell[528914, 21487, 414, 19, 23, "Text",
   CellTags->"DotSimplify"],
  Cell[529365, 21511, 59, 1, 33, "Subsubsection",
   CellTags->"DotSimplify"],
  Cell[529449, 21516, 342, 11, 27, "Input",
   CellTags->"DotSimplify"],
  Cell[529794, 21529, 376, 11, 25, "Output",
   CellTags->"DotSimplify"],
  Cell[530207, 21545, 116, 3, 27, "Input",
   CellTags->"DotSimplify"],
  Cell[530326, 21550, 1013, 39, 25, "Output",
   CellTags->"DotSimplify"],
  Cell[531354, 21592, 158, 4, 27, "Input",
   CellTags->"DotSimplify"],
  Cell[531537, 21600, 209, 7, 27, "Input",
   CellTags->"DotSimplify"],
  Cell[531749, 21609, 217, 8, 25, "Output",
   CellTags->"DotSimplify"],
  Cell[532003, 21622, 116, 3, 27, "Input",
   CellTags->"DotSimplify"],
  Cell[532122, 21627, 223, 7, 25, "Output",
   CellTags->"DotSimplify"],
  Cell[532382, 21639, 161, 5, 27, "Input",
   CellTags->"DotSimplify"],
  Cell[532546, 21646, 107, 3, 25, "Output",
   CellTags->"DotSimplify"],
  Cell[532690, 21654, 116, 3, 27, "Input",
   CellTags->"DotSimplify"],
  Cell[532809, 21659, 279, 10, 25, "Output",
   CellTags->"DotSimplify"],
  Cell[533103, 21672, 161, 5, 27, "Input",
   CellTags->"DotSimplify"],
  Cell[533289, 21681, 116, 3, 27, "Input",
   CellTags->"DotSimplify"],
  Cell[533408, 21686, 223, 7, 25, "Output",
   CellTags->"DotSimplify"],
  Cell[533668, 21698, 165, 5, 27, "Input",
   CellTags->"DotSimplify"],
  Cell[533836, 21705, 107, 3, 25, "Output",
   CellTags->"DotSimplify"],
  Cell[533980, 21713, 116, 3, 27, "Input",
   CellTags->"DotSimplify"],
  Cell[534099, 21718, 277, 9, 25, "Output",
   CellTags->"DotSimplify"],
  Cell[534391, 21730, 165, 5, 27, "Input",
   CellTags->"DotSimplify"],
  Cell[534581, 21739, 299, 9, 27, "Input",
   CellTags->"DotSimplify"],
  Cell[534883, 21750, 166, 6, 25, "Output",
   CellTags->"DotSimplify"],
  Cell[535064, 21759, 125, 3, 27, "Input",
   CellTags->"DotSimplify"],
  Cell[535214, 21766, 148, 4, 27, "Input",
   CellTags->"DotSimplify"],
  Cell[535365, 21772, 140, 4, 25, "Output",
   CellTags->"DotSimplify"],
  Cell[535542, 21781, 213, 6, 27, "Input",
   CellTags->"DotSimplify"],
  Cell[535758, 21789, 140, 4, 25, "Output",
   CellTags->"DotSimplify"],
  Cell[535913, 21796, 170, 4, 27, "Input",
   CellTags->"DotSimplify"]},
 "DummyIndex"->{
  Cell[536098, 21803, 57, 1, 39, "ObjectName",
   CellTags->"DummyIndex"],
  Cell[536180, 21808, 61, 1, 33, "Subsubsection",
   CellTags->"DummyIndex"],
  Cell[536244, 21811, 191, 4, 23, "Text",
   CellTags->"DummyIndex"],
  Cell[536438, 21817, 181, 8, 23, "Text",
   CellTags->"DummyIndex"]},
 "D0"->{
  Cell[536634, 21828, 41, 1, 39, "ObjectName",
   CellTags->"D0"],
  Cell[536700, 21833, 53, 1, 33, "Subsubsection",
   CellTags->"D0"],
  Cell[536756, 21836, 524, 12, 55, "Text",
   CellTags->"D0"],
  Cell[537283, 21850, 458, 24, 23, "Text",
   CellTags->"D0"],
  Cell[537778, 21879, 50, 1, 33, "Subsubsection",
   CellTags->"D0"],
  Cell[537853, 21884, 315, 9, 27, "Input",
   CellTags->"D0"],
  Cell[538171, 21895, 550, 20, 29, "Output",
   CellTags->"D0"],
  Cell[538758, 21920, 484, 14, 27, "Input",
   CellTags->"D0"],
  Cell[539245, 21936, 550, 20, 29, "Output",
   CellTags->"D0"],
  Cell[539832, 21961, 104, 3, 27, "Input",
   CellTags->"D0"],
  Cell[539939, 21966, 550, 20, 29, "Output",
   CellTags->"D0"]},
 "D0Convention"->{
  Cell[540516, 21990, 61, 1, 39, "ObjectName",
   CellTags->"D0Convention"],
  Cell[540602, 21995, 63, 1, 33, "Subsubsection",
   CellTags->"D0Convention"],
  Cell[540668, 21998, 307, 6, 39, "Text",
   CellTags->"D0Convention"],
  Cell[540978, 22006, 263, 13, 23, "Text",
   CellTags->"D0Convention"]},
 "Eps"->{
  Cell[541256, 22022, 43, 1, 39, "ObjectName",
   CellTags->"Eps"],
  Cell[541324, 22027, 54, 1, 33, "Subsubsection",
   CellTags->"Eps"],
  Cell[541381, 22030, 345, 8, 39, "Text",
   CellTags->"Eps"],
  Cell[541751, 22042, 105, 3, 27, "Input",
   CellTags->"Eps"],
  Cell[541859, 22047, 160, 5, 25, "Output",
   CellTags->"Eps"],
  Cell[542034, 22055, 486, 24, 23, "Text",
   CellTags->"Eps"],
  Cell[542557, 22084, 51, 1, 33, "Subsubsection",
   CellTags->"Eps"],
  Cell[542633, 22089, 322, 8, 27, "Input",
   CellTags->"Eps"],
  Cell[542958, 22099, 477, 21, 25, "Output",
   CellTags->"Eps"],
  Cell[543472, 22125, 314, 8, 27, "Input",
   CellTags->"Eps"],
  Cell[543789, 22135, 435, 19, 25, "Output",
   CellTags->"Eps"],
  Cell[544261, 22159, 181, 6, 27, "Input",
   CellTags->"Eps"],
  Cell[544445, 22167, 176, 5, 39, "Output",
   CellTags->"Eps"],
  Cell[544658, 22177, 142, 4, 27, "Input",
   CellTags->"Eps"],
  Cell[544803, 22183, 99, 3, 25, "Output",
   CellTags->"Eps"],
  Cell[544939, 22191, 142, 4, 27, "Input",
   CellTags->"Eps"],
  Cell[545084, 22197, 117, 4, 25, "Output",
   CellTags->"Eps"],
  Cell[545216, 22204, 189, 6, 27, "Input",
   CellTags->"Eps"],
  Cell[545430, 22214, 460, 13, 27, "Input",
   CellTags->"Eps"],
  Cell[545893, 22229, 477, 21, 25, "Output",
   CellTags->"Eps"],
  Cell[546407, 22255, 107, 3, 27, "Input",
   CellTags->"Eps"],
  Cell[546517, 22260, 102, 3, 25, "Output",
   CellTags->"Eps"],
  Cell[546634, 22266, 189, 6, 27, "Input",
   CellTags->"Eps"],
  Cell[546848, 22276, 460, 13, 27, "Input",
   CellTags->"Eps"],
  Cell[547311, 22291, 477, 21, 25, "Output",
   CellTags->"Eps"],
  Cell[547825, 22317, 137, 4, 27, "Input",
   CellTags->"Eps"],
  Cell[547965, 22323, 102, 3, 25, "Output",
   CellTags->"Eps"],
  Cell[549894, 22406, 433, 14, 43, "Input",
   CellTags->"Eps"],
  Cell[550330, 22422, 1119, 45, 43, "Output",
   CellTags->"Eps"],
  Cell[551486, 22472, 978, 28, 43, "Input",
   CellTags->"Eps"],
  Cell[552467, 22502, 1679, 61, 43, "Output",
   CellTags->"Eps"],
  Cell[554183, 22568, 188, 6, 27, "Input",
   CellTags->"Eps"],
  Cell[554374, 22576, 342, 12, 43, "Output",
   CellTags->"Eps"],
  Cell[554753, 22593, 124, 4, 27, "Input",
   CellTags->"Eps"],
  Cell[554880, 22599, 99, 3, 25, "Output",
   CellTags->"Eps"],
  Cell[554994, 22605, 164, 5, 27, "Input",
   CellTags->"Eps"]},
 "EpsChisholm"->{
  Cell[555173, 22613, 59, 1, 39, "ObjectName",
   CellTags->"EpsChisholm"],
  Cell[555257, 22618, 62, 1, 33, "Subsubsection",
   CellTags->"EpsChisholm"],
  Cell[555322, 22621, 166, 4, 23, "Text",
   CellTags->"EpsChisholm"],
  Cell[555491, 22627, 182, 9, 23, "Text",
   CellTags->"EpsChisholm"],
  Cell[555710, 22641, 59, 1, 33, "Subsubsection",
   CellTags->"EpsChisholm"],
  Cell[555794, 22646, 208, 6, 27, "Input",
   CellTags->"EpsChisholm"],
  Cell[556005, 22654, 2019, 78, 27, "Output",
   CellTags->"EpsChisholm"],
  Cell[558061, 22737, 115, 3, 27, "Input",
   CellTags->"EpsChisholm"],
  Cell[558179, 22742, 594, 24, 25, "Output",
   CellTags->"EpsChisholm"]},
 "EpsContract"->{
  Cell[558800, 22770, 59, 1, 39, "ObjectName",
   CellTags->"EpsContract"],
  Cell[558884, 22775, 62, 1, 33, "Subsubsection",
   CellTags->"EpsContract"],
  Cell[558949, 22778, 227, 5, 39, "Text",
   CellTags->"EpsContract"],
  Cell[559179, 22785, 277, 14, 23, "Text",
   CellTags->"EpsContract"],
  Cell[559493, 22804, 59, 1, 33, "Subsubsection",
   CellTags->"EpsContract"],
  Cell[559577, 22809, 468, 13, 27, "Input",
   CellTags->"EpsContract"],
  Cell[560048, 22824, 485, 21, 25, "Output",
   CellTags->"EpsContract"],
  Cell[560570, 22850, 205, 6, 27, "Input",
   CellTags->"EpsContract"],
  Cell[560778, 22858, 569, 23, 30, "Output",
   CellTags->"EpsContract"],
  Cell[561384, 22886, 204, 6, 27, "Input",
   CellTags->"EpsContract"],
  Cell[561591, 22894, 320, 11, 27, "Output",
   CellTags->"EpsContract"]},
 "EpsDiscard"->{
  Cell[562025, 22913, 57, 1, 39, "ObjectName",
   CellTags->"EpsDiscard"],
  Cell[562107, 22918, 61, 1, 33, "Subsubsection",
   CellTags->"EpsDiscard"],
  Cell[562171, 22921, 169, 4, 23, "Text",
   CellTags->"EpsDiscard"],
  Cell[562343, 22927, 196, 9, 23, "Text",
   CellTags->"EpsDiscard"]},
 "EpsEvaluate"->{
  Cell[562554, 22939, 59, 1, 39, "ObjectName",
   CellTags->"EpsEvaluate"],
  Cell[562638, 22944, 62, 1, 33, "Subsubsection",
   CellTags->"EpsEvaluate"],
  Cell[562703, 22947, 173, 4, 23, "Text",
   CellTags->"EpsEvaluate"],
  Cell[562879, 22953, 494, 24, 23, "Text",
   CellTags->"EpsEvaluate"],
  Cell[563410, 22982, 59, 1, 33, "Subsubsection",
   CellTags->"EpsEvaluate"],
  Cell[563494, 22987, 335, 10, 27, "Input",
   CellTags->"EpsEvaluate"],
  Cell[563832, 22999, 466, 20, 25, "Output",
   CellTags->"EpsEvaluate"],
  Cell[564335, 23024, 115, 3, 27, "Input",
   CellTags->"EpsEvaluate"],
  Cell[564453, 23029, 466, 20, 25, "Output",
   CellTags->"EpsEvaluate"],
  Cell[564956, 23054, 116, 3, 27, "Input",
   CellTags->"EpsEvaluate"],
  Cell[565075, 23059, 434, 12, 39, "Output",
   CellTags->"EpsEvaluate"]},
 "EpsUncontract"->{
  Cell[565536, 23075, 63, 1, 39, "ObjectName",
   CellTags->"EpsUncontract"],
  Cell[565624, 23080, 64, 1, 33, "Subsubsection",
   CellTags->"EpsUncontract"],
  Cell[565691, 23083, 115, 3, 23, "Text",
   CellTags->"EpsUncontract"],
  Cell[565809, 23088, 285, 14, 23, "Text",
   CellTags->"EpsUncontract"]},
 "Epsilon"->{
  Cell[566109, 23105, 51, 1, 39, "ObjectName",
   CellTags->"Epsilon"],
  Cell[566185, 23110, 58, 1, 33, "Subsubsection",
   CellTags->"Epsilon"],
  Cell[566246, 23113, 237, 9, 23, "Text",
   CellTags->"Epsilon"],
  Cell[566486, 23124, 175, 9, 23, "Text",
   CellTags->"Epsilon"],
  Cell[566698, 23138, 55, 1, 33, "Subsubsection",
   CellTags->"Epsilon"],
  Cell[566778, 23143, 80, 2, 27, "Input",
   CellTags->"Epsilon"],
  Cell[566861, 23147, 148, 5, 25, "Output",
   CellTags->"Epsilon"],
  Cell[567024, 23155, 114, 3, 23, "Text",
   CellTags->"Epsilon"],
  Cell[567163, 23162, 587, 19, 27, "Input",
   CellTags->"Epsilon"],
  Cell[567753, 23183, 199, 6, 25, "Output",
   CellTags->"Epsilon"]},
 "EpsilonOrder"->{
  Cell[567979, 23193, 61, 1, 39, "ObjectName",
   CellTags->"EpsilonOrder"],
  Cell[568065, 23198, 63, 1, 33, "Subsubsection",
   CellTags->"EpsilonOrder"],
  Cell[568131, 23201, 305, 12, 23, "Text",
   CellTags->"EpsilonOrder"],
  Cell[568439, 23215, 287, 14, 23, "Text",
   CellTags->"EpsilonOrder"]},
 "Expanding"->{
  Cell[568741, 23232, 55, 1, 39, "ObjectName",
   CellTags->"Expanding"],
  Cell[568821, 23237, 60, 1, 33, "Subsubsection",
   CellTags->"Expanding"],
  Cell[568884, 23240, 378, 7, 55, "Text",
   CellTags->"Expanding"],
  Cell[569265, 23249, 641, 29, 23, "Text",
   CellTags->"Expanding"]},
 "ExpandPartialD"->{
  Cell[569921, 23281, 65, 1, 39, "ObjectName",
   CellTags->"ExpandPartialD"],
  Cell[570011, 23286, 65, 1, 33, "Subsubsection",
   CellTags->"ExpandPartialD"],
  Cell[570079, 23289, 188, 4, 23, "Text",
   CellTags->"ExpandPartialD"],
  Cell[571449, 23340, 724, 28, 23, "Text",
   CellTags->"ExpandPartialD"],
  Cell[572210, 23373, 62, 1, 33, "Subsubsection",
   CellTags->"ExpandPartialD"],
  Cell[572297, 23378, 373, 10, 27, "Input",
   CellTags->"ExpandPartialD"],
  Cell[572673, 23390, 345, 12, 32, "Output",
   CellTags->"ExpandPartialD"],
  Cell[573055, 23407, 121, 3, 27, "Input",
   CellTags->"ExpandPartialD"],
  Cell[573179, 23412, 773, 30, 29, "Output",
   CellTags->"ExpandPartialD"],
  Cell[573989, 23447, 115, 3, 27, "Input",
   CellTags->"ExpandPartialD"],
  Cell[574107, 23452, 798, 21, 59, "Output",
   CellTags->"ExpandPartialD"],
  Cell[574942, 23478, 259, 7, 27, "Input",
   CellTags->"ExpandPartialD"],
  Cell[575204, 23487, 312, 11, 32, "Output",
   CellTags->"ExpandPartialD"],
  Cell[575553, 23503, 121, 3, 27, "Input",
   CellTags->"ExpandPartialD"],
  Cell[575677, 23508, 704, 26, 43, "Output",
   CellTags->"ExpandPartialD"],
  Cell[576418, 23539, 433, 13, 27, "Input",
   CellTags->"ExpandPartialD"],
  Cell[576854, 23554, 332, 10, 35, "Output",
   CellTags->"ExpandPartialD"],
  Cell[577223, 23569, 121, 3, 27, "Input",
   CellTags->"ExpandPartialD"],
  Cell[577347, 23574, 1940, 67, 43, "Output",
   CellTags->"ExpandPartialD"],
  Cell[579324, 23646, 180, 6, 27, "Input",
   CellTags->"ExpandPartialD"],
  Cell[579507, 23654, 267, 8, 34, "Output",
   CellTags->"ExpandPartialD"],
  Cell[579811, 23667, 123, 3, 27, "Input",
   CellTags->"ExpandPartialD"],
  Cell[579937, 23672, 438, 14, 36, "Output",
   CellTags->"ExpandPartialD"],
  Cell[580412, 23691, 121, 3, 27, "Input",
   CellTags->"ExpandPartialD"],
  Cell[580536, 23696, 1877, 59, 29, "Output",
   CellTags->"ExpandPartialD"],
  Cell[582450, 23760, 314, 9, 27, "Input",
   CellTags->"ExpandPartialD"],
  Cell[582767, 23771, 1192, 47, 32, "Output",
   CellTags->"ExpandPartialD"],
  Cell[583996, 23823, 121, 3, 27, "Input",
   CellTags->"ExpandPartialD"],
  Cell[584120, 23828, 110, 3, 25, "Output",
   CellTags->"ExpandPartialD"]},
 "ScalarProductCancel"->{
  Cell[584257, 23835, 121, 1, 39, "ObjectName",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[584403, 23840, 95, 1, 33, "Subsubsection",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[584501, 23843, 252, 5, 47, "Text",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[584778, 23852, 158, 3, 27, "Input",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[584939, 23857, 214, 6, 25, "Output",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[585168, 23866, 462, 19, 23, "Text",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[585667, 23890, 92, 1, 33, "Subsubsection",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[585784, 23895, 257, 7, 27, "Input",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[586044, 23904, 338, 10, 25, "Output",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[586419, 23919, 152, 3, 27, "Input",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[586574, 23924, 1214, 49, 25, "Output",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[587825, 23978, 186, 5, 27, "Input",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[588014, 23985, 277, 9, 25, "Output",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[588328, 23999, 156, 3, 27, "Input",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[588487, 24004, 331, 12, 27, "Output",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[588855, 24021, 190, 5, 27, "Input",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[589048, 24028, 227, 7, 25, "Output",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[589312, 24040, 156, 3, 27, "Input",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[589471, 24045, 441, 18, 25, "Output",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[589949, 24068, 239, 7, 27, "Input",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[590191, 24077, 312, 10, 25, "Output",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[590540, 24092, 184, 4, 27, "Input",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[590727, 24098, 565, 22, 27, "Output",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[1590810, 65232, 75, 1, 39, "ObjectName",
   CellTags->"ScalarProductCancel"],
  Cell[1590910, 65237, 70, 1, 33, "Subsubsection",
   CellTags->"ScalarProductCancel"],
  Cell[1590983, 65240, 186, 4, 23, "Text",
   CellTags->"ScalarProductCancel"],
  Cell[1591194, 65248, 89, 2, 27, "Input",
   CellTags->"ScalarProductCancel"],
  Cell[1591286, 65252, 134, 3, 25, "Output",
   CellTags->"ScalarProductCancel"],
  Cell[1591457, 65260, 134, 3, 27, "Input",
   CellTags->"ScalarProductCancel"],
  Cell[1591594, 65265, 392, 10, 25, "Output",
   CellTags->"ScalarProductCancel"],
  Cell[1592023, 65280, 106, 3, 27, "Input",
   CellTags->"ScalarProductCancel"],
  Cell[1592132, 65285, 179, 3, 38, "Print",
   CellTags->{"Info3522766000-2743550", "ScalarProductCancel"}],
  Cell[1592326, 65291, 743, 33, 23, "Text",
   CellTags->"ScalarProductCancel"],
  Cell[1593106, 65329, 67, 1, 33, "Subsubsection",
   CellTags->"ScalarProductCancel"],
  Cell[1593176, 65332, 244, 9, 23, "Text",
   CellTags->"ScalarProductCancel"],
  Cell[1593445, 65345, 429, 15, 27, "Input",
   CellTags->"ScalarProductCancel"],
  Cell[1593877, 65362, 454, 17, 46, "Output",
   CellTags->"ScalarProductCancel"],
  Cell[1594368, 65384, 156, 4, 27, "Input",
   CellTags->"ScalarProductCancel"],
  Cell[1594527, 65390, 849, 32, 56, "Output",
   CellTags->"ScalarProductCancel"],
  Cell[1595413, 65427, 162, 4, 27, "Input",
   CellTags->"ScalarProductCancel"],
  Cell[1595578, 65433, 708, 26, 56, "Output",
   CellTags->"ScalarProductCancel"],
  Cell[1596323, 65464, 185, 5, 27, "Input",
   CellTags->"ScalarProductCancel"],
  Cell[1596511, 65471, 708, 26, 56, "Output",
   CellTags->"ScalarProductCancel"],
  Cell[1597256, 65502, 578, 18, 27, "Input",
   CellTags->"ScalarProductCancel"],
  Cell[1597837, 65522, 898, 33, 49, "Output",
   CellTags->"ScalarProductCancel"],
  Cell[1598772, 65560, 197, 5, 27, "Input",
   CellTags->"ScalarProductCancel"],
  Cell[1598972, 65567, 3108, 111, 113, "Output",
   CellTags->"ScalarProductCancel"],
  Cell[1602095, 65681, 162, 5, 27, "Input",
   CellTags->"ScalarProductCancel"]},
 "ExpandScalarProduct"->{
  Cell[584257, 23835, 121, 1, 39, "ObjectName",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[584403, 23840, 95, 1, 33, "Subsubsection",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[584501, 23843, 252, 5, 47, "Text",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[584778, 23852, 158, 3, 27, "Input",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[584939, 23857, 214, 6, 25, "Output",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[585168, 23866, 462, 19, 23, "Text",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[585667, 23890, 92, 1, 33, "Subsubsection",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[585784, 23895, 257, 7, 27, "Input",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[586044, 23904, 338, 10, 25, "Output",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[586419, 23919, 152, 3, 27, "Input",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[586574, 23924, 1214, 49, 25, "Output",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[587825, 23978, 186, 5, 27, "Input",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[588014, 23985, 277, 9, 25, "Output",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[588328, 23999, 156, 3, 27, "Input",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[588487, 24004, 331, 12, 27, "Output",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[588855, 24021, 190, 5, 27, "Input",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[589048, 24028, 227, 7, 25, "Output",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[589312, 24040, 156, 3, 27, "Input",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[589471, 24045, 441, 18, 25, "Output",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[589949, 24068, 239, 7, 27, "Input",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[590191, 24077, 312, 10, 25, "Output",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[590540, 24092, 184, 4, 27, "Input",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
  Cell[590727, 24098, 565, 22, 27, "Output",
   CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}]},
 "Expand2"->{
  Cell[591319, 24124, 51, 1, 39, "ObjectName",
   CellTags->"Expand2"],
  Cell[591395, 24129, 58, 1, 33, "Subsubsection",
   CellTags->"Expand2"],
  Cell[591456, 24132, 164, 4, 23, "Text",
   CellTags->"Expand2"],
  Cell[591657, 24141, 55, 1, 33, "Subsubsection",
   CellTags->"Expand2"],
  Cell[591737, 24146, 579, 21, 27, "Input",
   CellTags->"Expand2"],
  Cell[592319, 24169, 574, 19, 27, "Output",
   CellTags->"Expand2"]},
 "Explicit"->{
  Cell[592920, 24192, 53, 1, 39, "ObjectName",
   CellTags->"Explicit"],
  Cell[592998, 24197, 59, 1, 33, "Subsubsection",
   CellTags->"Explicit"],
  Cell[593060, 24200, 401, 9, 39, "Text",
   CellTags->"Explicit"],
  Cell[593464, 24211, 331, 14, 23, "Text",
   CellTags->"Explicit"],
  Cell[594305, 24249, 56, 1, 33, "Subsubsection",
   CellTags->"Explicit"],
  Cell[596159, 24328, 230, 6, 27, "Input",
   CellTags->"Explicit"],
  Cell[596392, 24336, 940, 42, 27, "Output",
   CellTags->"Explicit"],
  Cell[597369, 24383, 109, 3, 27, "Input",
   CellTags->"Explicit"],
  Cell[597481, 24388, 1971, 79, 27, "Output",
   CellTags->"Explicit"],
  Cell[599489, 24472, 184, 5, 27, "Input",
   CellTags->"Explicit"],
  Cell[599676, 24479, 892, 36, 43, "Output",
   CellTags->"Explicit"],
  Cell[600605, 24520, 109, 3, 27, "Input",
   CellTags->"Explicit"],
  Cell[600717, 24525, 2644, 102, 43, "Output",
   CellTags->"Explicit"],
  Cell[603398, 24632, 155, 4, 27, "Input",
   CellTags->"Explicit"],
  Cell[603556, 24638, 163, 5, 29, "Output",
   CellTags->"Explicit"],
  Cell[603756, 24648, 109, 3, 27, "Input",
   CellTags->"Explicit"],
  Cell[603868, 24653, 1744, 77, 31, "Output",
   CellTags->"Explicit"]},
 "ExplicitLorentzIndex"->{
  Cell[605639, 24734, 77, 1, 39, "ObjectName",
   CellTags->"ExplicitLorentzIndex"],
  Cell[605741, 24739, 71, 1, 33, "Subsubsection",
   CellTags->"ExplicitLorentzIndex"],
  Cell[605815, 24742, 141, 4, 23, "Text",
   CellTags->"ExplicitLorentzIndex"],
  Cell[605959, 24748, 295, 13, 23, "Text",
   CellTags->"ExplicitLorentzIndex"],
  Cell[606291, 24766, 68, 1, 33, "Subsubsection",
   CellTags->"ExplicitLorentzIndex"],
  Cell[606384, 24771, 224, 6, 27, "Input",
   CellTags->"ExplicitLorentzIndex"],
  Cell[606611, 24779, 199, 7, 27, "Output",
   CellTags->"ExplicitLorentzIndex"],
  Cell[606847, 24791, 121, 3, 27, "Input",
   CellTags->"ExplicitLorentzIndex"],
  Cell[606971, 24796, 247, 6, 39, "Output",
   CellTags->"ExplicitLorentzIndex"]},
 "ExplicitPartialD"->{
  Cell[607245, 24806, 69, 1, 39, "ObjectName",
   CellTags->"ExplicitPartialD"],
  Cell[607339, 24811, 67, 1, 33, "Subsubsection",
   CellTags->"ExplicitPartialD"],
  Cell[607409, 24814, 162, 4, 23, "Text",
   CellTags->"ExplicitPartialD"],
  Cell[607574, 24820, 476, 18, 23, "Text",
   CellTags->"ExplicitPartialD"],
  Cell[608087, 24843, 64, 1, 33, "Subsubsection",
   CellTags->"ExplicitPartialD"],
  Cell[608176, 24848, 183, 4, 27, "Input",
   CellTags->"ExplicitPartialD"],
  Cell[608362, 24854, 525, 19, 43, "Output",
   CellTags->"ExplicitPartialD"],
  Cell[608924, 24878, 184, 4, 27, "Input",
   CellTags->"ExplicitPartialD"],
  Cell[609111, 24884, 430, 16, 32, "Output",
   CellTags->"ExplicitPartialD"],
  Cell[609578, 24905, 186, 4, 27, "Input",
   CellTags->"ExplicitPartialD"],
  Cell[609767, 24911, 461, 15, 43, "Output",
   CellTags->"ExplicitPartialD"],
  Cell[610265, 24931, 183, 6, 27, "Input",
   CellTags->"ExplicitPartialD"],
  Cell[610451, 24939, 270, 8, 34, "Output",
   CellTags->"ExplicitPartialD"],
  Cell[610758, 24952, 125, 3, 27, "Input",
   CellTags->"ExplicitPartialD"],
  Cell[610886, 24957, 440, 14, 36, "Output",
   CellTags->"ExplicitPartialD"]},
 "ExplicitSUNIndex"->{
  Cell[611353, 24975, 69, 1, 39, "ObjectName",
   CellTags->"ExplicitSUNIndex"],
  Cell[611447, 24980, 67, 1, 33, "Subsubsection",
   CellTags->"ExplicitSUNIndex"],
  Cell[611517, 24983, 178, 6, 23, "Text",
   CellTags->"ExplicitSUNIndex"],
  Cell[611698, 24991, 484, 23, 23, "Text",
   CellTags->"ExplicitSUNIndex"],
  Cell[612219, 25019, 64, 1, 33, "Subsubsection",
   CellTags->"ExplicitSUNIndex"],
  Cell[612308, 25024, 125, 3, 27, "Input",
   CellTags->"ExplicitSUNIndex"],
  Cell[612436, 25029, 112, 3, 25, "Output",
   CellTags->"ExplicitSUNIndex"]},
 "ExtraFactor"->{
  Cell[612995, 25054, 59, 1, 39, "ObjectName",
   CellTags->"ExtraFactor"],
  Cell[613079, 25059, 62, 1, 33, "Subsubsection",
   CellTags->"ExtraFactor"],
  Cell[613144, 25062, 199, 4, 23, "Text",
   CellTags->"ExtraFactor"],
  Cell[613346, 25068, 194, 8, 23, "Text",
   CellTags->"ExtraFactor"]},
 "ExtraVariables"->{
  Cell[613555, 25079, 65, 1, 39, "ObjectName",
   CellTags->"ExtraVariables"],
  Cell[613645, 25084, 65, 1, 33, "Subsubsection",
   CellTags->"ExtraVariables"],
  Cell[613713, 25087, 213, 5, 39, "Text",
   CellTags->"ExtraVariables"],
  Cell[613929, 25094, 298, 14, 23, "Text",
   CellTags->"ExtraVariables"]},
 "FactorFull"->{
  Cell[614242, 25111, 57, 1, 39, "ObjectName",
   CellTags->"FactorFull"],
  Cell[614324, 25116, 61, 1, 33, "Subsubsection",
   CellTags->"FactorFull"],
  Cell[614388, 25119, 509, 24, 23, "Text",
   CellTags->"FactorFull"],
  Cell[614900, 25145, 178, 9, 23, "Text",
   CellTags->"FactorFull"]},
 "Factoring"->{
  Cell[615093, 25157, 55, 1, 39, "ObjectName",
   CellTags->"Factoring"],
  Cell[615173, 25162, 60, 1, 33, "Subsubsection",
   CellTags->"Factoring"],
  Cell[615236, 25165, 235, 5, 39, "Text",
   CellTags->"Factoring"],
  Cell[615474, 25172, 382, 19, 23, "Text",
   CellTags->"Factoring"]},
 "Factorout"->{
  Cell[615871, 25194, 55, 1, 39, "ObjectName",
   CellTags->"Factorout"],
  Cell[615951, 25199, 60, 1, 33, "Subsubsection",
   CellTags->"Factorout"],
  Cell[616014, 25202, 74, 1, 23, "Text",
   CellTags->"Factorout"],
  Cell[616091, 25205, 174, 9, 23, "Text",
   CellTags->"Factorout"]},
 "FactorTime"->{
  Cell[616280, 25217, 57, 1, 39, "ObjectName",
   CellTags->"FactorTime"],
  Cell[616362, 25222, 61, 1, 33, "Subsubsection",
   CellTags->"FactorTime"],
  Cell[616426, 25225, 166, 4, 23, "Text",
   CellTags->"FactorTime"],
  Cell[616595, 25231, 178, 9, 23, "Text",
   CellTags->"FactorTime"]},
 "Factor1"->{
  Cell[616788, 25243, 51, 1, 39, "ObjectName",
   CellTags->"Factor1"],
  Cell[616864, 25248, 58, 1, 33, "Subsubsection",
   CellTags->"Factor1"],
  Cell[616925, 25251, 144, 4, 23, "Text",
   CellTags->"Factor1"],
  Cell[617072, 25257, 175, 9, 23, "Text",
   CellTags->"Factor1"],
  Cell[617284, 25271, 55, 1, 33, "Subsubsection",
   CellTags->"Factor1"],
  Cell[617364, 25276, 213, 8, 27, "Input",
   CellTags->"Factor1"],
  Cell[617580, 25286, 224, 8, 25, "Output",
   CellTags->"Factor1"],
  Cell[617841, 25299, 222, 7, 27, "Input",
   CellTags->"Factor1"],
  Cell[618066, 25308, 435, 16, 25, "Output",
   CellTags->"Factor1"],
  Cell[618538, 25329, 251, 9, 27, "Input",
   CellTags->"Factor1"],
  Cell[618792, 25340, 176, 6, 27, "Output",
   CellTags->"Factor1"],
  Cell[619005, 25351, 107, 3, 27, "Input",
   CellTags->"Factor1"],
  Cell[619115, 25356, 224, 8, 25, "Output",
   CellTags->"Factor1"],
  Cell[619376, 25369, 108, 3, 27, "Input",
   CellTags->"Factor1"],
  Cell[619487, 25374, 176, 6, 27, "Output",
   CellTags->"Factor1"],
  Cell[619678, 25383, 141, 4, 27, "Input",
   CellTags->"Factor1"]},
 "Factor2"->{
  Cell[619834, 25390, 51, 1, 39, "ObjectName",
   CellTags->"Factor2"],
  Cell[619910, 25395, 58, 1, 33, "Subsubsection",
   CellTags->"Factor2"],
  Cell[619971, 25398, 398, 7, 55, "Text",
   CellTags->"Factor2"],
  Cell[620394, 25409, 113, 3, 27, "Input",
   CellTags->"Factor2"],
  Cell[620510, 25414, 230, 7, 25, "Output",
   CellTags->"Factor2"],
  Cell[620755, 25424, 178, 9, 23, "Text",
   CellTags->"Factor2"],
  Cell[620970, 25438, 55, 1, 33, "Subsubsection",
   CellTags->"Factor2"],
  Cell[621050, 25443, 213, 8, 27, "Input",
   CellTags->"Factor2"],
  Cell[621266, 25453, 224, 8, 25, "Output",
   CellTags->"Factor2"],
  Cell[621527, 25466, 222, 7, 27, "Input",
   CellTags->"Factor2"],
  Cell[621752, 25475, 435, 16, 25, "Output",
   CellTags->"Factor2"],
  Cell[622224, 25496, 251, 9, 27, "Input",
   CellTags->"Factor2"],
  Cell[622478, 25507, 176, 6, 27, "Output",
   CellTags->"Factor2"],
  Cell[622691, 25518, 107, 3, 27, "Input",
   CellTags->"Factor2"],
  Cell[622801, 25523, 224, 8, 25, "Output",
   CellTags->"Factor2"],
  Cell[623062, 25536, 108, 3, 27, "Input",
   CellTags->"Factor2"],
  Cell[623173, 25541, 176, 6, 27, "Output",
   CellTags->"Factor2"],
  Cell[623386, 25552, 173, 5, 27, "Input",
   CellTags->"Factor2"],
  Cell[623562, 25559, 224, 8, 25, "Output",
   CellTags->"Factor2"],
  Cell[623801, 25570, 141, 4, 27, "Input",
   CellTags->"Factor2"]},
 "FAD"->{
  Cell[623957, 25577, 43, 1, 39, "ObjectName",
   CellTags->"FAD"],
  Cell[624025, 25582, 54, 1, 33, "Subsubsection",
   CellTags->"FAD"],
  Cell[624082, 25585, 335, 6, 55, "Text",
   CellTags->"FAD"],
  Cell[624420, 25593, 802, 34, 23, "Text",
   CellTags->"FAD"],
  Cell[625259, 25632, 51, 1, 33, "Subsubsection",
   CellTags->"FAD"],
  Cell[625335, 25637, 146, 5, 27, "Input",
   CellTags->"FAD"],
  Cell[625484, 25644, 700, 20, 49, "Output",
   CellTags->"FAD"],
  Cell[626221, 25669, 197, 7, 27, "Input",
   CellTags->"FAD"],
  Cell[626421, 25678, 819, 22, 49, "Output",
   CellTags->"FAD"],
  Cell[627277, 25705, 245, 9, 27, "Input",
   CellTags->"FAD"],
  Cell[627525, 25716, 161, 5, 39, "Output",
   CellTags->"FAD"],
  Cell[627723, 25726, 215, 8, 27, "Input",
   CellTags->"FAD"],
  Cell[627941, 25736, 525, 15, 59, "Output",
   CellTags->"FAD"],
  Cell[628503, 25756, 280, 9, 27, "Input",
   CellTags->"FAD"],
  Cell[628786, 25767, 527, 16, 59, "Output",
   CellTags->"FAD"]},
 "FC"->{
  Cell[629340, 25787, 41, 1, 39, "ObjectName",
   CellTags->"FC"],
  Cell[629406, 25792, 53, 1, 33, "Subsubsection",
   CellTags->"FC"],
  Cell[629462, 25795, 117, 3, 23, "Text",
   CellTags->"FC"],
  Cell[629582, 25800, 545, 24, 23, "Text",
   CellTags->"FC"],
  Cell[630164, 25829, 50, 1, 33, "Subsubsection",
   CellTags->"FC"],
  Cell[630217, 25832, 70, 2, 27, "Input",
   CellTags->"FC"],
  Cell[630312, 25838, 227, 7, 27, "Input",
   CellTags->"FC"],
  Cell[630542, 25847, 100, 2, 25, "Output",
   CellTags->"FC"],
  Cell[630657, 25852, 70, 2, 27, "Input",
   CellTags->"FC"],
  Cell[630752, 25858, 227, 7, 27, "Input",
   CellTags->"FC"],
  Cell[630982, 25867, 305, 11, 29, "Output",
   CellTags->"FC"]},
 "FCE"->{
  Cell[631314, 25882, 43, 1, 39, "ObjectName",
   CellTags->"FCE"],
  Cell[631382, 25887, 54, 1, 33, "Subsubsection",
   CellTags->"FCE"],
  Cell[631439, 25890, 126, 4, 23, "Text",
   CellTags->"FCE"],
  Cell[631568, 25896, 72, 1, 23, "Text",
   CellTags->"FCE"],
  Cell[631643, 25899, 427, 19, 23, "Text",
   CellTags->"FCE"],
  Cell[632107, 25923, 51, 1, 33, "Subsubsection",
   CellTags->"FCE"],
  Cell[632183, 25928, 262, 8, 27, "Input",
   CellTags->"FCE"],
  Cell[632448, 25938, 225, 8, 29, "Output",
   CellTags->"FCE"],
  Cell[632710, 25951, 104, 3, 27, "Input",
   CellTags->"FCE"],
  Cell[632817, 25956, 190, 6, 39, "Output",
   CellTags->"FCE"],
  Cell[633044, 25967, 437, 13, 27, "Input",
   CellTags->"FCE"],
  Cell[633484, 25982, 547, 18, 27, "Output",
   CellTags->"FCE"],
  Cell[634068, 26005, 104, 3, 27, "Input",
   CellTags->"FCE"],
  Cell[634175, 26010, 452, 13, 39, "Output",
   CellTags->"FCE"],
  Cell[634664, 26028, 95, 3, 27, "Input",
   CellTags->"FCE"],
  Cell[634762, 26033, 862, 34, 27, "Output",
   CellTags->"FCE"],
  Cell[635661, 26072, 104, 3, 27, "Input",
   CellTags->"FCE"],
  Cell[635768, 26077, 893, 24, 78, "Output",
   CellTags->"FCE"],
  Cell[636698, 26106, 134, 4, 27, "Input",
   CellTags->"FCE"],
  Cell[636835, 26112, 452, 13, 39, "Output",
   CellTags->"FCE"]},
 "FCI"->{
  Cell[637314, 26129, 43, 1, 39, "ObjectName",
   CellTags->"FCI"],
  Cell[637382, 26134, 54, 1, 33, "Subsubsection",
   CellTags->"FCI"],
  Cell[637439, 26137, 159, 4, 23, "Text",
   CellTags->"FCI"],
  Cell[637601, 26143, 427, 19, 23, "Text",
   CellTags->"FCI"],
  Cell[638065, 26167, 51, 1, 33, "Subsubsection",
   CellTags->"FCI"],
  Cell[638141, 26172, 437, 13, 27, "Input",
   CellTags->"FCI"],
  Cell[638581, 26187, 547, 18, 27, "Output",
   CellTags->"FCI"],
  Cell[639165, 26210, 104, 3, 27, "Input",
   CellTags->"FCI"],
  Cell[639272, 26215, 452, 13, 39, "Output",
   CellTags->"FCI"],
  Cell[639761, 26233, 95, 3, 27, "Input",
   CellTags->"FCI"],
  Cell[639859, 26238, 862, 34, 27, "Output",
   CellTags->"FCI"],
  Cell[640758, 26277, 104, 3, 27, "Input",
   CellTags->"FCI"],
  Cell[640865, 26282, 893, 24, 78, "Output",
   CellTags->"FCI"],
  Cell[641795, 26311, 134, 4, 27, "Input",
   CellTags->"FCI"],
  Cell[641932, 26317, 452, 13, 39, "Output",
   CellTags->"FCI"]},
 "FCIntegral"->{
  Cell[642411, 26334, 57, 1, 39, "ObjectName",
   CellTags->"FCIntegral"],
  Cell[642493, 26339, 61, 1, 33, "Subsubsection",
   CellTags->"FCIntegral"],
  Cell[642557, 26342, 209, 5, 39, "Text",
   CellTags->"FCIntegral"],
  Cell[642769, 26349, 360, 14, 23, "Text",
   CellTags->"FCIntegral"]},
 "FCIntegrate"->{
  Cell[643144, 26366, 59, 1, 39, "ObjectName",
   CellTags->"FCIntegrate"],
  Cell[643228, 26371, 62, 1, 33, "Subsubsection",
   CellTags->"FCIntegrate"],
  Cell[643293, 26374, 285, 5, 39, "Text",
   CellTags->"FCIntegrate"],
  Cell[643581, 26381, 194, 9, 23, "Text",
   CellTags->"FCIntegrate"]},
 "FCNIntegrate"->{
  Cell[643790, 26393, 61, 1, 39, "ObjectName",
   CellTags->"FCNIntegrate"],
  Cell[643876, 26398, 63, 1, 33, "Subsubsection",
   CellTags->"FCNIntegrate"],
  Cell[643942, 26401, 418, 7, 55, "Text",
   CellTags->"FCNIntegrate"],
  Cell[644363, 26410, 192, 9, 23, "Text",
   CellTags->"FCNIntegrate"]},
 "FC2RHI"->{
  Cell[644570, 26422, 50, 1, 39, "ObjectName",
   CellTags->"FC2RHI"],
  Cell[644645, 26427, 57, 1, 33, "Subsubsection",
   CellTags->"FC2RHI"],
  Cell[644705, 26430, 306, 6, 39, "Text",
   CellTags->"FC2RHI"],
  Cell[645036, 26440, 111, 3, 27, "Input",
   CellTags->"FC2RHI"],
  Cell[645150, 26445, 277, 8, 25, "Output",
   CellTags->"FC2RHI"],
  Cell[647186, 26533, 162, 9, 23, "Text",
   CellTags->"FC2RHI"],
  Cell[647385, 26547, 54, 1, 33, "Subsubsection",
   CellTags->"FC2RHI"],
  Cell[647442, 26550, 72, 2, 27, "Input",
   CellTags->"FC2RHI"]},
 "FC2TLI"->{
  Cell[647529, 26555, 50, 1, 39, "ObjectName",
   CellTags->"FC2TLI"],
  Cell[647604, 26560, 57, 1, 33, "Subsubsection",
   CellTags->"FC2TLI"],
  Cell[647664, 26563, 256, 5, 39, "Text",
   CellTags->"FC2TLI"],
  Cell[647945, 26572, 111, 3, 27, "Input",
   CellTags->"FC2TLI"],
  Cell[648059, 26577, 277, 8, 25, "Output",
   CellTags->"FC2TLI"],
  Cell[652464, 26742, 162, 9, 23, "Text",
   CellTags->"FC2TLI"],
  Cell[652663, 26756, 54, 1, 33, "Subsubsection",
   CellTags->"FC2TLI"],
  Cell[652720, 26759, 72, 2, 27, "Input",
   CellTags->"FC2TLI"]},
 "Info3522790263-4590919"->{
  Cell[648447, 26594, 321, 5, 107, "Print",
   CellTags->"Info3522790263-4590919"]},
 "FDS"->{
  Cell[652807, 26764, 43, 1, 39, "ObjectName",
   CellTags->"FDS"],
  Cell[652875, 26769, 54, 1, 33, "Subsubsection",
   CellTags->"FDS"],
  Cell[652932, 26772, 82, 1, 23, "Text",
   CellTags->"FDS"],
  Cell[653017, 26775, 228, 9, 23, "Text",
   CellTags->"FDS"]},
 "FermionSpinSum"->{
  Cell[653260, 26787, 65, 1, 39, "ObjectName",
   CellTags->"FermionSpinSum"],
  Cell[653350, 26792, 65, 1, 33, "Subsubsection",
   CellTags->"FermionSpinSum"],
  Cell[653418, 26795, 118, 3, 23, "Text",
   CellTags->"FermionSpinSum"],
  Cell[653561, 26802, 127, 3, 27, "Input",
   CellTags->"FermionSpinSum"],
  Cell[653691, 26807, 314, 9, 25, "Output",
   CellTags->"FermionSpinSum"],
  Cell[654020, 26819, 521, 24, 23, "Text",
   CellTags->"FermionSpinSum"],
  Cell[654578, 26848, 62, 1, 33, "Subsubsection",
   CellTags->"FermionSpinSum"],
  Cell[654643, 26851, 261, 12, 23, "Text",
   CellTags->"FermionSpinSum"],
  Cell[654929, 26867, 296, 9, 27, "Input",
   CellTags->"FermionSpinSum"],
  Cell[655228, 26878, 353, 13, 25, "Output",
   CellTags->"FermionSpinSum"],
  Cell[655618, 26896, 143, 4, 27, "Input",
   CellTags->"FermionSpinSum"],
  Cell[655764, 26902, 330, 12, 25, "Output",
   CellTags->"FermionSpinSum"],
  Cell[656131, 26919, 143, 4, 27, "Input",
   CellTags->"FermionSpinSum"],
  Cell[656277, 26925, 133, 4, 25, "Output",
   CellTags->"FermionSpinSum"],
  Cell[656447, 26934, 296, 9, 27, "Input",
   CellTags->"FermionSpinSum"],
  Cell[656746, 26945, 353, 13, 25, "Output",
   CellTags->"FermionSpinSum"],
  Cell[657136, 26963, 143, 4, 27, "Input",
   CellTags->"FermionSpinSum"],
  Cell[657282, 26969, 330, 12, 25, "Output",
   CellTags->"FermionSpinSum"],
  Cell[657649, 26986, 143, 4, 27, "Input",
   CellTags->"FermionSpinSum"],
  Cell[657795, 26992, 152, 5, 25, "Output",
   CellTags->"FermionSpinSum"],
  Cell[657984, 27002, 334, 10, 27, "Input",
   CellTags->"FermionSpinSum"],
  Cell[658321, 27014, 508, 17, 27, "Output",
   CellTags->"FermionSpinSum"],
  Cell[658844, 27034, 164, 4, 23, "Text",
   CellTags->"FermionSpinSum"],
  Cell[659033, 27042, 147, 4, 27, "Input",
   CellTags->"FermionSpinSum"],
  Cell[659183, 27048, 540, 18, 27, "Output",
   CellTags->"FermionSpinSum"],
  Cell[659760, 27071, 145, 4, 27, "Input",
   CellTags->"FermionSpinSum"],
  Cell[659908, 27077, 1074, 36, 29, "Output",
   CellTags->"FermionSpinSum"],
  Cell[661019, 27118, 148, 4, 27, "Input",
   CellTags->"FermionSpinSum"],
  Cell[661170, 27124, 837, 32, 29, "Output",
   CellTags->"FermionSpinSum"],
  Cell[662022, 27159, 141, 4, 27, "Input",
   CellTags->"FermionSpinSum"]},
 "FeynAmp"->{
  Cell[662178, 27166, 51, 1, 39, "ObjectName",
   CellTags->"FeynAmp"],
  Cell[662254, 27171, 58, 1, 33, "Subsubsection",
   CellTags->"FeynAmp"],
  Cell[662315, 27174, 243, 5, 39, "Text",
   CellTags->"FeynAmp"],
  Cell[662561, 27181, 165, 4, 23, "Text",
   CellTags->"FeynAmp"],
  Cell[662729, 27187, 181, 9, 23, "Text",
   CellTags->"FeynAmp"],
  Cell[662947, 27201, 55, 1, 33, "Subsubsection",
   CellTags->"FeynAmp"],
  Cell[663005, 27204, 125, 4, 23, "Text",
   CellTags->"FeynAmp"],
  Cell[663155, 27212, 846, 22, 48, "Input",
   CellTags->"FeynAmp"],
  Cell[664004, 27236, 2586, 102, 39, "Output",
   CellTags->"FeynAmp"],
  Cell[666605, 27341, 73, 1, 23, "Text",
   CellTags->"FeynAmp"],
  Cell[666703, 27346, 198, 6, 27, "Input",
   CellTags->"FeynAmp"],
  Cell[666904, 27354, 414, 14, 39, "Output",
   CellTags->"FeynAmp"]},
 "FeynAmpDenominator"->{
  Cell[667345, 27372, 73, 1, 39, "ObjectName",
   CellTags->"FeynAmpDenominator"],
  Cell[667443, 27377, 69, 1, 33, "Subsubsection",
   CellTags->"FeynAmpDenominator"],
  Cell[667515, 27380, 256, 5, 39, "Text",
   CellTags->"FeynAmpDenominator"],
  Cell[667774, 27387, 338, 14, 23, "Text",
   CellTags->"FeynAmpDenominator"],
  Cell[668149, 27406, 66, 1, 33, "Subsubsection",
   CellTags->"FeynAmpDenominator"],
  Cell[668240, 27411, 201, 5, 27, "Input",
   CellTags->"FeynAmpDenominator"],
  Cell[668444, 27418, 211, 7, 48, "Output",
   CellTags->"FeynAmpDenominator"],
  Cell[668692, 27430, 326, 9, 27, "Input",
   CellTags->"FeynAmpDenominator"],
  Cell[669021, 27441, 430, 15, 49, "Output",
   CellTags->"FeynAmpDenominator"],
  Cell[669466, 27459, 247, 7, 27, "Input",
   CellTags->"FeynAmpDenominator"],
  Cell[669738, 27470, 149, 4, 27, "Input",
   CellTags->"FeynAmpDenominator"],
  Cell[669890, 27476, 279, 7, 39, "Output",
   CellTags->"FeynAmpDenominator"],
  Cell[670206, 27488, 149, 4, 27, "Input",
   CellTags->"FeynAmpDenominator"],
  Cell[670358, 27494, 176, 5, 39, "Output",
   CellTags->"FeynAmpDenominator"],
  Cell[670549, 27502, 134, 4, 27, "Input",
   CellTags->"FeynAmpDenominator"]},
 "FeynAmpDenominatorCombine"->{
  Cell[670698, 27509, 87, 1, 39, "ObjectName",
   CellTags->"FeynAmpDenominatorCombine"],
  Cell[670810, 27514, 76, 1, 33, "Subsubsection",
   CellTags->"FeynAmpDenominatorCombine"],
  Cell[670889, 27517, 228, 5, 39, "Text",
   CellTags->"FeynAmpDenominatorCombine"],
  Cell[671120, 27524, 241, 9, 23, "Text",
   CellTags->"FeynAmpDenominatorCombine"],
  Cell[671398, 27538, 73, 1, 33, "Subsubsection",
   CellTags->"FeynAmpDenominatorCombine"],
  Cell[671496, 27543, 234, 7, 27, "Input",
   CellTags->"FeynAmpDenominatorCombine"],
  Cell[671733, 27552, 765, 23, 48, "Output",
   CellTags->"FeynAmpDenominatorCombine"],
  Cell[672535, 27580, 208, 6, 27, "Input",
   CellTags->"FeynAmpDenominatorCombine"],
  Cell[672746, 27588, 203, 6, 39, "Output",
   CellTags->"FeynAmpDenominatorCombine"],
  Cell[672986, 27599, 206, 6, 27, "Input",
   CellTags->"FeynAmpDenominatorCombine"],
  Cell[673195, 27607, 233, 7, 39, "Output",
   CellTags->"FeynAmpDenominatorCombine"]},
 "FeynAmpDenominatorSimplify"->{
  Cell[673455, 27618, 89, 1, 39, "ObjectName",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[673569, 27623, 77, 1, 33, "Subsubsection",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[673649, 27626, 398, 7, 55, "Text",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[674050, 27635, 85, 1, 23, "Text",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[674160, 27640, 95, 2, 27, "Input",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[674258, 27644, 147, 3, 25, "Output",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[674420, 27650, 218, 9, 23, "Text",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[674675, 27664, 74, 1, 33, "Subsubsection",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[674752, 27667, 432, 14, 25, "Text",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[675209, 27685, 280, 8, 27, "Input",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[675492, 27695, 122, 3, 25, "Output",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[675629, 27701, 468, 18, 25, "Text",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[676122, 27723, 328, 10, 27, "Input",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[676453, 27735, 336, 11, 48, "Output",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[676826, 27751, 260, 7, 27, "Input",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[677089, 27760, 308, 10, 48, "Output",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[677434, 27775, 339, 10, 27, "Input",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[677776, 27787, 362, 12, 48, "Output",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[678175, 27804, 449, 14, 27, "Input",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[678627, 27820, 1091, 40, 50, "Output",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[679755, 27865, 215, 6, 27, "Input",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[679973, 27873, 1959, 70, 50, "Output",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[681969, 27948, 157, 4, 27, "Input",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[682129, 27954, 493, 18, 45, "Output",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[682659, 27977, 373, 13, 27, "Input",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[683035, 27992, 1361, 50, 51, "Output",
   CellTags->"FeynAmpDenominatorSimplify"],
  Cell[684411, 28045, 147, 4, 27, "Input",
   CellTags->"FeynAmpDenominatorSimplify"]},
 "FeynAmpDenominatorSplit"->{
  Cell[684573, 28052, 83, 1, 39, "ObjectName",
   CellTags->"FeynAmpDenominatorSplit"],
  Cell[684681, 28057, 74, 1, 33, "Subsubsection",
   CellTags->"FeynAmpDenominatorSplit"],
  Cell[684758, 28060, 357, 7, 55, "Text",
   CellTags->"FeynAmpDenominatorSplit"],
  Cell[685118, 28069, 245, 9, 23, "Text",
   CellTags->"FeynAmpDenominatorSplit"],
  Cell[685400, 28083, 71, 1, 33, "Subsubsection",
   CellTags->"FeynAmpDenominatorSplit"],
  Cell[685496, 28088, 308, 9, 27, "Input",
   CellTags->"FeynAmpDenominatorSplit"],
  Cell[685807, 28099, 489, 16, 48, "Output",
   CellTags->"FeynAmpDenominatorSplit"],
  Cell[686333, 28120, 116, 3, 27, "Input",
   CellTags->"FeynAmpDenominatorSplit"],
  Cell[686452, 28125, 136, 3, 25, "Output",
   CellTags->"FeynAmpDenominatorSplit"],
  Cell[686625, 28133, 139, 3, 27, "Input",
   CellTags->"FeynAmpDenominatorSplit"],
  Cell[686767, 28138, 489, 16, 48, "Output",
   CellTags->"FeynAmpDenominatorSplit"],
  Cell[687293, 28159, 150, 4, 27, "Input",
   CellTags->"FeynAmpDenominatorSplit"],
  Cell[687446, 28165, 425, 13, 39, "Output",
   CellTags->"FeynAmpDenominatorSplit"],
  Cell[687908, 28183, 230, 7, 27, "Input",
   CellTags->"FeynAmpDenominatorSplit"],
  Cell[688141, 28192, 368, 12, 39, "Output",
   CellTags->"FeynAmpDenominatorSplit"],
  Cell[688546, 28209, 206, 6, 27, "Input",
   CellTags->"FeynAmpDenominatorSplit"],
  Cell[688755, 28217, 305, 9, 39, "Output",
   CellTags->"FeynAmpDenominatorSplit"],
  Cell[689075, 28229, 121, 3, 27, "Input",
   CellTags->"FeynAmpDenominatorSplit"]},
 "FeynAmpList"->{
  Cell[689211, 28235, 59, 1, 39, "ObjectName",
   CellTags->"FeynAmpList"],
  Cell[689295, 28240, 62, 1, 33, "Subsubsection",
   CellTags->"FeynAmpList"],
  Cell[689360, 28243, 145, 4, 23, "Text",
   CellTags->"FeynAmpList"],
  Cell[689508, 28249, 117, 3, 23, "Text",
   CellTags->"FeynAmpList"],
  Cell[689628, 28254, 179, 9, 23, "Text",
   CellTags->"FeynAmpList"]},
 "FeynCalc"->{
  Cell[689822, 28266, 53, 1, 39, "ObjectName",
   CellTags->"FeynCalc"],
  Cell[689900, 28271, 59, 1, 33, "Subsubsection",
   CellTags->"FeynCalc"],
  Cell[689962, 28274, 91, 1, 23, "Text",
   CellTags->"FeynCalc"],
  Cell[690078, 28279, 99, 3, 27, "Input",
   CellTags->"FeynCalc"],
  Cell[690180, 28284, 703, 11, 311, "Print",
   CellTags->{"FeynCalc", "Info3522790274-4590919"}]},
 "Info3522790274-4590919"->{
  Cell[690180, 28284, 703, 11, 311, "Print",
   CellTags->{"FeynCalc", "Info3522790274-4590919"}]},
 "FeynCalcExternal"->{
  Cell[690910, 28299, 69, 1, 39, "ObjectName",
   CellTags->"FeynCalcExternal"],
  Cell[691004, 28304, 67, 1, 33, "Subsubsection",
   CellTags->"FeynCalcExternal"],
  Cell[691074, 28307, 156, 4, 23, "Text",
   CellTags->"FeynCalcExternal"],
  Cell[691233, 28313, 211, 9, 23, "Text",
   CellTags->"FeynCalcExternal"],
  Cell[691481, 28327, 64, 1, 33, "Subsubsection",
   CellTags->"FeynCalcExternal"],
  Cell[691570, 28332, 162, 4, 27, "Input",
   CellTags->"FeynCalcExternal"],
  Cell[691735, 28338, 143, 4, 27, "Output",
   CellTags->"FeynCalcExternal"],
  Cell[691915, 28347, 117, 3, 27, "Input",
   CellTags->"FeynCalcExternal"],
  Cell[692035, 28352, 126, 3, 39, "Output",
   CellTags->"FeynCalcExternal"],
  Cell[692198, 28360, 450, 13, 27, "Input",
   CellTags->"FeynCalcExternal"],
  Cell[692651, 28375, 560, 18, 27, "Output",
   CellTags->"FeynCalcExternal"],
  Cell[693248, 28398, 117, 3, 27, "Input",
   CellTags->"FeynCalcExternal"],
  Cell[693368, 28403, 465, 13, 39, "Output",
   CellTags->"FeynCalcExternal"],
  Cell[693870, 28421, 121, 3, 27, "Input",
   CellTags->"FeynCalcExternal"],
  Cell[693994, 28426, 875, 34, 27, "Output",
   CellTags->"FeynCalcExternal"],
  Cell[694906, 28465, 117, 3, 27, "Input",
   CellTags->"FeynCalcExternal"],
  Cell[695026, 28470, 906, 24, 78, "Output",
   CellTags->"FeynCalcExternal"],
  Cell[695969, 28499, 163, 5, 27, "Input",
   CellTags->"FeynCalcExternal"],
  Cell[696135, 28506, 465, 13, 39, "Output",
   CellTags->"FeynCalcExternal"]},
 "FeynCalcForm"->{
  Cell[696627, 28523, 61, 1, 39, "ObjectName",
   CellTags->"FeynCalcForm"],
  Cell[696713, 28528, 63, 1, 33, "Subsubsection",
   CellTags->"FeynCalcForm"],
  Cell[696779, 28531, 534, 10, 55, "Text",
   CellTags->"FeynCalcForm"],
  Cell[697316, 28543, 433, 19, 23, "Text",
   CellTags->"FeynCalcForm"],
  Cell[697786, 28567, 60, 1, 33, "Subsubsection",
   CellTags->"FeynCalcForm"],
  Cell[697849, 28570, 79, 1, 23, "Text",
   CellTags->"FeynCalcForm"],
  Cell[697953, 28575, 242, 7, 27, "Input",
   CellTags->"FeynCalcForm"],
  Cell[698198, 28584, 527, 22, 25, "Output",
   CellTags->"FeynCalcForm"],
  Cell[698740, 28609, 112, 3, 23, "Text",
   CellTags->"FeynCalcForm"],
  Cell[698855, 28614, 148, 4, 27, "Input",
   CellTags->"FeynCalcForm"],
  Cell[699006, 28620, 647, 19, 68, "Input",
   CellTags->"FeynCalcForm"],
  Cell[699678, 28643, 242, 7, 27, "Input",
   CellTags->"FeynCalcForm"],
  Cell[699923, 28652, 564, 17, 25, "Output",
   CellTags->"FeynCalcForm"],
  Cell[700502, 28672, 76, 1, 23, "Text",
   CellTags->"FeynCalcForm"],
  Cell[700581, 28675, 123, 4, 27, "Input",
   CellTags->"FeynCalcForm"],
  Cell[700707, 28681, 652, 19, 68, "Input",
   CellTags->"FeynCalcForm"]},
 "FeynCalcInternal"->{
  Cell[701374, 28703, 69, 1, 39, "ObjectName",
   CellTags->"FeynCalcInternal"],
  Cell[701468, 28708, 67, 1, 33, "Subsubsection",
   CellTags->"FeynCalcInternal"],
  Cell[701538, 28711, 157, 4, 23, "Text",
   CellTags->"FeynCalcInternal"],
  Cell[701698, 28717, 401, 19, 23, "Text",
   CellTags->"FeynCalcInternal"],
  Cell[702136, 28741, 64, 1, 33, "Subsubsection",
   CellTags->"FeynCalcInternal"],
  Cell[702225, 28746, 450, 13, 27, "Input",
   CellTags->"FeynCalcInternal"],
  Cell[702678, 28761, 560, 18, 27, "Output",
   CellTags->"FeynCalcInternal"],
  Cell[703275, 28784, 117, 3, 27, "Input",
   CellTags->"FeynCalcInternal"],
  Cell[703395, 28789, 465, 13, 39, "Output",
   CellTags->"FeynCalcInternal"],
  Cell[703897, 28807, 121, 3, 27, "Input",
   CellTags->"FeynCalcInternal"],
  Cell[704021, 28812, 875, 34, 27, "Output",
   CellTags->"FeynCalcInternal"],
  Cell[704933, 28851, 117, 3, 27, "Input",
   CellTags->"FeynCalcInternal"],
  Cell[705053, 28856, 906, 24, 78, "Output",
   CellTags->"FeynCalcInternal"],
  Cell[705996, 28885, 163, 5, 27, "Input",
   CellTags->"FeynCalcInternal"],
  Cell[706162, 28892, 465, 13, 39, "Output",
   CellTags->"FeynCalcInternal"],
  Cell[706664, 28910, 517, 15, 27, "Input",
   CellTags->"FeynCalcInternal"],
  Cell[707184, 28927, 1461, 63, 48, "Output",
   CellTags->"FeynCalcInternal"],
  Cell[708682, 28995, 117, 3, 27, "Input",
   CellTags->"FeynCalcInternal"],
  Cell[708802, 29000, 1128, 30, 97, "Output",
   CellTags->"FeynCalcInternal"]},
 "FeynCalc2FORM"->{
  Cell[709957, 29034, 63, 1, 39, "ObjectName",
   CellTags->"FeynCalc2FORM"],
  Cell[710045, 29039, 64, 1, 33, "Subsubsection",
   CellTags->"FeynCalc2FORM"],
  Cell[710112, 29042, 226, 5, 39, "Text",
   CellTags->"FeynCalc2FORM"],
  Cell[710341, 29049, 199, 9, 23, "Text",
   CellTags->"FeynCalc2FORM"],
  Cell[710565, 29062, 125, 3, 27, "Input",
   CellTags->"FeynCalc2FORM"],
  Cell[710693, 29067, 1022, 22, 45, "Output",
   CellTags->"FeynCalc2FORM"],
  Cell[711764, 29095, 61, 1, 33, "Subsubsection",
   CellTags->"FeynCalc2FORM"],
  Cell[711850, 29100, 273, 9, 27, "Input",
   CellTags->"FeynCalc2FORM"],
  Cell[712126, 29111, 276, 9, 46, "Output",
   CellTags->"FeynCalc2FORM"],
  Cell[712439, 29125, 137, 4, 27, "Input",
   CellTags->"FeynCalc2FORM"],
  Cell[712579, 29131, 68, 1, 21, "Print",
   CellTags->"FeynCalc2FORM"],
  Cell[712684, 29137, 199, 6, 27, "Input",
   CellTags->"FeynCalc2FORM"],
  Cell[712886, 29145, 199, 6, 25, "Output",
   CellTags->"FeynCalc2FORM"],
  Cell[713122, 29156, 137, 4, 27, "Input",
   CellTags->"FeynCalc2FORM"],
  Cell[713262, 29162, 66, 1, 21, "Print",
   CellTags->"FeynCalc2FORM"],
  Cell[713365, 29168, 212, 6, 27, "Input",
   CellTags->"FeynCalc2FORM"],
  Cell[713580, 29176, 373, 11, 27, "Output",
   CellTags->"FeynCalc2FORM"],
  Cell[713990, 29192, 137, 4, 27, "Input",
   CellTags->"FeynCalc2FORM"],
  Cell[714130, 29198, 88, 3, 21, "Print",
   CellTags->"FeynCalc2FORM"],
  Cell[714255, 29206, 298, 9, 27, "Input",
   CellTags->"FeynCalc2FORM"],
  Cell[714556, 29217, 473, 16, 27, "Output",
   CellTags->"FeynCalc2FORM"],
  Cell[715066, 29238, 137, 4, 27, "Input",
   CellTags->"FeynCalc2FORM"],
  Cell[715206, 29244, 88, 3, 21, "Print",
   CellTags->"FeynCalc2FORM"],
  Cell[715309, 29250, 328, 10, 27, "Input",
   CellTags->"FeynCalc2FORM"],
  Cell[715662, 29264, 332, 10, 27, "Input",
   CellTags->"FeynCalc2FORM"],
  Cell[715997, 29276, 154, 4, 25, "Output",
   CellTags->"FeynCalc2FORM"],
  Cell[716188, 29285, 314, 10, 27, "Input",
   CellTags->"FeynCalc2FORM"],
  Cell[716505, 29297, 6179, 240, 47, "Output",
   CellTags->"FeynCalc2FORM"],
  Cell[722699, 29540, 209, 6, 27, "Input",
   CellTags->"FeynCalc2FORM"],
  Cell[722933, 29550, 376, 11, 27, "Input",
   CellTags->"FeynCalc2FORM"],
  Cell[723312, 29563, 1338, 36, 225, "Output",
   CellTags->"FeynCalc2FORM"],
  Cell[724665, 29602, 313, 10, 27, "Input",
   CellTags->"FeynCalc2FORM"],
  Cell[724981, 29614, 129, 4, 27, "Input",
   CellTags->"FeynCalc2FORM"]},
 "FeynCalcToLaTeX"->{
  Cell[725125, 29621, 67, 1, 39, "ObjectName",
   CellTags->"FeynCalcToLaTeX"],
  Cell[725217, 29626, 66, 1, 33, "Subsubsection",
   CellTags->"FeynCalcToLaTeX"],
  Cell[725286, 29629, 300, 6, 63, "Text",
   CellTags->"FeynCalcToLaTeX"]},
 "FeynmanParameterNames"->{
  Cell[726940, 29685, 79, 1, 39, "ObjectName",
   CellTags->"FeynmanParameterNames"],
  Cell[727044, 29690, 72, 1, 33, "Subsubsection",
   CellTags->"FeynmanParameterNames"],
  Cell[727119, 29693, 143, 4, 23, "Text",
   CellTags->"FeynmanParameterNames"],
  Cell[727265, 29699, 362, 14, 23, "Text",
   CellTags->"FeynmanParameterNames"]},
 "FeynmanParametrize"->{
  Cell[727642, 29716, 90, 1, 39, "ObjectName",
   CellTags->"FeynmanParametrize"],
  Cell[727757, 29721, 69, 1, 33, "Subsubsection",
   CellTags->"FeynmanParametrize"],
  Cell[727829, 29724, 176, 4, 23, "Text",
   CellTags->"FeynmanParametrize"],
  Cell[728030, 29732, 135, 3, 27, "Input",
   CellTags->"FeynmanParametrize"],
  Cell[728168, 29737, 251, 8, 25, "Output",
   CellTags->"FeynmanParametrize"],
  Cell[728468, 29751, 66, 1, 33, "Subsubsection",
   CellTags->"FeynmanParametrize"],
  Cell[728537, 29754, 84, 2, 27, "Input",
   CellTags->"FeynmanParametrize"]},
 "FeynRule"->{
  Cell[728636, 29759, 53, 1, 39, "ObjectName",
   CellTags->"FeynRule"],
  Cell[728714, 29764, 59, 1, 33, "Subsubsection",
   CellTags->"FeynRule"],
  Cell[728776, 29767, 168, 4, 23, "Text",
   CellTags->"FeynRule"],
  Cell[728969, 29775, 115, 3, 27, "Input",
   CellTags->"FeynRule"],
  Cell[729087, 29780, 630, 16, 45, "Output",
   CellTags->"FeynRule"],
  Cell[729732, 29799, 92, 1, 23, "Text",
   CellTags->"FeynRule"],
  Cell[729827, 29802, 133, 4, 23, "Text",
   CellTags->"FeynRule"],
  Cell[729963, 29808, 185, 9, 23, "Text",
   CellTags->"FeynRule"],
  Cell[730185, 29822, 56, 1, 33, "Subsubsection",
   CellTags->"FeynRule"],
  Cell[730266, 29827, 146, 4, 27, "Input",
   CellTags->"FeynRule"],
  Cell[730415, 29833, 680, 23, 43, "Output",
   CellTags->"FeynRule"],
  Cell[731132, 29861, 146, 4, 27, "Input",
   CellTags->"FeynRule"],
  Cell[731281, 29867, 1003, 36, 43, "Output",
   CellTags->"FeynRule"],
  Cell[732321, 29908, 111, 3, 27, "Input",
   CellTags->"FeynRule"],
  Cell[732435, 29913, 4554, 176, 43, "Output",
   CellTags->"FeynRule"],
  Cell[737026, 30094, 141, 4, 27, "Input",
   CellTags->"FeynRule"],
  Cell[737170, 30100, 2656, 113, 31, "Output",
   CellTags->"FeynRule"],
  Cell[739841, 30216, 74, 1, 23, "Text",
   CellTags->"FeynRule"],
  Cell[739940, 30221, 503, 16, 27, "Input",
   CellTags->"FeynRule"],
  Cell[740446, 30239, 700, 30, 31, "Output",
   CellTags->"FeynRule"],
  Cell[741183, 30274, 307, 9, 27, "Input",
   CellTags->"FeynRule"],
  Cell[741493, 30285, 3795, 138, 50, "Output",
   CellTags->"FeynRule"],
  Cell[745303, 30426, 72, 1, 23, "Text",
   CellTags->"FeynRule"],
  Cell[745400, 30431, 503, 16, 27, "Input",
   CellTags->"FeynRule"],
  Cell[745906, 30449, 700, 30, 31, "Output",
   CellTags->"FeynRule"],
  Cell[746643, 30484, 307, 9, 27, "Input",
   CellTags->"FeynRule"],
  Cell[746953, 30495, 4465, 151, 50, "Output",
   CellTags->"FeynRule"],
  Cell[751455, 30651, 218, 7, 27, "Input",
   CellTags->"FeynRule"],
  Cell[751676, 30660, 1044, 42, 29, "Output",
   CellTags->"FeynRule"],
  Cell[752735, 30705, 110, 3, 23, "Text",
   CellTags->"FeynRule"],
  Cell[752870, 30712, 360, 10, 27, "Input",
   CellTags->"FeynRule"],
  Cell[753233, 30724, 1108, 45, 29, "Output",
   CellTags->"FeynRule"],
  Cell[754356, 30772, 77, 1, 23, "Text",
   CellTags->"FeynRule"],
  Cell[754458, 30777, 145, 4, 27, "Input",
   CellTags->"FeynRule"],
  Cell[754606, 30783, 618, 22, 27, "Output",
   CellTags->"FeynRule"],
  Cell[755239, 30808, 90, 1, 23, "Text",
   CellTags->"FeynRule"],
  Cell[755354, 30813, 145, 4, 27, "Input",
   CellTags->"FeynRule"],
  Cell[755502, 30819, 618, 22, 27, "Output",
   CellTags->"FeynRule"],
  Cell[756157, 30846, 696, 21, 48, "Input",
   CellTags->"FeynRule"],
  Cell[756856, 30869, 893, 37, 31, "Output",
   CellTags->"FeynRule"],
  Cell[757786, 30911, 227, 7, 27, "Input",
   CellTags->"FeynRule"],
  Cell[758016, 30920, 4957, 177, 109, "Output",
   CellTags->"FeynRule"],
  Cell[763010, 31102, 420, 12, 27, "Input",
   CellTags->"FeynRule"],
  Cell[763433, 31116, 4764, 159, 78, "Output",
   CellTags->"FeynRule"],
  Cell[768234, 31280, 362, 12, 27, "Input",
   CellTags->"FeynRule"],
  Cell[768599, 31294, 104, 3, 25, "Output",
   CellTags->"FeynRule"],
  Cell[768718, 31300, 210, 5, 39, "Text",
   CellTags->"FeynRule"],
  Cell[768931, 31307, 144, 4, 27, "Input",
   CellTags->"FeynRule"],
  Cell[769078, 31313, 51, 1, 23, "Text",
   CellTags->"FeynRule"],
  Cell[769154, 31318, 693, 21, 48, "Input",
   CellTags->"FeynRule"],
  Cell[769850, 31341, 984, 42, 31, "Output",
   CellTags->"FeynRule"],
  Cell[770871, 31388, 212, 7, 27, "Input",
   CellTags->"FeynRule"],
  Cell[771086, 31397, 1971, 79, 27, "Output",
   CellTags->"FeynRule"],
  Cell[773094, 31481, 385, 11, 27, "Input",
   CellTags->"FeynRule"],
  Cell[773482, 31494, 1419, 57, 27, "Output",
   CellTags->"FeynRule"],
  Cell[774938, 31556, 197, 6, 27, "Input",
   CellTags->"FeynRule"],
  Cell[775138, 31564, 104, 3, 25, "Output",
   CellTags->"FeynRule"],
  Cell[775279, 31572, 884, 26, 48, "Input",
   CellTags->"FeynRule"],
  Cell[776166, 31600, 1270, 54, 31, "Output",
   CellTags->"FeynRule"],
  Cell[777473, 31659, 212, 7, 27, "Input",
   CellTags->"FeynRule"],
  Cell[777688, 31668, 3305, 131, 29, "Output",
   CellTags->"FeynRule"],
  Cell[781030, 31804, 461, 13, 27, "Input",
   CellTags->"FeynRule"],
  Cell[781494, 31819, 3470, 132, 29, "Output",
   CellTags->"FeynRule"],
  Cell[785001, 31956, 197, 6, 27, "Input",
   CellTags->"FeynRule"],
  Cell[785201, 31964, 104, 3, 25, "Output",
   CellTags->"FeynRule"],
  Cell[785320, 31970, 418, 9, 48, "Input",
   CellTags->"FeynRule"]},
 "FI"->{
  Cell[785753, 31982, 41, 1, 39, "ObjectName",
   CellTags->"FI"],
  Cell[785819, 31987, 53, 1, 33, "Subsubsection",
   CellTags->"FI"],
  Cell[785875, 31990, 195, 4, 39, "Text",
   CellTags->"FI"],
  Cell[786073, 31996, 545, 24, 23, "Text",
   CellTags->"FI"]},
 "FieldDerivative"->{
  Cell[786633, 32023, 67, 1, 39, "ObjectName",
   CellTags->"FieldDerivative"],
  Cell[786725, 32028, 66, 1, 33, "Subsubsection",
   CellTags->"FieldDerivative"],
  Cell[786794, 32031, 549, 9, 71, "Text",
   CellTags->"FieldDerivative"],
  Cell[787346, 32042, 314, 14, 23, "Text",
   CellTags->"FieldDerivative"],
  Cell[787697, 32061, 63, 1, 33, "Subsubsection",
   CellTags->"FieldDerivative"],
  Cell[787785, 32066, 620, 19, 27, "Input",
   CellTags->"FieldDerivative"],
  Cell[788408, 32087, 465, 17, 28, "Output",
   CellTags->"FieldDerivative"],
  Cell[788910, 32109, 218, 6, 27, "Input",
   CellTags->"FieldDerivative"],
  Cell[789131, 32117, 1529, 55, 29, "Output",
   CellTags->"FieldDerivative"],
  Cell[790697, 32177, 218, 6, 27, "Input",
   CellTags->"FieldDerivative"],
  Cell[790918, 32185, 4269, 153, 52, "Output",
   CellTags->"FieldDerivative"]},
 "FieldStrength"->{
  Cell[795214, 32342, 63, 1, 39, "ObjectName",
   CellTags->"FieldStrength"],
  Cell[795302, 32347, 64, 1, 33, "Subsubsection",
   CellTags->"FieldStrength"],
  Cell[795369, 32350, 1285, 37, 59, "Text",
   CellTags->"FieldStrength"],
  Cell[796679, 32391, 125, 3, 27, "Input",
   CellTags->"FieldStrength"],
  Cell[796807, 32396, 529, 15, 45, "Output",
   CellTags->"FieldStrength"],
  Cell[797351, 32414, 196, 9, 23, "Text",
   CellTags->"FieldStrength"],
  Cell[797584, 32428, 61, 1, 33, "Subsubsection",
   CellTags->"FieldStrength"],
  Cell[797670, 32433, 150, 4, 27, "Input",
   CellTags->"FieldStrength"],
  Cell[797823, 32439, 174, 5, 29, "Output",
   CellTags->"FieldStrength"],
  Cell[798034, 32449, 160, 4, 27, "Input",
   CellTags->"FieldStrength"],
  Cell[798197, 32455, 168, 5, 29, "Output",
   CellTags->"FieldStrength"],
  Cell[798402, 32465, 200, 5, 27, "Input",
   CellTags->"FieldStrength"],
  Cell[798605, 32472, 722, 30, 29, "Output",
   CellTags->"FieldStrength"],
  Cell[799364, 32507, 210, 5, 27, "Input",
   CellTags->"FieldStrength"],
  Cell[799577, 32514, 1507, 65, 31, "Output",
   CellTags->"FieldStrength"],
  Cell[801121, 32584, 241, 6, 27, "Input",
   CellTags->"FieldStrength"],
  Cell[801365, 32592, 547, 15, 59, "Output",
   CellTags->"FieldStrength"],
  Cell[801949, 32612, 244, 6, 27, "Input",
   CellTags->"FieldStrength"],
  Cell[802196, 32620, 545, 15, 59, "Output",
   CellTags->"FieldStrength"],
  Cell[802778, 32640, 291, 7, 27, "Input",
   CellTags->"FieldStrength"],
  Cell[803072, 32649, 1553, 66, 31, "Output",
   CellTags->"FieldStrength"]},
 "FinalFunction"->{
  Cell[804652, 32719, 63, 1, 39, "ObjectName",
   CellTags->"FinalFunction"],
  Cell[804740, 32724, 64, 1, 33, "Subsubsection",
   CellTags->"FinalFunction"],
  Cell[804807, 32727, 86, 1, 23, "Text",
   CellTags->"FinalFunction"],
  Cell[804896, 32730, 190, 9, 23, "Text",
   CellTags->"FinalFunction"]},
 "FinalSubstitutions"->{
  Cell[805101, 32742, 73, 1, 39, "ObjectName",
   CellTags->"FinalSubstitutions"],
  Cell[805199, 32747, 69, 1, 33, "Subsubsection",
   CellTags->"FinalSubstitutions"],
  Cell[805271, 32750, 204, 4, 23, "Text",
   CellTags->"FinalSubstitutions"],
  Cell[805478, 32756, 406, 19, 23, "Text",
   CellTags->"FinalSubstitutions"]},
 "FORM"->{
  Cell[805899, 32778, 45, 1, 39, "ObjectName",
   CellTags->"FORM"],
  Cell[805969, 32783, 55, 1, 33, "Subsubsection",
   CellTags->"FORM"],
  Cell[806027, 32786, 204, 5, 39, "Text",
   CellTags->"FORM"],
  Cell[806234, 32793, 285, 14, 23, "Text",
   CellTags->"FORM"]},
 "FORMEpilog"->{
  Cell[806534, 32810, 57, 1, 39, "ObjectName",
   CellTags->"FORMEpilog"],
  Cell[806616, 32815, 61, 1, 33, "Subsubsection",
   CellTags->"FORMEpilog"],
  Cell[806680, 32818, 161, 4, 23, "Text",
   CellTags->"FORMEpilog"],
  Cell[806844, 32824, 312, 14, 23, "Text",
   CellTags->"FORMEpilog"]},
 "FORMProlog"->{
  Cell[807171, 32841, 57, 1, 39, "ObjectName",
   CellTags->"FORMProlog"],
  Cell[807253, 32846, 61, 1, 33, "Subsubsection",
   CellTags->"FORMProlog"],
  Cell[807317, 32849, 178, 4, 23, "Text",
   CellTags->"FORMProlog"],
  Cell[807498, 32855, 312, 14, 23, "Text",
   CellTags->"FORMProlog"]},
 "FORM2FeynCalc"->{
  Cell[807825, 32872, 63, 1, 39, "ObjectName",
   CellTags->"FORM2FeynCalc"],
  Cell[807913, 32877, 64, 1, 33, "Subsubsection",
   CellTags->"FORM2FeynCalc"],
  Cell[807980, 32880, 470, 8, 55, "Text",
   CellTags->"FORM2FeynCalc"],
  Cell[808453, 32890, 199, 9, 23, "Text",
   CellTags->"FORM2FeynCalc"],
  Cell[808677, 32903, 125, 3, 27, "Input",
   CellTags->"FORM2FeynCalc"],
  Cell[808805, 32908, 662, 18, 45, "Output",
   CellTags->"FORM2FeynCalc"],
  Cell[809516, 32932, 61, 1, 33, "Subsubsection",
   CellTags->"FORM2FeynCalc"],
  Cell[809602, 32937, 139, 3, 27, "Input",
   CellTags->"FORM2FeynCalc"],
  Cell[809744, 32942, 354, 14, 27, "Output",
   CellTags->"FORM2FeynCalc"],
  Cell[810135, 32961, 114, 3, 27, "Input",
   CellTags->"FORM2FeynCalc"],
  Cell[810252, 32966, 243, 8, 39, "Output",
   CellTags->"FORM2FeynCalc"],
  Cell[810510, 32977, 159, 4, 23, "Text",
   CellTags->"FORM2FeynCalc"],
  Cell[810694, 32985, 314, 8, 27, "Input",
   CellTags->"FORM2FeynCalc"],
  Cell[811011, 32995, 298, 10, 27, "Output",
   CellTags->"FORM2FeynCalc"],
  Cell[811346, 33010, 114, 3, 27, "Input",
   CellTags->"FORM2FeynCalc"],
  Cell[811463, 33015, 303, 9, 39, "Output",
   CellTags->"FORM2FeynCalc"],
  Cell[811803, 33029, 150, 4, 27, "Input",
   CellTags->"FORM2FeynCalc"],
  Cell[811956, 33035, 331, 12, 27, "Output",
   CellTags->"FORM2FeynCalc"],
  Cell[812324, 33052, 117, 3, 27, "Input",
   CellTags->"FORM2FeynCalc"],
  Cell[812444, 33057, 259, 9, 25, "Output",
   CellTags->"FORM2FeynCalc"],
  Cell[812740, 33071, 150, 4, 27, "Input",
   CellTags->"FORM2FeynCalc"],
  Cell[812893, 33077, 257, 9, 25, "Output",
   CellTags->"FORM2FeynCalc"],
  Cell[813187, 33091, 114, 3, 27, "Input",
   CellTags->"FORM2FeynCalc"],
  Cell[813304, 33096, 307, 10, 39, "Output",
   CellTags->"FORM2FeynCalc"],
  Cell[813648, 33111, 333, 9, 27, "Input",
   CellTags->"FORM2FeynCalc"],
  Cell[813984, 33122, 269, 9, 25, "Output",
   CellTags->"FORM2FeynCalc"],
  Cell[814290, 33136, 195, 5, 27, "Input",
   CellTags->"FORM2FeynCalc"],
  Cell[814488, 33143, 3922, 121, 68, "Output",
   CellTags->"FORM2FeynCalc"]},
 "FourDivergence"->{
  Cell[818437, 33268, 65, 1, 39, "ObjectName",
   CellTags->"FourDivergence"],
  Cell[818527, 33273, 65, 1, 33, "Subsubsection",
   CellTags->"FourDivergence"],
  Cell[818595, 33276, 242, 5, 39, "Text",
   CellTags->"FourDivergence"],
  Cell[818840, 33283, 197, 9, 23, "Text",
   CellTags->"FourDivergence"],
  Cell[819074, 33297, 62, 1, 33, "Subsubsection",
   CellTags->"FourDivergence"],
  Cell[819161, 33302, 167, 5, 27, "Input",
   CellTags->"FourDivergence"],
  Cell[819331, 33309, 212, 8, 25, "Output",
   CellTags->"FourDivergence"],
  Cell[819580, 33322, 211, 6, 27, "Input",
   CellTags->"FourDivergence"],
  Cell[819794, 33330, 242, 10, 25, "Output",
   CellTags->"FourDivergence"],
  Cell[820073, 33345, 192, 6, 27, "Input",
   CellTags->"FourDivergence"],
  Cell[820268, 33353, 247, 9, 25, "Output",
   CellTags->"FourDivergence"],
  Cell[820552, 33367, 237, 7, 27, "Input",
   CellTags->"FourDivergence"],
  Cell[820792, 33376, 110, 3, 25, "Output",
   CellTags->"FourDivergence"],
  Cell[820917, 33382, 112, 3, 27, "Input",
   CellTags->"FourDivergence"]},
 "FourLaplacian"->{
  Cell[821044, 33388, 63, 1, 39, "ObjectName",
   CellTags->"FourLaplacian"],
  Cell[821132, 33393, 64, 1, 33, "Subsubsection",
   CellTags->"FourLaplacian"],
  Cell[821199, 33396, 426, 16, 26, "Text",
   CellTags->"FourLaplacian"],
  Cell[821650, 33416, 125, 3, 27, "Input",
   CellTags->"FourLaplacian"],
  Cell[821778, 33421, 170, 5, 25, "Output",
   CellTags->"FourLaplacian"],
  Cell[821963, 33429, 324, 14, 23, "Text",
   CellTags->"FourLaplacian"],
  Cell[822324, 33448, 61, 1, 33, "Subsubsection",
   CellTags->"FourLaplacian"],
  Cell[822410, 33453, 131, 4, 27, "Input",
   CellTags->"FourLaplacian"],
  Cell[822544, 33459, 167, 6, 27, "Output",
   CellTags->"FourLaplacian"],
  Cell[822748, 33470, 152, 4, 27, "Input",
   CellTags->"FourLaplacian"],
  Cell[822903, 33476, 132, 4, 25, "Output",
   CellTags->"FourLaplacian"],
  Cell[823072, 33485, 264, 9, 27, "Input",
   CellTags->"FourLaplacian"],
  Cell[823339, 33496, 440, 16, 49, "Output",
   CellTags->"FourLaplacian"],
  Cell[823816, 33517, 157, 4, 27, "Input",
   CellTags->"FourLaplacian"],
  Cell[823976, 33523, 3857, 136, 99, "Output",
   CellTags->"FourLaplacian"]},
 "FourVector"->{
  Cell[827860, 33663, 57, 1, 39, "ObjectName",
   CellTags->"FourVector"],
  Cell[827942, 33668, 61, 1, 33, "Subsubsection",
   CellTags->"FourVector"],
  Cell[828006, 33671, 339, 10, 39, "Text",
   CellTags->"FourVector"],
  Cell[828348, 33683, 356, 19, 23, "Text",
   CellTags->"FourVector"],
  Cell[828741, 33707, 58, 1, 33, "Subsubsection",
   CellTags->"FourVector"],
  Cell[828824, 33712, 140, 4, 27, "Input",
   CellTags->"FourVector"],
  Cell[828967, 33718, 132, 4, 28, "Output",
   CellTags->"FourVector"],
  Cell[829136, 33727, 164, 5, 27, "Input",
   CellTags->"FourVector"],
  Cell[829303, 33734, 249, 10, 28, "Output",
   CellTags->"FourVector"],
  Cell[829589, 33749, 180, 5, 27, "Input",
   CellTags->"FourVector"],
  Cell[829772, 33756, 155, 4, 39, "Output",
   CellTags->"FourVector"],
  Cell[829964, 33765, 229, 6, 27, "Input",
   CellTags->"FourVector"],
  Cell[830196, 33773, 203, 5, 39, "Output",
   CellTags->"FourVector"],
  Cell[830436, 33783, 212, 6, 27, "Input",
   CellTags->"FourVector"],
  Cell[830651, 33791, 155, 4, 39, "Output",
   CellTags->"FourVector"],
  Cell[830821, 33798, 193, 4, 23, "Text",
   CellTags->"FourVector"],
  Cell[831039, 33806, 212, 6, 27, "Input",
   CellTags->"FourVector"],
  Cell[831254, 33814, 407, 18, 25, "Output",
   CellTags->"FourVector"]},
 "FreeIndex"->{
  Cell[831688, 33836, 55, 1, 39, "ObjectName",
   CellTags->"FreeIndex"],
  Cell[831768, 33841, 60, 1, 33, "Subsubsection",
   CellTags->"FreeIndex"],
  Cell[831831, 33844, 152, 4, 23, "Text",
   CellTags->"FreeIndex"],
  Cell[831986, 33850, 290, 14, 23, "Text",
   CellTags->"FreeIndex"]},
 "FreeQ2"->{
  Cell[832291, 33867, 49, 1, 39, "ObjectName",
   CellTags->"FreeQ2"],
  Cell[832365, 33872, 57, 1, 33, "Subsubsection",
   CellTags->"FreeQ2"],
  Cell[832425, 33875, 228, 5, 39, "Text",
   CellTags->"FreeQ2"],
  Cell[832656, 33882, 308, 14, 23, "Text",
   CellTags->"FreeQ2"],
  Cell[833001, 33901, 54, 1, 33, "Subsubsection",
   CellTags->"FreeQ2"],
  Cell[833080, 33906, 246, 8, 27, "Input",
   CellTags->"FreeQ2"],
  Cell[833329, 33916, 106, 3, 25, "Output",
   CellTags->"FreeQ2"],
  Cell[833472, 33924, 241, 8, 27, "Input",
   CellTags->"FreeQ2"],
  Cell[833716, 33934, 105, 3, 25, "Output",
   CellTags->"FreeQ2"],
  Cell[833858, 33942, 133, 4, 27, "Input",
   CellTags->"FreeQ2"],
  Cell[833994, 33948, 105, 3, 25, "Output",
   CellTags->"FreeQ2"],
  Cell[834136, 33956, 162, 5, 27, "Input",
   CellTags->"FreeQ2"],
  Cell[834301, 33963, 106, 3, 25, "Output",
   CellTags->"FreeQ2"]},
 "FRH"->{
  Cell[834434, 33970, 43, 1, 39, "ObjectName",
   CellTags->"FRH"],
  Cell[834502, 33975, 54, 1, 33, "Subsubsection",
   CellTags->"FRH"],
  Cell[834559, 33978, 134, 4, 23, "Text",
   CellTags->"FRH"],
  Cell[834696, 33984, 171, 9, 23, "Text",
   CellTags->"FRH"],
  Cell[834904, 33998, 51, 1, 33, "Subsubsection",
   CellTags->"FRH"],
  Cell[834980, 34003, 200, 6, 27, "Input",
   CellTags->"FRH"],
  Cell[835183, 34011, 248, 9, 25, "Output",
   CellTags->"FRH"],
  Cell[835468, 34025, 99, 3, 27, "Input",
   CellTags->"FRH"],
  Cell[835570, 34030, 99, 3, 25, "Output",
   CellTags->"FRH"],
  Cell[835706, 34038, 304, 10, 27, "Input",
   CellTags->"FRH"],
  Cell[836013, 34050, 531, 20, 25, "Output",
   CellTags->"FRH"],
  Cell[836581, 34075, 128, 4, 27, "Input",
   CellTags->"FRH"],
  Cell[836712, 34081, 128, 4, 25, "Output",
   CellTags->"FRH"]},
 "FromTFi"->{
  Cell[836867, 34089, 51, 1, 39, "ObjectName",
   CellTags->"FromTFi"],
  Cell[836943, 34094, 58, 1, 33, "Subsubsection",
   CellTags->"FromTFi"],
  Cell[837004, 34097, 200, 5, 39, "Text",
   CellTags->"FromTFi"],
  Cell[837502, 34122, 55, 1, 33, "Subsubsection",
   CellTags->"FromTFi"],
  Cell[837582, 34127, 431, 14, 27, "Input",
   CellTags->"FromTFi"],
  Cell[838016, 34143, 776, 24, 92, "Output",
   CellTags->"FromTFi"],
  Cell[838829, 34172, 693, 22, 27, "Input",
   CellTags->"FromTFi"],
  Cell[839525, 34196, 966, 31, 92, "Output",
   CellTags->"FromTFi"],
  Cell[840528, 34232, 756, 24, 27, "Input",
   CellTags->"FromTFi"],
  Cell[841287, 34258, 1027, 33, 92, "Output",
   CellTags->"FromTFi"]},
 "FromTFI"->{
  Cell[837207, 34104, 258, 13, 23, "Text",
   CellTags->"FromTFI"]},
 "FUNCTION"->{
  Cell[842341, 34295, 53, 1, 39, "ObjectName",
   CellTags->"FUNCTION"],
  Cell[842419, 34300, 59, 1, 33, "Subsubsection",
   CellTags->"FUNCTION"],
  Cell[842481, 34303, 160, 4, 23, "Text",
   CellTags->"FUNCTION"],
  Cell[842644, 34309, 173, 9, 23, "Text",
   CellTags->"FUNCTION"]},
 "FunctionalD"->{
  Cell[842832, 34321, 59, 1, 39, "ObjectName",
   CellTags->"FunctionalD"],
  Cell[842916, 34326, 62, 1, 33, "Subsubsection",
   CellTags->"FunctionalD"],
  Cell[842981, 34329, 416, 7, 55, "Text",
   CellTags->"FunctionalD"],
  Cell[843400, 34338, 95, 1, 23, "Text",
   CellTags->"FunctionalD"],
  Cell[843498, 34341, 304, 14, 23, "Text",
   CellTags->"FunctionalD"],
  Cell[843839, 34360, 59, 1, 33, "Subsubsection",
   CellTags->"FunctionalD"],
  Cell[843901, 34363, 610, 20, 23, "Text",
   CellTags->"FunctionalD"],
  Cell[844536, 34387, 228, 6, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[844767, 34395, 107, 3, 25, "Output",
   CellTags->"FunctionalD"],
  Cell[844911, 34403, 253, 7, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[845167, 34412, 135, 4, 25, "Output",
   CellTags->"FunctionalD"],
  Cell[845317, 34419, 1269, 44, 49, "Text",
   CellTags->"FunctionalD"],
  Cell[846611, 34467, 295, 8, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[846909, 34477, 273, 10, 32, "Output",
   CellTags->"FunctionalD"],
  Cell[847197, 34490, 778, 24, 26, "Text",
   CellTags->"FunctionalD"],
  Cell[848000, 34518, 668, 22, 48, "Input",
   CellTags->"FunctionalD"],
  Cell[848671, 34542, 735, 26, 43, "Output",
   CellTags->"FunctionalD"],
  Cell[849443, 34573, 217, 6, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[849663, 34581, 652, 26, 30, "Output",
   CellTags->"FunctionalD"],
  Cell[850330, 34610, 489, 15, 30, "Text",
   CellTags->"FunctionalD"],
  Cell[850822, 34627, 97, 2, 23, "Text",
   CellTags->"FunctionalD"],
  Cell[850944, 34633, 315, 8, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[851262, 34643, 1303, 56, 31, "Output",
   CellTags->"FunctionalD"],
  Cell[852602, 34704, 315, 8, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[852920, 34714, 1303, 56, 31, "Output",
   CellTags->"FunctionalD"],
  Cell[854260, 34775, 216, 8, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[854479, 34785, 2956, 115, 43, "Output",
   CellTags->"FunctionalD"],
  Cell[857450, 34903, 560, 13, 57, "Text",
   CellTags->"FunctionalD"],
  Cell[858013, 34918, 1398, 50, 26, "Text",
   CellTags->"FunctionalD"],
  Cell[859414, 34970, 445, 13, 25, "Text",
   CellTags->"FunctionalD"],
  Cell[859884, 34987, 231, 7, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[860118, 34996, 286, 12, 27, "Output",
   CellTags->"FunctionalD"],
  Cell[860441, 35013, 165, 5, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[860609, 35020, 2288, 96, 33, "Output",
   CellTags->"FunctionalD"],
  Cell[862912, 35119, 120, 3, 23, "Text",
   CellTags->"FunctionalD"],
  Cell[863057, 35126, 176, 5, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[863236, 35133, 2288, 96, 33, "Output",
   CellTags->"FunctionalD"],
  Cell[865539, 35232, 290, 8, 25, "Text",
   CellTags->"FunctionalD"],
  Cell[865832, 35242, 523, 16, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[866380, 35262, 230, 7, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[866613, 35271, 384, 17, 29, "Output",
   CellTags->"FunctionalD"],
  Cell[867034, 35293, 240, 7, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[867277, 35302, 416, 18, 29, "Output",
   CellTags->"FunctionalD"],
  Cell[867730, 35325, 579, 16, 68, "Input",
   CellTags->"FunctionalD"],
  Cell[868312, 35343, 2958, 127, 43, "Output",
   CellTags->"FunctionalD"],
  Cell[871307, 35475, 184, 5, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[871494, 35482, 1405, 62, 29, "Output",
   CellTags->"FunctionalD"],
  Cell[872936, 35549, 352, 11, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[873291, 35562, 1159, 50, 29, "Output",
   CellTags->"FunctionalD"],
  Cell[874465, 35615, 269, 9, 27, "Text",
   CellTags->"FunctionalD"],
  Cell[874737, 35626, 98, 2, 23, "Text",
   CellTags->"FunctionalD"],
  Cell[874838, 35630, 167, 4, 23, "Text",
   CellTags->"FunctionalD"],
  Cell[875030, 35638, 105, 3, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[875138, 35643, 2956, 115, 43, "Output",
   CellTags->"FunctionalD"],
  Cell[878131, 35763, 194, 6, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[878328, 35771, 23483, 1005, 160, "Output",
   CellTags->"FunctionalD"],
  Cell[901826, 36779, 227, 5, 36, "Text",
   CellTags->"FunctionalD"],
  Cell[902056, 36786, 345, 6, 39, "Text",
   CellTags->"FunctionalD"],
  Cell[902404, 36794, 132, 4, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[902539, 36800, 2583, 67, 128, "Input",
   CellTags->"FunctionalD"],
  Cell[905147, 36871, 169, 5, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[905319, 36878, 12210, 526, 121, "Output",
   CellTags->"FunctionalD"],
  Cell[917566, 37409, 164, 5, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[917733, 37416, 6535, 286, 43, "Output",
   CellTags->"FunctionalD"],
  Cell[924283, 37705, 212, 8, 23, "Text",
   CellTags->"FunctionalD"],
  Cell[924520, 37717, 315, 11, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[924838, 37730, 2734, 119, 43, "Output",
   CellTags->"FunctionalD"],
  Cell[927609, 37854, 647, 20, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[928259, 37876, 1310, 60, 31, "Output",
   CellTags->"FunctionalD"],
  Cell[929606, 37941, 154, 4, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[929763, 37947, 5227, 228, 31, "Output",
   CellTags->"FunctionalD"],
  Cell[935005, 38178, 131, 4, 23, "Text",
   CellTags->"FunctionalD"],
  Cell[935161, 38186, 79, 2, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[935243, 38190, 1159, 50, 29, "Output",
   CellTags->"FunctionalD"],
  Cell[936439, 38245, 798, 21, 48, "Input",
   CellTags->"FunctionalD"],
  Cell[937240, 38268, 1064, 41, 33, "Output",
   CellTags->"FunctionalD"],
  Cell[938341, 38314, 137, 4, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[938481, 38320, 4174, 167, 33, "Output",
   CellTags->"FunctionalD"],
  Cell[942692, 38492, 204, 6, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[942899, 38500, 6098, 267, 31, "Output",
   CellTags->"FunctionalD"],
  Cell[949034, 38772, 138, 4, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[949175, 38778, 11189, 491, 55, "Output",
   CellTags->"FunctionalD"],
  Cell[960401, 39274, 163, 5, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[960567, 39281, 10243, 451, 55, "Output",
   CellTags->"FunctionalD"],
  Cell[970825, 39735, 66, 1, 23, "Text",
   CellTags->"FunctionalD"],
  Cell[970894, 39738, 539, 13, 48, "Input",
   CellTags->"FunctionalD"],
  Cell[971470, 39756, 110, 2, 32, "Subsubsection",
   CellTags->"FunctionalD"],
  Cell[971583, 39760, 79, 1, 23, "Text",
   CellTags->"FunctionalD"],
  Cell[974137, 39857, 765, 22, 48, "Input",
   CellTags->"FunctionalD"],
  Cell[974905, 39881, 8897, 329, 90, "Output",
   CellTags->"FunctionalD"],
  Cell[983839, 40215, 165, 5, 27, "Input",
   CellTags->"FunctionalD"],
  Cell[984007, 40222, 2097, 84, 43, "Output",
   CellTags->"FunctionalD"]},
 "FV"->{
  Cell[986131, 40310, 41, 1, 39, "ObjectName",
   CellTags->"FV"],
  Cell[986197, 40315, 53, 1, 26, "Subsubsection",
   CellTags->"FV"],
  Cell[986253, 40318, 275, 13, 21, "Text",
   CellTags->"FV"],
  Cell[986531, 40333, 562, 29, 22, "Text",
   CellTags->"FV"],
  Cell[987130, 40367, 50, 1, 33, "Subsubsection",
   CellTags->"FV"],
  Cell[987205, 40372, 124, 4, 27, "Input",
   CellTags->"FV"],
  Cell[987332, 40378, 126, 4, 25, "Output",
   CellTags->"FV"],
  Cell[987495, 40387, 148, 5, 27, "Input",
   CellTags->"FV"],
  Cell[987646, 40394, 185, 7, 25, "Output",
   CellTags->"FV"],
  Cell[987868, 40406, 160, 5, 27, "Input",
   CellTags->"FV"],
  Cell[988031, 40413, 139, 4, 39, "Output",
   CellTags->"FV"],
  Cell[988207, 40422, 195, 7, 27, "Input",
   CellTags->"FV"],
  Cell[988405, 40431, 217, 6, 39, "Output",
   CellTags->"FV"],
  Cell[988637, 40440, 130, 4, 23, "Text",
   CellTags->"FV"],
  Cell[988792, 40448, 196, 6, 27, "Input",
   CellTags->"FV"],
  Cell[988991, 40456, 399, 18, 25, "Output",
   CellTags->"FV"],
  Cell[989427, 40479, 107, 3, 27, "Input",
   CellTags->"FV"],
  Cell[989537, 40484, 380, 11, 39, "Output",
   CellTags->"FV"]},
 "FVD"->{
  Cell[989944, 40499, 43, 1, 61, "ObjectName",
   CellTags->"FVD"],
  Cell[990012, 40504, 54, 1, 54, "Subsubsection",
   CellTags->"FVD"],
  Cell[990069, 40507, 312, 15, 37, "Text",
   CellTags->"FVD"],
  Cell[990384, 40524, 560, 29, 37, "Text",
   CellTags->"FVD"],
  Cell[990981, 40558, 51, 1, 33, "Subsubsection",
   CellTags->"FVD"],
  Cell[991057, 40563, 126, 4, 27, "Input",
   CellTags->"FVD"],
  Cell[991186, 40569, 127, 4, 25, "Output",
   CellTags->"FVD"],
  Cell[991350, 40578, 150, 5, 27, "Input",
   CellTags->"FVD"],
  Cell[991503, 40585, 186, 7, 25, "Output",
   CellTags->"FVD"],
  Cell[991726, 40597, 162, 5, 27, "Input",
   CellTags->"FVD"],
  Cell[991891, 40604, 141, 4, 39, "Output",
   CellTags->"FVD"],
  Cell[992069, 40613, 197, 7, 27, "Input",
   CellTags->"FVD"],
  Cell[992269, 40622, 268, 8, 39, "Output",
   CellTags->"FVD"],
  Cell[992552, 40633, 88, 1, 23, "Text",
   CellTags->"FVD"],
  Cell[992665, 40638, 198, 6, 27, "Input",
   CellTags->"FVD"],
  Cell[992866, 40646, 400, 18, 25, "Output",
   CellTags->"FVD"],
  Cell[993303, 40669, 108, 3, 27, "Input",
   CellTags->"FVD"],
  Cell[993414, 40674, 485, 15, 39, "Output",
   CellTags->"FVD"]},
 "GA"->{
  Cell[993926, 40693, 41, 1, 39, "ObjectName",
   CellTags->"GA"],
  Cell[993992, 40698, 53, 1, 33, "Subsubsection",
   CellTags->"GA"],
  Cell[994048, 40701, 654, 24, 42, "Text",
   CellTags->"GA"],
  Cell[994705, 40727, 369, 19, 23, "Text",
   CellTags->"GA"],
  Cell[995111, 40751, 50, 1, 33, "Subsubsection",
   CellTags->"GA"],
  Cell[995186, 40756, 101, 3, 27, "Input",
   CellTags->"GA"],
  Cell[995290, 40761, 133, 4, 25, "Output",
   CellTags->"GA"],
  Cell[995460, 40770, 213, 7, 27, "Input",
   CellTags->"GA"],
  Cell[995676, 40779, 317, 10, 25, "Output",
   CellTags->"GA"],
  Cell[996030, 40794, 171, 5, 27, "Input",
   CellTags->"GA"],
  Cell[996204, 40801, 163, 4, 39, "Output",
   CellTags->"GA"],
  Cell[996404, 40810, 163, 5, 27, "Input",
   CellTags->"GA"],
  Cell[996570, 40817, 289, 8, 25, "Output",
   CellTags->"GA"],
  Cell[996896, 40830, 203, 6, 27, "Input",
   CellTags->"GA"],
  Cell[997102, 40838, 262, 7, 39, "Output",
   CellTags->"GA"],
  Cell[997401, 40850, 250, 8, 27, "Input",
   CellTags->"GA"],
  Cell[997654, 40860, 301, 9, 25, "Output",
   CellTags->"GA"]},
 "GAD"->{
  Cell[997982, 40873, 43, 1, 39, "ObjectName",
   CellTags->"GAD"],
  Cell[998050, 40878, 54, 1, 33, "Subsubsection",
   CellTags->"GAD"],
  Cell[998107, 40881, 671, 24, 42, "Text",
   CellTags->"GAD"],
  Cell[998781, 40907, 367, 19, 23, "Text",
   CellTags->"GAD"],
  Cell[999185, 40931, 51, 1, 33, "Subsubsection",
   CellTags->"GAD"],
  Cell[999261, 40936, 103, 3, 27, "Input",
   CellTags->"GAD"],
  Cell[999367, 40941, 134, 4, 25, "Output",
   CellTags->"GAD"],
  Cell[999538, 40950, 216, 7, 27, "Input",
   CellTags->"GAD"],
  Cell[999757, 40959, 318, 10, 25, "Output",
   CellTags->"GAD"],
  Cell[1000112, 40974, 173, 5, 27, "Input",
   CellTags->"GAD"],
  Cell[1000288, 40981, 213, 6, 39, "Output",
   CellTags->"GAD"],
  Cell[1000538, 40992, 165, 5, 27, "Input",
   CellTags->"GAD"],
  Cell[1000706, 40999, 290, 8, 25, "Output",
   CellTags->"GAD"],
  Cell[1001033, 41012, 205, 6, 27, "Input",
   CellTags->"GAD"],
  Cell[1001241, 41020, 267, 7, 39, "Output",
   CellTags->"GAD"],
  Cell[1001545, 41032, 254, 8, 27, "Input",
   CellTags->"GAD"],
  Cell[1001802, 41042, 302, 9, 25, "Output",
   CellTags->"GAD"]},
 "GammaEpsilon"->{
  Cell[1002131, 41055, 61, 1, 39, "ObjectName",
   CellTags->"GammaEpsilon"],
  Cell[1002217, 41060, 63, 1, 33, "Subsubsection",
   CellTags->"GammaEpsilon"],
  Cell[1002283, 41063, 167, 4, 23, "Text",
   CellTags->"GammaEpsilon"],
  Cell[1002453, 41069, 299, 14, 23, "Text",
   CellTags->"GammaEpsilon"],
  Cell[1002789, 41088, 60, 1, 33, "Subsubsection",
   CellTags->"GammaEpsilon"],
  Cell[1002852, 41091, 141, 4, 23, "Text",
   CellTags->"GammaEpsilon"],
  Cell[1003018, 41099, 170, 5, 27, "Input",
   CellTags->"GammaEpsilon"],
  Cell[1003191, 41106, 1361, 48, 52, "Output",
   CellTags->"GammaEpsilon"],
  Cell[1004589, 41159, 170, 5, 27, "Input",
   CellTags->"GammaEpsilon"],
  Cell[1004762, 41166, 1109, 41, 52, "Output",
   CellTags->"GammaEpsilon"],
  Cell[1005886, 41210, 91, 1, 23, "Text",
   CellTags->"GammaEpsilon"],
  Cell[1006002, 41215, 123, 3, 27, "Input",
   CellTags->"GammaEpsilon"],
  Cell[1006128, 41220, 2148, 77, 96, "Output",
   CellTags->"GammaEpsilon"],
  Cell[1008313, 41302, 117, 3, 27, "Input",
   CellTags->"GammaEpsilon"],
  Cell[1008433, 41307, 138, 5, 25, "Output",
   CellTags->"GammaEpsilon"]},
 "GammaExpand"->{
  Cell[1008598, 41316, 59, 1, 39, "ObjectName",
   CellTags->"GammaExpand"],
  Cell[1008682, 41321, 62, 1, 33, "Subsubsection",
   CellTags->"GammaExpand"],
  Cell[1008747, 41324, 123, 3, 23, "Text",
   CellTags->"GammaExpand"],
  Cell[1008873, 41329, 194, 9, 23, "Text",
   CellTags->"GammaExpand"],
  Cell[1009104, 41343, 59, 1, 33, "Subsubsection",
   CellTags->"GammaExpand"],
  Cell[1009188, 41348, 187, 5, 27, "Input",
   CellTags->"GammaExpand"],
  Cell[1009378, 41355, 329, 11, 25, "Output",
   CellTags->"GammaExpand"],
  Cell[1009744, 41371, 197, 6, 27, "Input",
   CellTags->"GammaExpand"],
  Cell[1009944, 41379, 632, 22, 45, "Output",
   CellTags->"GammaExpand"],
  Cell[1010613, 41406, 187, 5, 27, "Input",
   CellTags->"GammaExpand"],
  Cell[1010803, 41413, 203, 6, 25, "Output",
   CellTags->"GammaExpand"]},
 "Gamma1"->{
  Cell[1011033, 41423, 49, 1, 39, "ObjectName",
   CellTags->"Gamma1"],
  Cell[1011107, 41428, 57, 1, 33, "Subsubsection",
   CellTags->"Gamma1"],
  Cell[1011167, 41431, 139, 4, 23, "Text",
   CellTags->"Gamma1"],
  Cell[1011309, 41437, 275, 14, 23, "Text",
   CellTags->"Gamma1"]},
 "Gamma2"->{
  Cell[1011599, 41454, 49, 1, 39, "ObjectName",
   CellTags->"Gamma2"],
  Cell[1011673, 41459, 57, 1, 33, "Subsubsection",
   CellTags->"Gamma2"],
  Cell[1011733, 41462, 172, 4, 23, "Text",
   CellTags->"Gamma2"],
  Cell[1011908, 41468, 275, 14, 23, "Text",
   CellTags->"Gamma2"]},
 "Gamma3"->{
  Cell[1012198, 41485, 49, 1, 39, "ObjectName",
   CellTags->"Gamma3"],
  Cell[1012272, 41490, 57, 1, 33, "Subsubsection",
   CellTags->"Gamma3"],
  Cell[1012332, 41493, 237, 5, 39, "Text",
   CellTags->"Gamma3"],
  Cell[1012572, 41500, 275, 14, 23, "Text",
   CellTags->"Gamma3"]},
 "Gauge"->{
  Cell[1012862, 41517, 47, 1, 39, "ObjectName",
   CellTags->"Gauge"],
  Cell[1012934, 41522, 56, 1, 33, "Subsubsection",
   CellTags->"Gauge"],
  Cell[1012993, 41525, 133, 4, 23, "Text",
   CellTags->"Gauge"],
  Cell[1013129, 41531, 301, 14, 23, "Text",
   CellTags->"Gauge"]},
 "GaugeField"->{
  Cell[1013445, 41548, 57, 1, 39, "ObjectName",
   CellTags->"GaugeField"],
  Cell[1013527, 41553, 61, 1, 33, "Subsubsection",
   CellTags->"GaugeField"],
  Cell[1013591, 41556, 212, 5, 39, "Text",
   CellTags->"GaugeField"],
  Cell[1013806, 41563, 318, 14, 23, "Text",
   CellTags->"GaugeField"],
  Cell[1014161, 41582, 58, 1, 33, "Subsubsection",
   CellTags->"GaugeField"],
  Cell[1014244, 41587, 86, 2, 27, "Input",
   CellTags->"GaugeField"],
  Cell[1014333, 41591, 106, 3, 25, "Output",
   CellTags->"GaugeField"],
  Cell[1014476, 41599, 237, 6, 27, "Input",
   CellTags->"GaugeField"],
  Cell[1014716, 41607, 316, 14, 29, "Output",
   CellTags->"GaugeField"]},
 "GaugeXi"->{
  Cell[1015059, 41625, 51, 1, 39, "ObjectName",
   CellTags->"GaugeXi"],
  Cell[1015135, 41630, 58, 1, 33, "Subsubsection",
   CellTags->"GaugeXi"],
  Cell[1015196, 41633, 77, 1, 23, "Text",
   CellTags->"GaugeXi"],
  Cell[1015276, 41636, 285, 14, 23, "Text",
   CellTags->"GaugeXi"]},
 "GA5"->{
  Cell[1015576, 41653, 43, 1, 39, "ObjectName",
   CellTags->"GA5"],
  Cell[1015644, 41658, 54, 1, 33, "Subsubsection",
   CellTags->"GA5"],
  Cell[1015701, 41661, 88, 1, 23, "Text",
   CellTags->"GA5"],
  Cell[1015792, 41664, 364, 19, 23, "Text",
   CellTags->"GA5"],
  Cell[1016193, 41688, 51, 1, 33, "Subsubsection",
   CellTags->"GA5"],
  Cell[1016269, 41693, 72, 2, 27, "Input",
   CellTags->"GA5"],
  Cell[1016344, 41697, 130, 4, 27, "Output",
   CellTags->"GA5"],
  Cell[1016511, 41706, 94, 3, 27, "Input",
   CellTags->"GA5"],
  Cell[1016608, 41711, 99, 3, 25, "Output",
   CellTags->"GA5"]},
 "GGV"->{
  Cell[1016734, 41718, 43, 1, 39, "ObjectName",
   CellTags->"GGV"],
  Cell[1016802, 41723, 54, 1, 33, "Subsubsection",
   CellTags->"GGV"],
  Cell[1016859, 41726, 72, 1, 23, "Text",
   CellTags->"GGV"],
  Cell[1016934, 41729, 198, 9, 23, "Text",
   CellTags->"GGV"]},
 "GhostPropagator"->{
  Cell[1017147, 41741, 67, 1, 39, "ObjectName",
   CellTags->"GhostPropagator"],
  Cell[1017239, 41746, 66, 1, 33, "Subsubsection",
   CellTags->"GhostPropagator"],
  Cell[1017308, 41749, 324, 9, 23, "Text",
   CellTags->"GhostPropagator"],
  Cell[1017635, 41760, 436, 19, 23, "Text",
   CellTags->"GhostPropagator"],
  Cell[1018395, 41798, 63, 1, 33, "Subsubsection",
   CellTags->"GhostPropagator"],
  Cell[1018483, 41803, 156, 4, 27, "Input",
   CellTags->"GhostPropagator"],
  Cell[1018642, 41809, 193, 6, 27, "Output",
   CellTags->"GhostPropagator"],
  Cell[1018872, 41820, 206, 5, 27, "Input",
   CellTags->"GhostPropagator"],
  Cell[1019081, 41827, 409, 16, 46, "Output",
   CellTags->"GhostPropagator"],
  Cell[1019527, 41848, 123, 3, 27, "Input",
   CellTags->"GhostPropagator"],
  Cell[1019653, 41853, 176, 6, 25, "Output",
   CellTags->"GhostPropagator"],
  Cell[1019866, 41864, 188, 5, 27, "Input",
   CellTags->"GhostPropagator"],
  Cell[1020057, 41871, 413, 16, 46, "Output",
   CellTags->"GhostPropagator"],
  Cell[1020507, 41892, 285, 9, 27, "Input",
   CellTags->"GhostPropagator"],
  Cell[1020795, 41903, 228, 6, 39, "Output",
   CellTags->"GhostPropagator"]},
 "GHP"->{
  Cell[1021050, 41913, 43, 1, 39, "ObjectName",
   CellTags->"GHP"],
  Cell[1021118, 41918, 54, 1, 33, "Subsubsection",
   CellTags->"GHP"],
  Cell[1021175, 41921, 288, 9, 23, "Text",
   CellTags->"GHP"],
  Cell[1021466, 41932, 460, 19, 23, "Text",
   CellTags->"GHP"],
  Cell[1021963, 41956, 51, 1, 33, "Subsubsection",
   CellTags->"GHP"],
  Cell[1022039, 41961, 132, 4, 27, "Input",
   CellTags->"GHP"],
  Cell[1022174, 41967, 181, 6, 27, "Output",
   CellTags->"GHP"],
  Cell[1022392, 41978, 130, 4, 27, "Input",
   CellTags->"GHP"],
  Cell[1022525, 41984, 157, 5, 47, "Output",
   CellTags->"GHP"],
  Cell[1022719, 41994, 132, 4, 27, "Input",
   CellTags->"GHP"],
  Cell[1022854, 42000, 185, 6, 27, "Output",
   CellTags->"GHP"],
  Cell[1023076, 42011, 264, 9, 27, "Input",
   CellTags->"GHP"],
  Cell[1023343, 42022, 216, 6, 39, "Output",
   CellTags->"GHP"]},
 "GluonField"->{
  Cell[1023586, 42032, 57, 1, 39, "ObjectName",
   CellTags->"GluonField"],
  Cell[1023668, 42037, 61, 1, 33, "Subsubsection",
   CellTags->"GluonField"],
  Cell[1023732, 42040, 79, 1, 23, "Text",
   CellTags->"GluonField"],
  Cell[1023814, 42043, 187, 9, 23, "Text",
   CellTags->"GluonField"],
  Cell[1024038, 42057, 58, 1, 33, "Subsubsection",
   CellTags->"GluonField"],
  Cell[1024121, 42062, 86, 2, 27, "Input",
   CellTags->"GluonField"],
  Cell[1024210, 42066, 106, 3, 25, "Output",
   CellTags->"GluonField"],
  Cell[1024353, 42074, 237, 6, 27, "Input",
   CellTags->"GluonField"],
  Cell[1024593, 42082, 316, 14, 29, "Output",
   CellTags->"GluonField"]},
 "GluonGhostVertex"->{
  Cell[1024936, 42100, 69, 1, 39, "ObjectName",
   CellTags->"GluonGhostVertex"],
  Cell[1025030, 42105, 67, 1, 33, "Subsubsection",
   CellTags->"GluonGhostVertex"],
  Cell[1025100, 42108, 422, 7, 55, "Text",
   CellTags->"GluonGhostVertex"],
  Cell[1025525, 42117, 583, 23, 23, "Text",
   CellTags->"GluonGhostVertex"],
  Cell[1026133, 42144, 131, 3, 27, "Input",
   CellTags->"GluonGhostVertex"],
  Cell[1026267, 42149, 324, 10, 25, "Output",
   CellTags->"GluonGhostVertex"],
  Cell[1026640, 42165, 64, 1, 33, "Subsubsection",
   CellTags->"GluonGhostVertex"],
  Cell[1026729, 42170, 348, 10, 27, "Input",
   CellTags->"GluonGhostVertex"],
  Cell[1027080, 42182, 517, 21, 29, "Output",
   CellTags->"GluonGhostVertex"],
  Cell[1029092, 42280, 148, 4, 27, "Input",
   CellTags->"GluonGhostVertex"],
  Cell[1029243, 42286, 333, 10, 39, "Output",
   CellTags->"GluonGhostVertex"],
  Cell[1029613, 42301, 191, 5, 27, "Input",
   CellTags->"GluonGhostVertex"],
  Cell[1029807, 42308, 521, 21, 31, "Output",
   CellTags->"GluonGhostVertex"]},
 "GluonPropagator"->{
  Cell[1030355, 42333, 67, 1, 39, "ObjectName",
   CellTags->"GluonPropagator"],
  Cell[1030447, 42338, 66, 1, 33, "Subsubsection",
   CellTags->"GluonPropagator"],
  Cell[1030516, 42341, 535, 10, 55, "Text",
   CellTags->"GluonPropagator"],
  Cell[1031054, 42353, 99, 1, 23, "Text",
   CellTags->"GluonPropagator"],
  Cell[1031178, 42358, 83, 2, 27, "Input",
   CellTags->"GluonPropagator"],
  Cell[1031264, 42362, 125, 3, 25, "Output",
   CellTags->"GluonPropagator"],
  Cell[1031426, 42370, 129, 3, 27, "Input",
   CellTags->"GluonPropagator"],
  Cell[1031558, 42375, 482, 13, 25, "Output",
   CellTags->"GluonPropagator"],
  Cell[1032055, 42391, 591, 24, 23, "Text",
   CellTags->"GluonPropagator"],
  Cell[1032683, 42420, 72, 1, 34, "Subsubsection",
   CellTags->"GluonPropagator"],
  Cell[1032780, 42425, 187, 5, 27, "Input",
   CellTags->"GluonPropagator"],
  Cell[1032970, 42432, 233, 8, 28, "Output",
   CellTags->"GluonPropagator"],
  Cell[1033946, 42475, 271, 7, 27, "Input",
   CellTags->"GluonPropagator"],
  Cell[1034220, 42484, 1035, 39, 56, "Output",
   CellTags->"GluonPropagator"],
  Cell[1035292, 42528, 357, 10, 27, "Input",
   CellTags->"GluonPropagator"],
  Cell[1035652, 42540, 2748, 104, 57, "Output",
   CellTags->"GluonPropagator"],
  Cell[1038437, 42649, 199, 6, 27, "Input",
   CellTags->"GluonPropagator"],
  Cell[1038639, 42657, 271, 9, 49, "Output",
   CellTags->"GluonPropagator"],
  Cell[1038925, 42669, 149, 4, 23, "Text",
   CellTags->"GluonPropagator"],
  Cell[1039099, 42677, 242, 7, 27, "Input",
   CellTags->"GluonPropagator"],
  Cell[1039344, 42686, 1028, 39, 57, "Output",
   CellTags->"GluonPropagator"],
  Cell[1040409, 42730, 267, 9, 27, "Input",
   CellTags->"GluonPropagator"],
  Cell[1040679, 42741, 314, 9, 39, "Output",
   CellTags->"GluonPropagator"],
  Cell[1041030, 42755, 275, 7, 27, "Input",
   CellTags->"GluonPropagator"],
  Cell[1041308, 42764, 1274, 46, 52, "Output",
   CellTags->"GluonPropagator"],
  Cell[1042619, 42815, 275, 7, 27, "Input",
   CellTags->"GluonPropagator"],
  Cell[1042897, 42824, 1288, 47, 51, "Output",
   CellTags->"GluonPropagator"],
  Cell[1044222, 42876, 275, 7, 27, "Input",
   CellTags->"GluonPropagator"],
  Cell[1044500, 42885, 1282, 46, 52, "Output",
   CellTags->"GluonPropagator"],
  Cell[1045819, 42936, 275, 7, 27, "Input",
   CellTags->"GluonPropagator"],
  Cell[1046097, 42945, 1274, 46, 52, "Output",
   CellTags->"GluonPropagator"],
  Cell[1047408, 42996, 275, 7, 27, "Input",
   CellTags->"GluonPropagator"],
  Cell[1047686, 43005, 2422, 88, 52, "Output",
   CellTags->"GluonPropagator"]},
 "GluonSelfEnergy"->{
  Cell[1050135, 43097, 67, 1, 39, "ObjectName",
   CellTags->"GluonSelfEnergy"],
  Cell[1050227, 43102, 66, 1, 33, "Subsubsection",
   CellTags->"GluonSelfEnergy"],
  Cell[1050296, 43105, 122, 3, 23, "Text",
   CellTags->"GluonSelfEnergy"],
  Cell[1050443, 43112, 129, 3, 27, "Input",
   CellTags->"GluonSelfEnergy"],
  Cell[1050575, 43117, 794, 23, 29, "Output",
   CellTags->"GluonSelfEnergy"],
  Cell[1051384, 43143, 591, 24, 23, "Text",
   CellTags->"GluonSelfEnergy"],
  Cell[1052012, 43172, 72, 1, 34, "Subsubsection",
   CellTags->"GluonSelfEnergy"],
  Cell[1052109, 43177, 252, 8, 27, "Input",
   CellTags->"GluonSelfEnergy"],
  Cell[1052364, 43187, 2391, 92, 44, "Output",
   CellTags->"GluonSelfEnergy"],
  Cell[1054792, 43284, 300, 9, 27, "Input",
   CellTags->"GluonSelfEnergy"],
  Cell[1055095, 43295, 2734, 103, 60, "Output",
   CellTags->"GluonSelfEnergy"]},
 "GluonVertex"->{
  Cell[1057856, 43402, 59, 1, 39, "ObjectName",
   CellTags->"GluonVertex"],
  Cell[1057940, 43407, 62, 1, 33, "Subsubsection",
   CellTags->"GluonVertex"],
  Cell[1058005, 43410, 88, 1, 23, "Text",
   CellTags->"GluonVertex"],
  Cell[1058096, 43413, 621, 10, 71, "Text",
   CellTags->"GluonVertex"],
  Cell[1058720, 43425, 91, 1, 23, "Text",
   CellTags->"GluonVertex"],
  Cell[1058836, 43430, 79, 2, 27, "Input",
   CellTags->"GluonVertex"],
  Cell[1058918, 43434, 117, 3, 25, "Output",
   CellTags->"GluonVertex"],
  Cell[1059072, 43442, 121, 3, 27, "Input",
   CellTags->"GluonVertex"],
  Cell[1059196, 43447, 378, 11, 25, "Output",
   CellTags->"GluonVertex"],
  Cell[1059589, 43461, 337, 14, 23, "Text",
   CellTags->"GluonVertex"],
  Cell[1059963, 43480, 59, 1, 33, "Subsubsection",
   CellTags->"GluonVertex"],
  Cell[1060047, 43485, 338, 10, 27, "Input",
   CellTags->"GluonVertex"],
  Cell[1060388, 43497, 943, 42, 27, "Output",
   CellTags->"GluonVertex"],
  Cell[1061368, 43544, 379, 12, 27, "Input",
   CellTags->"GluonVertex"],
  Cell[1061750, 43558, 1974, 79, 27, "Output",
   CellTags->"GluonVertex"],
  Cell[1063761, 43642, 308, 10, 27, "Input",
   CellTags->"GluonVertex"],
  Cell[1064072, 43654, 272, 9, 25, "Output",
   CellTags->"GluonVertex"],
  Cell[1064381, 43668, 349, 12, 27, "Input",
   CellTags->"GluonVertex"],
  Cell[1064733, 43682, 1682, 65, 27, "Output",
   CellTags->"GluonVertex"],
  Cell[1066452, 43752, 414, 12, 27, "Input",
   CellTags->"GluonVertex"],
  Cell[1066869, 43766, 352, 11, 28, "Output",
   CellTags->"GluonVertex"],
  Cell[1071182, 43933, 374, 12, 27, "Input",
   CellTags->"GluonVertex"],
  Cell[1071559, 43947, 160, 5, 27, "Output",
   CellTags->"GluonVertex"],
  Cell[1071756, 43957, 259, 7, 27, "Input",
   CellTags->"GluonVertex"],
  Cell[1072018, 43966, 3479, 132, 29, "Output",
   CellTags->"GluonVertex"],
  Cell[1075512, 44101, 200, 4, 23, "Text",
   CellTags->"GluonVertex"],
  Cell[1075737, 44109, 172, 5, 27, "Input",
   CellTags->"GluonVertex"],
  Cell[1075912, 44116, 942, 42, 29, "Output",
   CellTags->"GluonVertex"],
  Cell[1076891, 44163, 230, 7, 27, "Input",
   CellTags->"GluonVertex"],
  Cell[1077124, 44172, 3431, 132, 51, "Output",
   CellTags->"GluonVertex"]},
 "GO"->{
  Cell[1080582, 44308, 41, 1, 39, "ObjectName",
   CellTags->"GO"],
  Cell[1080648, 44313, 53, 1, 33, "Subsubsection",
   CellTags->"GO"],
  Cell[1080704, 44316, 73, 1, 23, "Text",
   CellTags->"GO"],
  Cell[1080780, 44319, 206, 9, 23, "Text",
   CellTags->"GO"]},
 "GP"->{
  Cell[1081001, 44331, 41, 1, 39, "ObjectName",
   CellTags->"GP"],
  Cell[1081067, 44336, 53, 1, 33, "Subsubsection",
   CellTags->"GP"],
  Cell[1081123, 44339, 69, 1, 23, "Text",
   CellTags->"GP"],
  Cell[1081195, 44342, 194, 9, 23, "Text",
   CellTags->"GP"]},
 "GrassmannParity"->{
  Cell[1081404, 44354, 67, 1, 39, "ObjectName",
   CellTags->"GrassmannParity"],
  Cell[1081496, 44359, 66, 1, 33, "Subsubsection",
   CellTags->"GrassmannParity"],
  Cell[1081565, 44362, 216, 5, 39, "Text",
   CellTags->"GrassmannParity"],
  Cell[1081784, 44369, 186, 9, 23, "Text",
   CellTags->"GrassmannParity"]},
 "GS"->{
  Cell[1081985, 44381, 41, 1, 39, "ObjectName",
   CellTags->"GS"],
  Cell[1082051, 44386, 53, 1, 33, "Subsubsection",
   CellTags->"GS"],
  Cell[1082107, 44389, 635, 18, 42, "Text",
   CellTags->"GS"],
  Cell[1082745, 44409, 482, 24, 23, "Text",
   CellTags->"GS"],
  Cell[1083264, 44438, 50, 1, 33, "Subsubsection",
   CellTags->"GS"],
  Cell[1083339, 44443, 97, 3, 27, "Input",
   CellTags->"GS"],
  Cell[1083439, 44448, 139, 4, 25, "Output",
   CellTags->"GS"],
  Cell[1083615, 44457, 162, 6, 27, "Input",
   CellTags->"GS"],
  Cell[1083780, 44465, 155, 4, 39, "Output",
   CellTags->"GS"],
  Cell[1083972, 44474, 140, 4, 27, "Input",
   CellTags->"GS"],
  Cell[1084115, 44480, 412, 13, 25, "Output",
   CellTags->"GS"],
  Cell[1084564, 44498, 179, 6, 27, "Input",
   CellTags->"GS"],
  Cell[1084746, 44506, 242, 7, 39, "Output",
   CellTags->"GS"],
  Cell[1085025, 44518, 237, 8, 27, "Input",
   CellTags->"GS"],
  Cell[1085265, 44528, 361, 12, 25, "Output",
   CellTags->"GS"]},
 "GSD"->{
  Cell[1085653, 44544, 43, 1, 39, "ObjectName",
   CellTags->"GSD"],
  Cell[1085721, 44549, 54, 1, 33, "Subsubsection",
   CellTags->"GSD"],
  Cell[1085778, 44552, 644, 18, 42, "Text",
   CellTags->"GSD"],
  Cell[1086425, 44572, 483, 24, 23, "Text",
   CellTags->"GSD"],
  Cell[1086945, 44601, 51, 1, 33, "Subsubsection",
   CellTags->"GSD"],
  Cell[1087021, 44606, 99, 3, 27, "Input",
   CellTags->"GSD"],
  Cell[1087123, 44611, 140, 4, 25, "Output",
   CellTags->"GSD"],
  Cell[1087300, 44620, 164, 6, 27, "Input",
   CellTags->"GSD"],
  Cell[1087467, 44628, 205, 6, 39, "Output",
   CellTags->"GSD"],
  Cell[1087709, 44639, 142, 4, 27, "Input",
   CellTags->"GSD"],
  Cell[1087854, 44645, 413, 13, 25, "Output",
   CellTags->"GSD"],
  Cell[1088304, 44663, 181, 6, 27, "Input",
   CellTags->"GSD"],
  Cell[1088488, 44671, 247, 7, 39, "Output",
   CellTags->"GSD"],
  Cell[1088772, 44683, 241, 8, 27, "Input",
   CellTags->"GSD"],
  Cell[1089016, 44693, 362, 12, 25, "Output",
   CellTags->"GSD"]},
 "Gstrong"->{
  Cell[1089405, 44709, 51, 1, 39, "ObjectName",
   CellTags->"Gstrong"],
  Cell[1089481, 44714, 58, 1, 33, "Subsubsection",
   CellTags->"Gstrong"],
  Cell[1089542, 44717, 83, 1, 23, "Text",
   CellTags->"Gstrong"],
  Cell[1089628, 44720, 334, 15, 23, "Text",
   CellTags->"Gstrong"],
  Cell[1089999, 44740, 55, 1, 33, "Subsubsection",
   CellTags->"Gstrong"],
  Cell[1090057, 44743, 119, 3, 23, "Text",
   CellTags->"Gstrong"],
  Cell[1090201, 44750, 80, 2, 27, "Input",
   CellTags->"Gstrong"],
  Cell[1090284, 44754, 125, 4, 25, "Output",
   CellTags->"Gstrong"]},
 "GTI"->{
  Cell[1090436, 44762, 43, 1, 39, "ObjectName",
   CellTags->"GTI"],
  Cell[1090504, 44767, 54, 1, 33, "Subsubsection",
   CellTags->"GTI"],
  Cell[1090561, 44770, 85, 1, 23, "Text",
   CellTags->"GTI"],
  Cell[1090649, 44773, 159, 9, 23, "Text",
   CellTags->"GTI"]},
 "GV"->{
  Cell[1090823, 44785, 41, 1, 39, "ObjectName",
   CellTags->"GV"],
  Cell[1090889, 44790, 53, 1, 33, "Subsubsection",
   CellTags->"GV"],
  Cell[1090945, 44793, 65, 1, 23, "Text",
   CellTags->"GV"],
  Cell[1091013, 44796, 182, 9, 23, "Text",
   CellTags->"GV"]},
 "Hill"->{
  Cell[1091210, 44808, 45, 1, 39, "ObjectName",
   CellTags->"Hill"],
  Cell[1091280, 44813, 55, 1, 33, "Subsubsection",
   CellTags->"Hill"],
  Cell[1091338, 44816, 129, 4, 23, "Text",
   CellTags->"Hill"],
  Cell[1091470, 44822, 196, 9, 23, "Text",
   CellTags->"Hill"],
  Cell[1091703, 44836, 52, 1, 33, "Subsubsection",
   CellTags->"Hill"],
  Cell[1091780, 44841, 124, 4, 27, "Input",
   CellTags->"Hill"],
  Cell[1091907, 44847, 2145, 73, 90, "Output",
   CellTags->"Hill"],
  Cell[1094089, 44925, 270, 8, 27, "Input",
   CellTags->"Hill"],
  Cell[1094362, 44935, 100, 3, 25, "Output",
   CellTags->"Hill"],
  Cell[1094499, 44943, 262, 9, 27, "Input",
   CellTags->"Hill"],
  Cell[1094764, 44954, 985, 32, 46, "Output",
   CellTags->"Hill"],
  Cell[1095786, 44991, 273, 9, 27, "Input",
   CellTags->"Hill"],
  Cell[1096062, 45002, 100, 3, 25, "Output",
   CellTags->"Hill"]},
 "HypergeometricAC"->{
  Cell[1096189, 45009, 69, 1, 39, "ObjectName",
   CellTags->"HypergeometricAC"],
  Cell[1096283, 45014, 67, 1, 33, "Subsubsection",
   CellTags->"HypergeometricAC"],
  Cell[1096353, 45017, 553, 9, 71, "Text",
   CellTags->"HypergeometricAC"],
  Cell[1096931, 45030, 131, 3, 27, "Input",
   CellTags->"HypergeometricAC"],
  Cell[1097065, 45035, 177, 6, 25, "Output",
   CellTags->"HypergeometricAC"],
  Cell[1097257, 45044, 598, 24, 23, "Text",
   CellTags->"HypergeometricAC"],
  Cell[1097892, 45073, 64, 1, 33, "Subsubsection",
   CellTags->"HypergeometricAC"],
  Cell[1097959, 45076, 101, 1, 23, "Text",
   CellTags->"HypergeometricAC"],
  Cell[1098085, 45081, 264, 7, 27, "Input",
   CellTags->"HypergeometricAC"],
  Cell[1098352, 45090, 1411, 43, 47, "Output",
   CellTags->"HypergeometricAC"],
  Cell[1099800, 45138, 264, 7, 27, "Input",
   CellTags->"HypergeometricAC"],
  Cell[1100067, 45147, 1375, 43, 53, "Output",
   CellTags->"HypergeometricAC"],
  Cell[1101479, 45195, 264, 7, 27, "Input",
   CellTags->"HypergeometricAC"],
  Cell[1101746, 45204, 1416, 44, 53, "Output",
   CellTags->"HypergeometricAC"],
  Cell[1103199, 45253, 264, 7, 27, "Input",
   CellTags->"HypergeometricAC"],
  Cell[1103466, 45262, 1695, 51, 104, "Output",
   CellTags->"HypergeometricAC"],
  Cell[1105198, 45318, 264, 7, 27, "Input",
   CellTags->"HypergeometricAC"],
  Cell[1105465, 45327, 415, 13, 40, "Output",
   CellTags->"HypergeometricAC"],
  Cell[1105917, 45345, 265, 7, 27, "Input",
   CellTags->"HypergeometricAC"],
  Cell[1106185, 45354, 416, 13, 40, "Output",
   CellTags->"HypergeometricAC"]},
 "HypergeometricIR"->{
  Cell[1106628, 45371, 69, 1, 39, "ObjectName",
   CellTags->"HypergeometricIR"],
  Cell[1106722, 45376, 67, 1, 33, "Subsubsection",
   CellTags->"HypergeometricIR"],
  Cell[1106792, 45379, 269, 5, 39, "Text",
   CellTags->"HypergeometricIR"],
  Cell[1107064, 45386, 479, 19, 23, "Text",
   CellTags->"HypergeometricIR"],
  Cell[1107568, 45409, 131, 3, 27, "Input",
   CellTags->"HypergeometricIR"],
  Cell[1107702, 45414, 182, 6, 25, "Output",
   CellTags->"HypergeometricIR"],
  Cell[1107933, 45426, 64, 1, 33, "Subsubsection",
   CellTags->"HypergeometricIR"],
  Cell[1108022, 45431, 241, 7, 27, "Input",
   CellTags->"HypergeometricIR"],
  Cell[1108266, 45440, 640, 24, 48, "Output",
   CellTags->"HypergeometricIR"],
  Cell[1108943, 45469, 394, 14, 27, "Input",
   CellTags->"HypergeometricIR"],
  Cell[1109340, 45485, 488, 15, 45, "Output",
   CellTags->"HypergeometricIR"],
  Cell[1109865, 45505, 148, 4, 27, "Input",
   CellTags->"HypergeometricIR"],
  Cell[1110016, 45511, 352, 13, 27, "Output",
   CellTags->"HypergeometricIR"]},
 "HypergeometricSE"->{
  Cell[1110395, 45528, 69, 1, 39, "ObjectName",
   CellTags->"HypergeometricSE"],
  Cell[1110489, 45533, 67, 1, 33, "Subsubsection",
   CellTags->"HypergeometricSE"],
  Cell[1110559, 45536, 420, 13, 39, "Text",
   CellTags->"HypergeometricSE"],
  Cell[1111004, 45553, 131, 3, 27, "Input",
   CellTags->"HypergeometricSE"],
  Cell[1111138, 45558, 186, 6, 25, "Output",
   CellTags->"HypergeometricSE"],
  Cell[1111339, 45567, 211, 9, 23, "Text",
   CellTags->"HypergeometricSE"],
  Cell[1111587, 45581, 64, 1, 33, "Subsubsection",
   CellTags->"HypergeometricSE"],
  Cell[1111676, 45586, 245, 7, 27, "Input",
   CellTags->"HypergeometricSE"],
  Cell[1111924, 45595, 585, 21, 46, "Output",
   CellTags->"HypergeometricSE"],
  Cell[1112546, 45621, 351, 11, 27, "Input",
   CellTags->"HypergeometricSE"],
  Cell[1112900, 45634, 809, 29, 46, "Output",
   CellTags->"HypergeometricSE"]},
 "HypExplicit"->{
  Cell[1113736, 45667, 59, 1, 39, "ObjectName",
   CellTags->"HypExplicit"],
  Cell[1113820, 45672, 62, 1, 33, "Subsubsection",
   CellTags->"HypExplicit"],
  Cell[1113885, 45675, 325, 10, 39, "Text",
   CellTags->"HypExplicit"],
  Cell[1114213, 45687, 206, 9, 37, "Text",
   CellTags->"HypExplicit"],
  Cell[1114456, 45701, 59, 1, 33, "Subsubsection",
   CellTags->"HypExplicit"],
  Cell[1114540, 45706, 164, 4, 27, "Input",
   CellTags->"HypExplicit"],
  Cell[1114707, 45712, 161, 5, 25, "Output",
   CellTags->"HypExplicit"],
  Cell[1114905, 45722, 142, 4, 27, "Input",
   CellTags->"HypExplicit"],
  Cell[1115050, 45728, 580, 21, 46, "Output",
   CellTags->"HypExplicit"],
  Cell[1115667, 45754, 262, 8, 27, "Input",
   CellTags->"HypExplicit"],
  Cell[1115932, 45764, 1495, 55, 25, "Output",
   CellTags->"HypExplicit"],
  Cell[1117464, 45824, 142, 4, 27, "Input",
   CellTags->"HypExplicit"],
  Cell[1117609, 45830, 804, 29, 46, "Output",
   CellTags->"HypExplicit"]},
 "HypInt"->{
  Cell[1118440, 45863, 49, 1, 61, "ObjectName",
   CellTags->"HypInt"],
  Cell[1118514, 45868, 57, 1, 54, "Subsubsection",
   CellTags->"HypInt"],
  Cell[1118574, 45871, 206, 5, 36, "Text",
   CellTags->"HypInt"],
  Cell[1118817, 45881, 54, 1, 33, "Subsubsection",
   CellTags->"HypInt"],
  Cell[1118896, 45886, 159, 4, 27, "Input",
   CellTags->"HypInt"],
  Cell[1119058, 45892, 156, 5, 25, "Output",
   CellTags->"HypInt"],
  Cell[1119251, 45902, 128, 4, 27, "Input",
   CellTags->"HypInt"],
  Cell[1119382, 45908, 945, 36, 52, "Output",
   CellTags->"HypInt"]},
 "IFPD"->{
  Cell[1120354, 45948, 45, 1, 39, "ObjectName",
   CellTags->"IFPD"],
  Cell[1120424, 45953, 55, 1, 26, "Subsubsection",
   CellTags->"IFPD"],
  Cell[1120482, 45956, 66, 1, 21, "Text",
   CellTags->"IFPD"],
  Cell[1120551, 45959, 214, 9, 23, "Text",
   CellTags->"IFPD"]},
 "IFPDOff"->{
  Cell[1120780, 45971, 51, 1, 39, "ObjectName",
   CellTags->"IFPDOff"],
  Cell[1120856, 45976, 58, 1, 33, "Subsubsection",
   CellTags->"IFPDOff"],
  Cell[1120917, 45979, 182, 4, 23, "Text",
   CellTags->"IFPDOff"],
  Cell[1121102, 45985, 270, 14, 23, "Text",
   CellTags->"IFPDOff"],
  Cell[1121409, 46004, 55, 1, 33, "Subsubsection",
   CellTags->"IFPDOff"],
  Cell[1121489, 46009, 163, 5, 27, "Input",
   CellTags->"IFPDOff"],
  Cell[1121655, 46016, 384, 16, 27, "Output",
   CellTags->"IFPDOff"],
  Cell[1122076, 46037, 108, 3, 27, "Input",
   CellTags->"IFPDOff"],
  Cell[1122187, 46042, 178, 5, 39, "Output",
   CellTags->"IFPDOff"],
  Cell[1122402, 46052, 130, 4, 27, "Input",
   CellTags->"IFPDOff"],
  Cell[1122535, 46058, 212, 8, 27, "Output",
   CellTags->"IFPDOff"],
  Cell[1122784, 46071, 108, 3, 27, "Input",
   CellTags->"IFPDOff"],
  Cell[1122895, 46076, 283, 9, 39, "Output",
   CellTags->"IFPDOff"]},
 "IFPDOn"->{
  Cell[1123205, 46089, 49, 1, 39, "ObjectName",
   CellTags->"IFPDOn"],
  Cell[1123279, 46094, 57, 1, 33, "Subsubsection",
   CellTags->"IFPDOn"],
  Cell[1123339, 46097, 317, 6, 39, "Text",
   CellTags->"IFPDOn"],
  Cell[1123659, 46105, 272, 14, 23, "Text",
   CellTags->"IFPDOn"]},
 "IncludePair"->{
  Cell[1123946, 46122, 59, 1, 39, "ObjectName",
   CellTags->"IncludePair"],
  Cell[1124030, 46127, 62, 1, 33, "Subsubsection",
   CellTags->"IncludePair"],
  Cell[1124095, 46130, 124, 3, 23, "Text",
   CellTags->"IncludePair"],
  Cell[1124222, 46135, 176, 9, 23, "Text",
   CellTags->"IncludePair"]},
 "IndexPosition"->{
  Cell[1124413, 46147, 63, 1, 39, "ObjectName",
   CellTags->"IndexPosition"],
  Cell[1124501, 46152, 64, 1, 33, "Subsubsection",
   CellTags->"IndexPosition"],
  Cell[1124568, 46155, 89, 1, 23, "Text",
   CellTags->"IndexPosition"],
  Cell[1124660, 46158, 199, 9, 23, "Text",
   CellTags->"IndexPosition"]},
 "Indices"->{
  Cell[1124874, 46170, 51, 1, 39, "ObjectName",
   CellTags->"Indices"],
  Cell[1124950, 46175, 58, 1, 26, "Subsubsection",
   CellTags->"Indices"],
  Cell[1125011, 46178, 203, 4, 36, "Text",
   CellTags->"Indices"],
  Cell[1125217, 46184, 193, 9, 22, "Text",
   CellTags->"Indices"]},
 "InitialFunction"->{
  Cell[1125425, 46196, 67, 1, 39, "ObjectName",
   CellTags->"InitialFunction"],
  Cell[1125517, 46201, 66, 1, 33, "Subsubsection",
   CellTags->"InitialFunction"],
  Cell[1125586, 46204, 183, 4, 23, "Text",
   CellTags->"InitialFunction"],
  Cell[1125772, 46210, 186, 9, 23, "Text",
   CellTags->"InitialFunction"]},
 "InitialSubstitutions"->{
  Cell[1125973, 46222, 77, 1, 39, "ObjectName",
   CellTags->"InitialSubstitutions"],
  Cell[1126075, 46227, 71, 1, 33, "Subsubsection",
   CellTags->"InitialSubstitutions"],
  Cell[1126149, 46230, 208, 4, 23, "Text",
   CellTags->"InitialSubstitutions"],
  Cell[1126360, 46236, 408, 19, 23, "Text",
   CellTags->"InitialSubstitutions"]},
 "InsideDiracTrace"->{
  Cell[1126783, 46258, 69, 1, 39, "ObjectName",
   CellTags->"InsideDiracTrace"],
  Cell[1126877, 46263, 67, 1, 33, "Subsubsection",
   CellTags->"InsideDiracTrace"],
  Cell[1126947, 46266, 498, 9, 55, "Text",
   CellTags->"InsideDiracTrace"],
  Cell[1127448, 46277, 318, 14, 23, "Text",
   CellTags->"InsideDiracTrace"]},
 "IntegralTable"->{
  Cell[1127781, 46294, 63, 1, 39, "ObjectName",
   CellTags->"IntegralTable"],
  Cell[1127869, 46299, 64, 1, 33, "Subsubsection",
   CellTags->"IntegralTable"],
  Cell[1127936, 46302, 233, 5, 39, "Text",
   CellTags->"IntegralTable"],
  Cell[1128172, 46309, 500, 19, 23, "Text",
   CellTags->"IntegralTable"]},
 "IntegrateByParts"->{
  Cell[1128687, 46331, 69, 1, 39, "ObjectName",
   CellTags->"IntegrateByParts"],
  Cell[1128781, 46336, 67, 1, 33, "Subsubsection",
   CellTags->"IntegrateByParts"],
  Cell[1128851, 46339, 184, 4, 23, "Text",
   CellTags->"IntegrateByParts"],
  Cell[1129060, 46347, 131, 3, 27, "Input",
   CellTags->"IntegrateByParts"],
  Cell[1129194, 46352, 172, 5, 25, "Output",
   CellTags->"IntegrateByParts"],
  Cell[1129415, 46363, 64, 1, 33, "Subsubsection",
   CellTags->"IntegrateByParts"],
  Cell[1129504, 46368, 539, 19, 27, "Input",
   CellTags->"IntegrateByParts"],
  Cell[1130046, 46389, 648, 23, 45, "Output",
   CellTags->"IntegrateByParts"]},
 "Integratedx"->{
  Cell[1130721, 46416, 59, 1, 39, "ObjectName",
   CellTags->"Integratedx"],
  Cell[1130805, 46421, 62, 1, 33, "Subsubsection",
   CellTags->"Integratedx"],
  Cell[1130870, 46424, 154, 4, 23, "Text",
   CellTags->"Integratedx"],
  Cell[1131027, 46430, 852, 34, 23, "Text",
   CellTags->"Integratedx"]},
 "Integrate2"->{
  Cell[1131894, 46467, 57, 1, 39, "ObjectName",
   CellTags->"Integrate2"],
  Cell[1131976, 46472, 61, 1, 33, "Subsubsection",
   CellTags->"Integrate2"],
  Cell[1132040, 46475, 866, 17, 87, "Text",
   CellTags->"Integrate2"],
  Cell[1132909, 46494, 508, 24, 23, "Text",
   CellTags->"Integrate2"],
  Cell[1133420, 46520, 405, 7, 55, "Text",
   CellTags->"Integrate2"],
  Cell[1133862, 46532, 58, 1, 33, "Subsubsection",
   CellTags->"Integrate2"],
  Cell[1133945, 46537, 425, 15, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1134373, 46554, 368, 13, 43, "Output",
   CellTags->"Integrate2"],
  Cell[1134756, 46570, 190, 6, 23, "Text",
   CellTags->"Integrate2"],
  Cell[1134971, 46580, 281, 9, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1135255, 46591, 230, 7, 25, "Output",
   CellTags->"Integrate2"],
  Cell[1135522, 46603, 276, 9, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1135801, 46614, 345, 12, 43, "Output",
   CellTags->"Integrate2"],
  Cell[1136183, 46631, 336, 11, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1136522, 46644, 575, 20, 46, "Output",
   CellTags->"Integrate2"],
  Cell[1137134, 46669, 317, 10, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1137454, 46681, 134, 4, 25, "Output",
   CellTags->"Integrate2"],
  Cell[1137603, 46688, 1589, 53, 51, "Text",
   CellTags->"Integrate2"],
  Cell[1139217, 46745, 270, 9, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1139490, 46756, 106, 3, 25, "Output",
   CellTags->"Integrate2"],
  Cell[1139611, 46762, 649, 24, 32, "Text",
   CellTags->"Integrate2"],
  Cell[1140285, 46790, 317, 10, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1140605, 46802, 106, 3, 25, "Output",
   CellTags->"Integrate2"],
  Cell[1140748, 46810, 386, 13, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1141137, 46825, 164, 5, 25, "Output",
   CellTags->"Integrate2"],
  Cell[1141338, 46835, 417, 14, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1141758, 46851, 179, 7, 43, "Output",
   CellTags->"Integrate2"],
  Cell[1141974, 46863, 328, 11, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1142305, 46876, 160, 6, 25, "Output",
   CellTags->"Integrate2"],
  Cell[1142502, 46887, 354, 12, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1142859, 46901, 309, 11, 43, "Output",
   CellTags->"Integrate2"],
  Cell[1143205, 46917, 313, 10, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1143521, 46929, 189, 6, 25, "Output",
   CellTags->"Integrate2"],
  Cell[1143747, 46940, 281, 9, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1144031, 46951, 296, 11, 43, "Output",
   CellTags->"Integrate2"],
  Cell[1144364, 46967, 445, 15, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1144812, 46984, 487, 17, 46, "Output",
   CellTags->"Integrate2"],
  Cell[1145336, 47006, 721, 24, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1146060, 47032, 4351, 147, 142, "Output",
   CellTags->"Integrate2"],
  Cell[1150448, 47184, 471, 16, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1150922, 47202, 819, 29, 45, "Output",
   CellTags->"Integrate2"],
  Cell[1151778, 47236, 567, 19, 42, "Input",
   CellTags->"Integrate2"],
  Cell[1152348, 47257, 5252, 177, 158, "Output",
   CellTags->"Integrate2"],
  Cell[1157637, 47439, 142, 4, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1157782, 47445, 1696, 53, 81, "Output",
   CellTags->"Integrate2"],
  Cell[1159515, 47503, 104, 3, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1159622, 47508, 125, 3, 25, "Output",
   CellTags->"Integrate2"],
  Cell[1160343, 47538, 684, 23, 42, "Input",
   CellTags->"Integrate2"],
  Cell[1161030, 47563, 3678, 139, 86, "Output",
   CellTags->"Integrate2"],
  Cell[1166354, 47775, 151, 4, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1166508, 47781, 109, 3, 25, "Output",
   CellTags->"Integrate2"],
  Cell[1166654, 47789, 368, 12, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1167025, 47803, 106, 3, 25, "Output",
   CellTags->"Integrate2"],
  Cell[1167146, 47809, 137, 4, 23, "Text",
   CellTags->"Integrate2"],
  Cell[1167308, 47817, 147, 4, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1167458, 47823, 5377, 174, 246, "Output",
   CellTags->"Integrate2"],
  Cell[1172872, 48002, 230, 8, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1173105, 48012, 175, 6, 25, "Output",
   CellTags->"Integrate2"],
  Cell[1173295, 48021, 165, 4, 23, "Text",
   CellTags->"Integrate2"],
  Cell[1173485, 48029, 326, 11, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1173814, 48042, 175, 6, 25, "Output",
   CellTags->"Integrate2"],
  Cell[1174004, 48051, 126, 4, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1174155, 48059, 317, 10, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1174475, 48071, 134, 4, 25, "Output",
   CellTags->"Integrate2"],
  Cell[1174646, 48080, 325, 11, 29, "Input",
   CellTags->"Integrate2"],
  Cell[1174974, 48093, 240, 8, 43, "Output",
   CellTags->"Integrate2"],
  Cell[1175251, 48106, 99, 3, 27, "Input",
   CellTags->"Integrate2"],
  Cell[1175353, 48111, 125, 3, 25, "Output",
   CellTags->"Integrate2"],
  Cell[1175515, 48119, 325, 11, 29, "Input",
   CellTags->"Integrate2"],
  Cell[1175843, 48132, 125, 3, 25, "Output",
   CellTags->"Integrate2"],
  Cell[1176005, 48140, 381, 13, 29, "Input",
   CellTags->"Integrate2"],
  Cell[1176389, 48155, 4862, 184, 150, "Output",
   CellTags->"Integrate2"]},
 "Integrate3"->{
  Cell[1182345, 48392, 57, 1, 105, "ObjectName",
   CellTags->"Integrate3"],
  Cell[1182427, 48397, 61, 1, 105, "Subsubsection",
   CellTags->"Integrate3"],
  Cell[1182491, 48400, 331, 6, 105, "Text",
   CellTags->"Integrate3"],
  Cell[1182825, 48408, 187, 9, 105, "Text",
   CellTags->"Integrate3"],
  Cell[1183049, 48422, 58, 1, 33, "Subsubsection",
   CellTags->"Integrate3"],
  Cell[1183132, 48427, 280, 9, 29, "Input",
   CellTags->"Integrate3"],
  Cell[1183415, 48438, 225, 8, 47, "Output",
   CellTags->"Integrate3"],
  Cell[1183677, 48451, 400, 13, 45, "Input",
   CellTags->"Integrate3"],
  Cell[1184080, 48466, 513, 20, 25, "Output",
   CellTags->"Integrate3"],
  Cell[1184630, 48491, 676, 23, 45, "Input",
   CellTags->"Integrate3"],
  Cell[1185309, 48516, 2035, 73, 72, "Output",
   CellTags->"Integrate3"],
  Cell[1187381, 48594, 266, 8, 27, "Input",
   CellTags->"Integrate3"],
  Cell[1187650, 48604, 106, 3, 25, "Output",
   CellTags->"Integrate3"],
  Cell[1187793, 48612, 322, 10, 27, "Input",
   CellTags->"Integrate3"],
  Cell[1188118, 48624, 195, 6, 25, "Output",
   CellTags->"Integrate3"],
  Cell[1188350, 48635, 270, 9, 27, "Input",
   CellTags->"Integrate3"],
  Cell[1188623, 48646, 106, 3, 25, "Output",
   CellTags->"Integrate3"]},
 "IntermediateSubstitutions"->{
  Cell[1188756, 48653, 87, 1, 39, "ObjectName",
   CellTags->"IntermediateSubstitutions"],
  Cell[1188868, 48658, 76, 1, 33, "Subsubsection",
   CellTags->"IntermediateSubstitutions"],
  Cell[1188947, 48661, 206, 4, 23, "Text",
   CellTags->"IntermediateSubstitutions"],
  Cell[1189156, 48667, 193, 9, 23, "Text",
   CellTags->"IntermediateSubstitutions"]},
 "InverseMellin"->{
  Cell[1189364, 48679, 63, 1, 39, "ObjectName",
   CellTags->"InverseMellin"],
  Cell[1189452, 48684, 64, 1, 33, "Subsubsection",
   CellTags->"InverseMellin"],
  Cell[1189519, 48687, 531, 14, 55, "Text",
   CellTags->"InverseMellin"],
  Cell[1190053, 48703, 609, 29, 23, "Text",
   CellTags->"InverseMellin"],
  Cell[1190699, 48737, 61, 1, 33, "Subsubsection",
   CellTags->"InverseMellin"],
  Cell[1190785, 48742, 169, 5, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1190957, 48749, 157, 5, 27, "Output",
   CellTags->"InverseMellin"],
  Cell[1191151, 48759, 220, 7, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1191374, 48768, 157, 5, 27, "Output",
   CellTags->"InverseMellin"],
  Cell[1191568, 48778, 142, 4, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1191713, 48784, 280, 10, 27, "Output",
   CellTags->"InverseMellin"],
  Cell[1192030, 48799, 194, 6, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1192227, 48807, 293, 11, 43, "Output",
   CellTags->"InverseMellin"],
  Cell[1192557, 48823, 194, 6, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1192754, 48831, 360, 13, 27, "Output",
   CellTags->"InverseMellin"],
  Cell[1193151, 48849, 204, 7, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1193358, 48858, 361, 13, 27, "Output",
   CellTags->"InverseMellin"],
  Cell[1193734, 48874, 113, 3, 23, "Text",
   CellTags->"InverseMellin"],
  Cell[1193872, 48881, 294, 9, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1194169, 48892, 131, 4, 43, "Output",
   CellTags->"InverseMellin"],
  Cell[1194315, 48899, 117, 3, 23, "Text",
   CellTags->"InverseMellin"],
  Cell[1194435, 48904, 3132, 100, 166, "Input",
   CellTags->"InverseMellin"],
  Cell[1197570, 49006, 244, 7, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1197839, 49017, 179, 6, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1198021, 49025, 398, 14, 45, "Output",
   CellTags->"InverseMellin"],
  Cell[1198456, 49044, 179, 6, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1198638, 49052, 356, 12, 45, "Output",
   CellTags->"InverseMellin"],
  Cell[1199031, 49069, 172, 5, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1199206, 49076, 726, 25, 49, "Output",
   CellTags->"InverseMellin"],
  Cell[1199947, 49104, 81, 2, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1200053, 49110, 192, 6, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1200248, 49118, 529, 20, 49, "Output",
   CellTags->"InverseMellin"],
  Cell[1200814, 49143, 270, 9, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1201087, 49154, 502, 18, 43, "Output",
   CellTags->"InverseMellin"],
  Cell[1201626, 49177, 270, 9, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1201899, 49188, 695, 25, 43, "Output",
   CellTags->"InverseMellin"],
  Cell[1202631, 49218, 267, 9, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1202901, 49229, 693, 25, 45, "Output",
   CellTags->"InverseMellin"],
  Cell[1203631, 49259, 246, 9, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1203880, 49270, 549, 20, 43, "Output",
   CellTags->"InverseMellin"],
  Cell[1204466, 49295, 274, 10, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1204743, 49307, 914, 31, 51, "Output",
   CellTags->"InverseMellin"],
  Cell[1205694, 49343, 192, 6, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1205889, 49351, 700, 25, 46, "Output",
   CellTags->"InverseMellin"],
  Cell[1206626, 49381, 221, 7, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1206850, 49390, 687, 24, 43, "Output",
   CellTags->"InverseMellin"],
  Cell[1207574, 49419, 192, 6, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1207769, 49427, 793, 29, 52, "Output",
   CellTags->"InverseMellin"],
  Cell[1208599, 49461, 202, 6, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1208804, 49469, 544, 20, 49, "Output",
   CellTags->"InverseMellin"],
  Cell[1209385, 49494, 223, 7, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1209611, 49503, 931, 33, 50, "Output",
   CellTags->"InverseMellin"],
  Cell[1210579, 49541, 223, 7, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1210805, 49550, 921, 33, 50, "Output",
   CellTags->"InverseMellin"],
  Cell[1211763, 49588, 212, 6, 27, "Input",
   CellTags->"InverseMellin"],
  Cell[1211978, 49596, 632, 23, 52, "Output",
   CellTags->"InverseMellin"],
  Cell[1212625, 49622, 158, 5, 27, "Input",
   CellTags->"InverseMellin"]},
 "Isolate"->{
  Cell[1212798, 49630, 51, 1, 39, "ObjectName",
   CellTags->"Isolate"],
  Cell[1212874, 49635, 58, 1, 33, "Subsubsection",
   CellTags->"Isolate"],
  Cell[1212935, 49638, 422, 7, 55, "Text",
   CellTags->"Isolate"],
  Cell[1213382, 49649, 114, 3, 27, "Input",
   CellTags->"Isolate"],
  Cell[1213499, 49654, 404, 12, 45, "Output",
   CellTags->"Isolate"],
  Cell[1213952, 49672, 55, 1, 33, "Subsubsection",
   CellTags->"Isolate"],
  Cell[1214032, 49677, 156, 5, 27, "Input",
   CellTags->"Isolate"],
  Cell[1214191, 49684, 160, 6, 25, "Output",
   CellTags->"Isolate"],
  Cell[1214388, 49695, 378, 13, 27, "Input",
   CellTags->"Isolate"],
  Cell[1214769, 49710, 309, 12, 25, "Output",
   CellTags->"Isolate"],
  Cell[1215115, 49727, 114, 3, 27, "Input",
   CellTags->"Isolate"],
  Cell[1215232, 49732, 286, 11, 39, "Output",
   CellTags->"Isolate"],
  Cell[1215555, 49748, 182, 5, 27, "Input",
   CellTags->"Isolate"],
  Cell[1215740, 49755, 646, 25, 25, "Output",
   CellTags->"Isolate"],
  Cell[1216423, 49785, 561, 19, 27, "Input",
   CellTags->"Isolate"],
  Cell[1216987, 49806, 359, 14, 25, "Output",
   CellTags->"Isolate"],
  Cell[1217383, 49825, 94, 3, 27, "Input",
   CellTags->"Isolate"],
  Cell[1217480, 49830, 90, 1, 40, "Print",
   CellTags->{"Info3522790362-4590919", "Isolate"}],
  Cell[1217573, 49833, 1031, 30, 51, "Print",
   CellTags->{"Info3522790362-4590919", "Isolate"}],
  Cell[1218641, 49868, 278, 7, 27, "Input",
   CellTags->"Isolate"],
  Cell[1218922, 49877, 159, 6, 25, "Output",
   CellTags->"Isolate"],
  Cell[1219118, 49888, 178, 6, 27, "Input",
   CellTags->"Isolate"],
  Cell[1219299, 49896, 211, 7, 25, "Output",
   CellTags->"Isolate"],
  Cell[1219525, 49906, 152, 4, 27, "Input",
   CellTags->"Isolate"]},
 "Info3522790362-4590919"->{
  Cell[1217480, 49830, 90, 1, 40, "Print",
   CellTags->{"Info3522790362-4590919", "Isolate"}],
  Cell[1217573, 49833, 1031, 30, 51, "Print",
   CellTags->{"Info3522790362-4590919", "Isolate"}]},
 "IsolateHead"->{
  Cell[1219692, 49913, 59, 1, 39, "ObjectName",
   CellTags->"IsolateHead"],
  Cell[1219776, 49918, 62, 1, 33, "Subsubsection",
   CellTags->"IsolateHead"],
  Cell[1219841, 49921, 84, 1, 23, "Text",
   CellTags->"IsolateHead"],
  Cell[1219928, 49924, 194, 9, 23, "Text",
   CellTags->"IsolateHead"]},
 "IsolateNames"->{
  Cell[1220137, 49936, 61, 1, 39, "ObjectName",
   CellTags->"IsolateNames"],
  Cell[1220223, 49941, 63, 1, 33, "Subsubsection",
   CellTags->"IsolateNames"],
  Cell[1220289, 49944, 220, 5, 39, "Text",
   CellTags->"IsolateNames"],
  Cell[1220512, 49951, 290, 14, 23, "Text",
   CellTags->"IsolateNames"]},
 "IsolatePrint"->{
  Cell[1220817, 49968, 61, 1, 39, "ObjectName",
   CellTags->"IsolatePrint"],
  Cell[1220903, 49973, 63, 1, 33, "Subsubsection",
   CellTags->"IsolatePrint"],
  Cell[1220969, 49976, 284, 6, 39, "Text",
   CellTags->"IsolatePrint"],
  Cell[1221256, 49984, 180, 9, 23, "Text",
   CellTags->"IsolatePrint"]},
 "IsolateSplit"->{
  Cell[1221451, 49996, 61, 1, 39, "ObjectName",
   CellTags->"IsolateSplit"],
  Cell[1221537, 50001, 63, 1, 33, "Subsubsection",
   CellTags->"IsolateSplit"],
  Cell[1221603, 50004, 413, 7, 55, "Text",
   CellTags->"IsolateSplit"],
  Cell[1222019, 50013, 180, 9, 23, "Text",
   CellTags->"IsolateSplit"]},
 "KeepOnly"->{
  Cell[1222214, 50025, 53, 1, 39, "ObjectName",
   CellTags->"KeepOnly"],
  Cell[1222292, 50030, 59, 1, 33, "Subsubsection",
   CellTags->"KeepOnly"],
  Cell[1222354, 50033, 293, 6, 39, "Text",
   CellTags->"KeepOnly"],
  Cell[1222650, 50041, 452, 24, 23, "Text",
   CellTags->"KeepOnly"]},
 "KK"->{
  Cell[1223117, 50068, 41, 1, 39, "ObjectName",
   CellTags->"KK"],
  Cell[1223183, 50073, 53, 1, 33, "Subsubsection",
   CellTags->"KK"],
  Cell[1223239, 50076, 235, 5, 39, "Text",
   CellTags->"KK"],
  Cell[1223477, 50083, 292, 14, 23, "Text",
   CellTags->"KK"]},
 "Kummer"->{
  Cell[1223784, 50100, 49, 1, 39, "ObjectName",
   CellTags->"Kummer"],
  Cell[1223858, 50105, 57, 1, 33, "Subsubsection",
   CellTags->"Kummer"],
  Cell[1223918, 50108, 260, 5, 39, "Text",
   CellTags->"Kummer"],
  Cell[1224181, 50115, 201, 9, 23, "Text",
   CellTags->"Kummer"],
  Cell[1224419, 50129, 54, 1, 33, "Subsubsection",
   CellTags->"Kummer"],
  Cell[1224498, 50134, 337, 9, 27, "Input",
   CellTags->"Kummer"],
  Cell[1224838, 50145, 452, 14, 27, "Output",
   CellTags->"Kummer"],
  Cell[1225327, 50164, 337, 9, 27, "Input",
   CellTags->"Kummer"],
  Cell[1225667, 50175, 467, 15, 40, "Output",
   CellTags->"Kummer"],
  Cell[1226171, 50195, 337, 9, 27, "Input",
   CellTags->"Kummer"],
  Cell[1226511, 50206, 467, 15, 40, "Output",
   CellTags->"Kummer"],
  Cell[1227015, 50226, 388, 11, 27, "Input",
   CellTags->"Kummer"],
  Cell[1227406, 50239, 452, 14, 27, "Output",
   CellTags->"Kummer"],
  Cell[1227895, 50258, 479, 13, 27, "Input",
   CellTags->"Kummer"],
  Cell[1228377, 50273, 531, 15, 27, "Output",
   CellTags->"Kummer"],
  Cell[1228945, 50293, 388, 11, 27, "Input",
   CellTags->"Kummer"],
  Cell[1229336, 50306, 434, 13, 43, "Output",
   CellTags->"Kummer"],
  Cell[1229807, 50324, 479, 13, 27, "Input",
   CellTags->"Kummer"],
  Cell[1230289, 50339, 548, 17, 43, "Output",
   CellTags->"Kummer"],
  Cell[1230874, 50361, 388, 11, 27, "Input",
   CellTags->"Kummer"],
  Cell[1231265, 50374, 434, 13, 43, "Output",
   CellTags->"Kummer"],
  Cell[1231736, 50392, 479, 13, 27, "Input",
   CellTags->"Kummer"],
  Cell[1232218, 50407, 548, 17, 43, "Output",
   CellTags->"Kummer"],
  Cell[1232803, 50429, 487, 15, 27, "Input",
   CellTags->"Kummer"],
  Cell[1233293, 50446, 621, 20, 43, "Output",
   CellTags->"Kummer"],
  Cell[1233951, 50471, 629, 19, 48, "Input",
   CellTags->"Kummer"],
  Cell[1234583, 50492, 722, 22, 43, "Output",
   CellTags->"Kummer"],
  Cell[1235342, 50519, 487, 15, 27, "Input",
   CellTags->"Kummer"],
  Cell[1235832, 50536, 593, 19, 44, "Output",
   CellTags->"Kummer"],
  Cell[1236462, 50560, 629, 19, 48, "Input",
   CellTags->"Kummer"],
  Cell[1237094, 50581, 707, 23, 44, "Output",
   CellTags->"Kummer"],
  Cell[1237838, 50609, 487, 15, 27, "Input",
   CellTags->"Kummer"],
  Cell[1238328, 50626, 569, 18, 43, "Output",
   CellTags->"Kummer"],
  Cell[1238934, 50649, 629, 19, 48, "Input",
   CellTags->"Kummer"],
  Cell[1239566, 50670, 750, 23, 43, "Output",
   CellTags->"Kummer"],
  Cell[1240353, 50698, 487, 15, 27, "Input",
   CellTags->"Kummer"],
  Cell[1240843, 50715, 621, 20, 43, "Output",
   CellTags->"Kummer"],
  Cell[1241501, 50740, 629, 19, 48, "Input",
   CellTags->"Kummer"],
  Cell[1242133, 50761, 745, 20, 43, "Output",
   CellTags->"Kummer"],
  Cell[1242915, 50786, 487, 15, 27, "Input",
   CellTags->"Kummer"],
  Cell[1243405, 50803, 543, 17, 43, "Output",
   CellTags->"Kummer"],
  Cell[1243985, 50825, 629, 19, 48, "Input",
   CellTags->"Kummer"],
  Cell[1244617, 50846, 789, 22, 43, "Output",
   CellTags->"Kummer"],
  Cell[1245443, 50873, 487, 15, 27, "Input",
   CellTags->"Kummer"],
  Cell[1245933, 50890, 543, 17, 43, "Output",
   CellTags->"Kummer"],
  Cell[1246513, 50912, 629, 19, 48, "Input",
   CellTags->"Kummer"],
  Cell[1247145, 50933, 680, 19, 43, "Output",
   CellTags->"Kummer"],
  Cell[1247862, 50957, 531, 15, 48, "Input",
   CellTags->"Kummer"],
  Cell[1248396, 50974, 576, 18, 27, "Output",
   CellTags->"Kummer"],
  Cell[1249009, 50997, 338, 9, 27, "Input",
   CellTags->"Kummer"],
  Cell[1249350, 51008, 452, 14, 27, "Output",
   CellTags->"Kummer"],
  Cell[1249839, 51027, 531, 15, 48, "Input",
   CellTags->"Kummer"],
  Cell[1250373, 51044, 632, 19, 40, "Output",
   CellTags->"Kummer"],
  Cell[1251042, 51068, 338, 9, 27, "Input",
   CellTags->"Kummer"],
  Cell[1251383, 51079, 441, 14, 40, "Output",
   CellTags->"Kummer"],
  Cell[1251861, 51098, 531, 15, 48, "Input",
   CellTags->"Kummer"],
  Cell[1252395, 51115, 632, 19, 40, "Output",
   CellTags->"Kummer"],
  Cell[1253064, 51139, 338, 9, 27, "Input",
   CellTags->"Kummer"],
  Cell[1253405, 51150, 441, 14, 40, "Output",
   CellTags->"Kummer"],
  Cell[1253883, 51169, 582, 17, 48, "Input",
   CellTags->"Kummer"],
  Cell[1254468, 51188, 587, 15, 27, "Output",
   CellTags->"Kummer"],
  Cell[1255092, 51208, 389, 11, 27, "Input",
   CellTags->"Kummer"],
  Cell[1255484, 51221, 452, 14, 27, "Output",
   CellTags->"Kummer"],
  Cell[1255973, 51240, 582, 17, 48, "Input",
   CellTags->"Kummer"],
  Cell[1256558, 51259, 690, 18, 43, "Output",
   CellTags->"Kummer"],
  Cell[1257285, 51282, 389, 11, 27, "Input",
   CellTags->"Kummer"],
  Cell[1257677, 51295, 492, 15, 43, "Output",
   CellTags->"Kummer"],
  Cell[1258206, 51315, 582, 17, 48, "Input",
   CellTags->"Kummer"],
  Cell[1258791, 51334, 632, 16, 43, "Output",
   CellTags->"Kummer"],
  Cell[1259460, 51355, 389, 11, 27, "Input",
   CellTags->"Kummer"],
  Cell[1259852, 51368, 434, 13, 43, "Output",
   CellTags->"Kummer"],
  Cell[1260323, 51386, 338, 9, 27, "Input",
   CellTags->"Kummer"],
  Cell[1260664, 51397, 1310, 43, 69, "Output",
   CellTags->"Kummer"],
  Cell[1262011, 51445, 338, 9, 27, "Input",
   CellTags->"Kummer"],
  Cell[1262352, 51456, 1370, 46, 53, "Output",
   CellTags->"Kummer"],
  Cell[1263759, 51507, 338, 9, 27, "Input",
   CellTags->"Kummer"],
  Cell[1264100, 51518, 1396, 46, 53, "Output",
   CellTags->"Kummer"]},
 "Lagrangian"->{
  Cell[1265523, 51568, 57, 1, 39, "ObjectName",
   CellTags->"Lagrangian"],
  Cell[1265605, 51573, 61, 1, 26, "Subsubsection",
   CellTags->"Lagrangian"],
  Cell[1265669, 51576, 454, 9, 50, "Text",
   CellTags->"Lagrangian"],
  Cell[1266126, 51587, 181, 9, 37, "Text",
   CellTags->"Lagrangian"],
  Cell[1266344, 51601, 58, 1, 33, "Subsubsection",
   CellTags->"Lagrangian"],
  Cell[1266427, 51606, 124, 3, 27, "Input",
   CellTags->"Lagrangian"],
  Cell[1266554, 51611, 332, 11, 43, "Output",
   CellTags->"Lagrangian"],
  Cell[1266901, 51625, 85, 1, 23, "Text",
   CellTags->"Lagrangian"],
  Cell[1267011, 51630, 124, 3, 27, "Input",
   CellTags->"Lagrangian"],
  Cell[1267138, 51635, 683, 23, 43, "Output",
   CellTags->"Lagrangian"],
  Cell[1267858, 51663, 124, 3, 27, "Input",
   CellTags->"Lagrangian"],
  Cell[1267985, 51668, 1006, 36, 43, "Output",
   CellTags->"Lagrangian"],
  Cell[1269028, 51709, 124, 3, 27, "Input",
   CellTags->"Lagrangian"],
  Cell[1269155, 51714, 621, 22, 27, "Output",
   CellTags->"Lagrangian"],
  Cell[1269813, 51741, 124, 3, 27, "Input",
   CellTags->"Lagrangian"],
  Cell[1269940, 51746, 664, 23, 27, "Output",
   CellTags->"Lagrangian"]},
 "LC"->{
  Cell[1270631, 51773, 41, 1, 58, "ObjectName",
   CellTags->"LC"],
  Cell[1270697, 51778, 53, 1, 39, "Subsubsection",
   CellTags->"LC"],
  Cell[1270753, 51781, 240, 5, 54, "Text",
   CellTags->"LC"],
  Cell[1270996, 51788, 274, 14, 33, "Text",
   CellTags->"LC"],
  Cell[1271307, 51807, 50, 1, 33, "Subsubsection",
   CellTags->"LC"],
  Cell[1271382, 51812, 164, 5, 27, "Input",
   CellTags->"LC"],
  Cell[1271549, 51819, 184, 6, 25, "Output",
   CellTags->"LC"],
  Cell[1271770, 51830, 95, 3, 27, "Input",
   CellTags->"LC"],
  Cell[1271868, 51835, 477, 21, 25, "Output",
   CellTags->"LC"],
  Cell[1272382, 51861, 104, 3, 27, "Input",
   CellTags->"LC"],
  Cell[1272489, 51866, 337, 8, 39, "Output",
   CellTags->"LC"],
  Cell[1272863, 51879, 181, 6, 27, "Input",
   CellTags->"LC"],
  Cell[1273047, 51887, 169, 5, 25, "Output",
   CellTags->"LC"],
  Cell[1273253, 51897, 130, 4, 27, "Input",
   CellTags->"LC"],
  Cell[1273386, 51903, 367, 10, 39, "Output",
   CellTags->"LC"],
  Cell[1273790, 51918, 381, 13, 27, "Input",
   CellTags->"LC"],
  Cell[1274174, 51933, 396, 16, 25, "Output",
   CellTags->"LC"]},
 "LCD"->{
  Cell[1274597, 51953, 43, 1, 39, "ObjectName",
   CellTags->"LCD"],
  Cell[1274665, 51958, 54, 1, 26, "Subsubsection",
   CellTags->"LCD"],
  Cell[1274722, 51961, 234, 5, 36, "Text",
   CellTags->"LCD"],
  Cell[1274959, 51968, 161, 4, 21, "Text",
   CellTags->"LCD"],
  Cell[1275123, 51974, 272, 14, 22, "Text",
   CellTags->"LCD"],
  Cell[1275432, 51993, 51, 1, 33, "Subsubsection",
   CellTags->"LCD"],
  Cell[1275486, 51996, 190, 6, 27, "Input",
   CellTags->"LCD"],
  Cell[1275701, 52006, 166, 5, 27, "Input",
   CellTags->"LCD"],
  Cell[1275870, 52013, 185, 6, 25, "Output",
   CellTags->"LCD"],
  Cell[1276092, 52024, 96, 3, 27, "Input",
   CellTags->"LCD"],
  Cell[1276191, 52029, 478, 21, 25, "Output",
   CellTags->"LCD"],
  Cell[1276706, 52055, 105, 3, 27, "Input",
   CellTags->"LCD"],
  Cell[1276814, 52060, 438, 12, 39, "Output",
   CellTags->"LCD"],
  Cell[1277289, 52077, 183, 6, 27, "Input",
   CellTags->"LCD"],
  Cell[1277475, 52085, 170, 5, 25, "Output",
   CellTags->"LCD"],
  Cell[1277682, 52095, 131, 4, 27, "Input",
   CellTags->"LCD"],
  Cell[1277816, 52101, 418, 12, 39, "Output",
   CellTags->"LCD"],
  Cell[1278271, 52118, 400, 13, 27, "Input",
   CellTags->"LCD"],
  Cell[1278674, 52133, 397, 15, 25, "Output",
   CellTags->"LCD"],
  Cell[1279108, 52153, 170, 5, 27, "Input",
   CellTags->"LCD"],
  Cell[1279281, 52160, 161, 5, 25, "Output",
   CellTags->"LCD"]},
 "LeftPartialD"->{
  Cell[1279469, 52169, 61, 1, 58, "ObjectName",
   CellTags->"LeftPartialD"],
  Cell[1279555, 52174, 63, 1, 39, "Subsubsection",
   CellTags->"LeftPartialD"],
  Cell[1279621, 52177, 307, 12, 40, "Text",
   CellTags->"LeftPartialD"],
  Cell[1279931, 52191, 573, 24, 33, "Text",
   CellTags->"LeftPartialD"],
  Cell[1280541, 52220, 69, 1, 34, "Subsubsection",
   CellTags->"LeftPartialD"],
  Cell[1280635, 52225, 253, 7, 27, "Input",
   CellTags->"LeftPartialD"],
  Cell[1280891, 52234, 306, 11, 32, "Output",
   CellTags->"LeftPartialD"],
  Cell[1281234, 52250, 120, 3, 27, "Input",
   CellTags->"LeftPartialD"],
  Cell[1281357, 52255, 355, 14, 29, "Output",
   CellTags->"LeftPartialD"],
  Cell[1281749, 52274, 118, 3, 27, "Input",
   CellTags->"LeftPartialD"],
  Cell[1281870, 52279, 291, 7, 39, "Output",
   CellTags->"LeftPartialD"],
  Cell[1282198, 52291, 161, 4, 27, "Input",
   CellTags->"LeftPartialD"],
  Cell[1282362, 52297, 176, 4, 39, "Output",
   CellTags->"LeftPartialD"],
  Cell[1282575, 52306, 372, 10, 27, "Input",
   CellTags->"LeftPartialD"],
  Cell[1282950, 52318, 344, 12, 32, "Output",
   CellTags->"LeftPartialD"],
  Cell[1283331, 52335, 120, 3, 27, "Input",
   CellTags->"LeftPartialD"],
  Cell[1283454, 52340, 774, 30, 29, "Output",
   CellTags->"LeftPartialD"],
  Cell[1284265, 52375, 118, 3, 27, "Input",
   CellTags->"LeftPartialD"],
  Cell[1284386, 52380, 799, 21, 59, "Output",
   CellTags->"LeftPartialD"]},
 "LeftRightPartialD"->{
  Cell[1285212, 52405, 71, 1, 58, "ObjectName",
   CellTags->"LeftRightPartialD"],
  Cell[1285308, 52410, 68, 1, 39, "Subsubsection",
   CellTags->"LeftRightPartialD"],
  Cell[1285379, 52413, 592, 21, 26, "Text",
   CellTags->"LeftRightPartialD"],
  Cell[1285974, 52436, 831, 33, 22, "Text",
   CellTags->"LeftRightPartialD"],
  Cell[1286842, 52474, 65, 1, 33, "Subsubsection",
   CellTags->"LeftRightPartialD"],
  Cell[1286932, 52479, 132, 3, 27, "Input",
   CellTags->"LeftRightPartialD"],
  Cell[1287067, 52484, 260, 9, 32, "Output",
   CellTags->"LeftRightPartialD"],
  Cell[1287364, 52498, 127, 3, 27, "Input",
   CellTags->"LeftRightPartialD"],
  Cell[1287494, 52503, 527, 19, 43, "Output",
   CellTags->"LeftRightPartialD"],
  Cell[1288058, 52527, 263, 7, 27, "Input",
   CellTags->"LeftRightPartialD"],
  Cell[1288324, 52536, 316, 11, 32, "Output",
   CellTags->"LeftRightPartialD"],
  Cell[1288677, 52552, 125, 3, 27, "Input",
   CellTags->"LeftRightPartialD"],
  Cell[1288805, 52557, 708, 26, 43, "Output",
   CellTags->"LeftRightPartialD"],
  Cell[1289550, 52588, 382, 10, 27, "Input",
   CellTags->"LeftRightPartialD"],
  Cell[1289935, 52600, 354, 12, 32, "Output",
   CellTags->"LeftRightPartialD"],
  Cell[1290326, 52617, 125, 3, 27, "Input",
   CellTags->"LeftRightPartialD"],
  Cell[1290454, 52622, 902, 33, 43, "Output",
   CellTags->"LeftRightPartialD"]},
 "LeftRightPartialD2"->{
  Cell[1291383, 52659, 73, 1, 39, "ObjectName",
   CellTags->"LeftRightPartialD2"],
  Cell[1291481, 52664, 69, 1, 26, "Subsubsection",
   CellTags->"LeftRightPartialD2"],
  Cell[1291553, 52667, 591, 21, 26, "Text",
   CellTags->"LeftRightPartialD2"],
  Cell[1292147, 52690, 698, 29, 22, "Text",
   CellTags->"LeftRightPartialD2"],
  Cell[1292882, 52724, 66, 1, 33, "Subsubsection",
   CellTags->"LeftRightPartialD2"],
  Cell[1292973, 52729, 134, 3, 27, "Input",
   CellTags->"LeftRightPartialD2"],
  Cell[1293110, 52734, 261, 9, 32, "Output",
   CellTags->"LeftRightPartialD2"],
  Cell[1293408, 52748, 128, 3, 27, "Input",
   CellTags->"LeftRightPartialD2"],
  Cell[1293539, 52753, 433, 16, 32, "Output",
   CellTags->"LeftRightPartialD2"],
  Cell[1294009, 52774, 265, 7, 27, "Input",
   CellTags->"LeftRightPartialD2"],
  Cell[1294277, 52783, 317, 11, 32, "Output",
   CellTags->"LeftRightPartialD2"],
  Cell[1294631, 52799, 126, 3, 27, "Input",
   CellTags->"LeftRightPartialD2"],
  Cell[1294760, 52804, 600, 23, 32, "Output",
   CellTags->"LeftRightPartialD2"],
  Cell[1295397, 52832, 384, 10, 27, "Input",
   CellTags->"LeftRightPartialD2"],
  Cell[1295784, 52844, 355, 12, 32, "Output",
   CellTags->"LeftRightPartialD2"],
  Cell[1296176, 52861, 126, 3, 27, "Input",
   CellTags->"LeftRightPartialD2"],
  Cell[1296305, 52866, 780, 30, 29, "Output",
   CellTags->"LeftRightPartialD2"]},
 "LeviCivita"->{
  Cell[1297112, 52900, 58, 1, 58, "ObjectName",
   CellTags->"LeviCivita"],
  Cell[1297195, 52905, 61, 1, 39, "Subsubsection",
   CellTags->"LeviCivita"],
  Cell[1297259, 52908, 1210, 40, 55, "Text",
   CellTags->"LeviCivita"],
  Cell[1298494, 52952, 120, 3, 27, "Input",
   CellTags->"LeviCivita"],
  Cell[1298617, 52957, 168, 5, 25, "Output",
   CellTags->"LeviCivita"],
  Cell[1298800, 52965, 463, 24, 33, "Text",
   CellTags->"LeviCivita"],
  Cell[1299300, 52994, 58, 1, 33, "Subsubsection",
   CellTags->"LeviCivita"],
  Cell[1299383, 52999, 187, 5, 27, "Input",
   CellTags->"LeviCivita"],
  Cell[1299573, 53006, 492, 21, 25, "Output",
   CellTags->"LeviCivita"],
  Cell[1300102, 53032, 204, 6, 27, "Input",
   CellTags->"LeviCivita"],
  Cell[1300309, 53040, 411, 17, 25, "Output",
   CellTags->"LeviCivita"],
  Cell[1300757, 53062, 180, 5, 27, "Input",
   CellTags->"LeviCivita"],
  Cell[1300940, 53069, 313, 13, 25, "Output",
   CellTags->"LeviCivita"],
  Cell[1301290, 53087, 186, 5, 27, "Input",
   CellTags->"LeviCivita"],
  Cell[1301479, 53094, 107, 3, 25, "Output",
   CellTags->"LeviCivita"],
  Cell[1301623, 53102, 242, 7, 27, "Input",
   CellTags->"LeviCivita"],
  Cell[1301868, 53111, 332, 8, 39, "Output",
   CellTags->"LeviCivita"],
  Cell[1302237, 53124, 365, 10, 27, "Input",
   CellTags->"LeviCivita"],
  Cell[1302605, 53136, 932, 40, 25, "Output",
   CellTags->"LeviCivita"],
  Cell[1303574, 53181, 113, 3, 27, "Input",
   CellTags->"LeviCivita"],
  Cell[1303690, 53186, 126, 4, 25, "Output",
   CellTags->"LeviCivita"],
  Cell[1303831, 53193, 316, 9, 27, "Input",
   CellTags->"LeviCivita"],
  Cell[1304172, 53206, 403, 11, 27, "Input",
   CellTags->"LeviCivita"],
  Cell[1304578, 53219, 297, 10, 25, "Output",
   CellTags->"LeviCivita"],
  Cell[1304890, 53232, 316, 9, 27, "Input",
   CellTags->"LeviCivita"],
  Cell[1305231, 53245, 179, 5, 27, "Input",
   CellTags->"LeviCivita"],
  Cell[1305413, 53252, 199, 6, 25, "Output",
   CellTags->"LeviCivita"],
  Cell[1305627, 53261, 110, 3, 27, "Input",
   CellTags->"LeviCivita"]},
 "LeviCivitaSign"->{
  Cell[1305752, 53267, 65, 1, 39, "ObjectName",
   CellTags->"LeviCivitaSign"],
  Cell[1305842, 53272, 65, 1, 33, "Subsubsection",
   CellTags->"LeviCivitaSign"],
  Cell[1305910, 53275, 203, 4, 23, "Text",
   CellTags->"LeviCivitaSign"],
  Cell[1306116, 53281, 310, 14, 23, "Text",
   CellTags->"LeviCivitaSign"]},
 "ListIntegrals"->{
  Cell[1306441, 53298, 81, 1, 39, "ObjectName",
   CellTags->"ListIntegrals"],
  Cell[1306547, 53303, 64, 1, 33, "Subsubsection",
   CellTags->"ListIntegrals"],
  Cell[1306614, 53306, 470, 8, 55, "Text",
   CellTags->"ListIntegrals"],
  Cell[1307121, 53319, 61, 1, 33, "Subsubsection",
   CellTags->"ListIntegrals"],
  Cell[1307185, 53322, 80, 2, 27, "Input",
   CellTags->"ListIntegrals"]},
 "Li2"->{
  Cell[1307280, 53327, 44, 1, 39, "ObjectName",
   CellTags->"Li2"],
  Cell[1307349, 53332, 54, 1, 33, "Subsubsection",
   CellTags->"Li2"],
  Cell[1307406, 53335, 117, 3, 23, "Text",
   CellTags->"Li2"],
  Cell[1307526, 53340, 153, 8, 23, "Text",
   CellTags->"Li2"],
  Cell[1307716, 53353, 51, 1, 33, "Subsubsection",
   CellTags->"Li2"],
  Cell[1307792, 53358, 100, 3, 27, "Input",
   CellTags->"Li2"],
  Cell[1307895, 53363, 136, 5, 25, "Output",
   CellTags->"Li2"],
  Cell[1308068, 53373, 107, 3, 27, "Input",
   CellTags->"Li2"],
  Cell[1308178, 53378, 162, 5, 39, "Output",
   CellTags->"Li2"],
  Cell[1308377, 53388, 253, 9, 42, "Input",
   CellTags->"Li2"],
  Cell[1308633, 53399, 136, 5, 25, "Output",
   CellTags->"Li2"]},
 "Li3"->{
  Cell[1308796, 53408, 44, 1, 58, "ObjectName",
   CellTags->"Li3"],
  Cell[1308865, 53413, 54, 1, 39, "Subsubsection",
   CellTags->"Li3"],
  Cell[1308922, 53416, 118, 3, 32, "Text",
   CellTags->"Li3"],
  Cell[1309043, 53421, 153, 8, 33, "Text",
   CellTags->"Li3"],
  Cell[1309233, 53434, 51, 1, 33, "Subsubsection",
   CellTags->"Li3"],
  Cell[1309309, 53439, 100, 3, 27, "Input",
   CellTags->"Li3"],
  Cell[1309412, 53444, 136, 5, 25, "Output",
   CellTags->"Li3"],
  Cell[1309585, 53454, 107, 3, 27, "Input",
   CellTags->"Li3"],
  Cell[1309695, 53459, 162, 5, 39, "Output",
   CellTags->"Li3"],
  Cell[1309894, 53469, 152, 5, 27, "Input",
   CellTags->"Li3"],
  Cell[1310049, 53476, 159, 6, 43, "Output",
   CellTags->"Li3"],
  Cell[1310245, 53487, 204, 7, 42, "Input",
   CellTags->"Li3"],
  Cell[1310452, 53496, 136, 5, 25, "Output",
   CellTags->"Li3"]},
 "Loop"->{
  Cell[1310615, 53505, 45, 1, 39, "ObjectName",
   CellTags->"Loop"],
  Cell[1310685, 53510, 55, 1, 33, "Subsubsection",
   CellTags->"Loop"],
  Cell[1310743, 53513, 94, 1, 23, "Text",
   CellTags->"Loop"]},
 "LorentzIndex"->{
  Cell[1310852, 53517, 61, 1, 39, "ObjectName",
   CellTags->"LorentzIndex"],
  Cell[1310938, 53522, 63, 1, 33, "Subsubsection",
   CellTags->"LorentzIndex"],
  Cell[1311004, 53525, 243, 5, 39, "Text",
   CellTags->"LorentzIndex"],
  Cell[1311250, 53532, 314, 14, 23, "Text",
   CellTags->"LorentzIndex"],
  Cell[1311601, 53551, 60, 1, 33, "Subsubsection",
   CellTags->"LorentzIndex"],
  Cell[1311664, 53554, 89, 1, 23, "Text",
   CellTags->"LorentzIndex"],
  Cell[1311778, 53559, 125, 3, 27, "Input",
   CellTags->"LorentzIndex"],
  Cell[1311906, 53564, 116, 3, 25, "Output",
   CellTags->"LorentzIndex"],
  Cell[1312037, 53570, 125, 3, 23, "Text",
   CellTags->"LorentzIndex"],
  Cell[1312187, 53577, 148, 4, 27, "Input",
   CellTags->"LorentzIndex"],
  Cell[1312338, 53583, 116, 3, 25, "Output",
   CellTags->"LorentzIndex"],
  Cell[1312491, 53591, 106, 2, 27, "Input",
   CellTags->"LorentzIndex"],
  Cell[1312600, 53595, 140, 4, 25, "Output",
   CellTags->"LorentzIndex"],
  Cell[1312777, 53604, 165, 4, 27, "Input",
   CellTags->"LorentzIndex"],
  Cell[1312945, 53610, 113, 3, 25, "Output",
   CellTags->"LorentzIndex"],
  Cell[1313095, 53618, 207, 5, 27, "Input",
   CellTags->"LorentzIndex"],
  Cell[1313305, 53625, 139, 4, 25, "Output",
   CellTags->"LorentzIndex"],
  Cell[1313459, 53632, 141, 4, 23, "Text",
   CellTags->"LorentzIndex"],
  Cell[1313603, 53638, 137, 4, 27, "Input",
   CellTags->"LorentzIndex"],
  Cell[1313765, 53646, 347, 10, 27, "Input",
   CellTags->"LorentzIndex"],
  Cell[1314115, 53658, 385, 16, 25, "Output",
   CellTags->"LorentzIndex"],
  Cell[1314515, 53677, 148, 4, 27, "Input",
   CellTags->"LorentzIndex"]},
 "Lower"->{
  Cell[1314678, 53684, 47, 1, 39, "ObjectName",
   CellTags->"Lower"],
  Cell[1314750, 53689, 56, 1, 33, "Subsubsection",
   CellTags->"Lower"],
  Cell[1314809, 53692, 120, 3, 23, "Text",
   CellTags->"Lower"],
  Cell[1314932, 53697, 402, 19, 23, "Text",
   CellTags->"Lower"]},
 "MakeContext"->{
  Cell[1315349, 53719, 59, 1, 39, "ObjectName",
   CellTags->"MakeContext"],
  Cell[1315433, 53724, 62, 1, 33, "Subsubsection",
   CellTags->"MakeContext"],
  Cell[1315498, 53727, 238, 5, 39, "Text",
   CellTags->"MakeContext"],
  Cell[1315739, 53734, 530, 24, 23, "Text",
   CellTags->"MakeContext"]},
 "Mandelstam"->{
  Cell[1316284, 53761, 57, 1, 39, "ObjectName",
   CellTags->"Mandelstam"],
  Cell[1316366, 53766, 61, 1, 33, "Subsubsection",
   CellTags->"Mandelstam"],
  Cell[1316430, 53769, 1575, 73, 75, "Text",
   CellTags->"Mandelstam"],
  Cell[1318008, 53844, 758, 34, 33, "Text",
   CellTags->"Mandelstam"]},
 "Map2"->{
  Cell[1318781, 53881, 45, 1, 58, "ObjectName",
   CellTags->"Map2"],
  Cell[1318851, 53886, 55, 1, 39, "Subsubsection",
   CellTags->"Map2"],
  Cell[1318909, 53889, 135, 4, 32, "Text",
   CellTags->"Map2"],
  Cell[1319047, 53895, 169, 9, 33, "Text",
   CellTags->"Map2"],
  Cell[1319253, 53909, 52, 1, 33, "Subsubsection",
   CellTags->"Map2"],
  Cell[1319330, 53914, 149, 5, 27, "Input",
   CellTags->"Map2"],
  Cell[1319482, 53921, 202, 7, 25, "Output",
   CellTags->"Map2"],
  Cell[1319721, 53933, 125, 4, 27, "Input",
   CellTags->"Map2"],
  Cell[1319849, 53939, 129, 4, 25, "Output",
   CellTags->"Map2"],
  Cell[1320015, 53948, 184, 6, 27, "Input",
   CellTags->"Map2"],
  Cell[1320202, 53956, 191, 7, 25, "Output",
   CellTags->"Map2"],
  Cell[1320430, 53968, 125, 4, 27, "Input",
   CellTags->"Map2"],
  Cell[1320558, 53974, 129, 4, 25, "Output",
   CellTags->"Map2"]},
 "MemoryAvailable"->{
  Cell[1320714, 53982, 67, 1, 58, "ObjectName",
   CellTags->"MemoryAvailable"],
  Cell[1320806, 53987, 66, 1, 26, "Subsubsection",
   CellTags->"MemoryAvailable"],
  Cell[1320875, 53990, 230, 5, 36, "Text",
   CellTags->"MemoryAvailable"],
  Cell[1321108, 53997, 314, 14, 22, "Text",
   CellTags->"MemoryAvailable"]},
 "MemSet"->{
  Cell[1321437, 54014, 49, 1, 39, "ObjectName",
   CellTags->"MemSet"],
  Cell[1321511, 54019, 57, 1, 26, "Subsubsection",
   CellTags->"MemSet"],
  Cell[1321571, 54022, 345, 9, 36, "Text",
   CellTags->"MemSet"],
  Cell[1321919, 54033, 198, 9, 22, "Text",
   CellTags->"MemSet"]},
 "MetricTensor"->{
  Cell[1322132, 54045, 61, 1, 39, "ObjectName",
   CellTags->"MetricTensor"],
  Cell[1322218, 54050, 63, 1, 26, "Subsubsection",
   CellTags->"MetricTensor"],
  Cell[1322284, 54053, 214, 7, 21, "Text",
   CellTags->"MetricTensor"],
  Cell[1322501, 54062, 584, 29, 22, "Text",
   CellTags->"MetricTensor"],
  Cell[1323122, 54096, 60, 1, 33, "Subsubsection",
   CellTags->"MetricTensor"],
  Cell[1323207, 54101, 154, 4, 27, "Input",
   CellTags->"MetricTensor"],
  Cell[1323364, 54107, 165, 5, 25, "Output",
   CellTags->"MetricTensor"],
  Cell[1323566, 54117, 147, 4, 27, "Input",
   CellTags->"MetricTensor"],
  Cell[1323716, 54123, 109, 3, 25, "Output",
   CellTags->"MetricTensor"],
  Cell[1323862, 54131, 202, 5, 27, "Input",
   CellTags->"MetricTensor"],
  Cell[1324067, 54138, 165, 5, 25, "Output",
   CellTags->"MetricTensor"],
  Cell[1324269, 54148, 147, 4, 27, "Input",
   CellTags->"MetricTensor"],
  Cell[1324419, 54154, 109, 3, 25, "Output",
   CellTags->"MetricTensor"],
  Cell[1324565, 54162, 181, 5, 27, "Input",
   CellTags->"MetricTensor"],
  Cell[1324749, 54169, 156, 4, 39, "Output",
   CellTags->"MetricTensor"],
  Cell[1324942, 54178, 230, 6, 27, "Input",
   CellTags->"MetricTensor"],
  Cell[1325175, 54186, 204, 5, 39, "Output",
   CellTags->"MetricTensor"],
  Cell[1325416, 54196, 213, 6, 27, "Input",
   CellTags->"MetricTensor"],
  Cell[1325632, 54204, 156, 4, 39, "Output",
   CellTags->"MetricTensor"],
  Cell[1325825, 54213, 263, 7, 27, "Input",
   CellTags->"MetricTensor"],
  Cell[1326091, 54222, 204, 5, 39, "Output",
   CellTags->"MetricTensor"]},
 "MLimit"->{
  Cell[1326322, 54231, 49, 1, 39, "ObjectName",
   CellTags->"MLimit"],
  Cell[1326396, 54236, 57, 1, 33, "Subsubsection",
   CellTags->"MLimit"],
  Cell[1326456, 54239, 116, 3, 23, "Text",
   CellTags->"MLimit"],
  Cell[1326609, 54247, 54, 1, 33, "Subsubsection",
   CellTags->"MLimit"],
  Cell[1326688, 54252, 462, 16, 27, "Input",
   CellTags->"MLimit"],
  Cell[1327153, 54270, 103, 3, 25, "Output",
   CellTags->"MLimit"]},
 "Momentum"->{
  Cell[1327283, 54277, 53, 1, 39, "ObjectName",
   CellTags->"Momentum"],
  Cell[1327361, 54282, 59, 1, 33, "Subsubsection",
   CellTags->"Momentum"],
  Cell[1327423, 54285, 258, 5, 39, "Text",
   CellTags->"Momentum"],
  Cell[1327684, 54292, 530, 24, 23, "Text",
   CellTags->"Momentum"],
  Cell[1328251, 54321, 56, 1, 33, "Subsubsection",
   CellTags->"Momentum"],
  Cell[1328310, 54324, 75, 1, 23, "Text",
   CellTags->"Momentum"],
  Cell[1328410, 54329, 110, 3, 27, "Input",
   CellTags->"Momentum"],
  Cell[1328523, 54334, 105, 3, 25, "Output",
   CellTags->"Momentum"],
  Cell[1328643, 54340, 138, 4, 23, "Text",
   CellTags->"Momentum"],
  Cell[1328806, 54348, 133, 4, 27, "Input",
   CellTags->"Momentum"],
  Cell[1328942, 54354, 105, 3, 25, "Output",
   CellTags->"Momentum"],
  Cell[1329062, 54360, 86, 1, 23, "Text",
   CellTags->"Momentum"],
  Cell[1329173, 54365, 169, 5, 27, "Input",
   CellTags->"Momentum"],
  Cell[1329345, 54372, 148, 4, 39, "Output",
   CellTags->"Momentum"],
  Cell[1329530, 54381, 153, 5, 27, "Input",
   CellTags->"Momentum"],
  Cell[1329686, 54388, 123, 4, 25, "Output",
   CellTags->"Momentum"],
  Cell[1329846, 54397, 111, 3, 27, "Input",
   CellTags->"Momentum"],
  Cell[1329960, 54402, 143, 4, 39, "Output",
   CellTags->"Momentum"],
  Cell[1330140, 54411, 259, 8, 27, "Input",
   CellTags->"Momentum"],
  Cell[1330402, 54421, 201, 7, 25, "Output",
   CellTags->"Momentum"],
  Cell[1330640, 54433, 111, 3, 27, "Input",
   CellTags->"Momentum"],
  Cell[1330754, 54438, 231, 7, 39, "Output",
   CellTags->"Momentum"],
  Cell[1331022, 54450, 148, 4, 27, "Input",
   CellTags->"Momentum"],
  Cell[1331173, 54456, 183, 5, 39, "Output",
   CellTags->"Momentum"],
  Cell[1331393, 54466, 149, 4, 27, "Input",
   CellTags->"Momentum"],
  Cell[1331545, 54472, 231, 7, 39, "Output",
   CellTags->"Momentum"],
  Cell[1331813, 54484, 216, 7, 27, "Input",
   CellTags->"Momentum"],
  Cell[1332032, 54493, 148, 4, 39, "Output",
   CellTags->"Momentum"],
  Cell[1332195, 54500, 132, 4, 27, "Input",
   CellTags->"Momentum"]},
 "MomentumCombine"->{
  Cell[1332342, 54507, 67, 1, 39, "ObjectName",
   CellTags->"MomentumCombine"],
  Cell[1332434, 54512, 66, 1, 26, "Subsubsection",
   CellTags->"MomentumCombine"],
  Cell[1332503, 54515, 183, 4, 21, "Text",
   CellTags->"MomentumCombine"],
  Cell[1332689, 54521, 585, 23, 22, "Text",
   CellTags->"MomentumCombine"],
  Cell[1333311, 54549, 63, 1, 33, "Subsubsection",
   CellTags->"MomentumCombine"],
  Cell[1333399, 54554, 303, 9, 27, "Input",
   CellTags->"MomentumCombine"],
  Cell[1333705, 54565, 214, 6, 39, "Output",
   CellTags->"MomentumCombine"],
  Cell[1333956, 54576, 288, 9, 27, "Input",
   CellTags->"MomentumCombine"],
  Cell[1334247, 54587, 218, 7, 25, "Output",
   CellTags->"MomentumCombine"],
  Cell[1334502, 54599, 125, 3, 27, "Input",
   CellTags->"MomentumCombine"],
  Cell[1334630, 54604, 218, 7, 25, "Output",
   CellTags->"MomentumCombine"],
  Cell[1334885, 54616, 163, 5, 27, "Input",
   CellTags->"MomentumCombine"],
  Cell[1335051, 54623, 259, 8, 39, "Output",
   CellTags->"MomentumCombine"],
  Cell[1335347, 54636, 170, 5, 27, "Input",
   CellTags->"MomentumCombine"],
  Cell[1335520, 54643, 444, 19, 25, "Output",
   CellTags->"MomentumCombine"],
  Cell[1336001, 54667, 121, 3, 27, "Input",
   CellTags->"MomentumCombine"],
  Cell[1336125, 54672, 421, 12, 39, "Output",
   CellTags->"MomentumCombine"],
  Cell[1336561, 54687, 115, 3, 27, "Input",
   CellTags->"MomentumCombine"]},
 "MomentumCombine2"->{
  Cell[1336691, 54693, 69, 1, 39, "ObjectName",
   CellTags->"MomentumCombine2"],
  Cell[1336785, 54698, 67, 1, 26, "Subsubsection",
   CellTags->"MomentumCombine2"],
  Cell[1336855, 54701, 192, 4, 36, "Text",
   CellTags->"MomentumCombine2"],
  Cell[1337050, 54707, 589, 23, 22, "Text",
   CellTags->"MomentumCombine2"],
  Cell[1337676, 54735, 64, 1, 33, "Subsubsection",
   CellTags->"MomentumCombine2"],
  Cell[1337765, 54740, 434, 13, 27, "Input",
   CellTags->"MomentumCombine2"],
  Cell[1338202, 54755, 476, 20, 25, "Output",
   CellTags->"MomentumCombine2"],
  Cell[1338715, 54780, 164, 5, 27, "Input",
   CellTags->"MomentumCombine2"],
  Cell[1338882, 54787, 309, 9, 39, "Output",
   CellTags->"MomentumCombine2"]},
 "MomentumExpand"->{
  Cell[1339218, 54800, 65, 1, 39, "ObjectName",
   CellTags->"MomentumExpand"],
  Cell[1339308, 54805, 65, 1, 26, "Subsubsection",
   CellTags->"MomentumExpand"],
  Cell[1339376, 54808, 149, 4, 21, "Text",
   CellTags->"MomentumExpand"],
  Cell[1339528, 54814, 349, 14, 22, "Text",
   CellTags->"MomentumExpand"],
  Cell[1339914, 54833, 62, 1, 33, "Subsubsection",
   CellTags->"MomentumExpand"],
  Cell[1340001, 54838, 218, 6, 27, "Input",
   CellTags->"MomentumExpand"],
  Cell[1340222, 54846, 189, 5, 39, "Output",
   CellTags->"MomentumExpand"],
  Cell[1340448, 54856, 168, 5, 27, "Input",
   CellTags->"MomentumExpand"],
  Cell[1340619, 54863, 248, 9, 25, "Output",
   CellTags->"MomentumExpand"],
  Cell[1340904, 54877, 116, 3, 27, "Input",
   CellTags->"MomentumExpand"],
  Cell[1341023, 54882, 247, 7, 39, "Output",
   CellTags->"MomentumExpand"],
  Cell[1341307, 54894, 211, 6, 27, "Input",
   CellTags->"MomentumExpand"],
  Cell[1341521, 54902, 358, 15, 25, "Output",
   CellTags->"MomentumExpand"],
  Cell[1341916, 54922, 116, 3, 27, "Input",
   CellTags->"MomentumExpand"],
  Cell[1342035, 54927, 284, 8, 39, "Output",
   CellTags->"MomentumExpand"],
  Cell[1342356, 54940, 236, 7, 27, "Input",
   CellTags->"MomentumExpand"],
  Cell[1342595, 54949, 384, 16, 25, "Output",
   CellTags->"MomentumExpand"],
  Cell[1343016, 54970, 116, 3, 27, "Input",
   CellTags->"MomentumExpand"],
  Cell[1343135, 54975, 367, 11, 39, "Output",
   CellTags->"MomentumExpand"],
  Cell[1343539, 54991, 112, 3, 27, "Input",
   CellTags->"MomentumExpand"],
  Cell[1343654, 54996, 560, 23, 27, "Output",
   CellTags->"MomentumExpand"]},
 "MT"->{
  Cell[1344241, 55023, 41, 1, 39, "ObjectName",
   CellTags->"MT"],
  Cell[1344307, 55028, 53, 1, 33, "Subsubsection",
   CellTags->"MT"],
  Cell[1344363, 55031, 182, 7, 23, "Text",
   CellTags->"MT"],
  Cell[1344548, 55040, 604, 29, 23, "Text",
   CellTags->"MT"],
  Cell[1345189, 55074, 50, 1, 33, "Subsubsection",
   CellTags->"MT"],
  Cell[1345264, 55079, 134, 4, 27, "Input",
   CellTags->"MT"],
  Cell[1345401, 55085, 155, 5, 25, "Output",
   CellTags->"MT"],
  Cell[1345593, 55095, 263, 8, 27, "Input",
   CellTags->"MT"],
  Cell[1345859, 55105, 99, 3, 25, "Output",
   CellTags->"MT"],
  Cell[1345995, 55113, 157, 5, 27, "Input",
   CellTags->"MT"],
  Cell[1346155, 55120, 136, 4, 39, "Output",
   CellTags->"MT"],
  Cell[1346328, 55129, 189, 6, 27, "Input",
   CellTags->"MT"],
  Cell[1346520, 55137, 218, 6, 39, "Output",
   CellTags->"MT"],
  Cell[1346775, 55148, 225, 8, 27, "Input",
   CellTags->"MT"],
  Cell[1347003, 55158, 136, 4, 39, "Output",
   CellTags->"MT"]},
 "MTD"->{
  Cell[1347166, 55166, 43, 1, 39, "ObjectName",
   CellTags->"MTD"],
  Cell[1347234, 55171, 54, 1, 33, "Subsubsection",
   CellTags->"MTD"],
  Cell[1347291, 55174, 184, 7, 23, "Text",
   CellTags->"MTD"],
  Cell[1347478, 55183, 602, 29, 23, "Text",
   CellTags->"MTD"],
  Cell[1348117, 55217, 51, 1, 33, "Subsubsection",
   CellTags->"MTD"],
  Cell[1348193, 55222, 136, 4, 27, "Input",
   CellTags->"MTD"],
  Cell[1348332, 55228, 156, 5, 25, "Output",
   CellTags->"MTD"],
  Cell[1348525, 55238, 266, 8, 27, "Input",
   CellTags->"MTD"],
  Cell[1348794, 55248, 100, 3, 25, "Output",
   CellTags->"MTD"],
  Cell[1348931, 55256, 175, 6, 27, "Input",
   CellTags->"MTD"],
  Cell[1349109, 55264, 151, 4, 39, "Output",
   CellTags->"MTD"],
  Cell[1349297, 55273, 207, 7, 27, "Input",
   CellTags->"MTD"],
  Cell[1349507, 55282, 282, 8, 39, "Output",
   CellTags->"MTD"],
  Cell[1349826, 55295, 235, 8, 27, "Input",
   CellTags->"MTD"],
  Cell[1350064, 55305, 146, 4, 39, "Output",
   CellTags->"MTD"]},
 "NegativeInteger"->{
  Cell[1350237, 55313, 67, 1, 39, "ObjectName",
   CellTags->"NegativeInteger"],
  Cell[1350329, 55318, 66, 1, 33, "Subsubsection",
   CellTags->"NegativeInteger"],
  Cell[1350398, 55321, 141, 4, 23, "Text",
   CellTags->"NegativeInteger"],
  Cell[1350542, 55327, 186, 9, 23, "Text",
   CellTags->"NegativeInteger"]},
 "Nf"->{
  Cell[1350743, 55339, 41, 1, 39, "ObjectName",
   CellTags->"Nf"],
  Cell[1350809, 55344, 53, 1, 33, "Subsubsection",
   CellTags->"Nf"],
  Cell[1350865, 55347, 66, 1, 23, "Text",
   CellTags->"Nf"],
  Cell[1350934, 55350, 685, 29, 23, "Text",
   CellTags->"Nf"]},
 "Nielsen"->{
  Cell[1351634, 55382, 51, 1, 39, "ObjectName",
   CellTags->"Nielsen"],
  Cell[1351710, 55387, 58, 1, 33, "Subsubsection",
   CellTags->"Nielsen"],
  Cell[1351771, 55390, 86, 1, 23, "Text",
   CellTags->"Nielsen"],
  Cell[1351882, 55395, 114, 3, 27, "Input",
   CellTags->"Nielsen"],
  Cell[1351999, 55400, 169, 6, 25, "Output",
   CellTags->"Nielsen"],
  Cell[1352183, 55409, 199, 9, 23, "Text",
   CellTags->"Nielsen"],
  Cell[1352419, 55423, 55, 1, 33, "Subsubsection",
   CellTags->"Nielsen"],
  Cell[1352499, 55428, 141, 4, 27, "Input",
   CellTags->"Nielsen"],
  Cell[1352643, 55434, 251, 10, 27, "Output",
   CellTags->"Nielsen"],
  Cell[1352909, 55447, 176, 4, 23, "Text",
   CellTags->"Nielsen"],
  Cell[1353110, 55455, 172, 5, 27, "Input",
   CellTags->"Nielsen"],
  Cell[1353285, 55462, 123, 3, 25, "Output",
   CellTags->"Nielsen"],
  Cell[1353423, 55468, 71, 1, 23, "Text",
   CellTags->"Nielsen"],
  Cell[1353519, 55473, 467, 14, 27, "Input",
   CellTags->"Nielsen"],
  Cell[1353989, 55489, 320, 13, 43, "Output",
   CellTags->"Nielsen"],
  Cell[1354346, 55507, 190, 5, 27, "Input",
   CellTags->"Nielsen"],
  Cell[1354539, 55514, 573, 20, 43, "Output",
   CellTags->"Nielsen"],
  Cell[1355149, 55539, 190, 5, 27, "Input",
   CellTags->"Nielsen"],
  Cell[1355342, 55546, 807, 27, 46, "Output",
   CellTags->"Nielsen"],
  Cell[1356186, 55578, 190, 5, 27, "Input",
   CellTags->"Nielsen"],
  Cell[1356379, 55585, 140, 5, 25, "Output",
   CellTags->"Nielsen"]},
 "NonCommFreeQ"->{
  Cell[1356546, 55594, 61, 1, 39, "ObjectName",
   CellTags->"NonCommFreeQ"],
  Cell[1356632, 55599, 63, 1, 33, "Subsubsection",
   CellTags->"NonCommFreeQ"],
  Cell[1356698, 55602, 244, 5, 39, "Text",
   CellTags->"NonCommFreeQ"],
  Cell[1356945, 55609, 519, 24, 23, "Text",
   CellTags->"NonCommFreeQ"]},
 "NonCommQ"->{
  Cell[1357479, 55636, 53, 1, 39, "ObjectName",
   CellTags->"NonCommQ"],
  Cell[1357557, 55641, 59, 1, 33, "Subsubsection",
   CellTags->"NonCommQ"],
  Cell[1357619, 55644, 203, 4, 39, "Text",
   CellTags->"NonCommQ"],
  Cell[1357825, 55650, 527, 24, 23, "Text",
   CellTags->"NonCommQ"],
  Cell[1360749, 55794, 167, 9, 23, "Text",
   CellTags->"NonCommQ"]},
 "NonCommutative"->{
  Cell[1358367, 55677, 65, 1, 39, "ObjectName",
   CellTags->"NonCommutative"],
  Cell[1358457, 55682, 65, 1, 33, "Subsubsection",
   CellTags->"NonCommutative"],
  Cell[1358525, 55685, 150, 4, 23, "Text",
   CellTags->"NonCommutative"],
  Cell[1358678, 55691, 333, 14, 23, "Text",
   CellTags->"NonCommutative"]},
 "NTerms"->{
  Cell[1359026, 55708, 49, 1, 39, "ObjectName",
   CellTags->"NTerms"],
  Cell[1359100, 55713, 57, 1, 33, "Subsubsection",
   CellTags->"NTerms"],
  Cell[1359160, 55716, 154, 4, 23, "Text",
   CellTags->"NTerms"],
  Cell[1359351, 55725, 54, 1, 33, "Subsubsection",
   CellTags->"NTerms"],
  Cell[1359430, 55730, 129, 4, 27, "Input",
   CellTags->"NTerms"],
  Cell[1359562, 55736, 103, 3, 25, "Output",
   CellTags->"NTerms"],
  Cell[1359702, 55744, 139, 4, 27, "Input",
   CellTags->"NTerms"],
  Cell[1359844, 55750, 103, 3, 25, "Output",
   CellTags->"NTerms"],
  Cell[1359984, 55758, 106, 3, 27, "Input",
   CellTags->"NTerms"],
  Cell[1360093, 55763, 103, 3, 25, "Output",
   CellTags->"NTerms"],
  Cell[1360233, 55771, 106, 3, 27, "Input",
   CellTags->"NTerms"],
  Cell[1360342, 55776, 103, 3, 25, "Output",
   CellTags->"NTerms"]},
 "NumberOfMetricTensors"->{
  Cell[1360472, 55783, 79, 1, 39, "ObjectName",
   CellTags->"NumberOfMetricTensors"],
  Cell[1360576, 55788, 72, 1, 33, "Subsubsection",
   CellTags->"NumberOfMetricTensors"],
  Cell[1360651, 55791, 95, 1, 23, "Text",
   CellTags->"NumberOfMetricTensors"]},
 "NumericalFactor"->{
  Cell[1360931, 55806, 67, 1, 39, "ObjectName",
   CellTags->"NumericalFactor"],
  Cell[1361023, 55811, 66, 1, 33, "Subsubsection",
   CellTags->"NumericalFactor"],
  Cell[1361092, 55814, 119, 3, 23, "Text",
   CellTags->"NumericalFactor"]},
 "NumericQ1"->{
  Cell[1361226, 55820, 55, 1, 39, "ObjectName",
   CellTags->"NumericQ1"],
  Cell[1361306, 55825, 60, 1, 33, "Subsubsection",
   CellTags->"NumericQ1"],
  Cell[1361369, 55828, 139, 4, 23, "Text",
   CellTags->"NumericQ1"],
  Cell[1361545, 55837, 57, 1, 33, "Subsubsection",
   CellTags->"NumericQ1"],
  Cell[1361627, 55842, 224, 7, 29, "Input",
   CellTags->"NumericQ1"],
  Cell[1361854, 55851, 110, 3, 25, "Output",
   CellTags->"NumericQ1"],
  Cell[1362001, 55859, 271, 9, 29, "Input",
   CellTags->"NumericQ1"],
  Cell[1362275, 55870, 110, 3, 25, "Output",
   CellTags->"NumericQ1"],
  Cell[1362422, 55878, 311, 10, 29, "Input",
   CellTags->"NumericQ1"],
  Cell[1362736, 55890, 109, 3, 25, "Output",
   CellTags->"NumericQ1"]},
 "OneLoop"->{
  Cell[1362894, 55899, 69, 1, 39, "ObjectName",
   CellTags->"OneLoop"],
  Cell[1362966, 55902, 619, 16, 55, "Text",
   CellTags->"OneLoop"],
  Cell[1363588, 55920, 968, 26, 41, "Text",
   CellTags->"OneLoop"],
  Cell[1364593, 55951, 58, 1, 33, "Subsubsection",
   CellTags->"OneLoop"],
  Cell[1364654, 55954, 391, 12, 39, "Text",
   CellTags->"OneLoop"],
  Cell[1365048, 55968, 352, 6, 55, "Text",
   CellTags->"OneLoop"],
  Cell[1365425, 55978, 114, 3, 27, "Input",
   CellTags->"OneLoop"],
  Cell[1365542, 55983, 1275, 29, 83, "Output",
   CellTags->"OneLoop"],
  Cell[1366832, 56015, 781, 39, 23, "Text",
   CellTags->"OneLoop"],
  Cell[1367650, 56059, 55, 1, 33, "Subsubsection",
   CellTags->"OneLoop"],
  Cell[1367730, 56064, 275, 10, 27, "Input",
   CellTags->"OneLoop"],
  Cell[1368008, 56076, 323, 11, 48, "Output",
   CellTags->"OneLoop"],
  Cell[1368368, 56092, 131, 4, 27, "Input",
   CellTags->"OneLoop"],
  Cell[1368502, 56098, 266, 10, 29, "Output",
   CellTags->"OneLoop"],
  Cell[1368783, 56111, 363, 11, 27, "Input",
   CellTags->"OneLoop"],
  Cell[1369149, 56124, 588, 20, 25, "Text",
   CellTags->"OneLoop"],
  Cell[1369762, 56148, 908, 30, 48, "Input",
   CellTags->"OneLoop"],
  Cell[1370673, 56180, 1871, 65, 57, "Output",
   CellTags->"OneLoop"],
  Cell[1372559, 56248, 219, 5, 39, "Text",
   CellTags->"OneLoop"],
  Cell[1372803, 56257, 131, 4, 27, "Input",
   CellTags->"OneLoop"],
  Cell[1372937, 56263, 2406, 79, 58, "Output",
   CellTags->"OneLoop"],
  Cell[1375380, 56347, 113, 3, 27, "Input",
   CellTags->"OneLoop"],
  Cell[1375496, 56352, 1707, 58, 53, "Output",
   CellTags->"OneLoop"],
  Cell[1377240, 56415, 333, 11, 27, "Input",
   CellTags->"OneLoop"],
  Cell[1377576, 56428, 442, 17, 49, "Output",
   CellTags->"OneLoop"],
  Cell[1378055, 56450, 131, 4, 27, "Input",
   CellTags->"OneLoop"],
  Cell[1378189, 56456, 1880, 66, 51, "Output",
   CellTags->"OneLoop"],
  Cell[1380084, 56525, 106, 3, 27, "Input",
   CellTags->"OneLoop"]},
 "OneLoopSimplify"->{
  Cell[1380205, 56531, 67, 1, 39, "ObjectName",
   CellTags->"OneLoopSimplify"],
  Cell[1380297, 56536, 66, 1, 33, "Subsubsection",
   CellTags->"OneLoopSimplify"],
  Cell[1380366, 56539, 172, 4, 23, "Text",
   CellTags->"OneLoopSimplify"],
  Cell[1380563, 56547, 130, 3, 27, "Input",
   CellTags->"OneLoopSimplify"],
  Cell[1380696, 56552, 737, 18, 45, "Output",
   CellTags->"OneLoopSimplify"],
  Cell[1381448, 56573, 376, 19, 23, "Text",
   CellTags->"OneLoopSimplify"],
  Cell[1381861, 56597, 63, 1, 33, "Subsubsection",
   CellTags->"OneLoopSimplify"],
  Cell[1381949, 56602, 341, 11, 27, "Input",
   CellTags->"OneLoopSimplify"],
  Cell[1382293, 56615, 450, 17, 49, "Output",
   CellTags->"OneLoopSimplify"],
  Cell[1382780, 56637, 147, 4, 27, "Input",
   CellTags->"OneLoopSimplify"],
  Cell[1382930, 56643, 1129, 43, 51, "Output",
   CellTags->"OneLoopSimplify"],
  Cell[1384096, 56691, 203, 6, 27, "Input",
   CellTags->"OneLoopSimplify"],
  Cell[1384302, 56699, 400, 16, 45, "Output",
   CellTags->"OneLoopSimplify"],
  Cell[1384739, 56720, 401, 12, 27, "Input",
   CellTags->"OneLoopSimplify"],
  Cell[1385143, 56734, 580, 22, 49, "Output",
   CellTags->"OneLoopSimplify"],
  Cell[1385760, 56761, 152, 4, 27, "Input",
   CellTags->"OneLoopSimplify"],
  Cell[1385915, 56767, 7168, 261, 100, "Output",
   CellTags->"OneLoopSimplify"],
  Cell[1393120, 57033, 253, 9, 27, "Input",
   CellTags->"OneLoopSimplify"],
  Cell[1393376, 57044, 4274, 162, 50, "Output",
   CellTags->"OneLoopSimplify"],
  Cell[1397687, 57211, 424, 15, 27, "Input",
   CellTags->"OneLoopSimplify"],
  Cell[1398114, 57228, 2174, 83, 50, "Output",
   CellTags->"OneLoopSimplify"]},
 "OneLoopSum"->{
  Cell[1400315, 57315, 57, 1, 39, "ObjectName",
   CellTags->"OneLoopSum"],
  Cell[1400397, 57320, 61, 1, 33, "Subsubsection",
   CellTags->"OneLoopSum"],
  Cell[1400461, 57323, 190, 4, 23, "Text",
   CellTags->"OneLoopSum"],
  Cell[1400654, 57329, 178, 9, 23, "Text",
   CellTags->"OneLoopSum"]},
 "OPE"->{
  Cell[1400847, 57341, 43, 1, 39, "ObjectName",
   CellTags->"OPE"],
  Cell[1400915, 57346, 54, 1, 33, "Subsubsection",
   CellTags->"OPE"],
  Cell[1400972, 57349, 170, 4, 47, "Text",
   CellTags->"OPE"],
  Cell[1401490, 57372, 174, 9, 23, "Text",
   CellTags->"OPE"]},
 "OPEDelta"->{
  Cell[1401679, 57384, 53, 1, 39, "ObjectName",
   CellTags->"OPEDelta"],
  Cell[1401757, 57389, 59, 1, 33, "Subsubsection",
   CellTags->"OPEDelta"],
  Cell[1401819, 57392, 140, 4, 23, "Text",
   CellTags->"OPEDelta"],
  Cell[1401962, 57398, 212, 9, 23, "Text",
   CellTags->"OPEDelta"],
  Cell[1402211, 57412, 56, 1, 33, "Subsubsection",
   CellTags->"OPEDelta"],
  Cell[1402292, 57417, 146, 4, 27, "Input",
   CellTags->"OPEDelta"],
  Cell[1402441, 57423, 179, 6, 28, "Output",
   CellTags->"OPEDelta"],
  Cell[1402657, 57434, 133, 4, 27, "Input",
   CellTags->"OPEDelta"],
  Cell[1402793, 57440, 105, 3, 25, "Output",
   CellTags->"OPEDelta"],
  Cell[1402935, 57448, 141, 4, 27, "Input",
   CellTags->"OPEDelta"],
  Cell[1403079, 57454, 105, 3, 25, "Output",
   CellTags->"OPEDelta"]},
 "OPEi"->{
  Cell[1403211, 57461, 81, 1, 39, "ObjectName",
   CellTags->"OPEi"],
  Cell[1403317, 57466, 55, 1, 39, "Subsubsection",
   CellTags->"OPEi"],
  Cell[1403375, 57469, 171, 4, 32, "Text",
   CellTags->"OPEi"],
  Cell[1403583, 57478, 52, 1, 33, "Subsubsection",
   CellTags->"OPEi"],
  Cell[1403660, 57483, 75, 2, 27, "Input",
   CellTags->"OPEi"],
  Cell[1403738, 57487, 101, 3, 25, "Output",
   CellTags->"OPEi"],
  Cell[1403876, 57495, 259, 7, 27, "Input",
   CellTags->"OPEi"],
  Cell[1404138, 57504, 228, 7, 25, "Output",
   CellTags->"OPEi"],
  Cell[1404403, 57516, 1076, 40, 48, "Input",
   CellTags->"OPEi"],
  Cell[1405482, 57558, 202, 6, 25, "Output",
   CellTags->"OPEi"],
  Cell[1405699, 57567, 55, 1, 23, "Text",
   CellTags->"OPEi"],
  Cell[1405779, 57572, 519, 17, 27, "Input",
   CellTags->"OPEi"],
  Cell[1406301, 57591, 529, 19, 25, "Output",
   CellTags->"OPEi"],
  Cell[1406867, 57615, 534, 19, 27, "Input",
   CellTags->"OPEi"],
  Cell[1407404, 57636, 413, 15, 25, "Output",
   CellTags->"OPEi"],
  Cell[1407854, 57656, 519, 17, 27, "Input",
   CellTags->"OPEi"],
  Cell[1408376, 57675, 529, 19, 25, "Output",
   CellTags->"OPEi"]},
 "OPEInsert"->{
  Cell[1408932, 57698, 73, 1, 58, "ObjectName",
   CellTags->"OPEInsert"],
  Cell[1409030, 57703, 60, 1, 39, "Subsubsection",
   CellTags->"OPEInsert"],
  Cell[1409093, 57706, 264, 5, 54, "Text",
   CellTags->"OPEInsert"],
  Cell[1409360, 57713, 165, 9, 23, "Text",
   CellTags->"OPEInsert"],
  Cell[1409562, 57727, 57, 1, 33, "Subsubsection",
   CellTags->"OPEInsert"],
  Cell[1409622, 57730, 76, 2, 27, "Input",
   CellTags->"OPEInsert"]},
 "OPEInt"->{
  Cell[1409713, 57735, 67, 1, 39, "ObjectName",
   CellTags->"OPEInt"],
  Cell[1409805, 57740, 57, 1, 33, "Subsubsection",
   CellTags->"OPEInt"],
  Cell[1409865, 57743, 257, 5, 39, "Text",
   CellTags->"OPEInt"],
  Cell[1410125, 57750, 162, 9, 23, "Text",
   CellTags->"OPEInt"],
  Cell[1410324, 57764, 54, 1, 33, "Subsubsection",
   CellTags->"OPEInt"],
  Cell[1410381, 57767, 73, 2, 27, "Input",
   CellTags->"OPEInt"]},
 "OPEIntDelta"->{
  Cell[1410469, 57772, 77, 1, 39, "ObjectName",
   CellTags->"OPEIntDelta"],
  Cell[1410571, 57777, 62, 1, 33, "Subsubsection",
   CellTags->"OPEIntDelta"],
  Cell[1410636, 57780, 478, 10, 63, "Text",
   CellTags->"OPEIntDelta"],
  Cell[1411117, 57792, 167, 9, 23, "Text",
   CellTags->"OPEIntDelta"],
  Cell[1411321, 57806, 59, 1, 33, "Subsubsection",
   CellTags->"OPEIntDelta"],
  Cell[1411383, 57809, 78, 2, 27, "Input",
   CellTags->"OPEIntDelta"]},
 "OPEIntegrate"->{
  Cell[1411476, 57814, 79, 1, 39, "ObjectName",
   CellTags->"OPEIntegrate"],
  Cell[1411580, 57819, 63, 1, 33, "Subsubsection",
   CellTags->"OPEIntegrate"],
  Cell[1411646, 57822, 266, 5, 39, "Text",
   CellTags->"OPEIntegrate"],
  Cell[1411915, 57829, 168, 9, 23, "Text",
   CellTags->"OPEIntegrate"],
  Cell[1412120, 57843, 60, 1, 33, "Subsubsection",
   CellTags->"OPEIntegrate"],
  Cell[1412183, 57846, 79, 2, 27, "Input",
   CellTags->"OPEIntegrate"]},
 "OPEIntegrateDelta"->{
  Cell[1412277, 57851, 89, 1, 39, "ObjectName",
   CellTags->"OPEIntegrateDelta"],
  Cell[1412391, 57856, 68, 1, 33, "Subsubsection",
   CellTags->"OPEIntegrateDelta"],
  Cell[1412462, 57859, 499, 10, 63, "Text",
   CellTags->"OPEIntegrateDelta"],
  Cell[1412964, 57871, 173, 9, 23, "Text",
   CellTags->"OPEIntegrateDelta"],
  Cell[1413174, 57885, 65, 1, 33, "Subsubsection",
   CellTags->"OPEIntegrateDelta"],
  Cell[1413242, 57888, 84, 2, 27, "Input",
   CellTags->"OPEIntegrateDelta"]},
 "OPESumExplicit"->{
  Cell[1413341, 57893, 65, 1, 39, "ObjectName",
   CellTags->"OPESumExplicit"],
  Cell[1413431, 57898, 65, 1, 33, "Subsubsection",
   CellTags->"OPESumExplicit"],
  Cell[1413499, 57901, 85, 1, 23, "Text",
   CellTags->"OPESumExplicit"],
  Cell[1413587, 57904, 307, 14, 23, "Text",
   CellTags->"OPESumExplicit"],
  Cell[1413931, 57923, 62, 1, 33, "Subsubsection",
   CellTags->"OPESumExplicit"],
  Cell[1414018, 57928, 387, 13, 27, "Input",
   CellTags->"OPESumExplicit"],
  Cell[1414408, 57943, 407, 15, 53, "Output",
   CellTags->"OPESumExplicit"],
  Cell[1414852, 57963, 123, 3, 27, "Input",
   CellTags->"OPESumExplicit"],
  Cell[1414978, 57968, 408, 16, 46, "Output",
   CellTags->"OPESumExplicit"],
  Cell[1415423, 57989, 554, 18, 27, "Input",
   CellTags->"OPESumExplicit"],
  Cell[1415980, 58009, 702, 27, 55, "Output",
   CellTags->"OPESumExplicit"],
  Cell[1416719, 58041, 123, 3, 27, "Input",
   CellTags->"OPESumExplicit"],
  Cell[1416845, 58046, 1747, 66, 48, "Output",
   CellTags->"OPESumExplicit"],
  Cell[1418607, 58115, 157, 5, 27, "Input",
   CellTags->"OPESumExplicit"]},
 "OPESum"->{
  Cell[1418779, 58123, 49, 1, 39, "ObjectName",
   CellTags->"OPESum"],
  Cell[1418853, 58128, 57, 1, 33, "Subsubsection",
   CellTags->"OPESum"],
  Cell[1418913, 58131, 127, 4, 23, "Text",
   CellTags->"OPESum"],
  Cell[1419043, 58137, 323, 14, 23, "Text",
   CellTags->"OPESum"],
  Cell[1419403, 58156, 54, 1, 33, "Subsubsection",
   CellTags->"OPESum"],
  Cell[1419482, 58161, 460, 15, 27, "Input",
   CellTags->"OPESum"],
  Cell[1419945, 58178, 855, 31, 53, "Output",
   CellTags->"OPESum"],
  Cell[1420837, 58214, 115, 3, 27, "Input",
   CellTags->"OPESum"],
  Cell[1420955, 58219, 1604, 60, 49, "Output",
   CellTags->"OPESum"],
  Cell[1422596, 58284, 546, 18, 27, "Input",
   CellTags->"OPESum"],
  Cell[1423145, 58304, 694, 27, 55, "Output",
   CellTags->"OPESum"],
  Cell[1423876, 58336, 115, 3, 27, "Input",
   CellTags->"OPESum"],
  Cell[1423994, 58341, 1739, 66, 48, "Output",
   CellTags->"OPESum"],
  Cell[1425748, 58410, 149, 5, 27, "Input",
   CellTags->"OPESum"]},
 "OPESumSimplify"->{
  Cell[1425912, 58418, 65, 1, 39, "ObjectName",
   CellTags->"OPESumSimplify"],
  Cell[1426002, 58423, 65, 1, 26, "Subsubsection",
   CellTags->"OPESumSimplify"],
  Cell[1426070, 58426, 92, 1, 21, "Text",
   CellTags->"OPESumSimplify"],
  Cell[1426165, 58429, 307, 14, 22, "Text",
   CellTags->"OPESumSimplify"],
  Cell[1426509, 58448, 62, 1, 33, "Subsubsection",
   CellTags->"OPESumSimplify"],
  Cell[1426596, 58453, 143, 4, 27, "Input",
   CellTags->"OPESumSimplify"],
  Cell[1426742, 58459, 1052, 37, 51, "Output",
   CellTags->"OPESumSimplify"],
  Cell[1427831, 58501, 89, 2, 27, "Input",
   CellTags->"OPESumSimplify"],
  Cell[1427923, 58505, 1152, 39, 52, "Output",
   CellTags->"OPESumSimplify"],
  Cell[1429112, 58549, 273, 8, 27, "Input",
   CellTags->"OPESumSimplify"],
  Cell[1429388, 58559, 283, 11, 51, "Output",
   CellTags->"OPESumSimplify"],
  Cell[1429708, 58575, 439, 14, 27, "Input",
   CellTags->"OPESumSimplify"],
  Cell[1430150, 58591, 553, 22, 51, "Output",
   CellTags->"OPESumSimplify"],
  Cell[1430740, 58618, 116, 3, 27, "Input",
   CellTags->"OPESumSimplify"],
  Cell[1430859, 58623, 404, 13, 42, "Output",
   CellTags->"OPESumSimplify"]},
 "OPE1Loop"->{
  Cell[1431290, 58640, 54, 1, 58, "ObjectName",
   CellTags->"OPE1Loop"],
  Cell[1431369, 58645, 59, 1, 39, "Subsubsection",
   CellTags->"OPE1Loop"],
  Cell[1431431, 58648, 119, 3, 32, "Text",
   CellTags->"OPE1Loop"],
  Cell[1431553, 58653, 173, 9, 33, "Text",
   CellTags->"OPE1Loop"],
  Cell[1431763, 58667, 56, 1, 33, "Subsubsection",
   CellTags->"OPE1Loop"],
  Cell[1431822, 58670, 75, 2, 27, "Input",
   CellTags->"OPE1Loop"]},
 "OPE2TID"->{
  Cell[1431912, 58675, 69, 1, 58, "ObjectName",
   CellTags->"OPE2TID"],
  Cell[1432006, 58680, 58, 1, 39, "Subsubsection",
   CellTags->"OPE2TID"],
  Cell[1432067, 58683, 184, 4, 23, "Text",
   CellTags->"OPE2TID"],
  Cell[1432276, 58691, 114, 3, 27, "Input",
   CellTags->"OPE2TID"],
  Cell[1432393, 58696, 343, 10, 25, "Output",
   CellTags->"OPE2TID"],
  Cell[1432751, 58709, 172, 9, 33, "Text",
   CellTags->"OPE2TID"],
  Cell[1432960, 58723, 55, 1, 33, "Subsubsection",
   CellTags->"OPE2TID"],
  Cell[1433018, 58726, 74, 2, 27, "Input",
   CellTags->"OPE2TID"]},
 "OptionsSelect"->{
  Cell[1433107, 58731, 63, 1, 58, "ObjectName",
   CellTags->"OptionsSelect"],
  Cell[1433195, 58736, 64, 1, 39, "Subsubsection",
   CellTags->"OptionsSelect"],
  Cell[1433262, 58739, 219, 5, 54, "Text",
   CellTags->"OptionsSelect"]},
 "Pair"->{
  Cell[1433496, 58747, 45, 1, 58, "ObjectName",
   CellTags->"Pair"],
  Cell[1433566, 58752, 55, 1, 33, "Subsubsection",
   CellTags->"Pair"],
  Cell[1433624, 58755, 499, 11, 55, "Text",
   CellTags->"Pair"],
  Cell[1434126, 58768, 989, 49, 23, "Text",
   CellTags->"Pair"],
  Cell[1435152, 58822, 52, 1, 33, "Subsubsection",
   CellTags->"Pair"],
  Cell[1435207, 58825, 84, 1, 23, "Text",
   CellTags->"Pair"],
  Cell[1435316, 58830, 218, 6, 27, "Input",
   CellTags->"Pair"],
  Cell[1435537, 58838, 157, 5, 25, "Output",
   CellTags->"Pair"],
  Cell[1435709, 58846, 73, 1, 23, "Text",
   CellTags->"Pair"],
  Cell[1435807, 58851, 268, 8, 27, "Input",
   CellTags->"Pair"],
  Cell[1436078, 58861, 157, 5, 25, "Output",
   CellTags->"Pair"],
  Cell[1436272, 58871, 208, 6, 27, "Input",
   CellTags->"Pair"],
  Cell[1436483, 58879, 236, 10, 25, "Output",
   CellTags->"Pair"],
  Cell[1436756, 58894, 197, 6, 27, "Input",
   CellTags->"Pair"],
  Cell[1436956, 58902, 203, 8, 25, "Output",
   CellTags->"Pair"],
  Cell[1437196, 58915, 197, 6, 27, "Input",
   CellTags->"Pair"],
  Cell[1437396, 58923, 159, 6, 27, "Output",
   CellTags->"Pair"],
  Cell[1437592, 58934, 222, 7, 27, "Input",
   CellTags->"Pair"],
  Cell[1437817, 58943, 238, 9, 25, "Output",
   CellTags->"Pair"],
  Cell[1438092, 58957, 223, 7, 27, "Input",
   CellTags->"Pair"],
  Cell[1438318, 58966, 223, 9, 30, "Output",
   CellTags->"Pair"],
  Cell[1438578, 58980, 223, 7, 27, "Input",
   CellTags->"Pair"],
  Cell[1438804, 58989, 223, 9, 30, "Output",
   CellTags->"Pair"],
  Cell[1439064, 59003, 308, 10, 27, "Input",
   CellTags->"Pair"],
  Cell[1439375, 59015, 101, 3, 25, "Output",
   CellTags->"Pair"],
  Cell[1439513, 59023, 272, 8, 27, "Input",
   CellTags->"Pair"],
  Cell[1439788, 59033, 292, 12, 27, "Output",
   CellTags->"Pair"],
  Cell[1440117, 59050, 383, 12, 27, "Input",
   CellTags->"Pair"],
  Cell[1440503, 59064, 101, 3, 25, "Output",
   CellTags->"Pair"]},
 "PairCollect"->{
  Cell[1440631, 59071, 59, 1, 39, "ObjectName",
   CellTags->"PairCollect"],
  Cell[1440715, 59076, 62, 1, 33, "Subsubsection",
   CellTags->"PairCollect"],
  Cell[1440780, 59079, 153, 4, 21, "Text",
   CellTags->"PairCollect"],
  Cell[1440936, 59085, 286, 14, 22, "Text",
   CellTags->"PairCollect"]},
 "PairContract"->{
  Cell[1441237, 59102, 61, 1, 39, "ObjectName",
   CellTags->"PairContract"],
  Cell[1441323, 59107, 63, 1, 26, "Subsubsection",
   CellTags->"PairContract"],
  Cell[1441389, 59110, 118, 3, 21, "Text",
   CellTags->"PairContract"],
  Cell[1441510, 59115, 275, 13, 22, "Text",
   CellTags->"PairContract"]},
 "PairContract2"->{
  Cell[1441800, 59131, 63, 1, 39, "ObjectName",
   CellTags->"PairContract2"],
  Cell[1441888, 59136, 64, 1, 26, "Subsubsection",
   CellTags->"PairContract2"],
  Cell[1441955, 59139, 142, 4, 21, "Text",
   CellTags->"PairContract2"],
  Cell[1442100, 59145, 398, 18, 22, "Text",
   CellTags->"PairContract2"]},
 "PairContract3"->{
  Cell[1442513, 59166, 63, 1, 39, "ObjectName",
   CellTags->"PairContract3"],
  Cell[1442601, 59171, 64, 1, 26, "Subsubsection",
   CellTags->"PairContract3"],
  Cell[1442668, 59174, 142, 4, 21, "Text",
   CellTags->"PairContract3"],
  Cell[1442813, 59180, 398, 18, 22, "Text",
   CellTags->"PairContract3"]},
 "PartialD"->{
  Cell[1443226, 59201, 53, 1, 39, "ObjectName",
   CellTags->"PartialD"],
  Cell[1443304, 59206, 59, 1, 26, "Subsubsection",
   CellTags->"PartialD"],
  Cell[1443366, 59209, 864, 35, 38, "Text",
   CellTags->"PartialD"],
  Cell[1444233, 59246, 581, 24, 22, "Text",
   CellTags->"PartialD"],
  Cell[1444851, 59275, 65, 1, 34, "Subsubsection",
   CellTags->"PartialD"],
  Cell[1444941, 59280, 233, 7, 27, "Input",
   CellTags->"PartialD"],
  Cell[1445177, 59289, 302, 11, 32, "Output",
   CellTags->"PartialD"],
  Cell[1445516, 59305, 116, 3, 27, "Input",
   CellTags->"PartialD"],
  Cell[1445635, 59310, 351, 14, 29, "Output",
   CellTags->"PartialD"],
  Cell[1446023, 59329, 114, 3, 27, "Input",
   CellTags->"PartialD"],
  Cell[1446140, 59334, 287, 7, 39, "Output",
   CellTags->"PartialD"]},
 "PartialDRelations"->{
  Cell[1446454, 59345, 71, 1, 58, "ObjectName",
   CellTags->"PartialDRelations"],
  Cell[1446550, 59350, 68, 1, 39, "Subsubsection",
   CellTags->"PartialDRelations"],
  Cell[1446621, 59353, 191, 5, 32, "Text",
   CellTags->"PartialDRelations"],
  Cell[1446815, 59360, 700, 29, 33, "Text",
   CellTags->"PartialDRelations"],
  Cell[1447552, 59394, 74, 1, 34, "Subsubsection",
   CellTags->"PartialDRelations"],
  Cell[1447651, 59399, 344, 10, 27, "Input",
   CellTags->"PartialDRelations"],
  Cell[1447998, 59411, 348, 12, 32, "Output",
   CellTags->"PartialDRelations"],
  Cell[1448383, 59428, 256, 7, 27, "Input",
   CellTags->"PartialDRelations"],
  Cell[1448642, 59437, 855, 34, 29, "Output",
   CellTags->"PartialDRelations"]},
 "PartialFourVector"->{
  Cell[1449524, 59475, 71, 1, 58, "ObjectName",
   CellTags->"PartialFourVector"],
  Cell[1449620, 59480, 68, 1, 39, "Subsubsection",
   CellTags->"PartialFourVector"],
  Cell[1449691, 59483, 277, 6, 54, "Text",
   CellTags->"PartialFourVector"],
  Cell[1449971, 59491, 402, 19, 33, "Text",
   CellTags->"PartialFourVector"],
  Cell[1450410, 59515, 74, 1, 34, "Subsubsection",
   CellTags->"PartialFourVector"],
  Cell[1450509, 59520, 382, 11, 35, "Input",
   CellTags->"PartialFourVector"],
  Cell[1450894, 59533, 399, 15, 28, "Output",
   CellTags->"PartialFourVector"]},
 "PartialIntegrate"->{
  Cell[1451320, 59552, 69, 1, 58, "ObjectName",
   CellTags->"PartialIntegrate"],
  Cell[1451414, 59557, 67, 1, 39, "Subsubsection",
   CellTags->"PartialIntegrate"],
  Cell[1451484, 59560, 283, 6, 39, "Text",
   CellTags->"PartialIntegrate"],
  Cell[1451792, 59570, 132, 3, 27, "Input",
   CellTags->"PartialIntegrate"],
  Cell[1451927, 59575, 185, 6, 25, "Output",
   CellTags->"PartialIntegrate"],
  Cell[1452161, 59587, 73, 1, 34, "Subsubsection",
   CellTags->"PartialIntegrate"],
  Cell[1452259, 59592, 326, 10, 27, "Input",
   CellTags->"PartialIntegrate"],
  Cell[1452588, 59604, 1229, 40, 43, "Output",
   CellTags->"PartialIntegrate"],
  Cell[1454198, 59663, 275, 9, 27, "Input",
   CellTags->"PartialIntegrate"],
  Cell[1454476, 59674, 383, 14, 43, "Output",
   CellTags->"PartialIntegrate"],
  Cell[1454896, 59693, 293, 10, 44, "Input",
   CellTags->"PartialIntegrate"],
  Cell[1455192, 59705, 378, 14, 48, "Output",
   CellTags->"PartialIntegrate"],
  Cell[1455607, 59724, 443, 14, 27, "Input",
   CellTags->"PartialIntegrate"],
  Cell[1456053, 59740, 246, 8, 46, "Output",
   CellTags->"PartialIntegrate"],
  Cell[1456336, 59753, 320, 11, 27, "Input",
   CellTags->"PartialIntegrate"],
  Cell[1456659, 59766, 246, 8, 46, "Output",
   CellTags->"PartialIntegrate"],
  Cell[1456920, 59777, 138, 4, 27, "Input",
   CellTags->"PartialIntegrate"]},
 "PartitHead"->{
  Cell[1457073, 59784, 57, 1, 39, "ObjectName",
   CellTags->"PartitHead"],
  Cell[1457155, 59789, 61, 1, 33, "Subsubsection",
   CellTags->"PartitHead"],
  Cell[1457219, 59792, 167, 4, 23, "Text",
   CellTags->"PartitHead"]},
 "PauliSigma"->{
  Cell[1457401, 59799, 57, 1, 39, "ObjectName",
   CellTags->"PauliSigma"],
  Cell[1457483, 59804, 61, 1, 33, "Subsubsection",
   CellTags->"PauliSigma"],
  Cell[1457547, 59807, 252, 5, 39, "Text",
   CellTags->"PauliSigma"],
  Cell[1457824, 59816, 142, 4, 27, "Input",
   CellTags->"PauliSigma"],
  Cell[1457969, 59822, 4559, 125, 123, "Output",
   CellTags->"PauliSigma"]},
 "PaVe"->{
  Cell[1462555, 59951, 45, 1, 39, "ObjectName",
   CellTags->"PaVe"],
  Cell[1462625, 59956, 55, 1, 33, "Subsubsection",
   CellTags->"PaVe"],
  Cell[1462683, 59959, 428, 7, 55, "Text",
   CellTags->"PaVe"],
  Cell[1463114, 59968, 266, 8, 23, "Text",
   CellTags->"PaVe"],
  Cell[1463383, 59978, 181, 9, 23, "Text",
   CellTags->"PaVe"],
  Cell[1463601, 59992, 52, 1, 33, "Subsubsection",
   CellTags->"PaVe"],
  Cell[1463656, 59995, 78, 1, 23, "Text",
   CellTags->"PaVe"],
  Cell[1463759, 60000, 303, 10, 27, "Input",
   CellTags->"PaVe"],
  Cell[1464065, 60012, 304, 9, 25, "Output",
   CellTags->"PaVe"],
  Cell[1464406, 60026, 271, 9, 27, "Input",
   CellTags->"PaVe"],
  Cell[1464680, 60037, 311, 11, 29, "Output",
   CellTags->"PaVe"]},
 "PaVeOrderList"->{
  Cell[1465018, 60052, 63, 1, 39, "ObjectName",
   CellTags->"PaVeOrderList"],
  Cell[1465106, 60057, 64, 1, 33, "Subsubsection",
   CellTags->"PaVeOrderList"],
  Cell[1465173, 60060, 176, 4, 23, "Text",
   CellTags->"PaVeOrderList"],
  Cell[1465352, 60066, 487, 23, 23, "Text",
   CellTags->"PaVeOrderList"]},
 "PaVeOrder"->{
  Cell[1465854, 60092, 55, 1, 39, "ObjectName",
   CellTags->"PaVeOrder"],
  Cell[1465934, 60097, 60, 1, 33, "Subsubsection",
   CellTags->"PaVeOrder"],
  Cell[1465997, 60100, 564, 16, 39, "Text",
   CellTags->"PaVeOrder"],
  Cell[1466564, 60118, 186, 9, 23, "Text",
   CellTags->"PaVeOrder"],
  Cell[1466787, 60132, 57, 1, 33, "Subsubsection",
   CellTags->"PaVeOrder"],
  Cell[1466869, 60137, 413, 12, 27, "Input",
   CellTags->"PaVeOrder"],
  Cell[1467285, 60151, 382, 12, 25, "Output",
   CellTags->"PaVeOrder"],
  Cell[1467704, 60168, 413, 12, 27, "Input",
   CellTags->"PaVeOrder"],
  Cell[1468120, 60182, 382, 12, 25, "Output",
   CellTags->"PaVeOrder"],
  Cell[1468539, 60199, 706, 20, 48, "Input",
   CellTags->"PaVeOrder"],
  Cell[1469248, 60221, 623, 18, 25, "Output",
   CellTags->"PaVeOrder"]},
 "PaVeReduce"->{
  Cell[1469898, 60243, 57, 1, 39, "ObjectName",
   CellTags->"PaVeReduce"],
  Cell[1469980, 60248, 61, 1, 33, "Subsubsection",
   CellTags->"PaVeReduce"],
  Cell[1470044, 60251, 167, 4, 23, "Text",
   CellTags->"PaVeReduce"],
  Cell[1470236, 60259, 120, 3, 27, "Input",
   CellTags->"PaVeReduce"],
  Cell[1470359, 60264, 446, 13, 25, "Output",
   CellTags->"PaVeReduce"],
  Cell[1470842, 60282, 106, 3, 27, "Input",
   CellTags->"PaVeReduce"],
  Cell[1470951, 60287, 332, 5, 56, "Print",
   CellTags->{"Info3522790398-4590919", "PaVeReduce"}],
  Cell[1471298, 60295, 279, 14, 23, "Text",
   CellTags->"PaVeReduce"],
  Cell[1471614, 60314, 58, 1, 33, "Subsubsection",
   CellTags->"PaVeReduce"],
  Cell[1471697, 60319, 520, 16, 27, "Input",
   CellTags->"PaVeReduce"],
  Cell[1472220, 60337, 3016, 104, 107, "Output",
   CellTags->"PaVeReduce"],
  Cell[1475273, 60446, 106, 3, 27, "Input",
   CellTags->"PaVeReduce"],
  Cell[1475382, 60451, 136, 4, 25, "Output",
   CellTags->"PaVeReduce"],
  Cell[1475555, 60460, 107, 3, 27, "Input",
   CellTags->"PaVeReduce"],
  Cell[1475665, 60465, 136, 4, 25, "Output",
   CellTags->"PaVeReduce"],
  Cell[1475838, 60474, 491, 15, 27, "Input",
   CellTags->"PaVeReduce"],
  Cell[1476332, 60491, 468, 15, 43, "Output",
   CellTags->"PaVeReduce"],
  Cell[1476837, 60511, 398, 12, 48, "Input",
   CellTags->"PaVeReduce"],
  Cell[1477238, 60525, 792, 23, 72, "Output",
   CellTags->"PaVeReduce"],
  Cell[1478045, 60551, 209, 7, 27, "Input",
   CellTags->"PaVeReduce"],
  Cell[1478257, 60560, 162, 5, 27, "Input",
   CellTags->"PaVeReduce"],
  Cell[1478444, 60569, 633, 17, 48, "Input",
   CellTags->"PaVeReduce"],
  Cell[1479080, 60588, 8311, 259, 359, "Output",
   CellTags->"PaVeReduce"],
  Cell[1487406, 60850, 267, 8, 27, "Input",
   CellTags->"PaVeReduce"],
  Cell[1487698, 60862, 375, 11, 27, "Input",
   CellTags->"PaVeReduce"],
  Cell[1488076, 60875, 2976, 57, 633, "Output",
   CellTags->"PaVeReduce"],
  Cell[1491067, 60935, 253, 7, 27, "Input",
   CellTags->"PaVeReduce"]},
 "Info3522790398-4590919"->{
  Cell[1470951, 60287, 332, 5, 56, "Print",
   CellTags->{"Info3522790398-4590919", "PaVeReduce"}]},
 "PD"->{
  Cell[1491335, 60945, 41, 1, 39, "ObjectName",
   CellTags->"PD"],
  Cell[1491401, 60950, 53, 1, 33, "Subsubsection",
   CellTags->"PD"],
  Cell[1491457, 60953, 81, 1, 23, "Text",
   CellTags->"PD"],
  Cell[1491541, 60956, 310, 14, 23, "Text",
   CellTags->"PD"]},
 "PlusDistribution"->{
  Cell[1491866, 60973, 69, 1, 39, "ObjectName",
   CellTags->"PlusDistribution"],
  Cell[1491960, 60978, 67, 1, 33, "Subsubsection",
   CellTags->"PlusDistribution"],
  Cell[1492030, 60981, 147, 4, 23, "Text",
   CellTags->"PlusDistribution"],
  Cell[1492180, 60987, 193, 9, 23, "Text",
   CellTags->"PlusDistribution"],
  Cell[1492410, 61001, 64, 1, 33, "Subsubsection",
   CellTags->"PlusDistribution"],
  Cell[1492499, 61006, 198, 6, 27, "Input",
   CellTags->"PlusDistribution"],
  Cell[1492700, 61014, 208, 7, 44, "Output",
   CellTags->"PlusDistribution"],
  Cell[1492945, 61026, 254, 8, 27, "Input",
   CellTags->"PlusDistribution"],
  Cell[1493202, 61036, 268, 9, 44, "Output",
   CellTags->"PlusDistribution"],
  Cell[1493507, 61050, 329, 10, 27, "Input",
   CellTags->"PlusDistribution"],
  Cell[1493839, 61062, 113, 3, 25, "Output",
   CellTags->"PlusDistribution"],
  Cell[1493989, 61070, 389, 12, 27, "Input",
   CellTags->"PlusDistribution"],
  Cell[1494381, 61084, 113, 3, 25, "Output",
   CellTags->"PlusDistribution"],
  Cell[1494531, 61092, 417, 13, 27, "Input",
   CellTags->"PlusDistribution"],
  Cell[1494951, 61107, 113, 3, 25, "Output",
   CellTags->"PlusDistribution"],
  Cell[1495101, 61115, 307, 10, 27, "Input",
   CellTags->"PlusDistribution"],
  Cell[1495411, 61127, 376, 13, 44, "Output",
   CellTags->"PlusDistribution"]},
 "Polarization"->{
  Cell[1495814, 61144, 61, 1, 39, "ObjectName",
   CellTags->"Polarization"],
  Cell[1495900, 61149, 63, 1, 33, "Subsubsection",
   CellTags->"Polarization"],
  Cell[1495966, 61152, 769, 12, 87, "Text",
   CellTags->"Polarization"],
  Cell[1496738, 61166, 484, 19, 23, "Text",
   CellTags->"Polarization"],
  Cell[1497259, 61190, 60, 1, 33, "Subsubsection",
   CellTags->"Polarization"],
  Cell[1497344, 61195, 118, 3, 27, "Input",
   CellTags->"Polarization"],
  Cell[1497465, 61200, 151, 4, 25, "Output",
   CellTags->"Polarization"],
  Cell[1497653, 61209, 153, 4, 27, "Input",
   CellTags->"Polarization"],
  Cell[1497809, 61215, 168, 4, 39, "Output",
   CellTags->"Polarization"],
  Cell[1498014, 61224, 160, 5, 27, "Input",
   CellTags->"Polarization"],
  Cell[1498177, 61231, 237, 8, 27, "Output",
   CellTags->"Polarization"],
  Cell[1498451, 61244, 196, 6, 27, "Input",
   CellTags->"Polarization"],
  Cell[1498650, 61252, 187, 5, 39, "Output",
   CellTags->"Polarization"],
  Cell[1498874, 61262, 155, 4, 27, "Input",
   CellTags->"Polarization"],
  Cell[1499032, 61268, 270, 9, 25, "Output",
   CellTags->"Polarization"],
  Cell[1499339, 61282, 194, 6, 27, "Input",
   CellTags->"Polarization"],
  Cell[1499536, 61290, 206, 5, 39, "Output",
   CellTags->"Polarization"],
  Cell[1499779, 61300, 302, 8, 27, "Input",
   CellTags->"Polarization"],
  Cell[1500084, 61310, 109, 3, 25, "Output",
   CellTags->"Polarization"]},
 "PolarizationSum"->{
  Cell[1500220, 61317, 67, 1, 39, "ObjectName",
   CellTags->"PolarizationSum"],
  Cell[1500312, 61322, 66, 1, 33, "Subsubsection",
   CellTags->"PolarizationSum"],
  Cell[1500381, 61325, 277, 5, 39, "Text",
   CellTags->"PolarizationSum"],
  Cell[1500683, 61334, 130, 3, 27, "Input",
   CellTags->"PolarizationSum"],
  Cell[1500816, 61339, 173, 5, 25, "Output",
   CellTags->"PolarizationSum"],
  Cell[1501004, 61347, 198, 9, 23, "Text",
   CellTags->"PolarizationSum"],
  Cell[1501239, 61361, 63, 1, 33, "Subsubsection",
   CellTags->"PolarizationSum"],
  Cell[1501327, 61366, 155, 4, 27, "Input",
   CellTags->"PolarizationSum"],
  Cell[1501485, 61372, 183, 6, 25, "Output",
   CellTags->"PolarizationSum"],
  Cell[1501705, 61383, 165, 4, 27, "Input",
   CellTags->"PolarizationSum"],
  Cell[1501873, 61389, 605, 25, 46, "Output",
   CellTags->"PolarizationSum"],
  Cell[1502515, 61419, 175, 4, 27, "Input",
   CellTags->"PolarizationSum"],
  Cell[1502693, 61425, 1686, 71, 48, "Output",
   CellTags->"PolarizationSum"],
  Cell[1504416, 61501, 247, 7, 27, "Input",
   CellTags->"PolarizationSum"],
  Cell[1504666, 61510, 4044, 162, 50, "Output",
   CellTags->"PolarizationSum"]},
 "PolarizationUncontract"->{
  Cell[1508737, 61676, 81, 1, 39, "ObjectName",
   CellTags->"PolarizationUncontract"],
  Cell[1508843, 61681, 73, 1, 33, "Subsubsection",
   CellTags->"PolarizationUncontract"],
  Cell[1508919, 61684, 152, 4, 23, "Text",
   CellTags->"PolarizationUncontract"],
  Cell[1509074, 61690, 321, 14, 23, "Text",
   CellTags->"PolarizationUncontract"]},
 "PolarizationVector"->{
  Cell[1509410, 61707, 73, 1, 39, "ObjectName",
   CellTags->"PolarizationVector"],
  Cell[1509508, 61712, 69, 1, 33, "Subsubsection",
   CellTags->"PolarizationVector"],
  Cell[1509580, 61715, 103, 1, 23, "Text",
   CellTags->"PolarizationVector"],
  Cell[1509686, 61718, 409, 18, 23, "Text",
   CellTags->"PolarizationVector"],
  Cell[1510132, 61741, 66, 1, 33, "Subsubsection",
   CellTags->"PolarizationVector"],
  Cell[1510223, 61746, 157, 4, 27, "Input",
   CellTags->"PolarizationVector"],
  Cell[1510383, 61752, 258, 9, 28, "Output",
   CellTags->"PolarizationVector"],
  Cell[1510678, 61766, 194, 5, 27, "Input",
   CellTags->"PolarizationVector"],
  Cell[1510875, 61773, 268, 9, 29, "Output",
   CellTags->"PolarizationVector"],
  Cell[1511158, 61785, 241, 9, 26, "Text",
   CellTags->"PolarizationVector"],
  Cell[1511424, 61798, 190, 5, 27, "Input",
   CellTags->"PolarizationVector"],
  Cell[1511617, 61805, 310, 8, 39, "Output",
   CellTags->"PolarizationVector"],
  Cell[1511942, 61816, 440, 18, 26, "Text",
   CellTags->"PolarizationVector"],
  Cell[1512407, 61838, 284, 8, 27, "Input",
   CellTags->"PolarizationVector"],
  Cell[1512694, 61848, 314, 11, 28, "Output",
   CellTags->"PolarizationVector"],
  Cell[1513045, 61864, 121, 3, 27, "Input",
   CellTags->"PolarizationVector"],
  Cell[1513169, 61869, 115, 3, 25, "Output",
   CellTags->"PolarizationVector"],
  Cell[1513321, 61877, 310, 9, 27, "Input",
   CellTags->"PolarizationVector"],
  Cell[1513634, 61888, 376, 14, 28, "Output",
   CellTags->"PolarizationVector"],
  Cell[1514047, 61907, 121, 3, 27, "Input",
   CellTags->"PolarizationVector"],
  Cell[1514171, 61912, 336, 12, 25, "Output",
   CellTags->"PolarizationVector"],
  Cell[1514522, 61927, 1511, 51, 41, "Text",
   CellTags->"PolarizationVector"],
  Cell[1516058, 61982, 310, 9, 27, "Input",
   CellTags->"PolarizationVector"],
  Cell[1516371, 61993, 376, 14, 28, "Output",
   CellTags->"PolarizationVector"],
  Cell[1516784, 62012, 121, 3, 27, "Input",
   CellTags->"PolarizationVector"],
  Cell[1516908, 62017, 336, 12, 25, "Output",
   CellTags->"PolarizationVector"],
  Cell[1517259, 62032, 153, 4, 27, "Input",
   CellTags->"PolarizationVector"]},
 "PositiveInteger"->{
  Cell[1517427, 62039, 67, 1, 39, "ObjectName",
   CellTags->"PositiveInteger"],
  Cell[1517519, 62044, 66, 1, 33, "Subsubsection",
   CellTags->"PositiveInteger"],
  Cell[1517588, 62047, 136, 4, 23, "Text",
   CellTags->"PositiveInteger"],
  Cell[1517727, 62053, 186, 9, 23, "Text",
   CellTags->"PositiveInteger"]},
 "PositiveNumber"->{
  Cell[1517928, 62065, 65, 1, 39, "ObjectName",
   CellTags->"PositiveNumber"],
  Cell[1518018, 62070, 65, 1, 33, "Subsubsection",
   CellTags->"PositiveNumber"],
  Cell[1518086, 62073, 146, 4, 23, "Text",
   CellTags->"PositiveNumber"],
  Cell[1518235, 62079, 185, 9, 23, "Text",
   CellTags->"PositiveNumber"]},
 "PowerFactor"->{
  Cell[1518435, 62091, 59, 1, 39, "ObjectName",
   CellTags->"PowerFactor"],
  Cell[1518519, 62096, 62, 1, 33, "Subsubsection",
   CellTags->"PowerFactor"],
  Cell[1518584, 62099, 375, 16, 23, "Text",
   CellTags->"PowerFactor"],
  Cell[1518962, 62117, 197, 9, 23, "Text",
   CellTags->"PowerFactor"],
  Cell[1519196, 62131, 59, 1, 33, "Subsubsection",
   CellTags->"PowerFactor"],
  Cell[1519280, 62136, 144, 5, 27, "Input",
   CellTags->"PowerFactor"],
  Cell[1519427, 62143, 181, 6, 25, "Output",
   CellTags->"PowerFactor"],
  Cell[1519645, 62154, 116, 3, 27, "Input",
   CellTags->"PowerFactor"],
  Cell[1519764, 62159, 181, 6, 25, "Output",
   CellTags->"PowerFactor"]},
 "PowerSimplify"->{
  Cell[1519972, 62169, 63, 1, 39, "ObjectName",
   CellTags->"PowerSimplify"],
  Cell[1520060, 62174, 64, 1, 33, "Subsubsection",
   CellTags->"PowerSimplify"],
  Cell[1520127, 62177, 2559, 112, 55, "Text",
   CellTags->"PowerSimplify"],
  Cell[1522689, 62291, 282, 14, 23, "Text",
   CellTags->"PowerSimplify"],
  Cell[1523008, 62310, 61, 1, 33, "Subsubsection",
   CellTags->"PowerSimplify"],
  Cell[1523094, 62315, 234, 8, 27, "Input",
   CellTags->"PowerSimplify"],
  Cell[1523331, 62325, 110, 3, 25, "Output",
   CellTags->"PowerSimplify"],
  Cell[1523478, 62333, 239, 8, 27, "Input",
   CellTags->"PowerSimplify"],
  Cell[1523720, 62343, 178, 6, 25, "Output",
   CellTags->"PowerSimplify"],
  Cell[1523935, 62354, 239, 8, 27, "Input",
   CellTags->"PowerSimplify"],
  Cell[1524177, 62364, 178, 6, 25, "Output",
   CellTags->"PowerSimplify"],
  Cell[1524392, 62375, 190, 6, 27, "Input",
   CellTags->"PowerSimplify"],
  Cell[1524585, 62383, 178, 6, 25, "Output",
   CellTags->"PowerSimplify"]},
 "Power2"->{
  Cell[1524790, 62393, 49, 1, 39, "ObjectName",
   CellTags->"Power2"],
  Cell[1524864, 62398, 57, 1, 33, "Subsubsection",
   CellTags->"Power2"],
  Cell[1524924, 62401, 213, 5, 39, "Text",
   CellTags->"Power2"],
  Cell[1525140, 62408, 186, 9, 23, "Text",
   CellTags->"Power2"],
  Cell[1525363, 62422, 54, 1, 33, "Subsubsection",
   CellTags->"Power2"],
  Cell[1525442, 62427, 147, 5, 27, "Input",
   CellTags->"Power2"],
  Cell[1525592, 62434, 171, 6, 27, "Output",
   CellTags->"Power2"],
  Cell[1525800, 62445, 148, 5, 27, "Input",
   CellTags->"Power2"],
  Cell[1525951, 62452, 257, 10, 27, "Output",
   CellTags->"Power2"]},
 "PostFortranFile"->{
  Cell[1526235, 62466, 67, 1, 39, "ObjectName",
   CellTags->"PostFortranFile"],
  Cell[1526327, 62471, 66, 1, 33, "Subsubsection",
   CellTags->"PostFortranFile"],
  Cell[1526396, 62474, 229, 5, 39, "Text",
   CellTags->"PostFortranFile"],
  Cell[1526628, 62481, 308, 14, 23, "Text",
   CellTags->"PostFortranFile"]},
 "Prefactor"->{
  Cell[1526951, 62498, 55, 1, 39, "ObjectName",
   CellTags->"Prefactor"],
  Cell[1527031, 62503, 60, 1, 33, "Subsubsection",
   CellTags->"Prefactor"],
  Cell[1527094, 62506, 290, 6, 39, "Text",
   CellTags->"Prefactor"],
  Cell[1527387, 62514, 293, 14, 23, "Text",
   CellTags->"Prefactor"]},
 "PreFortranFile"->{
  Cell[1527695, 62531, 65, 1, 39, "ObjectName",
   CellTags->"PreFortranFile"],
  Cell[1527785, 62536, 65, 1, 33, "Subsubsection",
   CellTags->"PreFortranFile"],
  Cell[1527853, 62539, 232, 5, 39, "Text",
   CellTags->"PreFortranFile"],
  Cell[1528088, 62546, 310, 14, 23, "Text",
   CellTags->"PreFortranFile"]},
 "PropagatorDenominator"->{
  Cell[1528413, 62563, 79, 1, 39, "ObjectName",
   CellTags->"PropagatorDenominator"],
  Cell[1528517, 62568, 72, 1, 33, "Subsubsection",
   CellTags->"PropagatorDenominator"],
  Cell[1528592, 62571, 549, 16, 55, "Text",
   CellTags->"PropagatorDenominator"],
  Cell[1529144, 62589, 493, 19, 23, "Text",
   CellTags->"PropagatorDenominator"],
  Cell[1529674, 62613, 69, 1, 33, "Subsubsection",
   CellTags->"PropagatorDenominator"],
  Cell[1529768, 62618, 178, 5, 27, "Input",
   CellTags->"PropagatorDenominator"],
  Cell[1529949, 62625, 215, 7, 48, "Output",
   CellTags->"PropagatorDenominator"],
  Cell[1530201, 62637, 136, 3, 27, "Input",
   CellTags->"PropagatorDenominator"],
  Cell[1530340, 62642, 164, 5, 48, "Output",
   CellTags->"PropagatorDenominator"],
  Cell[1530541, 62652, 189, 5, 27, "Input",
   CellTags->"PropagatorDenominator"],
  Cell[1530733, 62659, 215, 7, 48, "Output",
   CellTags->"PropagatorDenominator"],
  Cell[1530985, 62671, 158, 4, 27, "Input",
   CellTags->"PropagatorDenominator"],
  Cell[1531146, 62677, 235, 6, 39, "Output",
   CellTags->"PropagatorDenominator"],
  Cell[1531418, 62688, 194, 5, 27, "Input",
   CellTags->"PropagatorDenominator"],
  Cell[1531615, 62695, 235, 6, 39, "Output",
   CellTags->"PropagatorDenominator"],
  Cell[1531887, 62706, 145, 3, 27, "Input",
   CellTags->"PropagatorDenominator"],
  Cell[1532035, 62711, 253, 9, 48, "Output",
   CellTags->"PropagatorDenominator"],
  Cell[1532325, 62725, 127, 3, 27, "Input",
   CellTags->"PropagatorDenominator"],
  Cell[1532455, 62730, 325, 10, 58, "Output",
   CellTags->"PropagatorDenominator"],
  Cell[1532795, 62743, 121, 3, 27, "Input",
   CellTags->"PropagatorDenominator"]},
 "PropagatorDenominatorExplicit"->{
  Cell[1532931, 62749, 95, 1, 39, "ObjectName",
   CellTags->"PropagatorDenominatorExplicit"],
  Cell[1533051, 62754, 80, 1, 33, "Subsubsection",
   CellTags->"PropagatorDenominatorExplicit"],
  Cell[1533134, 62757, 243, 5, 39, "Text",
   CellTags->"PropagatorDenominatorExplicit"],
  Cell[1533380, 62764, 379, 14, 23, "Text",
   CellTags->"PropagatorDenominatorExplicit"],
  Cell[1533796, 62783, 77, 1, 33, "Subsubsection",
   CellTags->"PropagatorDenominatorExplicit"],
  Cell[1533898, 62788, 308, 11, 27, "Input",
   CellTags->"PropagatorDenominatorExplicit"],
  Cell[1534209, 62801, 357, 12, 49, "Output",
   CellTags->"PropagatorDenominatorExplicit"],
  Cell[1534603, 62818, 181, 5, 27, "Input",
   CellTags->"PropagatorDenominatorExplicit"],
  Cell[1534787, 62825, 766, 29, 49, "Output",
   CellTags->"PropagatorDenominatorExplicit"],
  Cell[1535590, 62859, 131, 3, 27, "Input",
   CellTags->"PropagatorDenominatorExplicit"],
  Cell[1535724, 62864, 547, 18, 61, "Output",
   CellTags->"PropagatorDenominatorExplicit"]},
 "QGV"->{
  Cell[1536298, 62886, 43, 1, 39, "ObjectName",
   CellTags->"QGV"],
  Cell[1536366, 62891, 54, 1, 33, "Subsubsection",
   CellTags->"QGV"],
  Cell[1536423, 62894, 72, 1, 23, "Text",
   CellTags->"QGV"],
  Cell[1536498, 62897, 198, 9, 23, "Text",
   CellTags->"QGV"]},
 "QO"->{
  Cell[1536711, 62909, 41, 1, 39, "ObjectName",
   CellTags->"QO"],
  Cell[1536777, 62914, 53, 1, 33, "Subsubsection",
   CellTags->"QO"],
  Cell[1536833, 62917, 73, 1, 23, "Text",
   CellTags->"QO"],
  Cell[1536909, 62920, 206, 9, 23, "Text",
   CellTags->"QO"]},
 "QP"->{
  Cell[1537130, 62932, 41, 1, 39, "ObjectName",
   CellTags->"QP"],
  Cell[1537196, 62937, 53, 1, 33, "Subsubsection",
   CellTags->"QP"],
  Cell[1537252, 62940, 169, 4, 23, "Text",
   CellTags->"QP"],
  Cell[1537424, 62946, 194, 9, 23, "Text",
   CellTags->"QP"]},
 "QuantumField"->{
  Cell[1537633, 62958, 61, 1, 39, "ObjectName",
   CellTags->"QuantumField"],
  Cell[1537719, 62963, 63, 1, 33, "Subsubsection",
   CellTags->"QuantumField"],
  Cell[1537785, 62966, 404, 9, 39, "Text",
   CellTags->"QuantumField"],
  Cell[1538192, 62977, 421, 19, 23, "Text",
   CellTags->"QuantumField"],
  Cell[1538650, 63001, 60, 1, 33, "Subsubsection",
   CellTags->"QuantumField"],
  Cell[1538713, 63004, 71, 1, 23, "Text",
   CellTags->"QuantumField"],
  Cell[1538809, 63009, 118, 3, 27, "Input",
   CellTags->"QuantumField"],
  Cell[1538930, 63014, 109, 3, 25, "Output",
   CellTags->"QuantumField"],
  Cell[1539076, 63022, 131, 3, 27, "Input",
   CellTags->"QuantumField"],
  Cell[1539210, 63027, 137, 4, 25, "Output",
   CellTags->"QuantumField"],
  Cell[1539384, 63036, 127, 3, 27, "Input",
   CellTags->"QuantumField"],
  Cell[1539514, 63041, 114, 3, 25, "Output",
   CellTags->"QuantumField"],
  Cell[1539643, 63047, 80, 1, 23, "Text",
   CellTags->"QuantumField"],
  Cell[1539748, 63052, 169, 5, 27, "Input",
   CellTags->"QuantumField"],
  Cell[1539920, 63059, 135, 4, 28, "Output",
   CellTags->"QuantumField"],
  Cell[1540070, 63066, 94, 1, 23, "Text",
   CellTags->"QuantumField"],
  Cell[1540189, 63071, 212, 6, 27, "Input",
   CellTags->"QuantumField"],
  Cell[1540404, 63079, 319, 14, 29, "Output",
   CellTags->"QuantumField"],
  Cell[1540760, 63098, 114, 3, 27, "Input",
   CellTags->"QuantumField"],
  Cell[1540877, 63103, 255, 6, 39, "Output",
   CellTags->"QuantumField"],
  Cell[1541147, 63112, 358, 13, 27, "Text",
   CellTags->"QuantumField"],
  Cell[1541530, 63129, 206, 6, 27, "Input",
   CellTags->"QuantumField"],
  Cell[1541739, 63137, 259, 10, 27, "Output",
   CellTags->"QuantumField"],
  Cell[1542013, 63150, 185, 4, 23, "Text",
   CellTags->"QuantumField"],
  Cell[1542223, 63158, 244, 7, 27, "Input",
   CellTags->"QuantumField"],
  Cell[1542470, 63167, 245, 6, 39, "Output",
   CellTags->"QuantumField"],
  Cell[1542730, 63176, 88, 1, 23, "Text",
   CellTags->"QuantumField"],
  Cell[1542843, 63181, 219, 6, 27, "Input",
   CellTags->"QuantumField"],
  Cell[1543065, 63189, 355, 14, 29, "Output",
   CellTags->"QuantumField"],
  Cell[1543457, 63208, 184, 5, 27, "Input",
   CellTags->"QuantumField"],
  Cell[1543644, 63215, 257, 9, 27, "Output",
   CellTags->"QuantumField"],
  Cell[1543938, 63229, 259, 7, 27, "Input",
   CellTags->"QuantumField"],
  Cell[1544200, 63238, 404, 16, 27, "Output",
   CellTags->"QuantumField"],
  Cell[1544641, 63259, 291, 9, 27, "Input",
   CellTags->"QuantumField"],
  Cell[1544935, 63270, 413, 16, 27, "Output",
   CellTags->"QuantumField"],
  Cell[1545385, 63291, 232, 6, 27, "Input",
   CellTags->"QuantumField"],
  Cell[1545620, 63299, 112, 3, 25, "Output",
   CellTags->"QuantumField"]},
 "QuarkField"->{
  Cell[1545759, 63306, 57, 1, 58, "ObjectName",
   CellTags->"QuarkField"],
  Cell[1545841, 63311, 61, 1, 39, "Subsubsection",
   CellTags->"QuarkField"],
  Cell[1545905, 63314, 189, 4, 21, "Text",
   CellTags->"QuarkField"],
  Cell[1546097, 63320, 321, 14, 22, "Text",
   CellTags->"QuarkField"],
  Cell[1546455, 63339, 58, 1, 33, "Subsubsection",
   CellTags->"QuarkField"],
  Cell[1546538, 63344, 87, 2, 27, "Input",
   CellTags->"QuarkField"],
  Cell[1546628, 63348, 112, 3, 25, "Output",
   CellTags->"QuarkField"]},
 "QuarkGluonVertex"->{
  Cell[1546767, 63355, 69, 1, 39, "ObjectName",
   CellTags->"QuarkGluonVertex"],
  Cell[1546861, 63360, 67, 1, 33, "Subsubsection",
   CellTags->"QuarkGluonVertex"],
  Cell[1546931, 63363, 260, 9, 23, "Text",
   CellTags->"QuarkGluonVertex"],
  Cell[1547216, 63376, 132, 3, 27, "Input",
   CellTags->"QuarkGluonVertex"],
  Cell[1547351, 63381, 491, 13, 25, "Output",
   CellTags->"QuarkGluonVertex"],
  Cell[1547857, 63397, 196, 9, 23, "Text",
   CellTags->"QuarkGluonVertex"],
  Cell[1548090, 63411, 64, 1, 33, "Subsubsection",
   CellTags->"QuarkGluonVertex"],
  Cell[1548179, 63416, 153, 4, 27, "Input",
   CellTags->"QuarkGluonVertex"],
  Cell[1548335, 63422, 149, 4, 27, "Output",
   CellTags->"QuarkGluonVertex"],
  Cell[1548521, 63431, 208, 5, 27, "Input",
   CellTags->"QuarkGluonVertex"],
  Cell[1548732, 63438, 149, 4, 27, "Output",
   CellTags->"QuarkGluonVertex"],
  Cell[1548918, 63447, 208, 5, 27, "Input",
   CellTags->"QuarkGluonVertex"],
  Cell[1549129, 63454, 149, 4, 27, "Output",
   CellTags->"QuarkGluonVertex"],
  Cell[1549315, 63463, 208, 5, 27, "Input",
   CellTags->"QuarkGluonVertex"],
  Cell[1549526, 63470, 149, 4, 27, "Output",
   CellTags->"QuarkGluonVertex"],
  Cell[1549712, 63479, 315, 9, 27, "Input",
   CellTags->"QuarkGluonVertex"],
  Cell[1550030, 63490, 366, 11, 25, "Output",
   CellTags->"QuarkGluonVertex"],
  Cell[1550433, 63506, 316, 9, 27, "Input",
   CellTags->"QuarkGluonVertex"],
  Cell[1550752, 63517, 367, 11, 25, "Output",
   CellTags->"QuarkGluonVertex"]},
 "QuarkMass"->{
  Cell[1551146, 63532, 55, 1, 39, "ObjectName",
   CellTags->"QuarkMass"],
  Cell[1551226, 63537, 60, 1, 33, "Subsubsection",
   CellTags->"QuarkMass"],
  Cell[1551289, 63540, 76, 1, 23, "Text",
   CellTags->"QuarkMass"],
  Cell[1551368, 63543, 183, 9, 23, "Text",
   CellTags->"QuarkMass"]},
 "QuarkPropagator"->{
  Cell[1551566, 63555, 67, 1, 39, "ObjectName",
   CellTags->"QuarkPropagator"],
  Cell[1551658, 63560, 66, 1, 33, "Subsubsection",
   CellTags->"QuarkPropagator"],
  Cell[1551727, 63563, 174, 4, 23, "Text",
   CellTags->"QuarkPropagator"],
  Cell[1551926, 63571, 130, 3, 27, "Input",
   CellTags->"QuarkPropagator"],
  Cell[1552059, 63576, 534, 14, 25, "Output",
   CellTags->"QuarkPropagator"],
  Cell[1552608, 63593, 341, 14, 33, "Text",
   CellTags->"QuarkPropagator"],
  Cell[1552986, 63612, 63, 1, 33, "Subsubsection",
   CellTags->"QuarkPropagator"],
  Cell[1553074, 63617, 124, 3, 27, "Input",
   CellTags->"QuarkPropagator"],
  Cell[1553201, 63622, 177, 6, 28, "Output",
   CellTags->"QuarkPropagator"],
  Cell[1553415, 63633, 171, 5, 27, "Input",
   CellTags->"QuarkPropagator"],
  Cell[1553589, 63640, 177, 6, 28, "Output",
   CellTags->"QuarkPropagator"],
  Cell[1553803, 63651, 157, 4, 27, "Input",
   CellTags->"QuarkPropagator"],
  Cell[1553963, 63657, 177, 6, 28, "Output",
   CellTags->"QuarkPropagator"]},
 "ReduceGamma"->{
  Cell[1554167, 63667, 59, 1, 58, "ObjectName",
   CellTags->"ReduceGamma"],
  Cell[1554251, 63672, 62, 1, 39, "Subsubsection",
   CellTags->"ReduceGamma"],
  Cell[1554316, 63675, 194, 4, 32, "Text",
   CellTags->"ReduceGamma"],
  Cell[1554513, 63681, 179, 9, 33, "Text",
   CellTags->"ReduceGamma"]},
 "ReduceToScalars"->{
  Cell[1554707, 63693, 67, 1, 58, "ObjectName",
   CellTags->"ReduceToScalars"],
  Cell[1554799, 63698, 66, 1, 39, "Subsubsection",
   CellTags->"ReduceToScalars"],
  Cell[1554868, 63701, 210, 5, 36, "Text",
   CellTags->"ReduceToScalars"],
  Cell[1555081, 63708, 299, 14, 22, "Text",
   CellTags->"ReduceToScalars"]},
 "Rename"->{
  Cell[1555395, 63725, 49, 1, 39, "ObjectName",
   CellTags->"Rename"],
  Cell[1555469, 63730, 57, 1, 26, "Subsubsection",
   CellTags->"Rename"],
  Cell[1555529, 63733, 144, 4, 21, "Text",
   CellTags->"Rename"],
  Cell[1555676, 63739, 177, 9, 22, "Text",
   CellTags->"Rename"]},
 "RHI"->{
  Cell[1555868, 63751, 61, 1, 39, "ObjectName",
   CellTags->"RHI"],
  Cell[1555954, 63756, 54, 1, 26, "Subsubsection",
   CellTags->"RHI"],
  Cell[1556011, 63759, 611, 12, 114, "Text",
   CellTags->"RHI"],
  Cell[1556625, 63773, 168, 9, 23, "Text",
   CellTags->"RHI"],
  Cell[1556830, 63787, 51, 1, 33, "Subsubsection",
   CellTags->"RHI"],
  Cell[1556884, 63790, 70, 2, 27, "Input",
   CellTags->"RHI"]},
 "RHI2FC"->{
  Cell[1556969, 63795, 67, 1, 39, "ObjectName",
   CellTags->"RHI2FC"],
  Cell[1557061, 63800, 57, 1, 33, "Subsubsection",
   CellTags->"RHI2FC"],
  Cell[1557121, 63803, 614, 12, 135, "Text",
   CellTags->"RHI2FC"],
  Cell[1557738, 63817, 171, 9, 23, "Text",
   CellTags->"RHI2FC"],
  Cell[1557946, 63831, 54, 1, 33, "Subsubsection",
   CellTags->"RHI2FC"],
  Cell[1558003, 63834, 73, 2, 27, "Input",
   CellTags->"RHI2FC"]},
 "RHM"->{
  Cell[1558091, 63839, 61, 1, 39, "ObjectName",
   CellTags->"RHM"],
  Cell[1558177, 63844, 54, 1, 33, "Subsubsection",
   CellTags->"RHM"],
  Cell[1558234, 63847, 77, 1, 23, "Text",
   CellTags->"RHM"],
  Cell[1558314, 63850, 159, 9, 23, "Text",
   CellTags->"RHM"],
  Cell[1558510, 63864, 51, 1, 33, "Subsubsection",
   CellTags->"RHM"],
  Cell[1558564, 63867, 70, 2, 27, "Input",
   CellTags->"RHM"]},
 "RHO"->{
  Cell[1558649, 63872, 61, 1, 39, "ObjectName",
   CellTags->"RHO"],
  Cell[1558735, 63877, 54, 1, 33, "Subsubsection",
   CellTags->"RHO"],
  Cell[1558792, 63880, 267, 5, 39, "Text",
   CellTags->"RHO"],
  Cell[1559062, 63887, 159, 9, 23, "Text",
   CellTags->"RHO"],
  Cell[1559258, 63901, 51, 1, 33, "Subsubsection",
   CellTags->"RHO"],
  Cell[1559312, 63904, 70, 2, 27, "Input",
   CellTags->"RHO"]},
 "RHP"->{
  Cell[1559397, 63909, 45, 1, 39, "ObjectName",
   CellTags->"RHP"],
  Cell[1559467, 63914, 54, 1, 33, "Subsubsection",
   CellTags->"RHP"],
  Cell[1559524, 63917, 272, 5, 36, "Text",
   CellTags->"RHP"],
  Cell[1559799, 63924, 159, 9, 22, "Text",
   CellTags->"RHP"],
  Cell[1559995, 63938, 51, 1, 33, "Subsubsection",
   CellTags->"RHP"],
  Cell[1565313, 64168, 70, 2, 27, "Input",
   CellTags->"RHP"]},
 "RTL"->{
  Cell[1565398, 64173, 61, 1, 58, "ObjectName",
   CellTags->"RTL"],
  Cell[1565484, 64178, 54, 1, 39, "Subsubsection",
   CellTags->"RTL"],
  Cell[1565541, 64181, 188, 4, 32, "Text",
   CellTags->"RTL"],
  Cell[1565732, 64187, 266, 14, 33, "Text",
   CellTags->"RTL"],
  Cell[1566035, 64206, 51, 1, 33, "Subsubsection",
   CellTags->"RTL"],
  Cell[1566089, 64209, 70, 2, 27, "Input",
   CellTags->"RTL"]},
 "RightPartialD"->{
  Cell[1566174, 64214, 63, 1, 39, "ObjectName",
   CellTags->"RightPartialD"],
  Cell[1566262, 64219, 64, 1, 33, "Subsubsection",
   CellTags->"RightPartialD"],
  Cell[1566329, 64222, 256, 10, 26, "Text",
   CellTags->"RightPartialD"],
  Cell[1566588, 64234, 434, 19, 23, "Text",
   CellTags->"RightPartialD"],
  Cell[1567059, 64258, 61, 1, 33, "Subsubsection",
   CellTags->"RightPartialD"],
  Cell[1567145, 64263, 124, 3, 27, "Input",
   CellTags->"RightPartialD"],
  Cell[1567272, 64268, 252, 9, 32, "Output",
   CellTags->"RightPartialD"],
  Cell[1567561, 64282, 255, 7, 27, "Input",
   CellTags->"RightPartialD"],
  Cell[1567819, 64291, 308, 11, 32, "Output",
   CellTags->"RightPartialD"],
  Cell[1568164, 64307, 121, 3, 27, "Input",
   CellTags->"RightPartialD"],
  Cell[1568288, 64312, 356, 14, 29, "Output",
   CellTags->"RightPartialD"],
  Cell[1568681, 64331, 115, 3, 27, "Input",
   CellTags->"RightPartialD"],
  Cell[1568799, 64336, 292, 7, 39, "Output",
   CellTags->"RightPartialD"],
  Cell[1569128, 64348, 162, 5, 27, "Input",
   CellTags->"RightPartialD"],
  Cell[1569293, 64355, 178, 4, 39, "Output",
   CellTags->"RightPartialD"]},
 "RussianTrick"->{
  Cell[1569498, 64363, 61, 1, 39, "ObjectName",
   CellTags->"RussianTrick"],
  Cell[1569584, 64368, 63, 1, 33, "Subsubsection",
   CellTags->"RussianTrick"],
  Cell[1569650, 64371, 318, 6, 39, "Text",
   CellTags->"RussianTrick"],
  Cell[1569971, 64379, 90, 1, 23, "Text",
   CellTags->"RussianTrick"],
  Cell[1570064, 64382, 326, 14, 23, "Text",
   CellTags->"RussianTrick"],
  Cell[1570427, 64401, 60, 1, 33, "Subsubsection",
   CellTags->"RussianTrick"],
  Cell[1570512, 64406, 374, 12, 27, "Input",
   CellTags->"RussianTrick"],
  Cell[1570889, 64420, 501, 21, 29, "Output",
   CellTags->"RussianTrick"],
  Cell[1571427, 64446, 108, 3, 27, "Input",
   CellTags->"RussianTrick"],
  Cell[1571538, 64451, 661, 23, 49, "Output",
   CellTags->"RussianTrick"],
  Cell[1572236, 64479, 172, 5, 27, "Input",
   CellTags->"RussianTrick"],
  Cell[1572411, 64486, 3469, 121, 141, "Output",
   CellTags->"RussianTrick"],
  Cell[1575917, 64612, 112, 3, 27, "Input",
   CellTags->"RussianTrick"],
  Cell[1576032, 64617, 2675, 111, 29, "Output",
   CellTags->"RussianTrick"],
  Cell[1578744, 64733, 135, 4, 27, "Input",
   CellTags->"RussianTrick"],
  Cell[1578882, 64739, 2947, 112, 48, "Output",
   CellTags->"RussianTrick"],
  Cell[1581844, 64854, 111, 3, 27, "Input",
   CellTags->"RussianTrick"]},
 "ScalarGluonVertex"->{
  Cell[1581970, 64860, 71, 1, 39, "ObjectName",
   CellTags->"ScalarGluonVertex"],
  Cell[1582066, 64865, 68, 1, 39, "Subsubsection",
   CellTags->"ScalarGluonVertex"],
  Cell[1582137, 64868, 430, 8, 71, "Text",
   CellTags->"ScalarGluonVertex"],
  Cell[1582592, 64880, 134, 3, 27, "Input",
   CellTags->"ScalarGluonVertex"],
  Cell[1582729, 64885, 271, 8, 25, "Output",
   CellTags->"ScalarGluonVertex"],
  Cell[1583049, 64899, 65, 1, 33, "Subsubsection",
   CellTags->"ScalarGluonVertex"],
  Cell[1583139, 64904, 274, 8, 27, "Input",
   CellTags->"ScalarGluonVertex"],
  Cell[1583416, 64914, 479, 19, 25, "Output",
   CellTags->"ScalarGluonVertex"]},
 "ScalarProduct"->{
  Cell[1583922, 64937, 63, 1, 58, "ObjectName",
   CellTags->"ScalarProduct"],
  Cell[1584010, 64942, 64, 1, 33, "Subsubsection",
   CellTags->"ScalarProduct"],
  Cell[1584077, 64945, 836, 21, 71, "Text",
   CellTags->"ScalarProduct"],
  Cell[1584916, 64968, 880, 38, 23, "Text",
   CellTags->"ScalarProduct"],
  Cell[1585833, 65011, 61, 1, 33, "Subsubsection",
   CellTags->"ScalarProduct"],
  Cell[1585919, 65016, 143, 4, 27, "Input",
   CellTags->"ScalarProduct"],
  Cell[1586065, 65022, 212, 8, 25, "Output",
   CellTags->"ScalarProduct"],
  Cell[1586314, 65035, 186, 6, 27, "Input",
   CellTags->"ScalarProduct"],
  Cell[1586503, 65043, 301, 11, 25, "Output",
   CellTags->"ScalarProduct"],
  Cell[1586841, 65059, 143, 4, 27, "Input",
   CellTags->"ScalarProduct"],
  Cell[1586987, 65065, 168, 6, 27, "Output",
   CellTags->"ScalarProduct"],
  Cell[1587192, 65076, 120, 3, 27, "Input",
   CellTags->"ScalarProduct"],
  Cell[1587315, 65081, 168, 6, 27, "Output",
   CellTags->"ScalarProduct"],
  Cell[1587520, 65092, 179, 5, 27, "Input",
   CellTags->"ScalarProduct"],
  Cell[1587702, 65099, 221, 6, 39, "Output",
   CellTags->"ScalarProduct"],
  Cell[1587960, 65110, 231, 7, 27, "Input",
   CellTags->"ScalarProduct"],
  Cell[1588194, 65119, 271, 8, 39, "Output",
   CellTags->"ScalarProduct"],
  Cell[1588502, 65132, 248, 8, 27, "Input",
   CellTags->"ScalarProduct"],
  Cell[1588753, 65142, 131, 4, 40, "Output",
   CellTags->"ScalarProduct"],
  Cell[1588921, 65151, 295, 9, 27, "Input",
   CellTags->"ScalarProduct"],
  Cell[1589219, 65162, 571, 23, 40, "Output",
   CellTags->"ScalarProduct"],
  Cell[1589827, 65190, 280, 9, 27, "Input",
   CellTags->"ScalarProduct"],
  Cell[1590110, 65201, 571, 23, 40, "Output",
   CellTags->"ScalarProduct"],
  Cell[1590696, 65227, 99, 2, 27, "Input",
   CellTags->"ScalarProduct"]},
 "Info3522766000-2743550"->{
  Cell[1592132, 65285, 179, 3, 38, "Print",
   CellTags->{"Info3522766000-2743550", "ScalarProductCancel"}]},
 "ScaleMu"->{
  Cell[1602272, 65689, 51, 1, 39, "ObjectName",
   CellTags->"ScaleMu"],
  Cell[1602348, 65694, 58, 1, 33, "Subsubsection",
   CellTags->"ScaleMu"],
  Cell[1602409, 65697, 128, 4, 23, "Text",
   CellTags->"ScaleMu"],
  Cell[1602562, 65705, 81, 2, 27, "Input",
   CellTags->"ScaleMu"],
  Cell[1602646, 65709, 108, 3, 25, "Output",
   CellTags->"ScaleMu"]},
 "Schouten"->{
  Cell[1602781, 65716, 53, 1, 39, "ObjectName",
   CellTags->"Schouten"],
  Cell[1602859, 65721, 59, 1, 33, "Subsubsection",
   CellTags->"Schouten"],
  Cell[1602921, 65724, 460, 8, 79, "Text",
   CellTags->"Schouten"],
  Cell[1603384, 65734, 289, 13, 23, "Text",
   CellTags->"Schouten"],
  Cell[1603710, 65752, 56, 1, 33, "Subsubsection",
   CellTags->"Schouten"],
  Cell[1603791, 65757, 1938, 54, 156, "Input",
   CellTags->"Schouten"],
  Cell[1605732, 65813, 15696, 628, 199, "Output",
   CellTags->"Schouten"],
  Cell[1621465, 66446, 106, 3, 27, "Input",
   CellTags->"Schouten"],
  Cell[1621574, 66451, 105, 3, 25, "Output",
   CellTags->"Schouten"]},
 "SD"->{
  Cell[1621793, 66462, 41, 1, 39, "ObjectName",
   CellTags->"SD"],
  Cell[1621859, 66467, 53, 1, 33, "Subsubsection",
   CellTags->"SD"],
  Cell[1621915, 66470, 265, 7, 39, "Text",
   CellTags->"SD"],
  Cell[1622183, 66479, 173, 9, 23, "Text",
   CellTags->"SD"],
  Cell[1622393, 66493, 50, 1, 33, "Subsubsection",
   CellTags->"SD"],
  Cell[1622468, 66498, 121, 4, 27, "Input",
   CellTags->"SD"],
  Cell[1622592, 66504, 147, 5, 27, "Output",
   CellTags->"SD"],
  Cell[1622776, 66514, 130, 4, 27, "Input",
   CellTags->"SD"],
  Cell[1622909, 66520, 214, 6, 39, "Output",
   CellTags->"SD"],
  Cell[1623160, 66531, 130, 4, 27, "Input",
   CellTags->"SD"],
  Cell[1623293, 66537, 136, 4, 39, "Output",
   CellTags->"SD"]},
 "SelectFree"->{
  Cell[1623456, 66545, 57, 1, 39, "ObjectName",
   CellTags->"SelectFree"],
  Cell[1623538, 66550, 61, 1, 33, "Subsubsection",
   CellTags->"SelectFree"],
  Cell[1623602, 66553, 255, 5, 39, "Text",
   CellTags->"SelectFree"],
  Cell[1623860, 66560, 77, 1, 23, "Text",
   CellTags->"SelectFree"],
  Cell[1623940, 66563, 300, 14, 23, "Text",
   CellTags->"SelectFree"],
  Cell[1624277, 66582, 58, 1, 33, "Subsubsection",
   CellTags->"SelectFree"],
  Cell[1624360, 66587, 211, 6, 27, "Input",
   CellTags->"SelectFree"],
  Cell[1624574, 66595, 130, 4, 25, "Output",
   CellTags->"SelectFree"],
  Cell[1624741, 66604, 166, 5, 27, "Input",
   CellTags->"SelectFree"],
  Cell[1624910, 66611, 107, 3, 25, "Output",
   CellTags->"SelectFree"],
  Cell[1625054, 66619, 275, 8, 27, "Input",
   CellTags->"SelectFree"],
  Cell[1625332, 66629, 130, 4, 25, "Output",
   CellTags->"SelectFree"],
  Cell[1625499, 66638, 137, 4, 27, "Input",
   CellTags->"SelectFree"],
  Cell[1625639, 66644, 107, 3, 25, "Output",
   CellTags->"SelectFree"],
  Cell[1625783, 66652, 137, 4, 27, "Input",
   CellTags->"SelectFree"],
  Cell[1625923, 66658, 107, 3, 25, "Output",
   CellTags->"SelectFree"],
  Cell[1626067, 66666, 137, 4, 27, "Input",
   CellTags->"SelectFree"],
  Cell[1626207, 66672, 107, 3, 25, "Output",
   CellTags->"SelectFree"],
  Cell[1626351, 66680, 166, 5, 27, "Input",
   CellTags->"SelectFree"],
  Cell[1626520, 66687, 107, 3, 25, "Output",
   CellTags->"SelectFree"]},
 "SelectGraphs"->{
  Cell[1626654, 66694, 61, 1, 58, "ObjectName",
   CellTags->"SelectGraphs"],
  Cell[1626740, 66699, 63, 1, 39, "Subsubsection",
   CellTags->"SelectGraphs"],
  Cell[1626806, 66702, 486, 8, 75, "Text",
   CellTags->"SelectGraphs"],
  Cell[1627295, 66712, 189, 9, 33, "Text",
   CellTags->"SelectGraphs"]},
 "SelectNotFree"->{
  Cell[1627499, 66724, 63, 1, 58, "ObjectName",
   CellTags->"SelectNotFree"],
  Cell[1627587, 66729, 64, 1, 39, "Subsubsection",
   CellTags->"SelectNotFree"],
  Cell[1627654, 66732, 143, 4, 32, "Text",
   CellTags->"SelectNotFree"],
  Cell[1627800, 66738, 270, 5, 54, "Text",
   CellTags->"SelectNotFree"],
  Cell[1628073, 66745, 83, 1, 32, "Text",
   CellTags->"SelectNotFree"],
  Cell[1628159, 66748, 294, 14, 33, "Text",
   CellTags->"SelectNotFree"],
  Cell[1628490, 66767, 61, 1, 33, "Subsubsection",
   CellTags->"SelectNotFree"],
  Cell[1628576, 66772, 207, 6, 27, "Input",
   CellTags->"SelectNotFree"],
  Cell[1628786, 66780, 162, 5, 25, "Output",
   CellTags->"SelectNotFree"],
  Cell[1628985, 66790, 276, 8, 27, "Input",
   CellTags->"SelectNotFree"],
  Cell[1629264, 66800, 172, 5, 25, "Output",
   CellTags->"SelectNotFree"],
  Cell[1629473, 66810, 143, 4, 27, "Input",
   CellTags->"SelectNotFree"],
  Cell[1629619, 66816, 110, 3, 25, "Output",
   CellTags->"SelectNotFree"],
  Cell[1629766, 66824, 167, 5, 27, "Input",
   CellTags->"SelectNotFree"],
  Cell[1629936, 66831, 110, 3, 25, "Output",
   CellTags->"SelectNotFree"],
  Cell[1630083, 66839, 143, 4, 27, "Input",
   CellTags->"SelectNotFree"],
  Cell[1630229, 66845, 110, 3, 25, "Output",
   CellTags->"SelectNotFree"],
  Cell[1630376, 66853, 143, 4, 27, "Input",
   CellTags->"SelectNotFree"],
  Cell[1630522, 66859, 110, 3, 25, "Output",
   CellTags->"SelectNotFree"],
  Cell[1630669, 66867, 172, 5, 27, "Input",
   CellTags->"SelectNotFree"],
  Cell[1630844, 66874, 138, 4, 25, "Output",
   CellTags->"SelectNotFree"]},
 "SelectSplit"->{
  Cell[1631009, 66882, 59, 1, 39, "ObjectName",
   CellTags->"SelectSplit"],
  Cell[1631093, 66887, 62, 1, 33, "Subsubsection",
   CellTags->"SelectSplit"],
  Cell[1631158, 66890, 249, 5, 39, "Text",
   CellTags->"SelectSplit"],
  Cell[1631444, 66900, 59, 1, 33, "Subsubsection",
   CellTags->"SelectSplit"],
  Cell[1631528, 66905, 804, 26, 29, "Input",
   CellTags->"SelectSplit"],
  Cell[1632335, 66933, 532, 19, 29, "Output",
   CellTags->"SelectSplit"],
  Cell[1632904, 66957, 652, 21, 29, "Input",
   CellTags->"SelectSplit"],
  Cell[1633559, 66980, 495, 16, 29, "Output",
   CellTags->"SelectSplit"]},
 "Select1"->{
  Cell[1634081, 67000, 51, 1, 39, "ObjectName",
   CellTags->"Select1"],
  Cell[1634157, 67005, 58, 1, 33, "Subsubsection",
   CellTags->"Select1"],
  Cell[1634218, 67008, 243, 5, 39, "Text",
   CellTags->"Select1"],
  Cell[1634464, 67015, 175, 9, 23, "Text",
   CellTags->"Select1"]},
 "Select2"->{
  Cell[1634654, 67027, 51, 1, 39, "ObjectName",
   CellTags->"Select2"],
  Cell[1634730, 67032, 58, 1, 39, "Subsubsection",
   CellTags->"Select2"],
  Cell[1634791, 67035, 245, 5, 54, "Text",
   CellTags->"Select2"],
  Cell[1635039, 67042, 175, 9, 33, "Text",
   CellTags->"Select2"]},
 "Series2"->{
  Cell[1635229, 67054, 51, 1, 58, "ObjectName",
   CellTags->"Series2"],
  Cell[1635305, 67059, 58, 1, 39, "Subsubsection",
   CellTags->"Series2"],
  Cell[1635366, 67062, 383, 9, 39, "Text",
   CellTags->"Series2"],
  Cell[1635774, 67075, 114, 3, 27, "Input",
   CellTags->"Series2"],
  Cell[1635891, 67080, 528, 15, 25, "Output",
   CellTags->"Series2"],
  Cell[1636468, 67101, 55, 1, 33, "Subsubsection",
   CellTags->"Series2"],
  Cell[1636548, 67106, 339, 12, 27, "Input",
   CellTags->"Series2"],
  Cell[1636890, 67120, 357, 12, 43, "Output",
   CellTags->"Series2"],
  Cell[1637284, 67137, 174, 5, 27, "Input",
   CellTags->"Series2"],
  Cell[1637461, 67144, 242, 8, 43, "Output",
   CellTags->"Series2"],
  Cell[1637740, 67157, 222, 7, 27, "Input",
   CellTags->"Series2"],
  Cell[1637965, 67166, 806, 25, 43, "Output",
   CellTags->"Series2"],
  Cell[1638808, 67196, 174, 5, 27, "Input",
   CellTags->"Series2"],
  Cell[1638985, 67203, 385, 14, 46, "Output",
   CellTags->"Series2"],
  Cell[1639407, 67222, 290, 8, 27, "Input",
   CellTags->"Series2"],
  Cell[1639700, 67232, 994, 32, 43, "Output",
   CellTags->"Series2"],
  Cell[1640921, 67277, 460, 15, 27, "Input",
   CellTags->"Series2"],
  Cell[1641384, 67294, 1000, 33, 43, "Output",
   CellTags->"Series2"],
  Cell[1642399, 67330, 113, 3, 23, "Text",
   CellTags->"Series2"],
  Cell[1642537, 67337, 484, 15, 27, "Input",
   CellTags->"Series2"],
  Cell[1643024, 67354, 648, 24, 46, "Output",
   CellTags->"Series2"],
  Cell[1643709, 67383, 578, 17, 27, "Input",
   CellTags->"Series2"],
  Cell[1644290, 67402, 988, 35, 43, "Output",
   CellTags->"Series2"],
  Cell[1645315, 67442, 242, 6, 27, "Input",
   CellTags->"Series2"],
  Cell[1645560, 67450, 292, 7, 25, "Output",
   CellTags->"Series2"],
  Cell[1645889, 67462, 147, 4, 27, "Input",
   CellTags->"Series2"],
  Cell[1646039, 67468, 3114, 106, 67, "Output",
   CellTags->"Series2"],
  Cell[1649168, 67577, 351, 11, 23, "Text",
   CellTags->"Series2"]},
 "Series3"->{
  Cell[1649534, 67591, 51, 1, 39, "ObjectName",
   CellTags->"Series3"],
  Cell[1649610, 67596, 58, 1, 33, "Subsubsection",
   CellTags->"Series3"],
  Cell[1649671, 67599, 267, 5, 39, "Text",
   CellTags->"Series3"],
  Cell[1649963, 67608, 114, 3, 27, "Input",
   CellTags->"Series3"],
  Cell[1650080, 67613, 262, 8, 25, "Output",
   CellTags->"Series3"],
  Cell[1650357, 67624, 175, 9, 23, "Text",
   CellTags->"Series3"],
  Cell[1650569, 67638, 55, 1, 33, "Subsubsection",
   CellTags->"Series3"],
  Cell[1650649, 67643, 339, 12, 27, "Input",
   CellTags->"Series3"],
  Cell[1650991, 67657, 307, 11, 43, "Output",
   CellTags->"Series3"],
  Cell[1651335, 67673, 214, 7, 27, "Input",
   CellTags->"Series3"],
  Cell[1651552, 67682, 215, 7, 43, "Output",
   CellTags->"Series3"]},
 "SetMandelstam"->{
  Cell[1651794, 67693, 63, 1, 39, "ObjectName",
   CellTags->"SetMandelstam"],
  Cell[1651882, 67698, 64, 1, 33, "Subsubsection",
   CellTags->"SetMandelstam"],
  Cell[1651949, 67701, 462, 9, 79, "Text",
   CellTags->"SetMandelstam"],
  Cell[1652436, 67714, 126, 3, 27, "Input",
   CellTags->"SetMandelstam"],
  Cell[1652565, 67719, 237, 8, 25, "Output",
   CellTags->"SetMandelstam"],
  Cell[1652817, 67730, 190, 9, 23, "Text",
   CellTags->"SetMandelstam"]},
 "SimplifyDeltaFunction"->{
  Cell[1653022, 67742, 79, 1, 39, "ObjectName",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1653126, 67747, 72, 1, 33, "Subsubsection",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1653201, 67750, 299, 6, 39, "Text",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1653503, 67758, 347, 14, 23, "Text",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1653887, 67777, 69, 1, 33, "Subsubsection",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1653981, 67782, 203, 6, 27, "Input",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1654187, 67790, 268, 9, 25, "Output",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1654492, 67804, 164, 4, 27, "Input",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1654659, 67810, 392, 13, 41, "Output",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1655088, 67828, 203, 6, 27, "Input",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1655294, 67836, 301, 10, 25, "Output",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1655632, 67851, 164, 4, 27, "Input",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1655799, 67857, 812, 27, 41, "Output",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1656648, 67889, 220, 6, 27, "Input",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1656871, 67897, 313, 10, 25, "Output",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1657221, 67912, 164, 4, 27, "Input",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1657388, 67918, 212, 7, 25, "Output",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1657637, 67930, 263, 8, 27, "Input",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1657903, 67940, 330, 11, 25, "Output",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1658270, 67956, 164, 4, 27, "Input",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1658437, 67962, 234, 8, 25, "Output",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1658708, 67975, 298, 9, 27, "Input",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1659009, 67986, 371, 12, 25, "Output",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1659417, 68003, 164, 4, 27, "Input",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1659584, 68009, 118, 3, 25, "Output",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1659739, 68017, 263, 8, 27, "Input",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1660005, 68027, 330, 11, 25, "Output",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1660372, 68043, 164, 4, 27, "Input",
   CellTags->"SimplifyDeltaFunction"],
  Cell[1660539, 68049, 234, 8, 25, "Output",
   CellTags->"SimplifyDeltaFunction"]},
 "SimplifyGTI"->{
  Cell[1660800, 68061, 77, 1, 39, "ObjectName",
   CellTags->"SimplifyGTI"],
  Cell[1660902, 68066, 62, 1, 33, "Subsubsection",
   CellTags->"SimplifyGTI"],
  Cell[1660967, 68069, 71, 1, 23, "Text",
   CellTags->"SimplifyGTI"],
  Cell[1661041, 68072, 167, 9, 23, "Text",
   CellTags->"SimplifyGTI"],
  Cell[1661245, 68086, 59, 1, 33, "Subsubsection",
   CellTags->"SimplifyGTI"],
  Cell[1661307, 68089, 78, 2, 27, "Input",
   CellTags->"SimplifyGTI"]},
 "SimplifyPolyLog"->{
  Cell[1661400, 68094, 67, 1, 39, "ObjectName",
   CellTags->"SimplifyPolyLog"],
  Cell[1661492, 68099, 66, 1, 33, "Subsubsection",
   CellTags->"SimplifyPolyLog"],
  Cell[1661561, 68102, 199, 4, 23, "Text",
   CellTags->"SimplifyPolyLog"],
  Cell[1661763, 68108, 183, 9, 23, "Text",
   CellTags->"SimplifyPolyLog"],
  Cell[1661983, 68122, 63, 1, 33, "Subsubsection",
   CellTags->"SimplifyPolyLog"],
  Cell[1662049, 68125, 224, 6, 27, "Input",
   CellTags->"SimplifyPolyLog"],
  Cell[1662298, 68135, 195, 6, 27, "Input",
   CellTags->"SimplifyPolyLog"],
  Cell[1662496, 68143, 664, 20, 43, "Output",
   CellTags->"SimplifyPolyLog"],
  Cell[1663197, 68168, 170, 5, 27, "Input",
   CellTags->"SimplifyPolyLog"],
  Cell[1663370, 68175, 432, 14, 25, "Output",
   CellTags->"SimplifyPolyLog"],
  Cell[1663839, 68194, 221, 7, 27, "Input",
   CellTags->"SimplifyPolyLog"],
  Cell[1664063, 68203, 631, 20, 29, "Output",
   CellTags->"SimplifyPolyLog"],
  Cell[1664731, 68228, 195, 6, 27, "Input",
   CellTags->"SimplifyPolyLog"],
  Cell[1664929, 68236, 608, 19, 29, "Output",
   CellTags->"SimplifyPolyLog"],
  Cell[1665574, 68260, 271, 9, 27, "Input",
   CellTags->"SimplifyPolyLog"],
  Cell[1665848, 68271, 670, 22, 43, "Output",
   CellTags->"SimplifyPolyLog"],
  Cell[1666555, 68298, 248, 8, 27, "Input",
   CellTags->"SimplifyPolyLog"],
  Cell[1666806, 68308, 645, 21, 43, "Output",
   CellTags->"SimplifyPolyLog"],
  Cell[1667488, 68334, 281, 9, 27, "Input",
   CellTags->"SimplifyPolyLog"],
  Cell[1667772, 68345, 732, 29, 43, "Output",
   CellTags->"SimplifyPolyLog"],
  Cell[1668541, 68379, 216, 7, 27, "Input",
   CellTags->"SimplifyPolyLog"],
  Cell[1668760, 68388, 496, 17, 46, "Output",
   CellTags->"SimplifyPolyLog"],
  Cell[1669293, 68410, 195, 6, 27, "Input",
   CellTags->"SimplifyPolyLog"],
  Cell[1669491, 68418, 115, 3, 25, "Output",
   CellTags->"SimplifyPolyLog"],
  Cell[1669643, 68426, 195, 6, 27, "Input",
   CellTags->"SimplifyPolyLog"],
  Cell[1669841, 68434, 1063, 36, 29, "Output",
   CellTags->"SimplifyPolyLog"],
  Cell[1670941, 68475, 271, 9, 27, "Input",
   CellTags->"SimplifyPolyLog"],
  Cell[1671215, 68486, 1480, 50, 79, "Output",
   CellTags->"SimplifyPolyLog"],
  Cell[1672732, 68541, 221, 7, 27, "Input",
   CellTags->"SimplifyPolyLog"],
  Cell[1672956, 68550, 1255, 45, 46, "Output",
   CellTags->"SimplifyPolyLog"],
  Cell[1674248, 68600, 271, 9, 27, "Input",
   CellTags->"SimplifyPolyLog"],
  Cell[1674522, 68611, 2740, 96, 118, "Output",
   CellTags->"SimplifyPolyLog"],
  Cell[1677299, 68712, 191, 6, 27, "Input",
   CellTags->"SimplifyPolyLog"],
  Cell[1677493, 68720, 336, 12, 43, "Output",
   CellTags->"SimplifyPolyLog"],
  Cell[1677866, 68737, 166, 5, 27, "Input",
   CellTags->"SimplifyPolyLog"],
  Cell[1678035, 68744, 251, 8, 43, "Output",
   CellTags->"SimplifyPolyLog"],
  Cell[1678323, 68757, 146, 4, 27, "Input",
   CellTags->"SimplifyPolyLog"],
  Cell[1678472, 68763, 406, 14, 43, "Output",
   CellTags->"SimplifyPolyLog"],
  Cell[1678915, 68782, 146, 4, 27, "Input",
   CellTags->"SimplifyPolyLog"],
  Cell[1679064, 68788, 355, 13, 41, "Output",
   CellTags->"SimplifyPolyLog"],
  Cell[1679456, 68806, 146, 4, 27, "Input",
   CellTags->"SimplifyPolyLog"],
  Cell[1679605, 68812, 355, 13, 41, "Output",
   CellTags->"SimplifyPolyLog"],
  Cell[1679975, 68828, 116, 3, 27, "Input",
   CellTags->"SimplifyPolyLog"]},
 "Simplify2"->{
  Cell[1680106, 68834, 73, 1, 39, "ObjectName",
   CellTags->"Simplify2"],
  Cell[1680204, 68839, 60, 1, 33, "Subsubsection",
   CellTags->"Simplify2"],
  Cell[1680267, 68842, 81, 1, 23, "Text",
   CellTags->"Simplify2"],
  Cell[1680385, 68848, 57, 1, 33, "Subsubsection",
   CellTags->"Simplify2"],
  Cell[1680445, 68851, 76, 2, 27, "Input",
   CellTags->"Simplify2"]},
 "SmallDelta"->{
  Cell[1680536, 68856, 57, 1, 39, "ObjectName",
   CellTags->"SmallDelta"],
  Cell[1680618, 68861, 61, 1, 33, "Subsubsection",
   CellTags->"SmallDelta"],
  Cell[1680682, 68864, 87, 1, 23, "Text",
   CellTags->"SmallDelta"]},
 "SmallEpsilon"->{
  Cell[1680784, 68868, 61, 1, 39, "ObjectName",
   CellTags->"SmallEpsilon"],
  Cell[1680870, 68873, 63, 1, 33, "Subsubsection",
   CellTags->"SmallEpsilon"],
  Cell[1680936, 68876, 91, 1, 23, "Text",
   CellTags->"SmallEpsilon"]},
 "SmallVariable"->{
  Cell[1681042, 68880, 63, 1, 39, "ObjectName",
   CellTags->"SmallVariable"],
  Cell[1681130, 68885, 64, 1, 33, "Subsubsection",
   CellTags->"SmallVariable"],
  Cell[1681197, 68888, 281, 5, 39, "Text",
   CellTags->"SmallVariable"],
  Cell[1681481, 68895, 437, 19, 23, "Text",
   CellTags->"SmallVariable"]},
 "SmallVariables"->{
  Cell[1681933, 68917, 65, 1, 39, "ObjectName",
   CellTags->"SmallVariables"],
  Cell[1682023, 68922, 65, 1, 33, "Subsubsection",
   CellTags->"SmallVariables"],
  Cell[1682091, 68925, 225, 5, 39, "Text",
   CellTags->"SmallVariables"],
  Cell[1682319, 68932, 182, 9, 23, "Text",
   CellTags->"SmallVariables"]},
 "SMP"->{
  Cell[1682516, 68944, 43, 1, 39, "ObjectName",
   CellTags->"SMP"],
  Cell[1682584, 68949, 54, 1, 33, "Subsubsection",
   CellTags->"SMP"],
  Cell[1682641, 68952, 232, 5, 39, "Text",
   CellTags->"SMP"],
  Cell[1682898, 68961, 127, 4, 27, "Input",
   CellTags->"SMP"],
  Cell[1683028, 68967, 166, 5, 39, "Output",
   CellTags->"SMP"],
  Cell[1683209, 68975, 168, 8, 23, "Text",
   CellTags->"SMP"],
  Cell[1683414, 68988, 51, 1, 33, "Subsubsection",
   CellTags->"SMP"],
  Cell[1683490, 68993, 109, 3, 27, "Input",
   CellTags->"SMP"],
  Cell[1683602, 68998, 101, 3, 25, "Output",
   CellTags->"SMP"],
  Cell[1696721, 69593, 162, 8, 23, "Text",
   CellTags->"SMP"]},
 "SMVertex"->{
  Cell[1683730, 69005, 53, 1, 39, "ObjectName",
   CellTags->"SMVertex"],
  Cell[1683808, 69010, 59, 1, 33, "Subsubsection",
   CellTags->"SMVertex"],
  Cell[1683870, 69013, 304, 6, 39, "Text",
   CellTags->"SMVertex"],
  Cell[1684199, 69023, 112, 3, 27, "Input",
   CellTags->"SMVertex"],
  Cell[1684314, 69028, 235, 8, 25, "Output",
   CellTags->"SMVertex"],
  Cell[1684598, 69042, 56, 1, 33, "Subsubsection",
   CellTags->"SMVertex"],
  Cell[1684679, 69047, 223, 6, 27, "Input",
   CellTags->"SMVertex"],
  Cell[1684905, 69055, 1179, 44, 27, "Output",
   CellTags->"SMVertex"]},
 "Smu"->{
  Cell[1686111, 69103, 61, 1, 39, "ObjectName",
   CellTags->"Smu"],
  Cell[1686197, 69108, 54, 1, 33, "Subsubsection",
   CellTags->"Smu"],
  Cell[1686254, 69111, 45, 1, 23, "Text",
   CellTags->"Smu"]},
 "Sn"->{
  Cell[1686314, 69115, 41, 1, 39, "ObjectName",
   CellTags->"Sn"],
  Cell[1686380, 69120, 53, 1, 33, "Subsubsection",
   CellTags->"Sn"],
  Cell[1686436, 69123, 300, 14, 23, "Text",
   CellTags->"Sn"]},
 "SO"->{
  Cell[1686751, 69140, 41, 1, 58, "ObjectName",
   CellTags->"SO"],
  Cell[1686817, 69145, 53, 1, 39, "Subsubsection",
   CellTags->"SO"],
  Cell[1686873, 69148, 173, 4, 32, "Text",
   CellTags->"SO"],
  Cell[1687049, 69154, 580, 28, 33, "Text",
   CellTags->"SO"],
  Cell[1687666, 69187, 50, 1, 33, "Subsubsection",
   CellTags->"SO"],
  Cell[1687741, 69192, 98, 3, 27, "Input",
   CellTags->"SO"],
  Cell[1687842, 69197, 265, 10, 25, "Output",
   CellTags->"SO"],
  Cell[1688144, 69212, 121, 4, 27, "Input",
   CellTags->"SO"],
  Cell[1688268, 69218, 384, 15, 25, "Output",
   CellTags->"SO"],
  Cell[1688689, 69238, 163, 6, 27, "Input",
   CellTags->"SO"],
  Cell[1688855, 69246, 217, 6, 39, "Output",
   CellTags->"SO"]},
 "SOD"->{
  Cell[1689099, 69256, 43, 1, 39, "ObjectName",
   CellTags->"SOD"],
  Cell[1689167, 69261, 54, 1, 26, "Subsubsection",
   CellTags->"SOD"],
  Cell[1689224, 69264, 189, 4, 36, "Text",
   CellTags->"SOD"],
  Cell[1689416, 69270, 492, 24, 22, "Text",
   CellTags->"SOD"],
  Cell[1689945, 69299, 51, 1, 33, "Subsubsection",
   CellTags->"SOD"],
  Cell[1690021, 69304, 100, 3, 27, "Input",
   CellTags->"SOD"],
  Cell[1690124, 69309, 266, 10, 25, "Output",
   CellTags->"SOD"],
  Cell[1690427, 69324, 123, 4, 27, "Input",
   CellTags->"SOD"],
  Cell[1690553, 69330, 385, 15, 25, "Output",
   CellTags->"SOD"],
  Cell[1690975, 69350, 165, 6, 27, "Input",
   CellTags->"SOD"],
  Cell[1691143, 69358, 268, 8, 39, "Output",
   CellTags->"SOD"]},
 "Solve2"->{
  Cell[1691438, 69370, 49, 1, 39, "ObjectName",
   CellTags->"Solve2"],
  Cell[1691512, 69375, 57, 1, 26, "Subsubsection",
   CellTags->"Solve2"],
  Cell[1691572, 69378, 346, 7, 39, "Text",
   CellTags->"Solve2"],
  Cell[1691943, 69389, 112, 3, 27, "Input",
   CellTags->"Solve2"],
  Cell[1692058, 69394, 264, 8, 25, "Output",
   CellTags->"Solve2"],
  Cell[1692371, 69408, 54, 1, 33, "Subsubsection",
   CellTags->"Solve2"],
  Cell[1692450, 69413, 390, 14, 27, "Input",
   CellTags->"Solve2"],
  Cell[1692843, 69429, 373, 13, 43, "Output",
   CellTags->"Solve2"],
  Cell[1693231, 69445, 111, 3, 23, "Text",
   CellTags->"Solve2"],
  Cell[1693367, 69452, 153, 5, 27, "Input",
   CellTags->"Solve2"],
  Cell[1693523, 69459, 176, 6, 25, "Output",
   CellTags->"Solve2"],
  Cell[1693736, 69470, 267, 8, 27, "Input",
   CellTags->"Solve2"],
  Cell[1694006, 69480, 176, 6, 25, "Output",
   CellTags->"Solve2"],
  Cell[1694219, 69491, 443, 15, 27, "Input",
   CellTags->"Solve2"],
  Cell[1694665, 69508, 314, 11, 43, "Output",
   CellTags->"Solve2"],
  Cell[1695016, 69524, 389, 14, 27, "Input",
   CellTags->"Solve2"],
  Cell[1695408, 69540, 406, 14, 43, "Output",
   CellTags->"Solve2"]},
 "Solve3"->{
  Cell[1695841, 69558, 49, 1, 39, "ObjectName",
   CellTags->"Solve3"],
  Cell[1695915, 69563, 57, 1, 26, "Subsubsection",
   CellTags->"Solve3"],
  Cell[1695975, 69566, 271, 5, 39, "Text",
   CellTags->"Solve3"],
  Cell[1696271, 69575, 112, 3, 27, "Input",
   CellTags->"Solve3"],
  Cell[1696386, 69580, 320, 10, 25, "Output",
   CellTags->"Solve3"],
  Cell[1696920, 69606, 54, 1, 33, "Subsubsection",
   CellTags->"Solve3"],
  Cell[1696999, 69611, 390, 14, 27, "Input",
   CellTags->"Solve3"],
  Cell[1697392, 69627, 373, 13, 43, "Output",
   CellTags->"Solve3"]},
 "SP"->{
  Cell[1697792, 69644, 41, 1, 39, "ObjectName",
   CellTags->"SP"],
  Cell[1697858, 69649, 53, 1, 33, "Subsubsection",
   CellTags->"SP"],
  Cell[1697914, 69652, 327, 11, 41, "Text",
   CellTags->"SP"],
  Cell[1698244, 69665, 429, 19, 23, "Text",
   CellTags->"SP"],
  Cell[1698710, 69689, 50, 1, 33, "Subsubsection",
   CellTags->"SP"],
  Cell[1698785, 69694, 184, 6, 27, "Input",
   CellTags->"SP"],
  Cell[1698972, 69702, 366, 16, 27, "Output",
   CellTags->"SP"],
  Cell[1699375, 69723, 189, 7, 27, "Input",
   CellTags->"SP"],
  Cell[1699567, 69732, 297, 11, 25, "Output",
   CellTags->"SP"],
  Cell[1699901, 69748, 234, 8, 27, "Input",
   CellTags->"SP"],
  Cell[1700138, 69758, 412, 17, 27, "Output",
   CellTags->"SP"],
  Cell[1700587, 69780, 168, 5, 27, "Input",
   CellTags->"SP"],
  Cell[1700758, 69787, 415, 17, 27, "Output",
   CellTags->"SP"],
  Cell[1701210, 69809, 157, 5, 27, "Input",
   CellTags->"SP"],
  Cell[1701370, 69816, 136, 4, 39, "Output",
   CellTags->"SP"],
  Cell[1701543, 69825, 188, 7, 27, "Input",
   CellTags->"SP"],
  Cell[1701734, 69834, 210, 6, 39, "Output",
   CellTags->"SP"],
  Cell[1701981, 69845, 217, 8, 27, "Input",
   CellTags->"SP"],
  Cell[1702201, 69855, 136, 4, 39, "Output",
   CellTags->"SP"]},
 "SPC"->{
  Cell[1702364, 69863, 43, 1, 39, "ObjectName",
   CellTags->"SPC"],
  Cell[1702432, 69868, 54, 1, 33, "Subsubsection",
   CellTags->"SPC"],
  Cell[1702489, 69871, 81, 1, 23, "Text",
   CellTags->"SPC"],
  Cell[1702573, 69874, 207, 9, 23, "Text",
   CellTags->"SPC"]},
 "SPD"->{
  Cell[1702795, 69886, 43, 1, 39, "ObjectName",
   CellTags->"SPD"],
  Cell[1702863, 69891, 54, 1, 33, "Subsubsection",
   CellTags->"SPD"],
  Cell[1702920, 69894, 346, 11, 41, "Text",
   CellTags->"SPD"],
  Cell[1703269, 69907, 522, 24, 23, "Text",
   CellTags->"SPD"],
  Cell[1703828, 69936, 51, 1, 33, "Subsubsection",
   CellTags->"SPD"],
  Cell[1703904, 69941, 187, 6, 27, "Input",
   CellTags->"SPD"],
  Cell[1704094, 69949, 367, 16, 27, "Output",
   CellTags->"SPD"],
  Cell[1704498, 69970, 191, 7, 27, "Input",
   CellTags->"SPD"],
  Cell[1704692, 69979, 298, 11, 25, "Output",
   CellTags->"SPD"],
  Cell[1705027, 69995, 236, 8, 27, "Input",
   CellTags->"SPD"],
  Cell[1705266, 70005, 413, 17, 27, "Output",
   CellTags->"SPD"],
  Cell[1705716, 70027, 170, 5, 27, "Input",
   CellTags->"SPD"],
  Cell[1705889, 70034, 416, 17, 27, "Output",
   CellTags->"SPD"],
  Cell[1706342, 70056, 159, 5, 27, "Input",
   CellTags->"SPD"],
  Cell[1706504, 70063, 138, 4, 39, "Output",
   CellTags->"SPD"],
  Cell[1706679, 70072, 190, 7, 27, "Input",
   CellTags->"SPD"],
  Cell[1706872, 70081, 261, 8, 39, "Output",
   CellTags->"SPD"],
  Cell[1707170, 70094, 219, 8, 27, "Input",
   CellTags->"SPD"],
  Cell[1707392, 70104, 138, 4, 39, "Output",
   CellTags->"SPD"],
  Cell[1707567, 70113, 270, 9, 27, "Input",
   CellTags->"SPD"],
  Cell[1707840, 70124, 138, 4, 39, "Output",
   CellTags->"SPD"]},
 "Spinor"->{
  Cell[1708005, 70132, 49, 1, 39, "ObjectName",
   CellTags->"Spinor"],
  Cell[1708079, 70137, 57, 1, 33, "Subsubsection",
   CellTags->"Spinor"],
  Cell[1708139, 70140, 1326, 49, 103, "Text",
   CellTags->"Spinor"],
  Cell[1709468, 70191, 766, 34, 23, "Text",
   CellTags->"Spinor"],
  Cell[1710271, 70230, 54, 1, 33, "Subsubsection",
   CellTags->"Spinor"],
  Cell[1710350, 70235, 106, 3, 27, "Input",
   CellTags->"Spinor"],
  Cell[1710459, 70240, 175, 6, 25, "Output",
   CellTags->"Spinor"],
  Cell[1710671, 70251, 129, 4, 27, "Input",
   CellTags->"Spinor"],
  Cell[1710803, 70257, 185, 6, 25, "Output",
   CellTags->"Spinor"],
  Cell[1711003, 70266, 146, 4, 23, "Text",
   CellTags->"Spinor"],
  Cell[1711174, 70274, 250, 8, 27, "Input",
   CellTags->"Spinor"],
  Cell[1711427, 70284, 126, 4, 25, "Output",
   CellTags->"Spinor"],
  Cell[1711590, 70293, 254, 8, 27, "Input",
   CellTags->"Spinor"],
  Cell[1711847, 70303, 251, 9, 25, "Output",
   CellTags->"Spinor"],
  Cell[1712135, 70317, 141, 4, 27, "Input",
   CellTags->"Spinor"],
  Cell[1712279, 70323, 192, 6, 39, "Output",
   CellTags->"Spinor"],
  Cell[1712486, 70332, 158, 4, 23, "Text",
   CellTags->"Spinor"],
  Cell[1712669, 70340, 212, 7, 27, "Input",
   CellTags->"Spinor"],
  Cell[1712884, 70349, 192, 6, 39, "Output",
   CellTags->"Spinor"],
  Cell[1713113, 70360, 165, 5, 27, "Input",
   CellTags->"Spinor"],
  Cell[1713281, 70367, 192, 6, 39, "Output",
   CellTags->"Spinor"],
  Cell[1713488, 70376, 77, 1, 23, "Text",
   CellTags->"Spinor"],
  Cell[1713590, 70381, 210, 7, 27, "Input",
   CellTags->"Spinor"],
  Cell[1713803, 70390, 192, 6, 39, "Output",
   CellTags->"Spinor"]},
 "SpinorCollect"->{
  Cell[1714022, 70400, 63, 1, 39, "ObjectName",
   CellTags->"SpinorCollect"],
  Cell[1714110, 70405, 64, 1, 33, "Subsubsection",
   CellTags->"SpinorCollect"],
  Cell[1714177, 70408, 191, 4, 23, "Text",
   CellTags->"SpinorCollect"],
  Cell[1714371, 70414, 301, 13, 23, "Text",
   CellTags->"SpinorCollect"]},
 "SpinorUBar"->{
  Cell[1714687, 70430, 57, 1, 39, "ObjectName",
   CellTags->"SpinorUBar"],
  Cell[1714769, 70435, 61, 1, 33, "Subsubsection",
   CellTags->"SpinorUBar"],
  Cell[1714833, 70438, 170, 7, 23, "Text",
   CellTags->"SpinorUBar"],
  Cell[1715006, 70447, 505, 24, 23, "Text",
   CellTags->"SpinorUBar"],
  Cell[1715548, 70476, 58, 1, 33, "Subsubsection",
   CellTags->"SpinorUBar"],
  Cell[1715609, 70479, 85, 1, 23, "Text",
   CellTags->"SpinorUBar"],
  Cell[1715719, 70484, 114, 3, 27, "Input",
   CellTags->"SpinorUBar"],
  Cell[1715836, 70489, 202, 7, 25, "Output",
   CellTags->"SpinorUBar"],
  Cell[1716075, 70501, 137, 4, 27, "Input",
   CellTags->"SpinorUBar"],
  Cell[1716215, 70507, 212, 7, 25, "Output",
   CellTags->"SpinorUBar"],
  Cell[1716464, 70519, 173, 5, 27, "Input",
   CellTags->"SpinorUBar"],
  Cell[1716640, 70526, 152, 4, 39, "Output",
   CellTags->"SpinorUBar"],
  Cell[1716829, 70535, 204, 7, 27, "Input",
   CellTags->"SpinorUBar"],
  Cell[1717036, 70544, 196, 6, 39, "Output",
   CellTags->"SpinorUBar"],
  Cell[1717269, 70555, 233, 8, 27, "Input",
   CellTags->"SpinorUBar"],
  Cell[1717505, 70565, 196, 6, 39, "Output",
   CellTags->"SpinorUBar"]},
 "SpinorU"->{
  Cell[1717728, 70575, 51, 1, 39, "ObjectName",
   CellTags->"SpinorU"],
  Cell[1717804, 70580, 58, 1, 33, "Subsubsection",
   CellTags->"SpinorU"],
  Cell[1717865, 70583, 79, 1, 23, "Text",
   CellTags->"SpinorU"],
  Cell[1717947, 70586, 511, 24, 23, "Text",
   CellTags->"SpinorU"],
  Cell[1718495, 70615, 55, 1, 33, "Subsubsection",
   CellTags->"SpinorU"],
  Cell[1718575, 70620, 108, 3, 27, "Input",
   CellTags->"SpinorU"],
  Cell[1718686, 70625, 132, 4, 25, "Output",
   CellTags->"SpinorU"],
  Cell[1718855, 70634, 131, 4, 27, "Input",
   CellTags->"SpinorU"],
  Cell[1718989, 70640, 142, 4, 25, "Output",
   CellTags->"SpinorU"],
  Cell[1719168, 70649, 167, 5, 27, "Input",
   CellTags->"SpinorU"],
  Cell[1719338, 70656, 146, 4, 39, "Output",
   CellTags->"SpinorU"],
  Cell[1719521, 70665, 198, 7, 27, "Input",
   CellTags->"SpinorU"],
  Cell[1719722, 70674, 193, 6, 39, "Output",
   CellTags->"SpinorU"],
  Cell[1719952, 70685, 227, 8, 27, "Input",
   CellTags->"SpinorU"],
  Cell[1720182, 70695, 193, 6, 39, "Output",
   CellTags->"SpinorU"]},
 "SpinorVBar"->{
  Cell[1720402, 70705, 57, 1, 39, "ObjectName",
   CellTags->"SpinorVBar"],
  Cell[1720484, 70710, 61, 1, 33, "Subsubsection",
   CellTags->"SpinorVBar"],
  Cell[1720548, 70713, 175, 7, 23, "Text",
   CellTags->"SpinorVBar"],
  Cell[1720726, 70722, 505, 24, 23, "Text",
   CellTags->"SpinorVBar"],
  Cell[1721268, 70751, 58, 1, 33, "Subsubsection",
   CellTags->"SpinorVBar"],
  Cell[1721351, 70756, 114, 3, 27, "Input",
   CellTags->"SpinorVBar"],
  Cell[1721468, 70761, 202, 7, 25, "Output",
   CellTags->"SpinorVBar"],
  Cell[1721707, 70773, 137, 4, 27, "Input",
   CellTags->"SpinorVBar"],
  Cell[1721847, 70779, 212, 7, 25, "Output",
   CellTags->"SpinorVBar"],
  Cell[1722096, 70791, 173, 5, 27, "Input",
   CellTags->"SpinorVBar"],
  Cell[1722272, 70798, 152, 4, 39, "Output",
   CellTags->"SpinorVBar"],
  Cell[1722461, 70807, 204, 7, 27, "Input",
   CellTags->"SpinorVBar"],
  Cell[1722668, 70816, 217, 7, 39, "Output",
   CellTags->"SpinorVBar"],
  Cell[1722922, 70828, 233, 8, 27, "Input",
   CellTags->"SpinorVBar"],
  Cell[1723158, 70838, 217, 7, 39, "Output",
   CellTags->"SpinorVBar"]},
 "SpinorV"->{
  Cell[1723402, 70849, 51, 1, 39, "ObjectName",
   CellTags->"SpinorV"],
  Cell[1723478, 70854, 58, 1, 33, "Subsubsection",
   CellTags->"SpinorV"],
  Cell[1723539, 70857, 79, 1, 23, "Text",
   CellTags->"SpinorV"],
  Cell[1723621, 70860, 511, 24, 23, "Text",
   CellTags->"SpinorV"],
  Cell[1724169, 70889, 55, 1, 33, "Subsubsection",
   CellTags->"SpinorV"],
  Cell[1724249, 70894, 108, 3, 27, "Input",
   CellTags->"SpinorV"],
  Cell[1724360, 70899, 132, 4, 25, "Output",
   CellTags->"SpinorV"],
  Cell[1724529, 70908, 131, 4, 27, "Input",
   CellTags->"SpinorV"],
  Cell[1724663, 70914, 142, 4, 25, "Output",
   CellTags->"SpinorV"],
  Cell[1724842, 70923, 167, 5, 27, "Input",
   CellTags->"SpinorV"],
  Cell[1725012, 70930, 146, 4, 39, "Output",
   CellTags->"SpinorV"],
  Cell[1725195, 70939, 198, 7, 27, "Input",
   CellTags->"SpinorV"],
  Cell[1725396, 70948, 214, 7, 39, "Output",
   CellTags->"SpinorV"],
  Cell[1725647, 70960, 227, 8, 27, "Input",
   CellTags->"SpinorV"],
  Cell[1725877, 70970, 214, 7, 39, "Output",
   CellTags->"SpinorV"]},
 "SpinPolarizationSum"->{
  Cell[1726118, 70981, 75, 1, 39, "ObjectName",
   CellTags->"SpinPolarizationSum"],
  Cell[1726218, 70986, 70, 1, 33, "Subsubsection",
   CellTags->"SpinPolarizationSum"],
  Cell[1726291, 70989, 164, 4, 23, "Text",
   CellTags->"SpinPolarizationSum"],
  Cell[1726458, 70995, 203, 8, 23, "Text",
   CellTags->"SpinPolarizationSum"]},
 "SPL"->{
  Cell[1726676, 71006, 43, 1, 39, "ObjectName",
   CellTags->"SPL"],
  Cell[1726744, 71011, 54, 1, 33, "Subsubsection",
   CellTags->"SPL"],
  Cell[1726801, 71014, 77, 1, 23, "Text",
   CellTags->"SPL"],
  Cell[1726881, 71017, 195, 9, 23, "Text",
   CellTags->"SPL"]},
 "SplittingFunction"->{
  Cell[1727091, 71029, 71, 1, 39, "ObjectName",
   CellTags->"SplittingFunction"],
  Cell[1727187, 71034, 68, 1, 33, "Subsubsection",
   CellTags->"SplittingFunction"],
  Cell[1727258, 71037, 218, 7, 23, "Text",
   CellTags->"SplittingFunction"],
  Cell[1727501, 71048, 134, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1727638, 71053, 181, 6, 25, "Output",
   CellTags->"SplittingFunction"],
  Cell[1727834, 71062, 218, 9, 23, "Text",
   CellTags->"SplittingFunction"],
  Cell[1728089, 71076, 65, 1, 33, "Subsubsection",
   CellTags->"SplittingFunction"],
  Cell[1728157, 71079, 65, 1, 23, "Text",
   CellTags->"SplittingFunction"],
  Cell[1728225, 71082, 221, 6, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1728449, 71090, 170, 4, 23, "Text",
   CellTags->"SplittingFunction"],
  Cell[1728644, 71098, 130, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1728777, 71103, 531, 19, 44, "Output",
   CellTags->"SplittingFunction"],
  Cell[1729345, 71127, 130, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1729478, 71132, 301, 10, 30, "Output",
   CellTags->"SplittingFunction"],
  Cell[1729816, 71147, 130, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1729949, 71152, 269, 9, 43, "Output",
   CellTags->"SplittingFunction"],
  Cell[1730255, 71166, 130, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1730388, 71171, 859, 29, 44, "Output",
   CellTags->"SplittingFunction"],
  Cell[1731284, 71205, 130, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1731417, 71210, 1128, 38, 44, "Output",
   CellTags->"SplittingFunction"],
  Cell[1732582, 71253, 130, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1732715, 71258, 599, 21, 43, "Output",
   CellTags->"SplittingFunction"],
  Cell[1733351, 71284, 130, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1733484, 71289, 541, 19, 30, "Output",
   CellTags->"SplittingFunction"],
  Cell[1734040, 71311, 130, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1734173, 71316, 63, 1, 23, "Text",
   CellTags->"SplittingFunction"],
  Cell[1734239, 71319, 221, 6, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1734485, 71329, 130, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1734618, 71334, 531, 19, 44, "Output",
   CellTags->"SplittingFunction"],
  Cell[1735186, 71358, 130, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1735319, 71363, 236, 8, 28, "Output",
   CellTags->"SplittingFunction"],
  Cell[1735592, 71376, 130, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1735725, 71381, 235, 8, 25, "Output",
   CellTags->"SplittingFunction"],
  Cell[1735997, 71394, 130, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1736130, 71399, 811, 28, 44, "Output",
   CellTags->"SplittingFunction"],
  Cell[1736978, 71432, 130, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1737111, 71437, 1247, 42, 44, "Output",
   CellTags->"SplittingFunction"],
  Cell[1738395, 71484, 130, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1738528, 71489, 503, 18, 25, "Output",
   CellTags->"SplittingFunction"],
  Cell[1739068, 71512, 131, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1739202, 71517, 445, 16, 25, "Output",
   CellTags->"SplittingFunction"],
  Cell[1739684, 71538, 130, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1739817, 71543, 445, 16, 28, "Output",
   CellTags->"SplittingFunction"],
  Cell[1740299, 71564, 131, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1740433, 71569, 445, 16, 28, "Output",
   CellTags->"SplittingFunction"],
  Cell[1740915, 71590, 130, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1741048, 71595, 1362, 46, 44, "Output",
   CellTags->"SplittingFunction"],
  Cell[1742447, 71646, 131, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1742581, 71651, 1362, 46, 44, "Output",
   CellTags->"SplittingFunction"],
  Cell[1743980, 71702, 131, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1744114, 71707, 637, 22, 30, "Output",
   CellTags->"SplittingFunction"],
  Cell[1744788, 71734, 132, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1744923, 71739, 5385, 174, 246, "Output",
   CellTags->"SplittingFunction"],
  Cell[1750345, 71918, 130, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1750478, 71923, 2906, 92, 75, "Output",
   CellTags->"SplittingFunction"],
  Cell[1753421, 72020, 130, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1753554, 72025, 3584, 117, 146, "Output",
   CellTags->"SplittingFunction"],
  Cell[1757175, 72147, 130, 3, 27, "Input",
   CellTags->"SplittingFunction"],
  Cell[1757308, 72152, 4258, 139, 188, "Output",
   CellTags->"SplittingFunction"]},
 "StandardMatrixElement"->{
  Cell[1761593, 72295, 79, 1, 39, "ObjectName",
   CellTags->"StandardMatrixElement"],
  Cell[1761697, 72300, 72, 1, 33, "Subsubsection",
   CellTags->"StandardMatrixElement"],
  Cell[1761772, 72303, 134, 3, 23, "Text",
   CellTags->"StandardMatrixElement"],
  Cell[1761909, 72308, 189, 9, 23, "Text",
   CellTags->"StandardMatrixElement"]},
 "SubContext"->{
  Cell[1762113, 72320, 57, 1, 39, "ObjectName",
   CellTags->"SubContext"],
  Cell[1762195, 72325, 61, 1, 33, "Subsubsection",
   CellTags->"SubContext"],
  Cell[1762259, 72328, 120, 3, 23, "Text",
   CellTags->"SubContext"],
  Cell[1762382, 72333, 279, 14, 23, "Text",
   CellTags->"SubContext"]},
 "SubLoop"->{
  Cell[1762676, 72350, 51, 1, 39, "ObjectName",
   CellTags->"SubLoop"],
  Cell[1762752, 72355, 58, 1, 33, "Subsubsection",
   CellTags->"SubLoop"],
  Cell[1762813, 72358, 152, 4, 23, "Text",
   CellTags->"SubLoop"],
  Cell[1762968, 72364, 178, 9, 23, "Text",
   CellTags->"SubLoop"]},
 "SumP"->{
  Cell[1763161, 72376, 45, 1, 39, "ObjectName",
   CellTags->"SumP"],
  Cell[1763231, 72381, 55, 1, 33, "Subsubsection",
   CellTags->"SumP"],
  Cell[1763289, 72384, 767, 31, 27, "Text",
   CellTags->"SumP"],
  Cell[1764059, 72417, 261, 14, 23, "Text",
   CellTags->"SumP"],
  Cell[1764357, 72436, 52, 1, 33, "Subsubsection",
   CellTags->"SumP"],
  Cell[1764434, 72441, 149, 5, 27, "Input",
   CellTags->"SumP"],
  Cell[1764586, 72448, 263, 8, 29, "Output",
   CellTags->"SumP"],
  Cell[1764886, 72461, 149, 5, 27, "Input",
   CellTags->"SumP"],
  Cell[1765038, 72468, 263, 8, 29, "Output",
   CellTags->"SumP"],
  Cell[1765338, 72481, 125, 4, 27, "Input",
   CellTags->"SumP"],
  Cell[1765466, 72487, 238, 7, 29, "Output",
   CellTags->"SumP"],
  Cell[1765741, 72499, 125, 4, 27, "Input",
   CellTags->"SumP"],
  Cell[1765869, 72505, 124, 4, 43, "Output",
   CellTags->"SumP"],
  Cell[1766030, 72514, 301, 12, 51, "Input",
   CellTags->"SumP"],
  Cell[1766334, 72528, 124, 4, 43, "Output",
   CellTags->"SumP"],
  Cell[1766495, 72537, 186, 6, 27, "Input",
   CellTags->"SumP"],
  Cell[1766684, 72545, 764, 29, 43, "Output",
   CellTags->"SumP"],
  Cell[1767485, 72579, 124, 4, 27, "Input",
   CellTags->"SumP"],
  Cell[1767612, 72585, 124, 4, 43, "Output",
   CellTags->"SumP"]},
 "SumS"->{
  Cell[1767763, 72593, 45, 1, 39, "ObjectName",
   CellTags->"SumS"],
  Cell[1767833, 72598, 55, 1, 33, "Subsubsection",
   CellTags->"SumS"],
  Cell[1767891, 72601, 1438, 57, 41, "Text",
   CellTags->"SumS"],
  Cell[1769354, 72662, 108, 3, 27, "Input",
   CellTags->"SumS"],
  Cell[1769465, 72667, 165, 6, 25, "Output",
   CellTags->"SumS"],
  Cell[1769645, 72676, 261, 14, 23, "Text",
   CellTags->"SumS"],
  Cell[1769943, 72695, 52, 1, 33, "Subsubsection",
   CellTags->"SumS"],
  Cell[1770020, 72700, 149, 5, 27, "Input",
   CellTags->"SumS"],
  Cell[1770172, 72707, 211, 8, 25, "Output",
   CellTags->"SumS"],
  Cell[1770420, 72720, 149, 5, 27, "Input",
   CellTags->"SumS"],
  Cell[1770572, 72727, 211, 8, 25, "Output",
   CellTags->"SumS"],
  Cell[1770820, 72740, 144, 5, 27, "Input",
   CellTags->"SumS"],
  Cell[1770967, 72747, 172, 6, 25, "Output",
   CellTags->"SumS"],
  Cell[1771176, 72758, 173, 5, 27, "Input",
   CellTags->"SumS"],
  Cell[1771352, 72765, 261, 10, 43, "Output",
   CellTags->"SumS"],
  Cell[1771650, 72780, 197, 6, 27, "Input",
   CellTags->"SumS"],
  Cell[1771850, 72788, 340, 13, 47, "Output",
   CellTags->"SumS"],
  Cell[1772205, 72804, 192, 6, 27, "Input",
   CellTags->"SumS"],
  Cell[1772422, 72814, 149, 5, 27, "Input",
   CellTags->"SumS"],
  Cell[1772574, 72821, 509, 19, 47, "Output",
   CellTags->"SumS"],
  Cell[1773098, 72843, 193, 6, 27, "Input",
   CellTags->"SumS"],
  Cell[1773316, 72853, 125, 4, 27, "Input",
   CellTags->"SumS"],
  Cell[1773444, 72859, 124, 4, 43, "Output",
   CellTags->"SumS"],
  Cell[1773605, 72868, 174, 6, 51, "Input",
   CellTags->"SumS"],
  Cell[1773782, 72876, 124, 4, 43, "Output",
   CellTags->"SumS"],
  Cell[1773943, 72885, 159, 5, 27, "Input",
   CellTags->"SumS"],
  Cell[1774105, 72892, 212, 8, 25, "Output",
   CellTags->"SumS"],
  Cell[1774354, 72905, 146, 4, 27, "Input",
   CellTags->"SumS"],
  Cell[1774503, 72911, 149, 5, 43, "Output",
   CellTags->"SumS"],
  Cell[1774689, 72921, 144, 5, 27, "Input",
   CellTags->"SumS"],
  Cell[1774836, 72928, 142, 5, 43, "Output",
   CellTags->"SumS"],
  Cell[1775015, 72938, 125, 4, 27, "Input",
   CellTags->"SumS"],
  Cell[1775143, 72944, 142, 5, 43, "Output",
   CellTags->"SumS"]},
 "SumT"->{
  Cell[1775312, 72953, 45, 1, 39, "ObjectName",
   CellTags->"SumT"],
  Cell[1775382, 72958, 55, 1, 33, "Subsubsection",
   CellTags->"SumT"],
  Cell[1775440, 72961, 461, 15, 41, "Text",
   CellTags->"SumT"],
  Cell[1775904, 72978, 261, 14, 23, "Text",
   CellTags->"SumT"],
  Cell[1776202, 72997, 52, 1, 33, "Subsubsection",
   CellTags->"SumT"],
  Cell[1776279, 73002, 149, 5, 27, "Input",
   CellTags->"SumT"],
  Cell[1776431, 73009, 236, 9, 27, "Output",
   CellTags->"SumT"],
  Cell[1776704, 73023, 149, 5, 27, "Input",
   CellTags->"SumT"],
  Cell[1776856, 73030, 236, 9, 27, "Output",
   CellTags->"SumT"],
  Cell[1777129, 73044, 125, 4, 27, "Input",
   CellTags->"SumT"],
  Cell[1777257, 73050, 180, 7, 27, "Output",
   CellTags->"SumT"],
  Cell[1777474, 73062, 173, 5, 27, "Input",
   CellTags->"SumT"],
  Cell[1777650, 73069, 361, 14, 44, "Output",
   CellTags->"SumT"],
  Cell[1778048, 73088, 125, 4, 27, "Input",
   CellTags->"SumT"],
  Cell[1778176, 73094, 142, 5, 43, "Output",
   CellTags->"SumT"],
  Cell[1778355, 73104, 244, 9, 51, "Input",
   CellTags->"SumT"],
  Cell[1778602, 73115, 142, 5, 43, "Output",
   CellTags->"SumT"],
  Cell[1778781, 73125, 159, 5, 27, "Input",
   CellTags->"SumT"],
  Cell[1778943, 73132, 237, 9, 27, "Output",
   CellTags->"SumT"],
  Cell[1779217, 73146, 136, 4, 27, "Input",
   CellTags->"SumT"],
  Cell[1779356, 73152, 253, 7, 43, "Output",
   CellTags->"SumT"],
  Cell[1779646, 73164, 125, 4, 27, "Input",
   CellTags->"SumT"],
  Cell[1779774, 73170, 142, 5, 43, "Output",
   CellTags->"SumT"],
  Cell[1779953, 73180, 144, 5, 27, "Input",
   CellTags->"SumT"],
  Cell[1780100, 73187, 142, 5, 43, "Output",
   CellTags->"SumT"],
  Cell[1780279, 73197, 268, 10, 51, "Input",
   CellTags->"SumT"],
  Cell[1780550, 73209, 336, 12, 25, "Output",
   CellTags->"SumT"],
  Cell[1780923, 73226, 136, 4, 27, "Input",
   CellTags->"SumT"],
  Cell[1781062, 73232, 170, 6, 43, "Output",
   CellTags->"SumT"],
  Cell[1781269, 73243, 155, 5, 27, "Input",
   CellTags->"SumT"],
  Cell[1781427, 73250, 253, 7, 43, "Output",
   CellTags->"SumT"],
  Cell[1781717, 73262, 129, 4, 27, "Input",
   CellTags->"SumT"],
  Cell[1781849, 73268, 458, 16, 43, "Output",
   CellTags->"SumT"],
  Cell[1782344, 73289, 240, 9, 27, "Input",
   CellTags->"SumT"],
  Cell[1782587, 73300, 458, 16, 43, "Output",
   CellTags->"SumT"]},
 "SUND"->{
  Cell[1783072, 73320, 45, 1, 39, "ObjectName",
   CellTags->"SUND"],
  Cell[1783142, 73325, 55, 1, 33, "Subsubsection",
   CellTags->"SUND"],
  Cell[1783200, 73328, 224, 10, 23, "Text",
   CellTags->"SUND"],
  Cell[1783427, 73340, 392, 19, 22, "Text",
   CellTags->"SUND"],
  Cell[1783856, 73364, 52, 1, 33, "Subsubsection",
   CellTags->"SUND"],
  Cell[1783933, 73369, 135, 4, 27, "Input",
   CellTags->"SUND"],
  Cell[1784071, 73375, 147, 5, 27, "Output",
   CellTags->"SUND"],
  Cell[1784255, 73385, 211, 6, 27, "Input",
   CellTags->"SUND"],
  Cell[1784469, 73393, 1086, 44, 25, "Output",
   CellTags->"SUND"],
  Cell[1785592, 73442, 135, 4, 27, "Input",
   CellTags->"SUND"],
  Cell[1785730, 73448, 147, 5, 27, "Output",
   CellTags->"SUND"],
  Cell[1785914, 73458, 135, 4, 27, "Input",
   CellTags->"SUND"],
  Cell[1786052, 73464, 147, 5, 27, "Output",
   CellTags->"SUND"],
  Cell[1786236, 73474, 266, 8, 27, "Input",
   CellTags->"SUND"],
  Cell[1786505, 73484, 260, 9, 29, "Output",
   CellTags->"SUND"],
  Cell[1786802, 73498, 377, 12, 27, "Input",
   CellTags->"SUND"],
  Cell[1787182, 73512, 304, 11, 47, "Output",
   CellTags->"SUND"],
  Cell[1787523, 73528, 377, 12, 27, "Input",
   CellTags->"SUND"],
  Cell[1787903, 73542, 474, 19, 47, "Output",
   CellTags->"SUND"],
  Cell[1788414, 73566, 173, 6, 27, "Input",
   CellTags->"SUND"],
  Cell[1788590, 73574, 150, 4, 39, "Output",
   CellTags->"SUND"],
  Cell[1788777, 73583, 202, 7, 27, "Input",
   CellTags->"SUND"],
  Cell[1788982, 73592, 258, 7, 39, "Output",
   CellTags->"SUND"],
  Cell[1789277, 73604, 231, 8, 27, "Input",
   CellTags->"SUND"],
  Cell[1789511, 73614, 150, 4, 39, "Output",
   CellTags->"SUND"],
  Cell[1789676, 73621, 104, 3, 27, "Input",
   CellTags->"SUND"]},
 "SUNDelta"->{
  Cell[1789795, 73627, 53, 1, 39, "ObjectName",
   CellTags->"SUNDelta"],
  Cell[1789873, 73632, 59, 1, 33, "Subsubsection",
   CellTags->"SUNDelta"],
  Cell[1789935, 73635, 172, 6, 23, "Text",
   CellTags->"SUNDelta"],
  Cell[1790110, 73643, 717, 33, 23, "Text",
   CellTags->"SUNDelta"],
  Cell[1790864, 73681, 56, 1, 33, "Subsubsection",
   CellTags->"SUNDelta"],
  Cell[1790945, 73686, 133, 4, 27, "Input",
   CellTags->"SUNDelta"],
  Cell[1791081, 73692, 153, 5, 27, "Output",
   CellTags->"SUNDelta"],
  Cell[1791271, 73702, 262, 8, 27, "Input",
   CellTags->"SUNDelta"],
  Cell[1791536, 73712, 301, 13, 27, "Output",
   CellTags->"SUNDelta"],
  Cell[1791874, 73730, 205, 6, 27, "Input",
   CellTags->"SUNDelta"],
  Cell[1792082, 73738, 301, 13, 27, "Output",
   CellTags->"SUNDelta"],
  Cell[1792420, 73756, 169, 5, 27, "Input",
   CellTags->"SUNDelta"],
  Cell[1792592, 73763, 148, 4, 39, "Output",
   CellTags->"SUNDelta"],
  Cell[1792777, 73772, 200, 7, 27, "Input",
   CellTags->"SUNDelta"],
  Cell[1792980, 73781, 220, 6, 39, "Output",
   CellTags->"SUNDelta"],
  Cell[1793237, 73792, 229, 8, 27, "Input",
   CellTags->"SUNDelta"],
  Cell[1793469, 73802, 142, 4, 39, "Output",
   CellTags->"SUNDelta"],
  Cell[1793648, 73811, 194, 7, 27, "Input",
   CellTags->"SUNDelta"],
  Cell[1793845, 73820, 220, 6, 39, "Output",
   CellTags->"SUNDelta"],
  Cell[1794080, 73829, 256, 5, 39, "Text",
   CellTags->"SUNDelta"],
  Cell[1794361, 73838, 315, 10, 27, "Input",
   CellTags->"SUNDelta"],
  Cell[1794679, 73850, 460, 20, 27, "Output",
   CellTags->"SUNDelta"],
  Cell[1795176, 73875, 110, 3, 27, "Input",
   CellTags->"SUNDelta"],
  Cell[1795289, 73880, 395, 11, 39, "Output",
   CellTags->"SUNDelta"],
  Cell[1795721, 73896, 200, 7, 27, "Input",
   CellTags->"SUNDelta"],
  Cell[1795924, 73905, 236, 6, 39, "Output",
   CellTags->"SUNDelta"]},
 "SUNDeltaContract"->{
  Cell[1796187, 73915, 69, 1, 39, "ObjectName",
   CellTags->"SUNDeltaContract"],
  Cell[1796281, 73920, 67, 1, 33, "Subsubsection",
   CellTags->"SUNDeltaContract"],
  Cell[1796351, 73923, 397, 9, 55, "Text",
   CellTags->"SUNDeltaContract"],
  Cell[1796751, 73934, 297, 14, 23, "Text",
   CellTags->"SUNDeltaContract"]},
 "SUNF"->{
  Cell[1797063, 73951, 45, 1, 39, "ObjectName",
   CellTags->"SUNF"],
  Cell[1797133, 73956, 55, 1, 33, "Subsubsection",
   CellTags->"SUNF"],
  Cell[1797191, 73959, 190, 6, 23, "Text",
   CellTags->"SUNF"],
  Cell[1797406, 73969, 108, 3, 27, "Input",
   CellTags->"SUNF"],
  Cell[1797517, 73974, 168, 6, 25, "Output",
   CellTags->"SUNF"],
  Cell[1797700, 73983, 701, 34, 23, "Text",
   CellTags->"SUNF"],
  Cell[1798438, 74022, 52, 1, 33, "Subsubsection",
   CellTags->"SUNF"],
  Cell[1798515, 74027, 294, 10, 27, "Input",
   CellTags->"SUNF"],
  Cell[1798812, 74039, 272, 10, 27, "Output",
   CellTags->"SUNF"],
  Cell[1799121, 74054, 103, 3, 27, "Input",
   CellTags->"SUNF"],
  Cell[1799227, 74059, 764, 34, 27, "Output",
   CellTags->"SUNF"],
  Cell[1800028, 74098, 110, 3, 27, "Input",
   CellTags->"SUNF"],
  Cell[1800141, 74103, 455, 20, 27, "Output",
   CellTags->"SUNF"],
  Cell[1800633, 74128, 135, 4, 27, "Input",
   CellTags->"SUNF"],
  Cell[1800771, 74134, 147, 5, 27, "Output",
   CellTags->"SUNF"],
  Cell[1800955, 74144, 163, 5, 27, "Input",
   CellTags->"SUNF"],
  Cell[1801121, 74151, 101, 3, 25, "Output",
   CellTags->"SUNF"],
  Cell[1801237, 74157, 319, 10, 23, "Text",
   CellTags->"SUNF"],
  Cell[1801581, 74171, 185, 5, 27, "Input",
   CellTags->"SUNF"],
  Cell[1801769, 74178, 1147, 44, 25, "Output",
   CellTags->"SUNF"],
  Cell[1802953, 74227, 266, 8, 27, "Input",
   CellTags->"SUNF"],
  Cell[1803222, 74237, 353, 15, 27, "Output",
   CellTags->"SUNF"],
  Cell[1803612, 74257, 239, 7, 27, "Input",
   CellTags->"SUNF"],
  Cell[1803854, 74266, 1166, 45, 25, "Output",
   CellTags->"SUNF"],
  Cell[1805057, 74316, 173, 6, 27, "Input",
   CellTags->"SUNF"],
  Cell[1805233, 74324, 150, 4, 39, "Output",
   CellTags->"SUNF"],
  Cell[1805420, 74333, 202, 7, 27, "Input",
   CellTags->"SUNF"],
  Cell[1805625, 74342, 258, 7, 39, "Output",
   CellTags->"SUNF"],
  Cell[1805920, 74354, 231, 8, 27, "Input",
   CellTags->"SUNF"],
  Cell[1806154, 74364, 150, 4, 39, "Output",
   CellTags->"SUNF"],
  Cell[1806341, 74373, 135, 4, 27, "Input",
   CellTags->"SUNF"],
  Cell[1806479, 74379, 147, 5, 27, "Output",
   CellTags->"SUNF"],
  Cell[1806663, 74389, 162, 5, 27, "Input",
   CellTags->"SUNF"],
  Cell[1806828, 74396, 401, 18, 27, "Output",
   CellTags->"SUNF"]},
 "SUNFJacobi"->{
  Cell[1807256, 74418, 57, 1, 39, "ObjectName",
   CellTags->"SUNFJacobi"],
  Cell[1807338, 74423, 61, 1, 33, "Subsubsection",
   CellTags->"SUNFJacobi"],
  Cell[1807402, 74426, 146, 4, 23, "Text",
   CellTags->"SUNFJacobi"],
  Cell[1807551, 74432, 283, 13, 23, "Text",
   CellTags->"SUNFJacobi"],
  Cell[1807871, 74450, 58, 1, 33, "Subsubsection",
   CellTags->"SUNFJacobi"],
  Cell[1807954, 74455, 380, 12, 27, "Input",
   CellTags->"SUNFJacobi"],
  Cell[1808337, 74469, 694, 32, 28, "Output",
   CellTags->"SUNFJacobi"],
  Cell[1809068, 74506, 379, 12, 27, "Input",
   CellTags->"SUNFJacobi"],
  Cell[1809450, 74520, 1362, 62, 28, "Output",
   CellTags->"SUNFJacobi"]},
 "SUNIndex"->{
  Cell[1810839, 74586, 53, 1, 39, "ObjectName",
   CellTags->"SUNIndex"],
  Cell[1810917, 74591, 59, 1, 33, "Subsubsection",
   CellTags->"SUNIndex"],
  Cell[1810979, 74594, 135, 6, 23, "Text",
   CellTags->"SUNIndex"],
  Cell[1811117, 74602, 405, 18, 23, "Text",
   CellTags->"SUNIndex"],
  Cell[1811559, 74625, 56, 1, 33, "Subsubsection",
   CellTags->"SUNIndex"],
  Cell[1811640, 74630, 110, 3, 27, "Input",
   CellTags->"SUNIndex"],
  Cell[1811753, 74635, 105, 3, 25, "Output",
   CellTags->"SUNIndex"],
  Cell[1811895, 74643, 110, 3, 27, "Input",
   CellTags->"SUNIndex"],
  Cell[1812008, 74648, 125, 3, 39, "Output",
   CellTags->"SUNIndex"],
  Cell[1812170, 74656, 200, 7, 27, "Input",
   CellTags->"SUNIndex"],
  Cell[1812373, 74665, 220, 6, 39, "Output",
   CellTags->"SUNIndex"]},
 "SUNIndexRename"->{
  Cell[1812620, 74675, 65, 1, 39, "ObjectName",
   CellTags->"SUNIndexRename"],
  Cell[1812710, 74680, 65, 1, 33, "Subsubsection",
   CellTags->"SUNIndexRename"],
  Cell[1812778, 74683, 163, 4, 23, "Text",
   CellTags->"SUNIndexRename"],
  Cell[1812944, 74689, 304, 14, 23, "Text",
   CellTags->"SUNIndexRename"]},
 "SUNN"->{
  Cell[1813263, 74706, 45, 1, 39, "ObjectName",
   CellTags->"SUNN"],
  Cell[1813333, 74711, 55, 1, 33, "Subsubsection",
   CellTags->"SUNN"],
  Cell[1813391, 74714, 203, 7, 23, "Text",
   CellTags->"SUNN"],
  Cell[1813597, 74723, 579, 29, 23, "Text",
   CellTags->"SUNN"],
  Cell[1814213, 74757, 52, 1, 33, "Subsubsection",
   CellTags->"SUNN"],
  Cell[1814290, 74762, 317, 9, 27, "Input",
   CellTags->"SUNN"],
  Cell[1814610, 74773, 149, 5, 27, "Output",
   CellTags->"SUNN"]},
 "SUNNToCACF"->{
  Cell[1814786, 74782, 57, 1, 39, "ObjectName",
   CellTags->"SUNNToCACF"],
  Cell[1814868, 74787, 61, 1, 33, "Subsubsection",
   CellTags->"SUNNToCACF"],
  Cell[1814932, 74790, 187, 4, 23, "Text",
   CellTags->"SUNNToCACF"],
  Cell[1815122, 74796, 573, 29, 23, "Text",
   CellTags->"SUNNToCACF"],
  Cell[1815732, 74830, 58, 1, 33, "Subsubsection",
   CellTags->"SUNNToCACF"],
  Cell[1815815, 74835, 322, 9, 27, "Input",
   CellTags->"SUNNToCACF"],
  Cell[1816140, 74846, 186, 6, 25, "Output",
   CellTags->"SUNNToCACF"]},
 "SUNSimplify"->{
  Cell[1816353, 74856, 59, 1, 39, "ObjectName",
   CellTags->"SUNSimplify"],
  Cell[1816437, 74861, 62, 1, 33, "Subsubsection",
   CellTags->"SUNSimplify"],
  Cell[1816502, 74864, 376, 7, 55, "Text",
   CellTags->"SUNSimplify"],
  Cell[1816903, 74875, 122, 3, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1817028, 74880, 512, 13, 45, "Output",
   CellTags->"SUNSimplify"],
  Cell[1817555, 74896, 299, 13, 23, "Text",
   CellTags->"SUNSimplify"],
  Cell[1817891, 74914, 59, 1, 33, "Subsubsection",
   CellTags->"SUNSimplify"],
  Cell[1817975, 74919, 247, 8, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1818225, 74929, 231, 8, 27, "Output",
   CellTags->"SUNSimplify"],
  Cell[1818493, 74942, 117, 3, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1818613, 74947, 304, 13, 27, "Output",
   CellTags->"SUNSimplify"],
  Cell[1818954, 74965, 189, 6, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1819146, 74973, 249, 10, 25, "Output",
   CellTags->"SUNSimplify"],
  Cell[1819432, 74988, 117, 3, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1819552, 74993, 130, 4, 25, "Output",
   CellTags->"SUNSimplify"],
  Cell[1819719, 75002, 183, 5, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1819905, 75009, 203, 7, 47, "Output",
   CellTags->"SUNSimplify"],
  Cell[1820145, 75021, 254, 8, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1820402, 75031, 227, 8, 27, "Output",
   CellTags->"SUNSimplify"],
  Cell[1820666, 75044, 117, 3, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1820786, 75049, 360, 15, 27, "Output",
   CellTags->"SUNSimplify"],
  Cell[1821183, 75069, 269, 8, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1821455, 75079, 227, 8, 27, "Output",
   CellTags->"SUNSimplify"],
  Cell[1821719, 75092, 117, 3, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1821839, 75097, 197, 6, 29, "Output",
   CellTags->"SUNSimplify"],
  Cell[1822073, 75108, 259, 8, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1822335, 75118, 227, 8, 27, "Output",
   CellTags->"SUNSimplify"],
  Cell[1822599, 75131, 117, 3, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1822719, 75136, 360, 15, 27, "Output",
   CellTags->"SUNSimplify"],
  Cell[1823116, 75156, 259, 8, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1823378, 75166, 227, 8, 27, "Output",
   CellTags->"SUNSimplify"],
  Cell[1823642, 75179, 180, 5, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1823825, 75186, 108, 3, 25, "Output",
   CellTags->"SUNSimplify"],
  Cell[1823970, 75194, 384, 12, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1824357, 75208, 311, 11, 47, "Output",
   CellTags->"SUNSimplify"],
  Cell[1824705, 75224, 389, 12, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1825097, 75238, 448, 18, 47, "Output",
   CellTags->"SUNSimplify"],
  Cell[1825582, 75261, 246, 7, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1825831, 75270, 1173, 45, 25, "Output",
   CellTags->"SUNSimplify"],
  Cell[1827041, 75320, 246, 7, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1827290, 75329, 1132, 44, 25, "Output",
   CellTags->"SUNSimplify"],
  Cell[1828459, 75378, 273, 8, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1828735, 75388, 251, 8, 43, "Output",
   CellTags->"SUNSimplify"],
  Cell[1829023, 75401, 439, 14, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1829465, 75417, 379, 14, 27, "Output",
   CellTags->"SUNSimplify"],
  Cell[1829881, 75436, 181, 5, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1830065, 75443, 705, 32, 27, "Output",
   CellTags->"SUNSimplify"],
  Cell[1830807, 75480, 238, 6, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1831048, 75488, 1363, 62, 27, "Output",
   CellTags->"SUNSimplify"],
  Cell[1832448, 75555, 200, 6, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1832651, 75563, 164, 5, 29, "Output",
   CellTags->"SUNSimplify"],
  Cell[1832852, 75573, 341, 10, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1833196, 75585, 543, 21, 27, "Output",
   CellTags->"SUNSimplify"],
  Cell[1833776, 75611, 181, 5, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1833960, 75618, 543, 21, 27, "Output",
   CellTags->"SUNSimplify"],
  Cell[1834540, 75644, 180, 5, 27, "Input",
   CellTags->"SUNSimplify"],
  Cell[1834723, 75651, 571, 22, 27, "Output",
   CellTags->"SUNSimplify"],
  Cell[1835309, 75676, 208, 6, 27, "Input",
   CellTags->"SUNSimplify"]},
 "SUNT"->{
  Cell[1835532, 75685, 45, 1, 39, "ObjectName",
   CellTags->"SUNT"],
  Cell[1835602, 75690, 55, 1, 33, "Subsubsection",
   CellTags->"SUNT"],
  Cell[1835660, 75693, 237, 10, 23, "Text",
   CellTags->"SUNT"],
  Cell[1835900, 75705, 674, 34, 23, "Text",
   CellTags->"SUNT"],
  Cell[1836611, 75744, 52, 1, 33, "Subsubsection",
   CellTags->"SUNT"],
  Cell[1836688, 75749, 102, 3, 27, "Input",
   CellTags->"SUNT"],
  Cell[1836793, 75754, 157, 6, 25, "Output",
   CellTags->"SUNT"],
  Cell[1836965, 75763, 203, 7, 23, "Text",
   CellTags->"SUNT"],
  Cell[1837193, 75774, 207, 6, 27, "Input",
   CellTags->"SUNT"],
  Cell[1837403, 75782, 311, 13, 25, "Output",
   CellTags->"SUNT"],
  Cell[1837751, 75800, 145, 4, 27, "Input",
   CellTags->"SUNT"],
  Cell[1837899, 75806, 365, 16, 25, "Output",
   CellTags->"SUNT"],
  Cell[1838301, 75827, 242, 7, 27, "Input",
   CellTags->"SUNT"],
  Cell[1838546, 75836, 268, 11, 44, "Output",
   CellTags->"SUNT"],
  Cell[1838851, 75852, 184, 5, 27, "Input",
   CellTags->"SUNT"],
  Cell[1839038, 75859, 133, 4, 29, "Output",
   CellTags->"SUNT"],
  Cell[1839208, 75868, 174, 5, 27, "Input",
   CellTags->"SUNT"],
  Cell[1839385, 75875, 399, 16, 43, "Output",
   CellTags->"SUNT"],
  Cell[1839821, 75896, 242, 7, 27, "Input",
   CellTags->"SUNT"],
  Cell[1840066, 75905, 268, 11, 44, "Output",
   CellTags->"SUNT"],
  Cell[1840349, 75919, 422, 15, 23, "Text",
   CellTags->"SUNT"],
  Cell[1840796, 75938, 161, 5, 27, "Input",
   CellTags->"SUNT"],
  Cell[1840960, 75945, 328, 14, 43, "Output",
   CellTags->"SUNT"],
  Cell[1841303, 75962, 197, 7, 26, "Text",
   CellTags->"SUNT"],
  Cell[1841525, 75973, 197, 6, 27, "Input",
   CellTags->"SUNT"],
  Cell[1841725, 75981, 353, 15, 28, "Output",
   CellTags->"SUNT"],
  Cell[1842115, 76001, 198, 6, 27, "Input",
   CellTags->"SUNT"],
  Cell[1842316, 76009, 263, 8, 55, "Output",
   CellTags->"SUNT"],
  Cell[1842616, 76022, 167, 6, 27, "Input",
   CellTags->"SUNT"],
  Cell[1842786, 76030, 152, 4, 39, "Output",
   CellTags->"SUNT"],
  Cell[1842975, 76039, 195, 7, 27, "Input",
   CellTags->"SUNT"],
  Cell[1843173, 76048, 117, 3, 39, "Output",
   CellTags->"SUNT"]},
 "SUNTrace"->{
  Cell[1843317, 76055, 53, 1, 39, "ObjectName",
   CellTags->"SUNTrace"],
  Cell[1843395, 76060, 59, 1, 33, "Subsubsection",
   CellTags->"SUNTrace"],
  Cell[1843457, 76063, 81, 1, 23, "Text",
   CellTags->"SUNTrace"],
  Cell[1843563, 76068, 116, 3, 27, "Input",
   CellTags->"SUNTrace"],
  Cell[1843682, 76073, 172, 6, 25, "Output",
   CellTags->"SUNTrace"],
  Cell[1843869, 76082, 280, 14, 23, "Text",
   CellTags->"SUNTrace"],
  Cell[1844186, 76101, 56, 1, 33, "Subsubsection",
   CellTags->"SUNTrace"],
  Cell[1844267, 76106, 165, 5, 27, "Input",
   CellTags->"SUNTrace"],
  Cell[1844435, 76113, 332, 14, 43, "Output",
   CellTags->"SUNTrace"],
  Cell[1844804, 76132, 175, 5, 27, "Input",
   CellTags->"SUNTrace"],
  Cell[1844982, 76139, 524, 22, 25, "Output",
   CellTags->"SUNTrace"],
  Cell[1845543, 76166, 240, 7, 27, "Input",
   CellTags->"SUNTrace"],
  Cell[1845786, 76175, 811, 35, 44, "Output",
   CellTags->"SUNTrace"],
  Cell[1846634, 76215, 185, 5, 27, "Input",
   CellTags->"SUNTrace"],
  Cell[1846822, 76222, 641, 27, 25, "Output",
   CellTags->"SUNTrace"],
  Cell[1847500, 76254, 278, 8, 27, "Input",
   CellTags->"SUNTrace"],
  Cell[1847781, 76264, 4270, 184, 44, "Output",
   CellTags->"SUNTrace"],
  Cell[1852088, 76453, 177, 5, 27, "Input",
   CellTags->"SUNTrace"],
  Cell[1852268, 76460, 641, 27, 25, "Output",
   CellTags->"SUNTrace"],
  Cell[1852946, 76492, 288, 8, 27, "Input",
   CellTags->"SUNTrace"],
  Cell[1853237, 76502, 11352, 436, 173, "Output",
   CellTags->"SUNTrace"],
  Cell[1864626, 76943, 177, 5, 27, "Input",
   CellTags->"SUNTrace"],
  Cell[1864806, 76950, 758, 32, 25, "Output",
   CellTags->"SUNTrace"],
  Cell[1865601, 76987, 270, 8, 27, "Input",
   CellTags->"SUNTrace"],
  Cell[1865874, 76997, 105, 3, 25, "Output",
   CellTags->"SUNTrace"],
  Cell[1866016, 77005, 270, 8, 27, "Input",
   CellTags->"SUNTrace"],
  Cell[1866289, 77015, 105, 3, 25, "Output",
   CellTags->"SUNTrace"],
  Cell[1866431, 77023, 270, 8, 27, "Input",
   CellTags->"SUNTrace"],
  Cell[1866704, 77033, 105, 3, 25, "Output",
   CellTags->"SUNTrace"],
  Cell[1866846, 77041, 270, 8, 27, "Input",
   CellTags->"SUNTrace"],
  Cell[1867119, 77051, 576, 23, 29, "Output",
   CellTags->"SUNTrace"]},
 "SymbolicSum2"->{
  Cell[1867722, 77078, 61, 1, 39, "ObjectName",
   CellTags->"SymbolicSum2"],
  Cell[1867808, 77083, 63, 1, 33, "Subsubsection",
   CellTags->"SymbolicSum2"],
  Cell[1867874, 77086, 284, 6, 39, "Text",
   CellTags->"SymbolicSum2"]},
 "SymbolicSum3"->{
  Cell[1868173, 77095, 61, 1, 39, "ObjectName",
   CellTags->"SymbolicSum3"],
  Cell[1868259, 77100, 63, 1, 33, "Subsubsection",
   CellTags->"SymbolicSum3"],
  Cell[1868325, 77103, 292, 6, 39, "Text",
   CellTags->"SymbolicSum3"]},
 "Symmetrize"->{
  Cell[1868632, 77112, 57, 1, 39, "ObjectName",
   CellTags->"Symmetrize"],
  Cell[1868714, 77117, 61, 1, 33, "Subsubsection",
   CellTags->"Symmetrize"],
  Cell[1868778, 77120, 145, 4, 23, "Text",
   CellTags->"Symmetrize"],
  Cell[1868926, 77126, 193, 8, 23, "Text",
   CellTags->"Symmetrize"],
  Cell[1869156, 77139, 58, 1, 33, "Subsubsection",
   CellTags->"Symmetrize"],
  Cell[1869239, 77144, 240, 8, 27, "Input",
   CellTags->"Symmetrize"],
  Cell[1869482, 77154, 317, 11, 43, "Output",
   CellTags->"Symmetrize"],
  Cell[1869836, 77170, 260, 8, 27, "Input",
   CellTags->"Symmetrize"],
  Cell[1870099, 77180, 652, 20, 43, "Output",
   CellTags->"Symmetrize"]},
 "TBox"->{
  Cell[1870778, 77204, 61, 1, 39, "ObjectName",
   CellTags->{"TBox", "Tbox"}],
  Cell[1870864, 77209, 65, 1, 33, "Subsubsection",
   CellTags->{"TBox", "Tbox"}],
  Cell[1870932, 77212, 262, 5, 39, "Text",
   CellTags->{"TBox", "Tbox"}]},
 "Tbox"->{
  Cell[1870778, 77204, 61, 1, 39, "ObjectName",
   CellTags->{"TBox", "Tbox"}],
  Cell[1870864, 77209, 65, 1, 33, "Subsubsection",
   CellTags->{"TBox", "Tbox"}],
  Cell[1870932, 77212, 262, 5, 39, "Text",
   CellTags->{"TBox", "Tbox"}]},
 "Tdec"->{
  Cell[1871209, 77220, 45, 1, 39, "ObjectName",
   CellTags->"Tdec"],
  Cell[1871279, 77225, 55, 1, 33, "Subsubsection",
   CellTags->"Tdec"],
  Cell[1871337, 77228, 256, 5, 39, "Text",
   CellTags->"Tdec"],
  Cell[1871618, 77237, 108, 3, 27, "Input",
   CellTags->"Tdec"],
  Cell[1871729, 77242, 412, 11, 25, "Output",
   CellTags->"Tdec"],
  Cell[1872156, 77256, 389, 19, 23, "Text",
   CellTags->"Tdec"],
  Cell[1872582, 77280, 52, 1, 33, "Subsubsection",
   CellTags->"Tdec"],
  Cell[1872637, 77283, 608, 22, 32, "Text",
   CellTags->"Tdec"],
  Cell[1873270, 77309, 202, 7, 27, "Input",
   CellTags->"Tdec"],
  Cell[1873475, 77318, 556, 21, 44, "Output",
   CellTags->"Tdec"],
  Cell[1874068, 77344, 199, 7, 27, "Input",
   CellTags->"Tdec"],
  Cell[1874270, 77353, 354, 14, 46, "Output",
   CellTags->"Tdec"],
  Cell[1874639, 77370, 776, 28, 25, "Text",
   CellTags->"Tdec"],
  Cell[1875418, 77400, 529, 18, 27, "Input",
   CellTags->"Tdec"],
  Cell[1875972, 77422, 199, 7, 27, "Input",
   CellTags->"Tdec"],
  Cell[1876174, 77431, 7304, 266, 96, "Output",
   CellTags->"Tdec"],
  Cell[1883515, 77702, 380, 13, 27, "Input",
   CellTags->"Tdec"],
  Cell[1883898, 77717, 4966, 181, 71, "Output",
   CellTags->"Tdec"],
  Cell[1888879, 77901, 121, 4, 27, "Input",
   CellTags->"Tdec"]},
 "TensorFunction"->{
  Cell[1889015, 77908, 65, 1, 39, "ObjectName",
   CellTags->"TensorFunction"],
  Cell[1889105, 77913, 65, 1, 33, "Subsubsection",
   CellTags->"TensorFunction"],
  Cell[1889173, 77916, 360, 7, 39, "Text",
   CellTags->"TensorFunction"],
  Cell[1889536, 77925, 191, 9, 23, "Text",
   CellTags->"TensorFunction"],
  Cell[1889764, 77939, 62, 1, 33, "Subsubsection",
   CellTags->"TensorFunction"],
  Cell[1889851, 77944, 178, 4, 27, "Input",
   CellTags->"TensorFunction"],
  Cell[1890032, 77950, 212, 6, 25, "Output",
   CellTags->"TensorFunction"],
  Cell[1890281, 77961, 116, 3, 27, "Input",
   CellTags->"TensorFunction"],
  Cell[1890400, 77966, 193, 4, 39, "Output",
   CellTags->"TensorFunction"],
  Cell[1890630, 77975, 198, 6, 27, "Input",
   CellTags->"TensorFunction"],
  Cell[1890831, 77983, 376, 14, 25, "Output",
   CellTags->"TensorFunction"],
  Cell[1891244, 78002, 116, 3, 27, "Input",
   CellTags->"TensorFunction"],
  Cell[1891363, 78007, 358, 10, 39, "Output",
   CellTags->"TensorFunction"],
  Cell[1891758, 78022, 228, 7, 27, "Input",
   CellTags->"TensorFunction"],
  Cell[1891989, 78031, 263, 8, 25, "Output",
   CellTags->"TensorFunction"],
  Cell[1892289, 78044, 228, 7, 27, "Input",
   CellTags->"TensorFunction"],
  Cell[1892520, 78053, 263, 8, 25, "Output",
   CellTags->"TensorFunction"],
  Cell[1892820, 78066, 116, 3, 27, "Input",
   CellTags->"TensorFunction"],
  Cell[1892939, 78071, 243, 7, 39, "Output",
   CellTags->"TensorFunction"],
  Cell[1893219, 78083, 118, 3, 27, "Input",
   CellTags->"TensorFunction"],
  Cell[1893340, 78088, 129, 4, 25, "Output",
   CellTags->"TensorFunction"],
  Cell[1893484, 78095, 154, 4, 27, "Input",
   CellTags->"TensorFunction"]},
 "Tf"->{
  Cell[1893653, 78102, 41, 1, 39, "ObjectName",
   CellTags->"Tf"],
  Cell[1893719, 78107, 53, 1, 33, "Subsubsection",
   CellTags->"Tf"],
  Cell[1893775, 78110, 214, 10, 26, "Text",
   CellTags->"Tf"],
  Cell[1893992, 78122, 414, 18, 23, "Text",
   CellTags->"Tf"]},
 "TFi"->{
  Cell[1894421, 78143, 43, 1, 39, "ObjectName",
   CellTags->"TFi"],
  Cell[1894489, 78148, 54, 1, 33, "Subsubsection",
   CellTags->"TFi"],
  Cell[1895114, 78170, 576, 10, 87, "Text",
   CellTags->"TFi"],
  Cell[1895693, 78182, 237, 8, 23, "Text",
   CellTags->"TFi"],
  Cell[1895933, 78192, 185, 4, 23, "Text",
   CellTags->"TFi"],
  Cell[1896121, 78198, 266, 13, 23, "Text",
   CellTags->"TFi"],
  Cell[1896424, 78216, 51, 1, 33, "Subsubsection",
   CellTags->"TFi"],
  Cell[1896500, 78221, 506, 17, 27, "Input",
   CellTags->"TFi"],
  Cell[1897009, 78240, 778, 24, 92, "Output",
   CellTags->"TFi"],
  Cell[1897824, 78269, 295, 10, 27, "Input",
   CellTags->"TFi"],
  Cell[1898122, 78281, 333, 11, 29, "Output",
   CellTags->"TFi"]},
 "ThreeVector"->{
  Cell[1898482, 78296, 59, 1, 39, "ObjectName",
   CellTags->"ThreeVector"],
  Cell[1898566, 78301, 62, 1, 33, "Subsubsection",
   CellTags->"ThreeVector"],
  Cell[1898631, 78304, 91, 1, 23, "Text",
   CellTags->"ThreeVector"],
  Cell[1898725, 78307, 304, 13, 23, "Text",
   CellTags->"ThreeVector"]},
 "TID"->{
  Cell[1899044, 78323, 43, 1, 39, "ObjectName",
   CellTags->"TID"],
  Cell[1899112, 78328, 54, 1, 33, "Subsubsection",
   CellTags->"TID"],
  Cell[1899169, 78331, 80, 1, 23, "Text",
   CellTags->"TID"],
  Cell[1899274, 78336, 106, 3, 27, "Input",
   CellTags->"TID"],
  Cell[1899383, 78341, 655, 15, 45, "Output",
   CellTags->"TID"],
  Cell[1900053, 78359, 293, 14, 23, "Text",
   CellTags->"TID"],
  Cell[1900383, 78378, 51, 1, 33, "Subsubsection",
   CellTags->"TID"],
  Cell[1900459, 78383, 374, 12, 27, "Input",
   CellTags->"TID"],
  Cell[1900836, 78397, 532, 21, 49, "Output",
   CellTags->"TID"],
  Cell[1901405, 78423, 181, 6, 27, "Input",
   CellTags->"TID"],
  Cell[1901589, 78431, 4307, 136, 65, "Output",
   CellTags->"TID"],
  Cell[1905933, 78572, 271, 9, 27, "Input",
   CellTags->"TID"],
  Cell[1906207, 78583, 389, 16, 49, "Output",
   CellTags->"TID"],
  Cell[1906633, 78604, 123, 4, 27, "Input",
   CellTags->"TID"],
  Cell[1906759, 78610, 627, 27, 49, "Output",
   CellTags->"TID"],
  Cell[1907423, 78642, 195, 6, 27, "Input",
   CellTags->"TID"],
  Cell[1907621, 78650, 627, 27, 49, "Output",
   CellTags->"TID"]},
 "TIDL"->{
  Cell[1908275, 78681, 45, 1, 39, "ObjectName",
   CellTags->"TIDL"],
  Cell[1908345, 78686, 55, 1, 33, "Subsubsection",
   CellTags->"TIDL"],
  Cell[1908403, 78689, 87, 1, 23, "Text",
   CellTags->"TIDL"],
  Cell[1908493, 78692, 154, 8, 23, "Text",
   CellTags->"TIDL"],
  Cell[1908662, 78703, 52, 1, 33, "Subsubsection",
   CellTags->"TIDL"],
  Cell[1908739, 78708, 154, 5, 36, "Subsubsection",
   CellTags->"TIDL"],
  Cell[1908896, 78715, 414, 13, 25, "Text",
   CellTags->"TIDL"],
  Cell[1909335, 78732, 202, 7, 27, "Input",
   CellTags->"TIDL"],
  Cell[1909540, 78741, 465, 20, 49, "Output",
   CellTags->"TIDL"],
  Cell[1910054, 78767, 159, 5, 36, "Subsubsection",
   CellTags->"TIDL"],
  Cell[1910238, 78776, 312, 11, 27, "Input",
   CellTags->"TIDL"],
  Cell[1910553, 78789, 1876, 74, 53, "Output",
   CellTags->"TIDL"],
  Cell[1912478, 78869, 154, 5, 36, "Subsubsection",
   CellTags->"TIDL"],
  Cell[1912657, 78878, 277, 10, 27, "Input",
   CellTags->"TIDL"],
  Cell[1912937, 78890, 2812, 108, 51, "Output",
   CellTags->"TIDL"],
  Cell[1915798, 79004, 159, 5, 36, "Subsubsection",
   CellTags->"TIDL"],
  Cell[1915982, 79013, 387, 14, 27, "Input",
   CellTags->"TIDL"],
  Cell[1916372, 79029, 24393, 841, 353, "Output",
   CellTags->"TIDL"],
  Cell[1940814, 79876, 165, 5, 36, "Subsubsection",
   CellTags->"TIDL"],
  Cell[1940982, 79883, 434, 15, 27, "Input",
   CellTags->"TIDL"],
  Cell[1941453, 79903, 173, 5, 36, "Subsubsection",
   CellTags->"TIDL"],
  Cell[1941629, 79910, 506, 17, 27, "Input",
   CellTags->"TIDL"],
  Cell[1942172, 79932, 154, 5, 36, "Subsubsection",
   CellTags->"TIDL"],
  Cell[1942351, 79941, 312, 11, 27, "Input",
   CellTags->"TIDL"],
  Cell[1942666, 79954, 14684, 522, 149, "Output",
   CellTags->"TIDL"],
  Cell[1957399, 80482, 159, 5, 36, "Subsubsection",
   CellTags->"TIDL"],
  Cell[1957561, 80489, 374, 13, 27, "Input",
   CellTags->"TIDL"],
  Cell[1957972, 80507, 165, 5, 36, "Subsubsection",
   CellTags->"TIDL"],
  Cell[1958140, 80514, 444, 15, 27, "Input",
   CellTags->"TIDL"],
  Cell[1958621, 80534, 173, 5, 36, "Subsubsection",
   CellTags->"TIDL"],
  Cell[1958797, 80541, 529, 18, 27, "Input",
   CellTags->"TIDL"],
  Cell[1959351, 80563, 240, 7, 27, "Input",
   CellTags->"TIDL"],
  Cell[1959594, 80572, 161, 5, 25, "Output",
   CellTags->"TIDL"]},
 "TimedIntegrate"->{
  Cell[1959782, 80581, 65, 1, 39, "ObjectName",
   CellTags->"TimedIntegrate"],
  Cell[1959872, 80586, 65, 1, 33, "Subsubsection",
   CellTags->"TimedIntegrate"],
  Cell[1959940, 80589, 225, 5, 39, "Text",
   CellTags->"TimedIntegrate"],
  Cell[1960190, 80598, 128, 3, 27, "Input",
   CellTags->"TimedIntegrate"],
  Cell[1960321, 80603, 424, 13, 25, "Output",
   CellTags->"TimedIntegrate"],
  Cell[1960794, 80622, 62, 1, 33, "Subsubsection",
   CellTags->"TimedIntegrate"],
  Cell[1960859, 80625, 73, 1, 23, "Text",
   CellTags->"TimedIntegrate"],
  Cell[1960957, 80630, 305, 9, 27, "Input",
   CellTags->"TimedIntegrate"],
  Cell[1961265, 80641, 129, 4, 25, "Output",
   CellTags->"TimedIntegrate"],
  Cell[1961409, 80648, 59, 1, 23, "Text",
   CellTags->"TimedIntegrate"],
  Cell[1961493, 80653, 389, 11, 27, "Input",
   CellTags->"TimedIntegrate"],
  Cell[1961885, 80666, 449, 14, 29, "Output",
   CellTags->"TimedIntegrate"]},
 "TLI"->{
  Cell[1962361, 80684, 61, 1, 39, "ObjectName",
   CellTags->"TLI"],
  Cell[1962447, 80689, 54, 1, 33, "Subsubsection",
   CellTags->"TLI"],
  Cell[1962504, 80692, 616, 12, 111, "Text",
   CellTags->"TLI"],
  Cell[1963145, 80708, 106, 3, 27, "Input",
   CellTags->"TLI"],
  Cell[1963254, 80713, 229, 8, 25, "Output",
   CellTags->"TLI"],
  Cell[1963498, 80724, 168, 9, 23, "Text",
   CellTags->"TLI"],
  Cell[1963703, 80738, 51, 1, 33, "Subsubsection",
   CellTags->"TLI"],
  Cell[1963757, 80741, 70, 2, 27, "Input",
   CellTags->"TLI"]},
 "TLIFP"->{
  Cell[1963842, 80746, 65, 1, 39, "ObjectName",
   CellTags->"TLIFP"],
  Cell[1963932, 80751, 56, 1, 33, "Subsubsection",
   CellTags->"TLIFP"],
  Cell[1963991, 80754, 93, 1, 23, "Text",
   CellTags->"TLIFP"],
  Cell[1964109, 80759, 110, 3, 27, "Input",
   CellTags->"TLIFP"],
  Cell[1964222, 80764, 425, 12, 25, "Output",
   CellTags->"TLIFP"],
  Cell[1964662, 80779, 161, 9, 23, "Text",
   CellTags->"TLIFP"],
  Cell[1964860, 80793, 53, 1, 33, "Subsubsection",
   CellTags->"TLIFP"],
  Cell[1964916, 80796, 72, 2, 27, "Input",
   CellTags->"TLIFP"]},
 "TLIHYP"->{
  Cell[1965003, 80801, 67, 1, 39, "ObjectName",
   CellTags->"TLIHYP"],
  Cell[1965095, 80806, 57, 1, 33, "Subsubsection",
   CellTags->"TLIHYP"],
  Cell[1965155, 80809, 136, 4, 23, "Text",
   CellTags->"TLIHYP"],
  Cell[1965316, 80817, 112, 3, 27, "Input",
   CellTags->"TLIHYP"],
  Cell[1965431, 80822, 241, 8, 25, "Output",
   CellTags->"TLIHYP"],
  Cell[1965687, 80833, 162, 9, 23, "Text",
   CellTags->"TLIHYP"],
  Cell[1965886, 80847, 54, 1, 33, "Subsubsection",
   CellTags->"TLIHYP"],
  Cell[1965943, 80850, 73, 2, 27, "Input",
   CellTags->"TLIHYP"]},
 "TLI2"->{
  Cell[1966031, 80855, 45, 1, 39, "ObjectName",
   CellTags->"TLI2"],
  Cell[1966101, 80860, 55, 1, 33, "Subsubsection",
   CellTags->"TLI2"],
  Cell[1966159, 80863, 83, 1, 23, "Text",
   CellTags->"TLI2"],
  Cell[1966245, 80866, 160, 9, 23, "Text",
   CellTags->"TLI2"]},
 "TLI2FC"->{
  Cell[1966420, 80878, 67, 1, 39, "ObjectName",
   CellTags->"TLI2FC"],
  Cell[1966512, 80883, 57, 1, 33, "Subsubsection",
   CellTags->"TLI2FC"],
  Cell[1966572, 80886, 109, 3, 23, "Text",
   CellTags->"TLI2FC"],
  Cell[1966706, 80893, 112, 3, 27, "Input",
   CellTags->"TLI2FC"],
  Cell[1966821, 80898, 355, 11, 25, "Output",
   CellTags->"TLI2FC"],
  Cell[1967191, 80912, 262, 13, 23, "Text",
   CellTags->"TLI2FC"],
  Cell[1967490, 80930, 54, 1, 33, "Subsubsection",
   CellTags->"TLI2FC"],
  Cell[1967547, 80933, 73, 2, 27, "Input",
   CellTags->"TLI2FC"]},
 "ToDistribution"->{
  Cell[1967635, 80938, 65, 1, 39, "ObjectName",
   CellTags->"ToDistribution"],
  Cell[1967725, 80943, 65, 1, 33, "Subsubsection",
   CellTags->"ToDistribution"],
  Cell[1967793, 80946, 424, 7, 55, "Text",
   CellTags->"ToDistribution"],
  Cell[1968242, 80957, 128, 3, 27, "Input",
   CellTags->"ToDistribution"],
  Cell[1968373, 80962, 189, 6, 25, "Output",
   CellTags->"ToDistribution"],
  Cell[1968577, 80971, 209, 9, 23, "Text",
   CellTags->"ToDistribution"],
  Cell[1968823, 80985, 62, 1, 33, "Subsubsection",
   CellTags->"ToDistribution"],
  Cell[1968910, 80990, 217, 6, 27, "Input",
   CellTags->"ToDistribution"],
  Cell[1969130, 80998, 197, 6, 25, "Output",
   CellTags->"ToDistribution"],
  Cell[1969364, 81009, 277, 9, 27, "Input",
   CellTags->"ToDistribution"],
  Cell[1969644, 81020, 1338, 48, 52, "Output",
   CellTags->"ToDistribution"],
  Cell[1971019, 81073, 206, 5, 27, "Input",
   CellTags->"ToDistribution"],
  Cell[1971228, 81080, 189, 6, 25, "Output",
   CellTags->"ToDistribution"],
  Cell[1971454, 81091, 277, 9, 27, "Input",
   CellTags->"ToDistribution"],
  Cell[1971734, 81102, 1380, 50, 50, "Output",
   CellTags->"ToDistribution"],
  Cell[1973151, 81157, 461, 14, 29, "Input",
   CellTags->"ToDistribution"],
  Cell[1973615, 81173, 371, 13, 27, "Output",
   CellTags->"ToDistribution"],
  Cell[1974023, 81191, 118, 3, 27, "Input",
   CellTags->"ToDistribution"],
  Cell[1974144, 81196, 334, 9, 25, "Output",
   CellTags->"ToDistribution"],
  Cell[1974515, 81210, 409, 13, 27, "Input",
   CellTags->"ToDistribution"],
  Cell[1974927, 81225, 371, 13, 27, "Output",
   CellTags->"ToDistribution"]},
 "ToHypergeometric"->{
  Cell[1975325, 81242, 69, 1, 39, "ObjectName",
   CellTags->"ToHypergeometric"],
  Cell[1975419, 81247, 67, 1, 33, "Subsubsection",
   CellTags->"ToHypergeometric"],
  Cell[1975489, 81250, 1686, 67, 39, "Text",
   CellTags->"ToHypergeometric"],
  Cell[1977178, 81319, 479, 19, 23, "Text",
   CellTags->"ToHypergeometric"],
  Cell[1977694, 81343, 64, 1, 33, "Subsubsection",
   CellTags->"ToHypergeometric"],
  Cell[1977783, 81348, 395, 13, 29, "Input",
   CellTags->"ToHypergeometric"],
  Cell[1978181, 81363, 489, 15, 45, "Output",
   CellTags->"ToHypergeometric"],
  Cell[1978707, 81383, 488, 16, 29, "Input",
   CellTags->"ToHypergeometric"],
  Cell[1979198, 81401, 356, 13, 45, "Output",
   CellTags->"ToHypergeometric"],
  Cell[1979591, 81419, 395, 13, 29, "Input",
   CellTags->"ToHypergeometric"],
  Cell[1979989, 81434, 552, 17, 51, "Output",
   CellTags->"ToHypergeometric"],
  Cell[1980578, 81456, 488, 16, 29, "Input",
   CellTags->"ToHypergeometric"],
  Cell[1981069, 81474, 431, 15, 51, "Output",
   CellTags->"ToHypergeometric"]},
 "ToLarin"->{
  Cell[1981527, 81493, 51, 1, 39, "ObjectName",
   CellTags->"ToLarin"],
  Cell[1981603, 81498, 58, 1, 33, "Subsubsection",
   CellTags->"ToLarin"],
  Cell[1981664, 81501, 605, 19, 23, "Text",
   CellTags->"ToLarin"],
  Cell[1982272, 81522, 163, 9, 23, "Text",
   CellTags->"ToLarin"],
  Cell[1982472, 81536, 55, 1, 33, "Subsubsection",
   CellTags->"ToLarin"],
  Cell[1982552, 81541, 229, 6, 27, "Input",
   CellTags->"ToLarin"],
  Cell[1982784, 81549, 389, 15, 27, "Output",
   CellTags->"ToLarin"],
  Cell[1983210, 81569, 108, 3, 27, "Input",
   CellTags->"ToLarin"],
  Cell[1983321, 81574, 1097, 45, 43, "Output",
   CellTags->"ToLarin"]},
 "ToTFi"->{
  Cell[1984445, 81623, 47, 1, 39, "ObjectName",
   CellTags->"ToTFi"],
  Cell[1984517, 81628, 56, 1, 33, "Subsubsection",
   CellTags->"ToTFi"],
  Cell[1984576, 81631, 272, 5, 39, "Text",
   CellTags->"ToTFi"],
  Cell[1984851, 81638, 262, 13, 23, "Text",
   CellTags->"ToTFi"],
  Cell[1985150, 81656, 53, 1, 33, "Subsubsection",
   CellTags->"ToTFi"],
  Cell[1985228, 81661, 333, 11, 27, "Input",
   CellTags->"ToTFi"],
  Cell[1985564, 81674, 1870, 49, 49, "Output",
   CellTags->"ToTFi"],
  Cell[1987471, 81728, 149, 4, 27, "Input",
   CellTags->"ToTFi"],
  Cell[1987623, 81734, 2126, 54, 50, "Output",
   CellTags->"ToTFi"],
  Cell[1989786, 81793, 107, 3, 27, "Input",
   CellTags->"ToTFi"],
  Cell[1989896, 81798, 491, 16, 39, "Output",
   CellTags->"ToTFi"],
  Cell[1990424, 81819, 468, 15, 27, "Input",
   CellTags->"ToTFi"],
  Cell[1990895, 81836, 916, 33, 49, "Output",
   CellTags->"ToTFi"]},
 "TR"->{
  Cell[1991860, 81875, 41, 1, 39, "ObjectName",
   CellTags->"TR"],
  Cell[1991904, 81878, 100, 3, 25, "Output",
   CellTags->"TR"],
  Cell[1992041, 81886, 53, 1, 33, "Subsubsection",
   CellTags->"TR"],
  Cell[1992097, 81889, 420, 12, 39, "Text",
   CellTags->"TR"],
  Cell[1992542, 81905, 104, 3, 27, "Input",
   CellTags->"TR"],
  Cell[1992649, 81910, 761, 18, 45, "Output",
   CellTags->"TR"],
  Cell[1993425, 81931, 536, 23, 23, "Text",
   CellTags->"TR"],
  Cell[1993998, 81959, 50, 1, 33, "Subsubsection",
   CellTags->"TR"],
  Cell[1994073, 81964, 129, 4, 27, "Input",
   CellTags->"TR"],
  Cell[1994205, 81970, 194, 6, 25, "Output",
   CellTags->"TR"],
  Cell[1994436, 81981, 98, 3, 27, "Input",
   CellTags->"TR"],
  Cell[1994537, 81986, 175, 6, 25, "Output",
   CellTags->"TR"],
  Cell[1994749, 81997, 375, 12, 27, "Input",
   CellTags->"TR"],
  Cell[1995127, 82011, 1257, 50, 29, "Output",
   CellTags->"TR"],
  Cell[1996421, 82066, 205, 6, 27, "Input",
   CellTags->"TR"],
  Cell[1996629, 82074, 559, 23, 25, "Output",
   CellTags->"TR"],
  Cell[1997225, 82102, 240, 7, 27, "Input",
   CellTags->"TR"],
  Cell[1997468, 82111, 8363, 321, 47, "Output",
   CellTags->"TR"],
  Cell[2005868, 82437, 421, 13, 27, "Input",
   CellTags->"TR"],
  Cell[2006292, 82452, 10947, 412, 66, "Output",
   CellTags->"TR"],
  Cell[2017276, 82869, 171, 5, 27, "Input",
   CellTags->"TR"],
  Cell[2017450, 82876, 991, 39, 25, "Output",
   CellTags->"TR"],
  Cell[2018478, 82920, 444, 14, 27, "Input",
   CellTags->"TR"],
  Cell[2018925, 82936, 342, 13, 29, "Output",
   CellTags->"TR"],
  Cell[2019304, 82954, 224, 7, 27, "Input",
   CellTags->"TR"],
  Cell[2019531, 82963, 180, 6, 25, "Output",
   CellTags->"TR"],
  Cell[2019748, 82974, 104, 3, 27, "Input",
   CellTags->"TR"],
  Cell[2019855, 82979, 173, 5, 39, "Output",
   CellTags->"TR"],
  Cell[2020065, 82989, 347, 10, 27, "Input",
   CellTags->"TR"],
  Cell[2020415, 83001, 190, 6, 25, "Output",
   CellTags->"TR"],
  Cell[2020642, 83012, 104, 3, 27, "Input",
   CellTags->"TR"],
  Cell[2020749, 83017, 183, 5, 39, "Output",
   CellTags->"TR"],
  Cell[2020969, 83027, 339, 11, 27, "Input",
   CellTags->"TR"],
  Cell[2021311, 83040, 428, 16, 27, "Output",
   CellTags->"TR"],
  Cell[2021776, 83061, 214, 6, 27, "Input",
   CellTags->"TR"],
  Cell[2021993, 83069, 208, 7, 25, "Output",
   CellTags->"TR"],
  Cell[2022238, 83081, 213, 6, 27, "Input",
   CellTags->"TR"],
  Cell[2022454, 83089, 208, 7, 25, "Output",
   CellTags->"TR"],
  Cell[2022699, 83101, 214, 6, 27, "Input",
   CellTags->"TR"],
  Cell[2022916, 83109, 99, 3, 25, "Output",
   CellTags->"TR"],
  Cell[2023052, 83117, 213, 6, 27, "Input",
   CellTags->"TR"],
  Cell[2023268, 83125, 99, 3, 25, "Output",
   CellTags->"TR"],
  Cell[2028493, 83315, 143, 5, 27, "Input",
   CellTags->"TR"]},
 "Info3522766033-2743550"->{
  Cell[2023867, 83157, 644, 13, 155, "Print",
   CellTags->"Info3522766033-2743550"]},
 "TraceDimension"->{
  Cell[2028651, 83323, 65, 1, 39, "ObjectName",
   CellTags->"TraceDimension"],
  Cell[2028741, 83328, 65, 1, 33, "Subsubsection",
   CellTags->"TraceDimension"],
  Cell[2028809, 83331, 142, 4, 23, "Text",
   CellTags->"TraceDimension"],
  Cell[2028954, 83337, 200, 9, 23, "Text",
   CellTags->"TraceDimension"]},
 "TraceOfOne"->{
  Cell[2029169, 83349, 57, 1, 39, "ObjectName",
   CellTags->"TraceOfOne"],
  Cell[2029251, 83354, 61, 1, 33, "Subsubsection",
   CellTags->"TraceOfOne"],
  Cell[2029315, 83357, 149, 4, 23, "Text",
   CellTags->"TraceOfOne"],
  Cell[2029467, 83363, 273, 13, 23, "Text",
   CellTags->"TraceOfOne"],
  Cell[2029777, 83381, 58, 1, 33, "Subsubsection",
   CellTags->"TraceOfOne"],
  Cell[2029860, 83386, 273, 7, 27, "Input",
   CellTags->"TraceOfOne"],
  Cell[2030136, 83395, 109, 3, 25, "Output",
   CellTags->"TraceOfOne"],
  Cell[2030282, 83403, 272, 7, 27, "Input",
   CellTags->"TraceOfOne"],
  Cell[2030557, 83412, 109, 3, 25, "Output",
   CellTags->"TraceOfOne"]},
 "Trick"->{
  Cell[2030693, 83419, 47, 1, 39, "ObjectName",
   CellTags->"Trick"],
  Cell[2030765, 83424, 56, 1, 33, "Subsubsection",
   CellTags->"Trick"],
  Cell[2030824, 83427, 174, 4, 23, "Text",
   CellTags->"Trick"],
  Cell[2031001, 83433, 625, 29, 23, "Text",
   CellTags->"Trick"],
  Cell[2031663, 83467, 62, 1, 34, "Subsubsection",
   CellTags->"Trick"],
  Cell[2031728, 83470, 376, 15, 26, "Text",
   CellTags->"Trick"],
  Cell[2032129, 83489, 350, 11, 27, "Input",
   CellTags->"Trick"],
  Cell[2032482, 83502, 264, 10, 27, "Output",
   CellTags->"Trick"],
  Cell[2032783, 83517, 330, 11, 27, "Input",
   CellTags->"Trick"],
  Cell[2033116, 83530, 426, 16, 27, "Output",
   CellTags->"Trick"],
  Cell[2033579, 83551, 104, 3, 27, "Input",
   CellTags->"Trick"],
  Cell[2033686, 83556, 527, 22, 27, "Output",
   CellTags->"Trick"],
  Cell[2034250, 83583, 227, 6, 27, "Input",
   CellTags->"Trick"],
  Cell[2034480, 83591, 391, 15, 27, "Output",
   CellTags->"Trick"],
  Cell[2034908, 83611, 133, 4, 27, "Input",
   CellTags->"Trick"],
  Cell[2035044, 83617, 213, 6, 39, "Output",
   CellTags->"Trick"]},
 "TrickIntegrate"->{
  Cell[2035284, 83627, 65, 1, 39, "ObjectName",
   CellTags->"TrickIntegrate"],
  Cell[2035374, 83632, 65, 1, 33, "Subsubsection",
   CellTags->"TrickIntegrate"],
  Cell[2035442, 83635, 483, 8, 55, "Text",
   CellTags->"TrickIntegrate"],
  Cell[2035962, 83648, 62, 1, 33, "Subsubsection",
   CellTags->"TrickIntegrate"],
  Cell[2036049, 83653, 364, 12, 27, "Input",
   CellTags->"TrickIntegrate"],
  Cell[2036416, 83667, 517, 18, 29, "Output",
   CellTags->"TrickIntegrate"]},
 "TrickMandelstam"->{
  Cell[2036960, 83689, 67, 1, 39, "ObjectName",
   CellTags->"TrickMandelstam"],
  Cell[2037052, 83694, 66, 1, 33, "Subsubsection",
   CellTags->"TrickMandelstam"],
  Cell[2037121, 83697, 1340, 55, 43, "Text",
   CellTags->"TrickMandelstam"],
  Cell[2038498, 83757, 63, 1, 33, "Subsubsection",
   CellTags->"TrickMandelstam"],
  Cell[2038586, 83762, 528, 18, 29, "Input",
   CellTags->"TrickMandelstam"],
  Cell[2039117, 83782, 250, 9, 29, "Output",
   CellTags->"TrickMandelstam"],
  Cell[2039404, 83796, 568, 17, 27, "Input",
   CellTags->"TrickMandelstam"],
  Cell[2039975, 83815, 235, 8, 27, "Output",
   CellTags->"TrickMandelstam"]},
 "Tr2"->{
  Cell[2040237, 83827, 43, 1, 39, "ObjectName",
   CellTags->"Tr2"],
  Cell[2040305, 83832, 54, 1, 33, "Subsubsection",
   CellTags->"Tr2"],
  Cell[2040362, 83835, 347, 6, 55, "Text",
   CellTags->"Tr2"],
  Cell[2040734, 83845, 106, 3, 27, "Input",
   CellTags->"Tr2"],
  Cell[2040843, 83850, 168, 6, 25, "Output",
   CellTags->"Tr2"],
  Cell[2041026, 83859, 593, 28, 23, "Text",
   CellTags->"Tr2"],
  Cell[2041656, 83892, 51, 1, 33, "Subsubsection",
   CellTags->"Tr2"],
  Cell[2042484, 83928, 187, 6, 27, "Input",
   CellTags->"Tr2"],
  Cell[2042674, 83936, 156, 5, 28, "Output",
   CellTags->"Tr2"]},
 "Twist2AlienOperator"->{
  Cell[2042857, 83945, 116, 2, 39, "ObjectName",
   CellTags->"Twist2AlienOperator"],
  Cell[2042998, 83951, 70, 1, 33, "Subsubsection",
   CellTags->"Twist2AlienOperator"],
  Cell[2043071, 83954, 194, 4, 23, "Text",
   CellTags->"Twist2AlienOperator"],
  Cell[2043302, 83963, 67, 1, 33, "Subsubsection",
   CellTags->"Twist2AlienOperator"],
  Cell[2043394, 83968, 160, 4, 27, "Input",
   CellTags->"Twist2AlienOperator"],
  Cell[2043557, 83974, 887, 30, 51, "Output",
   CellTags->"Twist2AlienOperator"],
  Cell[2044481, 84009, 246, 7, 27, "Input",
   CellTags->"Twist2AlienOperator"],
  Cell[2044730, 84018, 3113, 103, 56, "Output",
   CellTags->"Twist2AlienOperator"]},
 "Twist2CounterOperator"->{
  Cell[2047870, 84125, 120, 2, 39, "ObjectName",
   CellTags->"Twist2CounterOperator"],
  Cell[2048015, 84131, 72, 1, 33, "Subsubsection",
   CellTags->"Twist2CounterOperator"],
  Cell[2048090, 84134, 239, 5, 39, "Text",
   CellTags->"Twist2CounterOperator"],
  Cell[2048366, 84144, 69, 1, 33, "Subsubsection",
   CellTags->"Twist2CounterOperator"],
  Cell[2048460, 84149, 204, 5, 27, "Input",
   CellTags->"Twist2CounterOperator"],
  Cell[2048667, 84156, 4002, 136, 83, "Output",
   CellTags->"Twist2CounterOperator"],
  Cell[2052706, 84297, 159, 4, 27, "Input",
   CellTags->"Twist2CounterOperator"],
  Cell[2052868, 84303, 1020, 35, 51, "Output",
   CellTags->"Twist2CounterOperator"],
  Cell[2053925, 84343, 242, 6, 27, "Input",
   CellTags->"Twist2CounterOperator"],
  Cell[2054170, 84351, 2610, 89, 57, "Output",
   CellTags->"Twist2CounterOperator"]},
 "Twist2GluonOperator"->{
  Cell[2056807, 84444, 75, 1, 39, "ObjectName",
   CellTags->"Twist2GluonOperator"],
  Cell[2056907, 84449, 70, 1, 33, "Subsubsection",
   CellTags->"Twist2GluonOperator"],
  Cell[2056980, 84452, 964, 15, 119, "Text",
   CellTags->"Twist2GluonOperator"],
  Cell[2057947, 84469, 223, 9, 23, "Text",
   CellTags->"Twist2GluonOperator"],
  Cell[2058207, 84483, 99, 1, 33, "Subsubsection",
   CellTags->"Twist2GluonOperator"],
  Cell[2058331, 84488, 352, 8, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2058686, 84498, 444, 12, 25, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2059145, 84513, 62, 1, 23, "Text",
   CellTags->"Twist2GluonOperator"],
  Cell[2059232, 84518, 271, 8, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2059506, 84528, 894, 35, 31, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2060437, 84568, 321, 9, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2060761, 84579, 1120, 45, 29, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2061918, 84629, 221, 6, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2062142, 84637, 336, 12, 31, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2062515, 84654, 271, 7, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2062789, 84663, 705, 28, 27, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2063509, 84694, 62, 1, 23, "Text",
   CellTags->"Twist2GluonOperator"],
  Cell[2063596, 84699, 355, 10, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2063954, 84711, 1193, 48, 31, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2065184, 84764, 325, 10, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2065512, 84776, 492, 18, 31, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2066041, 84799, 375, 11, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2066419, 84812, 11308, 411, 130, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2077742, 85226, 62, 1, 23, "Text",
   CellTags->"Twist2GluonOperator"],
  Cell[2077829, 85231, 431, 12, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2078263, 85245, 4976, 185, 31, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2083276, 85435, 391, 12, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2083670, 85449, 606, 22, 31, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2084313, 85476, 441, 13, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2084757, 85491, 24305, 869, 373, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2109111, 86366, 100, 1, 33, "Subsubsection",
   CellTags->"Twist2GluonOperator"],
  Cell[2109236, 86371, 268, 6, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2109507, 86379, 444, 12, 25, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2109966, 86394, 62, 1, 23, "Text",
   CellTags->"Twist2GluonOperator"],
  Cell[2110053, 86399, 271, 8, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2110327, 86409, 904, 36, 43, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2111268, 86450, 321, 9, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2111592, 86461, 2656, 102, 43, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2114285, 86568, 221, 6, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2114509, 86576, 336, 12, 31, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2114882, 86593, 271, 7, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2115156, 86602, 2231, 84, 29, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2117402, 86689, 62, 1, 23, "Text",
   CellTags->"Twist2GluonOperator"],
  Cell[2117489, 86694, 355, 10, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2117847, 86706, 1267, 50, 43, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2119151, 86761, 325, 10, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2119479, 86773, 492, 18, 31, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2120008, 86796, 375, 11, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2120386, 86809, 16342, 587, 204, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2136743, 87399, 62, 1, 23, "Text",
   CellTags->"Twist2GluonOperator"],
  Cell[2136830, 87404, 431, 12, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2137264, 87418, 4986, 186, 43, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2142287, 87609, 391, 12, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2142681, 87623, 606, 22, 31, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2143324, 87650, 441, 13, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2143768, 87665, 31861, 1141, 450, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2175678, 88812, 76, 1, 33, "Subsubsection",
   CellTags->"Twist2GluonOperator"],
  Cell[2175757, 88815, 97, 1, 23, "Text",
   CellTags->"Twist2GluonOperator"],
  Cell[2175857, 88818, 295, 7, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2176155, 88827, 380, 11, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2176572, 88843, 102, 1, 33, "Subsubsection",
   CellTags->"Twist2GluonOperator"],
  Cell[2176699, 88848, 284, 6, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2176986, 88856, 443, 12, 25, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2177444, 88871, 62, 1, 23, "Text",
   CellTags->"Twist2GluonOperator"],
  Cell[2177531, 88876, 320, 10, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2177854, 88888, 3609, 129, 43, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2181478, 89020, 62, 1, 23, "Text",
   CellTags->"Twist2GluonOperator"],
  Cell[2181565, 89025, 355, 10, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2181923, 89037, 54187, 1690, 830, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2236125, 90730, 62, 1, 23, "Text",
   CellTags->"Twist2GluonOperator"],
  Cell[2236212, 90735, 482, 13, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2236697, 90750, 4976, 185, 31, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2241722, 90941, 104, 1, 33, "Subsubsection",
   CellTags->"Twist2GluonOperator"],
  Cell[2241851, 90946, 284, 6, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2242138, 90954, 443, 12, 25, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2242596, 90969, 62, 1, 23, "Text",
   CellTags->"Twist2GluonOperator"],
  Cell[2242683, 90974, 320, 10, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2243006, 90986, 3074, 116, 43, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2246095, 91105, 62, 1, 23, "Text",
   CellTags->"Twist2GluonOperator"],
  Cell[2246160, 91108, 380, 11, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2246565, 91123, 325, 10, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2246893, 91135, 3075, 116, 43, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2250005, 91256, 375, 11, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2250383, 91269, 3075, 116, 43, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2253473, 91388, 62, 1, 23, "Text",
   CellTags->"Twist2GluonOperator"],
  Cell[2253560, 91393, 482, 13, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2254045, 91408, 4986, 186, 43, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2259046, 91597, 78, 1, 23, "Text",
   CellTags->"Twist2GluonOperator"],
  Cell[2259149, 91602, 520, 16, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2259672, 91620, 10907, 376, 148, "Output",
   CellTags->"Twist2GluonOperator"],
  Cell[2270594, 91999, 109, 3, 23, "Text",
   CellTags->"Twist2GluonOperator"],
  Cell[2270706, 92004, 295, 7, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2271026, 92015, 428, 13, 27, "Input",
   CellTags->"Twist2GluonOperator"],
  Cell[2271457, 92030, 9245, 285, 168, "Output",
   CellTags->"Twist2GluonOperator"]},
 "Twist2QuarkOperator"->{
  Cell[2280729, 92319, 75, 1, 39, "ObjectName",
   CellTags->"Twist2QuarkOperator"],
  Cell[2280829, 92324, 70, 1, 33, "Subsubsection",
   CellTags->"Twist2QuarkOperator"],
  Cell[2280902, 92327, 980, 15, 119, "Text",
   CellTags->"Twist2QuarkOperator"],
  Cell[2281885, 92344, 223, 9, 23, "Text",
   CellTags->"Twist2QuarkOperator"],
  Cell[2282123, 92356, 67, 1, 33, "Subsubsection",
   CellTags->"Twist2QuarkOperator"],
  Cell[2282215, 92361, 98, 1, 33, "Subsubsection",
   CellTags->"Twist2QuarkOperator"],
  Cell[2282338, 92366, 268, 6, 27, "Input",
   CellTags->"Twist2QuarkOperator"],
  Cell[2282609, 92374, 443, 12, 25, "Output",
   CellTags->"Twist2QuarkOperator"],
  Cell[2283067, 92389, 75, 1, 23, "Text",
   CellTags->"Twist2QuarkOperator"],
  Cell[2283167, 92394, 156, 4, 27, "Input",
   CellTags->"Twist2QuarkOperator"],
  Cell[2283326, 92400, 600, 21, 27, "Output",
   CellTags->"Twist2QuarkOperator"],
  Cell[2283941, 92424, 81, 1, 23, "Text",
   CellTags->"Twist2QuarkOperator"],
  Cell[2284047, 92429, 305, 9, 27, "Input",
   CellTags->"Twist2QuarkOperator"],
  Cell[2284355, 92440, 1581, 57, 53, "Output",
   CellTags->"Twist2QuarkOperator"],
  Cell[2285951, 92500, 87, 1, 23, "Text",
   CellTags->"Twist2QuarkOperator"],
  Cell[2286063, 92505, 380, 11, 27, "Input",
   CellTags->"Twist2QuarkOperator"],
  Cell[2286446, 92518, 4917, 163, 109, "Output",
   CellTags->"Twist2QuarkOperator"],
  Cell[2291412, 92687, 100, 1, 33, "Subsubsection",
   CellTags->"Twist2QuarkOperator"],
  Cell[2291537, 92692, 273, 6, 27, "Input",
   CellTags->"Twist2QuarkOperator"],
  Cell[2291813, 92700, 443, 12, 25, "Output",
   CellTags->"Twist2QuarkOperator"],
  Cell[2292271, 92715, 75, 1, 23, "Text",
   CellTags->"Twist2QuarkOperator"],
  Cell[2292371, 92720, 156, 4, 27, "Input",
   CellTags->"Twist2QuarkOperator"],
  Cell[2292530, 92726, 481, 17, 27, "Output",
   CellTags->"Twist2QuarkOperator"],
  Cell[2293026, 92746, 81, 1, 23, "Text",
   CellTags->"Twist2QuarkOperator"],
  Cell[2293132, 92751, 305, 9, 27, "Input",
   CellTags->"Twist2QuarkOperator"],
  Cell[2293440, 92762, 1492, 54, 53, "Output",
   CellTags->"Twist2QuarkOperator"],
  Cell[2294947, 92819, 87, 1, 23, "Text",
   CellTags->"Twist2QuarkOperator"],
  Cell[2295059, 92824, 380, 11, 27, "Input",
   CellTags->"Twist2QuarkOperator"],
  Cell[2295442, 92837, 4776, 159, 78, "Output",
   CellTags->"Twist2QuarkOperator"],
  Cell[2300233, 92999, 93, 1, 23, "Text",
   CellTags->"Twist2QuarkOperator"],
  Cell[2300351, 93004, 197, 6, 27, "Input",
   CellTags->"Twist2QuarkOperator"],
  Cell[2300551, 93012, 263, 8, 39, "Output",
   CellTags->"Twist2QuarkOperator"],
  Cell[2300851, 93025, 376, 10, 27, "Input",
   CellTags->"Twist2QuarkOperator"],
  Cell[2301230, 93037, 1971, 72, 52, "Output",
   CellTags->"Twist2QuarkOperator"],
  Cell[2303238, 93114, 449, 12, 27, "Input",
   CellTags->"Twist2QuarkOperator"],
  Cell[2303690, 93128, 9405, 298, 101, "Output",
   CellTags->"Twist2QuarkOperator"],
  Cell[2313144, 93432, 102, 1, 33, "Subsubsection",
   CellTags->"Twist2QuarkOperator"],
  Cell[2313271, 93437, 269, 6, 27, "Input",
   CellTags->"Twist2QuarkOperator"],
  Cell[2313543, 93445, 444, 12, 25, "Output",
   CellTags->"Twist2QuarkOperator"],
  Cell[2314002, 93460, 178, 4, 23, "Text",
   CellTags->"Twist2QuarkOperator"],
  Cell[2314183, 93466, 275, 5, 39, "Text",
   CellTags->"Twist2QuarkOperator"],
  Cell[2314483, 93475, 205, 6, 27, "Input",
   CellTags->"Twist2QuarkOperator"],
  Cell[2314691, 93483, 800, 28, 27, "Output",
   CellTags->"Twist2QuarkOperator"],
  Cell[2315506, 93514, 100, 1, 23, "Text",
   CellTags->"Twist2QuarkOperator"],
  Cell[2315631, 93519, 305, 9, 27, "Input",
   CellTags->"Twist2QuarkOperator"],
  Cell[2315939, 93530, 2305, 78, 53, "Output",
   CellTags->"Twist2QuarkOperator"],
  Cell[2318259, 93611, 87, 1, 23, "Text",
   CellTags->"Twist2QuarkOperator"],
  Cell[2318371, 93616, 156, 4, 27, "Input",
   CellTags->"Twist2QuarkOperator"],
  Cell[2318530, 93622, 1102, 33, 61, "Output",
   CellTags->"Twist2QuarkOperator"],
  Cell[2319681, 93661, 104, 1, 33, "Subsubsection",
   CellTags->"Twist2QuarkOperator"],
  Cell[2319810, 93666, 269, 6, 27, "Input",
   CellTags->"Twist2QuarkOperator"],
  Cell[2320082, 93674, 444, 12, 25, "Output",
   CellTags->"Twist2QuarkOperator"],
  Cell[2320541, 93689, 75, 1, 23, "Text",
   CellTags->"Twist2QuarkOperator"],
  Cell[2320641, 93694, 205, 6, 27, "Input",
   CellTags->"Twist2QuarkOperator"],
  Cell[2320849, 93702, 800, 28, 27, "Output",
   CellTags->"Twist2QuarkOperator"],
  Cell[2321664, 93733, 81, 1, 23, "Text",
   CellTags->"Twist2QuarkOperator"],
  Cell[2321770, 93738, 305, 9, 27, "Input",
   CellTags->"Twist2QuarkOperator"],
  Cell[2322078, 93749, 2305, 78, 53, "Output",
   CellTags->"Twist2QuarkOperator"],
  Cell[2324398, 93830, 210, 6, 27, "Input",
   CellTags->"Twist2QuarkOperator"]},
 "Twist3QuarkOperator"->{
  Cell[2324623, 93839, 75, 1, 39, "ObjectName",
   CellTags->"Twist3QuarkOperator"],
  Cell[2324723, 93844, 70, 1, 33, "Subsubsection",
   CellTags->"Twist3QuarkOperator"],
  Cell[2324796, 93847, 768, 12, 87, "Text",
   CellTags->"Twist3QuarkOperator"],
  Cell[2325589, 93863, 134, 3, 27, "Input",
   CellTags->"Twist3QuarkOperator"],
  Cell[2325726, 93868, 328, 10, 25, "Output",
   CellTags->"Twist3QuarkOperator"],
  Cell[2326069, 93881, 366, 14, 23, "Text",
   CellTags->"Twist3QuarkOperator"],
  Cell[2326472, 93900, 67, 1, 33, "Subsubsection",
   CellTags->"Twist3QuarkOperator"],
  Cell[2326564, 93905, 132, 3, 27, "Input",
   CellTags->"Twist3QuarkOperator"],
  Cell[2326699, 93910, 654, 23, 27, "Output",
   CellTags->"Twist3QuarkOperator"]},
 "Twist4GluonOperator"->{
  Cell[2327380, 93937, 75, 1, 39, "ObjectName",
   CellTags->"Twist4GluonOperator"],
  Cell[2327480, 93942, 70, 1, 33, "Subsubsection",
   CellTags->"Twist4GluonOperator"],
  Cell[2327553, 93945, 150, 4, 23, "Text",
   CellTags->"Twist4GluonOperator"],
  Cell[2327706, 93951, 509, 19, 23, "Text",
   CellTags->"Twist4GluonOperator"],
  Cell[2328252, 93975, 67, 1, 33, "Subsubsection",
   CellTags->"Twist4GluonOperator"],
  Cell[2328344, 93980, 529, 15, 27, "Input",
   CellTags->"Twist4GluonOperator"],
  Cell[2328876, 93997, 119831, 4588, 1063, "Output",
   CellTags->"Twist4GluonOperator"]},
 "TwoLoopSimplify"->{
  Cell[2448734, 98589, 104, 1, 39, "ObjectName",
   CellTags->"TwoLoopSimplify"],
  Cell[2448863, 98594, 66, 1, 33, "Subsubsection",
   CellTags->"TwoLoopSimplify"],
  Cell[2448932, 98597, 335, 6, 55, "Text",
   CellTags->"TwoLoopSimplify"],
  Cell[2449270, 98605, 207, 9, 23, "Text",
   CellTags->"TwoLoopSimplify"],
  Cell[2449514, 98619, 63, 1, 33, "Subsubsection",
   CellTags->"TwoLoopSimplify"],
  Cell[2449580, 98622, 82, 2, 27, "Input",
   CellTags->"TwoLoopSimplify"]},
 "Uncontract"->{
  Cell[2449677, 98627, 57, 1, 39, "ObjectName",
   CellTags->"Uncontract"],
  Cell[2449759, 98632, 61, 1, 33, "Subsubsection",
   CellTags->"Uncontract"],
  Cell[2449823, 98635, 256, 5, 39, "Text",
   CellTags->"Uncontract"],
  Cell[2450104, 98644, 120, 3, 27, "Input",
   CellTags->"Uncontract"],
  Cell[2450227, 98649, 372, 11, 25, "Output",
   CellTags->"Uncontract"],
  Cell[2450614, 98663, 181, 9, 23, "Text",
   CellTags->"Uncontract"],
  Cell[2450832, 98677, 58, 1, 33, "Subsubsection",
   CellTags->"Uncontract"],
  Cell[2450915, 98682, 234, 7, 27, "Input",
   CellTags->"Uncontract"],
  Cell[2451152, 98691, 397, 17, 25, "Output",
   CellTags->"Uncontract"],
  Cell[2451586, 98713, 143, 4, 27, "Input",
   CellTags->"Uncontract"],
  Cell[2451732, 98719, 781, 31, 27, "Output",
   CellTags->"Uncontract"],
  Cell[2452550, 98755, 138, 4, 27, "Input",
   CellTags->"Uncontract"],
  Cell[2452691, 98761, 224, 8, 25, "Output",
   CellTags->"Uncontract"],
  Cell[2452952, 98774, 143, 4, 27, "Input",
   CellTags->"Uncontract"],
  Cell[2453098, 98780, 224, 8, 25, "Output",
   CellTags->"Uncontract"],
  Cell[2453359, 98793, 153, 4, 27, "Input",
   CellTags->"Uncontract"],
  Cell[2453515, 98799, 1138, 44, 27, "Output",
   CellTags->"Uncontract"],
  Cell[2454668, 98846, 89, 1, 23, "Text",
   CellTags->"Uncontract"],
  Cell[2454782, 98851, 208, 6, 27, "Input",
   CellTags->"Uncontract"],
  Cell[2454993, 98859, 209, 8, 25, "Output",
   CellTags->"Uncontract"],
  Cell[2455217, 98870, 152, 4, 23, "Text",
   CellTags->"Uncontract"],
  Cell[2455394, 98878, 248, 7, 27, "Input",
   CellTags->"Uncontract"],
  Cell[2455645, 98887, 570, 22, 27, "Output",
   CellTags->"Uncontract"],
  Cell[2456252, 98914, 274, 8, 27, "Input",
   CellTags->"Uncontract"],
  Cell[2456529, 98924, 1030, 40, 27, "Output",
   CellTags->"Uncontract"],
  Cell[2457574, 98967, 134, 4, 27, "Input",
   CellTags->"Uncontract"]},
 "UnDeclareNonCommutative"->{
  Cell[2457723, 98974, 83, 1, 39, "ObjectName",
   CellTags->"UnDeclareNonCommutative"],
  Cell[2457831, 98979, 74, 1, 33, "Subsubsection",
   CellTags->"UnDeclareNonCommutative"],
  Cell[2457908, 98982, 198, 4, 23, "Text",
   CellTags->"UnDeclareNonCommutative"],
  Cell[2458109, 98988, 343, 14, 23, "Text",
   CellTags->"UnDeclareNonCommutative"],
  Cell[2458489, 99007, 71, 1, 33, "Subsubsection",
   CellTags->"UnDeclareNonCommutative"],
  Cell[2458563, 99010, 138, 3, 27, "Input",
   CellTags->"UnDeclareNonCommutative"],
  Cell[2458704, 99015, 153, 4, 23, "Text",
   CellTags->"UnDeclareNonCommutative"],
  Cell[2458882, 99023, 107, 2, 27, "Input",
   CellTags->"UnDeclareNonCommutative"],
  Cell[2458992, 99027, 123, 3, 25, "Output",
   CellTags->"UnDeclareNonCommutative"],
  Cell[2459130, 99033, 103, 1, 23, "Text",
   CellTags->"UnDeclareNonCommutative"],
  Cell[2459236, 99036, 140, 3, 27, "Input",
   CellTags->"UnDeclareNonCommutative"],
  Cell[2459401, 99043, 161, 4, 27, "Input",
   CellTags->"UnDeclareNonCommutative"],
  Cell[2459565, 99049, 123, 3, 25, "Output",
   CellTags->"UnDeclareNonCommutative"],
  Cell[2459703, 99055, 161, 4, 27, "Input",
   CellTags->"UnDeclareNonCommutative"],
  Cell[2459889, 99063, 171, 4, 27, "Input",
   CellTags->"UnDeclareNonCommutative"],
  Cell[2460063, 99069, 173, 5, 25, "Output",
   CellTags->"UnDeclareNonCommutative"],
  Cell[2460251, 99077, 163, 4, 27, "Input",
   CellTags->"UnDeclareNonCommutative"],
  Cell[2460439, 99085, 171, 4, 27, "Input",
   CellTags->"UnDeclareNonCommutative"],
  Cell[2460613, 99091, 173, 5, 25, "Output",
   CellTags->"UnDeclareNonCommutative"]},
 "Upper"->{
  Cell[2460813, 99100, 47, 1, 39, "ObjectName",
   CellTags->"Upper"],
  Cell[2460885, 99105, 56, 1, 33, "Subsubsection",
   CellTags->"Upper"],
  Cell[2460944, 99108, 126, 4, 23, "Text",
   CellTags->"Upper"],
  Cell[2461073, 99114, 397, 18, 23, "Text",
   CellTags->"Upper"]},
 "UVPart"->{
  Cell[2461485, 99135, 86, 1, 39, "ObjectName",
   CellTags->"UVPart"],
  Cell[2461596, 99140, 57, 1, 33, "Subsubsection",
   CellTags->"UVPart"],
  Cell[2461656, 99143, 128, 4, 23, "Text",
   CellTags->"UVPart"],
  Cell[2461821, 99152, 54, 1, 33, "Subsubsection",
   CellTags->"UVPart"],
  Cell[2461878, 99155, 73, 2, 27, "Input",
   CellTags->"UVPart"]},
 "Vectors"->{
  Cell[2461966, 99160, 51, 1, 39, "ObjectName",
   CellTags->"Vectors"],
  Cell[2462042, 99165, 58, 1, 33, "Subsubsection",
   CellTags->"Vectors"],
  Cell[2462103, 99168, 203, 4, 39, "Text",
   CellTags->"Vectors"],
  Cell[2462309, 99174, 188, 8, 23, "Text",
   CellTags->"Vectors"]},
 "WriteOut"->{
  Cell[2462512, 99185, 53, 1, 39, "ObjectName",
   CellTags->"WriteOut"],
  Cell[2462590, 99190, 59, 1, 33, "Subsubsection",
   CellTags->"WriteOut"],
  Cell[2462652, 99193, 216, 5, 39, "Text",
   CellTags->"WriteOut"],
  Cell[2462871, 99200, 171, 8, 23, "Text",
   CellTags->"WriteOut"]},
 "WriteOutPaVe"->{
  Cell[2463057, 99211, 61, 1, 39, "ObjectName",
   CellTags->"WriteOutPaVe"],
  Cell[2463143, 99216, 63, 1, 33, "Subsubsection",
   CellTags->"WriteOutPaVe"],
  Cell[2463209, 99219, 260, 5, 39, "Text",
   CellTags->"WriteOutPaVe"],
  Cell[2463472, 99226, 398, 18, 23, "Text",
   CellTags->"WriteOutPaVe"]},
 "Write2"->{
  Cell[2463885, 99247, 49, 1, 39, "ObjectName",
   CellTags->"Write2"],
  Cell[2463959, 99252, 57, 1, 33, "Subsubsection",
   CellTags->"Write2"],
  Cell[2464019, 99255, 297, 6, 39, "Text",
   CellTags->"Write2"],
  Cell[2464319, 99263, 153, 4, 23, "Text",
   CellTags->"Write2"],
  Cell[2464497, 99271, 136, 3, 27, "Input",
   CellTags->"Write2"],
  Cell[2464636, 99276, 248, 9, 39, "Output",
   CellTags->"Write2"],
  Cell[2464921, 99290, 112, 3, 27, "Input",
   CellTags->"Write2"],
  Cell[2465036, 99295, 637, 15, 45, "Output",
   CellTags->"Write2"],
  Cell[2465710, 99315, 115, 3, 27, "Input",
   CellTags->"Write2"],
  Cell[2465828, 99320, 133, 4, 25, "Output",
   CellTags->"Write2"],
  Cell[2465976, 99327, 290, 14, 23, "Text",
   CellTags->"Write2"],
  Cell[2466303, 99346, 54, 1, 33, "Subsubsection",
   CellTags->"Write2"],
  Cell[2466382, 99351, 429, 15, 35, "Input",
   CellTags->"Write2"],
  Cell[2466814, 99368, 855, 29, 31, "Output",
   CellTags->"Write2"],
  Cell[2467684, 99400, 208, 7, 27, "Input",
   CellTags->"Write2"],
  Cell[2467895, 99409, 78, 1, 23, "Text",
   CellTags->"Write2"],
  Cell[2467976, 99412, 184, 6, 27, "Input",
   CellTags->"Write2"],
  Cell[2468163, 99420, 73, 1, 23, "Text",
   CellTags->"Write2"],
  Cell[2468261, 99425, 363, 11, 27, "Input",
   CellTags->"Write2"],
  Cell[2468627, 99438, 801, 22, 72, "Output",
   CellTags->"Write2"],
  Cell[2469443, 99463, 286, 8, 27, "Input",
   CellTags->"Write2"],
  Cell[2469754, 99475, 233, 7, 27, "Input",
   CellTags->"Write2"],
  Cell[2469990, 99484, 710, 27, 27, "Output",
   CellTags->"Write2"],
  Cell[2470715, 99514, 185, 6, 27, "Input",
   CellTags->"Write2"],
  Cell[2470925, 99524, 363, 11, 27, "Input",
   CellTags->"Write2"],
  Cell[2471291, 99537, 1061, 30, 191, "Output",
   CellTags->"Write2"],
  Cell[2472367, 99570, 286, 8, 27, "Input",
   CellTags->"Write2"],
  Cell[2472656, 99580, 106, 3, 23, "Text",
   CellTags->"Write2"],
  Cell[2472765, 99585, 247, 8, 27, "Input",
   CellTags->"Write2"],
  Cell[2473037, 99597, 363, 11, 27, "Input",
   CellTags->"Write2"],
  Cell[2473403, 99610, 954, 25, 123, "Output",
   CellTags->"Write2"],
  Cell[2474372, 99638, 397, 11, 27, "Input",
   CellTags->"Write2"]},
 "XYT"->{
  Cell[2474784, 99652, 43, 1, 39, "ObjectName",
   CellTags->"XYT"],
  Cell[2474852, 99657, 54, 1, 33, "Subsubsection",
   CellTags->"XYT"],
  Cell[2474909, 99660, 215, 9, 23, "Text",
   CellTags->"XYT"]},
 "ZeroMomentumInsertion"->{
  Cell[2475139, 99672, 79, 1, 39, "ObjectName",
   CellTags->"ZeroMomentumInsertion"],
  Cell[2475243, 99677, 72, 1, 33, "Subsubsection",
   CellTags->"ZeroMomentumInsertion"],
  Cell[2475318, 99680, 154, 4, 23, "Text",
   CellTags->"ZeroMomentumInsertion"],
  Cell[2475475, 99686, 473, 18, 23, "Text",
   CellTags->"ZeroMomentumInsertion"]},
 "Zeta2"->{
  Cell[2475963, 99707, 47, 1, 39, "ObjectName",
   CellTags->"Zeta2"],
  Cell[2476035, 99712, 56, 1, 33, "Subsubsection",
   CellTags->"Zeta2"],
  Cell[2476094, 99715, 94, 1, 23, "Text",
   CellTags->"Zeta2"],
  Cell[2476191, 99718, 191, 8, 23, "Text",
   CellTags->"Zeta2"],
  Cell[2476419, 99731, 53, 1, 33, "Subsubsection",
   CellTags->"Zeta2"],
  Cell[2476497, 99736, 77, 2, 27, "Input",
   CellTags->"Zeta2"],
  Cell[2476577, 99740, 136, 4, 25, "Output",
   CellTags->"Zeta2"],
  Cell[2476750, 99749, 104, 3, 27, "Input",
   CellTags->"Zeta2"],
  Cell[2476857, 99754, 120, 3, 25, "Output",
   CellTags->"Zeta2"],
  Cell[2477014, 99762, 138, 4, 27, "Input",
   CellTags->"Zeta2"],
  Cell[2477155, 99768, 160, 5, 25, "Output",
   CellTags->"Zeta2"]},
 "$Abbreviations"->{
  Cell[2477342, 99777, 65, 1, 39, "ObjectName",
   CellTags->"$Abbreviations"],
  Cell[2477432, 99782, 65, 1, 33, "Subsubsection",
   CellTags->"$Abbreviations"],
  Cell[2477500, 99785, 293, 6, 39, "Text",
   CellTags->"$Abbreviations"],
  Cell[2477818, 99795, 129, 3, 27, "Input",
   CellTags->"$Abbreviations"],
  Cell[2477950, 99800, 867, 17, 78, "Output",
   CellTags->"$Abbreviations"],
  Cell[2478832, 99820, 652, 29, 23, "Text",
   CellTags->"$Abbreviations"]},
 "$AL"->{
  Cell[2479499, 99852, 43, 1, 39, "ObjectName",
   CellTags->"$AL"],
  Cell[2479567, 99857, 54, 1, 33, "Subsubsection",
   CellTags->"$AL"],
  Cell[2479624, 99860, 114, 3, 23, "Text",
   CellTags->"$AL"],
  Cell[2479763, 99867, 73, 2, 27, "Input",
   CellTags->"$AL"],
  Cell[2479839, 99871, 102, 3, 25, "Output",
   CellTags->"$AL"],
  Cell[2479978, 99879, 241, 7, 27, "Input",
   CellTags->"$AL"],
  Cell[2480222, 99888, 563, 22, 27, "Output",
   CellTags->"$AL"],
  Cell[2480800, 99913, 117, 4, 27, "Input",
   CellTags->"$AL"],
  Cell[2480942, 99921, 241, 7, 27, "Input",
   CellTags->"$AL"],
  Cell[2481186, 99930, 477, 20, 27, "Output",
   CellTags->"$AL"],
  Cell[2481678, 99953, 109, 4, 27, "Input",
   CellTags->"$AL"]},
 "$BreitMaison"->{
  Cell[2481802, 99960, 61, 1, 39, "ObjectName",
   CellTags->"$BreitMaison"],
  Cell[2481888, 99965, 63, 1, 33, "Subsubsection",
   CellTags->"$BreitMaison"],
  Cell[2481954, 99968, 319, 9, 39, "Text",
   CellTags->"$BreitMaison"],
  Cell[2482276, 99979, 370, 19, 23, "Text",
   CellTags->"$BreitMaison"]},
 "$Color"->{
  Cell[2482661, 100001, 49, 1, 39, "ObjectName",
   CellTags->"$Color"],
  Cell[2482735, 100006, 57, 1, 33, "Subsubsection",
   CellTags->"$Color"],
  Cell[2482795, 100009, 130, 4, 23, "Text",
   CellTags->"$Color"]},
 "$Covariant"->{
  Cell[2482940, 100016, 57, 1, 39, "ObjectName",
   CellTags->"$Covariant"],
  Cell[2483022, 100021, 61, 1, 33, "Subsubsection",
   CellTags->"$Covariant"],
  Cell[2483086, 100024, 183, 4, 23, "Text",
   CellTags->"$Covariant"],
  Cell[2483294, 100032, 87, 2, 27, "Input",
   CellTags->"$Covariant"],
  Cell[2483384, 100036, 111, 3, 25, "Output",
   CellTags->"$Covariant"],
  Cell[2483532, 100044, 110, 3, 27, "Input",
   CellTags->"$Covariant"],
  Cell[2483645, 100049, 142, 4, 25, "Output",
   CellTags->"$Covariant"],
  Cell[2483802, 100056, 130, 4, 27, "Input",
   CellTags->"$Covariant"],
  Cell[2483957, 100064, 110, 3, 27, "Input",
   CellTags->"$Covariant"],
  Cell[2484070, 100069, 140, 4, 28, "Output",
   CellTags->"$Covariant"],
  Cell[2484225, 100076, 131, 4, 27, "Input",
   CellTags->"$Covariant"]},
 "$FCS"->{
  Cell[2484371, 100083, 45, 1, 39, "ObjectName",
   CellTags->"$FCS"],
  Cell[2484441, 100088, 55, 1, 33, "Subsubsection",
   CellTags->"$FCS"],
  Cell[2484499, 100091, 142, 4, 23, "Text",
   CellTags->"$FCS"],
  Cell[2484666, 100099, 75, 2, 27, "Input",
   CellTags->"$FCS"],
  Cell[2484744, 100103, 700, 14, 45, "Output",
   CellTags->"$FCS"]},
 "$FCT"->{
  Cell[2485471, 100121, 45, 1, 39, "ObjectName",
   CellTags->"$FCT"],
  Cell[2485541, 100126, 55, 1, 33, "Subsubsection",
   CellTags->"$FCT"],
  Cell[2485599, 100129, 177, 4, 23, "Text",
   CellTags->"$FCT"],
  Cell[2485779, 100135, 128, 4, 27, "Input",
   CellTags->"$FCT"],
  Cell[2485932, 100143, 170, 5, 27, "Input",
   CellTags->"$FCT"],
  Cell[2486105, 100150, 196, 6, 25, "Output",
   CellTags->"$FCT"],
  Cell[2486316, 100159, 129, 4, 27, "Input",
   CellTags->"$FCT"],
  Cell[2486470, 100167, 170, 5, 27, "Input",
   CellTags->"$FCT"],
  Cell[2486643, 100174, 196, 6, 25, "Output",
   CellTags->"$FCT"]},
 "$FeynCalcStuff"->{
  Cell[2486866, 100184, 65, 1, 39, "ObjectName",
   CellTags->"$FeynCalcStuff"],
  Cell[2486956, 100189, 65, 1, 33, "Subsubsection",
   CellTags->"$FeynCalcStuff"],
  Cell[2487024, 100192, 102, 1, 23, "Text",
   CellTags->"$FeynCalcStuff"]},
 "$FeynCalcVersion"->{
  Cell[2487141, 100196, 69, 1, 39, "ObjectName",
   CellTags->"$FeynCalcVersion"],
  Cell[2487235, 100201, 67, 1, 33, "Subsubsection",
   CellTags->"$FeynCalcVersion"],
  Cell[2487305, 100204, 124, 3, 23, "Text",
   CellTags->"$FeynCalcVersion"],
  Cell[2487454, 100211, 99, 2, 27, "Input",
   CellTags->"$FeynCalcVersion"],
  Cell[2487556, 100215, 125, 3, 25, "Output",
   CellTags->"$FeynCalcVersion"]},
 "$FortranContinuationCharacter"->{
  Cell[2487708, 100222, 95, 1, 39, "ObjectName",
   CellTags->"$FortranContinuationCharacter"],
  Cell[2487828, 100227, 80, 1, 33, "Subsubsection",
   CellTags->"$FortranContinuationCharacter"],
  Cell[2487911, 100230, 143, 3, 23, "Text",
   CellTags->"$FortranContinuationCharacter"],
  Cell[2488079, 100237, 125, 2, 27, "Input",
   CellTags->"$FortranContinuationCharacter"],
  Cell[2488207, 100241, 134, 3, 25, "Output",
   CellTags->"$FortranContinuationCharacter"],
  Cell[2488356, 100247, 194, 9, 23, "Text",
   CellTags->"$FortranContinuationCharacter"]},
 "$Gauge"->{
  Cell[2488565, 100259, 49, 1, 39, "ObjectName",
   CellTags->"$Gauge"],
  Cell[2488639, 100264, 57, 1, 33, "Subsubsection",
   CellTags->"$Gauge"],
  Cell[2488699, 100267, 260, 5, 39, "Text",
   CellTags->"$Gauge"],
  Cell[2488962, 100274, 168, 9, 23, "Text",
   CellTags->"$Gauge"]},
 "$Larin"->{
  Cell[2489145, 100286, 49, 1, 39, "ObjectName",
   CellTags->"$Larin"],
  Cell[2489219, 100291, 57, 1, 33, "Subsubsection",
   CellTags->"$Larin"],
  Cell[2489279, 100294, 1133, 30, 87, "Text",
   CellTags->"$Larin"],
  Cell[2490437, 100328, 79, 2, 27, "Input",
   CellTags->"$Larin"],
  Cell[2490519, 100332, 107, 3, 25, "Output",
   CellTags->"$Larin"],
  Cell[2490641, 100338, 377, 18, 23, "Text",
   CellTags->"$Larin"]},
 "$LimitTo4"->{
  Cell[2491033, 100359, 55, 1, 39, "ObjectName",
   CellTags->"$LimitTo4"],
  Cell[2491113, 100364, 60, 1, 33, "Subsubsection",
   CellTags->"$LimitTo4"],
  Cell[2491176, 100367, 203, 4, 23, "Text",
   CellTags->"$LimitTo4"],
  Cell[2491404, 100375, 85, 2, 27, "Input",
   CellTags->"$LimitTo4"],
  Cell[2491492, 100379, 109, 3, 25, "Output",
   CellTags->"$LimitTo4"],
  Cell[2491616, 100385, 391, 19, 23, "Text",
   CellTags->"$LimitTo4"]},
 "$LorentzIndices"->{
  Cell[2492022, 100407, 67, 1, 39, "ObjectName",
   CellTags->"$LorentzIndices"],
  Cell[2492114, 100412, 66, 1, 33, "Subsubsection",
   CellTags->"$LorentzIndices"],
  Cell[2492183, 100415, 164, 4, 23, "Text",
   CellTags->"$LorentzIndices"],
  Cell[2492350, 100421, 140, 4, 27, "Input",
   CellTags->"$LorentzIndices"],
  Cell[2492515, 100429, 333, 9, 27, "Input",
   CellTags->"$LorentzIndices"],
  Cell[2492851, 100440, 669, 28, 25, "Output",
   CellTags->"$LorentzIndices"],
  Cell[2493557, 100473, 117, 3, 27, "Input",
   CellTags->"$LorentzIndices"],
  Cell[2493677, 100478, 380, 10, 39, "Output",
   CellTags->"$LorentzIndices"],
  Cell[2494094, 100493, 302, 9, 27, "Input",
   CellTags->"$LorentzIndices"],
  Cell[2494399, 100504, 884, 38, 25, "Output",
   CellTags->"$LorentzIndices"],
  Cell[2495320, 100547, 117, 3, 27, "Input",
   CellTags->"$LorentzIndices"],
  Cell[2495440, 100552, 655, 19, 59, "Output",
   CellTags->"$LorentzIndices"],
  Cell[2496110, 100574, 141, 4, 27, "Input",
   CellTags->"$LorentzIndices"]},
 "$MIntegrate"->{
  Cell[2496266, 100581, 59, 1, 39, "ObjectName",
   CellTags->"$MIntegrate"],
  Cell[2496350, 100586, 62, 1, 33, "Subsubsection",
   CellTags->"$MIntegrate"],
  Cell[2496415, 100589, 136, 4, 23, "Text",
   CellTags->"$MIntegrate"],
  Cell[2496576, 100597, 89, 2, 27, "Input",
   CellTags->"$MIntegrate"],
  Cell[2496668, 100601, 126, 4, 25, "Output",
   CellTags->"$MIntegrate"],
  Cell[2496809, 100608, 191, 9, 23, "Text",
   CellTags->"$MIntegrate"]},
 "$MU"->{
  Cell[2497015, 100620, 43, 1, 39, "ObjectName",
   CellTags->"$MU"],
  Cell[2497083, 100625, 54, 1, 33, "Subsubsection",
   CellTags->"$MU"],
  Cell[2497140, 100628, 151, 4, 23, "Text",
   CellTags->"$MU"],
  Cell[2497316, 100636, 73, 2, 27, "Input",
   CellTags->"$MU"],
  Cell[2497392, 100640, 102, 3, 25, "Output",
   CellTags->"$MU"],
  Cell[2497509, 100646, 174, 9, 23, "Text",
   CellTags->"$MU"]},
 "$MemoryAvailable"->{
  Cell[2497698, 100658, 69, 1, 39, "ObjectName",
   CellTags->"$MemoryAvailable"],
  Cell[2497792, 100663, 67, 1, 33, "Subsubsection",
   CellTags->"$MemoryAvailable"],
  Cell[2497862, 100666, 434, 11, 39, "Text",
   CellTags->"$MemoryAvailable"],
  Cell[2498321, 100681, 99, 2, 27, "Input",
   CellTags->"$MemoryAvailable"],
  Cell[2498423, 100685, 115, 3, 25, "Output",
   CellTags->"$MemoryAvailable"]},
 "$NonComm"->{
  Cell[2498565, 100692, 53, 1, 39, "ObjectName",
   CellTags->"$NonComm"],
  Cell[2498643, 100697, 59, 1, 33, "Subsubsection",
   CellTags->"$NonComm"],
  Cell[2498705, 100700, 109, 3, 23, "Text",
   CellTags->"$NonComm"],
  Cell[2498839, 100707, 83, 2, 27, "Input",
   CellTags->"$NonComm"],
  Cell[2498925, 100711, 803, 15, 83, "Output",
   CellTags->"$NonComm"],
  Cell[2499743, 100729, 307, 14, 23, "Text",
   CellTags->"$NonComm"]},
 "$PairBrackets"->{
  Cell[2500065, 100746, 63, 1, 39, "ObjectName",
   CellTags->"$PairBrackets"],
  Cell[2500153, 100751, 64, 1, 33, "Subsubsection",
   CellTags->"$PairBrackets"],
  Cell[2500220, 100754, 155, 4, 23, "Text",
   CellTags->"$PairBrackets"],
  Cell[2500400, 100762, 93, 2, 27, "Input",
   CellTags->"$PairBrackets"],
  Cell[2500496, 100766, 114, 3, 25, "Output",
   CellTags->"$PairBrackets"],
  Cell[2500647, 100774, 204, 7, 27, "Input",
   CellTags->"$PairBrackets"],
  Cell[2500854, 100783, 425, 18, 25, "Output",
   CellTags->"$PairBrackets"],
  Cell[2501316, 100806, 118, 3, 27, "Input",
   CellTags->"$PairBrackets"],
  Cell[2501437, 100811, 113, 3, 25, "Output",
   CellTags->"$PairBrackets"],
  Cell[2501587, 100819, 204, 7, 27, "Input",
   CellTags->"$PairBrackets"],
  Cell[2501794, 100828, 445, 18, 25, "Output",
   CellTags->"$PairBrackets"],
  Cell[2502276, 100851, 119, 3, 27, "Input",
   CellTags->"$PairBrackets"],
  Cell[2502398, 100856, 114, 3, 25, "Output",
   CellTags->"$PairBrackets"]},
 "$SpinorMinimal"->{
  Cell[2502539, 100863, 65, 1, 39, "ObjectName",
   CellTags->"$SpinorMinimal"],
  Cell[2502629, 100868, 65, 1, 33, "Subsubsection",
   CellTags->"$SpinorMinimal"],
  Cell[2502697, 100871, 241, 5, 39, "Text",
   CellTags->"$SpinorMinimal"],
  Cell[2502963, 100880, 95, 2, 27, "Input",
   CellTags->"$SpinorMinimal"],
  Cell[2503061, 100884, 115, 3, 25, "Output",
   CellTags->"$SpinorMinimal"],
  Cell[2503191, 100890, 200, 9, 23, "Text",
   CellTags->"$SpinorMinimal"]},
 "$VeryVerbose"->{
  Cell[2503406, 100902, 61, 1, 39, "ObjectName",
   CellTags->"$VeryVerbose"],
  Cell[2503492, 100907, 63, 1, 33, "Subsubsection",
   CellTags->"$VeryVerbose"],
  Cell[2503558, 100910, 221, 5, 39, "Text",
   CellTags->"$VeryVerbose"],
  Cell[2503804, 100919, 91, 2, 27, "Input",
   CellTags->"$VeryVerbose"],
  Cell[2503898, 100923, 109, 3, 25, "Output",
   CellTags->"$VeryVerbose"],
  Cell[2504022, 100929, 141, 4, 27, "Input",
   CellTags->"$VeryVerbose"],
  Cell[2504188, 100937, 287, 10, 27, "Input",
   CellTags->"$VeryVerbose"],
  Cell[2504478, 100949, 121, 3, 21, "Print",
   CellTags->"$VeryVerbose"],
  Cell[2504602, 100954, 255, 7, 21, "Print",
   CellTags->"$VeryVerbose"],
  Cell[2504860, 100963, 273, 7, 21, "Print",
   CellTags->"$VeryVerbose"],
  Cell[2505148, 100973, 131, 4, 27, "Input",
   CellTags->"$VeryVerbose"]},
 "$V0"->{
  Cell[2505282, 100979, 159, 9, 23, "Text",
   CellTags->"$V0"]},
 "$West"->{
  Cell[2505456, 100991, 47, 1, 39, "ObjectName",
   CellTags->"$West"],
  Cell[2505528, 100996, 56, 1, 33, "Subsubsection",
   CellTags->"$West"],
  Cell[2505587, 100999, 577, 14, 63, "Text",
   CellTags->"$West"],
  Cell[2506167, 101015, 158, 8, 23, "Text",
   CellTags->"$West"]},
 "Experimental"->{
  Cell[2507356, 101076, 70, 1, 63, "Section",
   CellTags->"Experimental"],
  Cell[2528288, 101839, 122, 3, 23, "Text",
   CellTags->"Experimental"],
  Cell[2528435, 101846, 198, 6, 27, "Input",
   CellTags->"Experimental"],
  Cell[2528636, 101854, 193, 6, 25, "Output",
   CellTags->"Experimental"],
  Cell[2528844, 101863, 100, 1, 23, "Text",
   CellTags->"Experimental"],
  Cell[2528969, 101868, 222, 6, 27, "Input",
   CellTags->"Experimental"],
  Cell[2529194, 101876, 246, 7, 25, "Output",
   CellTags->"Experimental"]},
 "DoPolarizationSums"->{
  Cell[2507429, 101079, 73, 1, 39, "ObjectName",
   CellTags->"DoPolarizationSums"],
  Cell[2507527, 101084, 69, 1, 33, "Subsubsection",
   CellTags->"DoPolarizationSums"],
  Cell[2507599, 101087, 291, 7, 95, "Text",
   CellTags->"DoPolarizationSums"],
  Cell[2507893, 101096, 317, 14, 23, "Text",
   CellTags->"DoPolarizationSums"],
  Cell[2508247, 101115, 66, 1, 33, "Subsubsection",
   CellTags->"DoPolarizationSums"],
  Cell[2508316, 101118, 310, 6, 39, "Text",
   CellTags->"DoPolarizationSums"],
  Cell[2508629, 101126, 123, 3, 23, "Text",
   CellTags->"DoPolarizationSums"],
  Cell[2508777, 101133, 571, 17, 48, "Input",
   CellTags->"DoPolarizationSums"],
  Cell[2509351, 101152, 448, 16, 29, "Output",
   CellTags->"DoPolarizationSums"],
  Cell[2509836, 101173, 116, 3, 27, "Input",
   CellTags->"DoPolarizationSums"],
  Cell[2509955, 101178, 133, 4, 25, "Output",
   CellTags->"DoPolarizationSums"],
  Cell[2510103, 101185, 1270, 48, 26, "Text",
   CellTags->"DoPolarizationSums"],
  Cell[2511376, 101235, 562, 21, 23, "Text",
   CellTags->"DoPolarizationSums"],
  Cell[2511941, 101258, 142, 4, 27, "Input",
   CellTags->"DoPolarizationSums"],
  Cell[2512086, 101264, 311, 10, 27, "Input",
   CellTags->"DoPolarizationSums"],
  Cell[2512422, 101278, 271, 8, 27, "Input",
   CellTags->"DoPolarizationSums"],
  Cell[2512696, 101288, 735, 20, 75, "Output",
   CellTags->"DoPolarizationSums"],
  Cell[2513446, 101311, 213, 9, 24, "Text",
   CellTags->"DoPolarizationSums"],
  Cell[2513662, 101322, 276, 9, 27, "Input",
   CellTags->"DoPolarizationSums"],
  Cell[2513941, 101333, 328, 10, 27, "Input",
   CellTags->"DoPolarizationSums"],
  Cell[2514272, 101345, 323, 13, 26, "Text",
   CellTags->"DoPolarizationSums"],
  Cell[2514598, 101360, 697, 30, 26, "Text",
   CellTags->"DoPolarizationSums"],
  Cell[2515320, 101394, 434, 13, 51, "Input",
   CellTags->"DoPolarizationSums"],
  Cell[2515757, 101409, 775, 24, 75, "Output",
   CellTags->"DoPolarizationSums"],
  Cell[2516547, 101436, 624, 27, 26, "Text",
   CellTags->"DoPolarizationSums"],
  Cell[2517196, 101467, 433, 13, 51, "Input",
   CellTags->"DoPolarizationSums"],
  Cell[2517632, 101482, 775, 24, 75, "Output",
   CellTags->"DoPolarizationSums"],
  Cell[2518444, 101511, 859, 24, 68, "Input",
   CellTags->"DoPolarizationSums"],
  Cell[2519306, 101537, 606, 22, 31, "Output",
   CellTags->"DoPolarizationSums"],
  Cell[2519949, 101564, 130, 3, 27, "Input",
   CellTags->"DoPolarizationSums"],
  Cell[2520082, 101569, 323, 12, 30, "Output",
   CellTags->"DoPolarizationSums"],
  Cell[2520442, 101586, 116, 3, 27, "Input",
   CellTags->"DoPolarizationSums"],
  Cell[2520561, 101591, 133, 4, 25, "Output",
   CellTags->"DoPolarizationSums"],
  Cell[2520731, 101600, 120, 3, 27, "Input",
   CellTags->"DoPolarizationSums"],
  Cell[2520854, 101605, 133, 4, 25, "Output",
   CellTags->"DoPolarizationSums"],
  Cell[2521024, 101614, 126, 3, 27, "Input",
   CellTags->"DoPolarizationSums"],
  Cell[2521153, 101619, 133, 4, 25, "Output",
   CellTags->"DoPolarizationSums"],
  Cell[2521301, 101626, 167, 4, 27, "Input",
   CellTags->"DoPolarizationSums"]},
 "FeynmanDoIntegrals"->{
  Cell[2521483, 101633, 90, 1, 39, "ObjectName",
   CellTags->"FeynmanDoIntegrals"],
  Cell[2521598, 101638, 69, 1, 33, "Subsubsection",
   CellTags->"FeynmanDoIntegrals"],
  Cell[2521670, 101641, 1518, 23, 191, "Text",
   CellTags->"FeynmanDoIntegrals"],
  Cell[2523191, 101666, 347, 14, 23, "Text",
   CellTags->"FeynmanDoIntegrals"],
  Cell[2523563, 101684, 136, 3, 27, "Input",
   CellTags->"FeynmanDoIntegrals"],
  Cell[2523702, 101689, 1037, 29, 64, "Output",
   CellTags->"FeynmanDoIntegrals"],
  Cell[2524788, 101724, 66, 1, 33, "Subsubsection",
   CellTags->"FeynmanDoIntegrals"],
  Cell[2524857, 101727, 85, 2, 27, "Input",
   CellTags->"FeynmanDoIntegrals"]},
 "FeynmanParametrize1"->{
  Cell[2524957, 101732, 92, 1, 39, "ObjectName",
   CellTags->"FeynmanParametrize1"],
  Cell[2525074, 101737, 70, 1, 33, "Subsubsection",
   CellTags->"FeynmanParametrize1"],
  Cell[2525147, 101740, 717, 12, 111, "Text",
   CellTags->"FeynmanParametrize1"],
  Cell[2525889, 101756, 138, 3, 27, "Input",
   CellTags->"FeynmanParametrize1"],
  Cell[2526030, 101761, 505, 13, 25, "Output",
   CellTags->"FeynmanParametrize1"],
  Cell[2526584, 101780, 67, 1, 33, "Subsubsection",
   CellTags->"FeynmanParametrize1"],
  Cell[2526654, 101783, 86, 2, 27, "Input",
   CellTags->"FeynmanParametrize1"]},
 "FeynmanReduce"->{
  Cell[2526755, 101788, 80, 1, 39, "ObjectName",
   CellTags->"FeynmanReduce"],
  Cell[2526860, 101793, 64, 1, 33, "Subsubsection",
   CellTags->"FeynmanReduce"],
  Cell[2526927, 101796, 723, 12, 111, "Text",
   CellTags->"FeynmanReduce"],
  Cell[2527675, 101812, 126, 3, 27, "Input",
   CellTags->"FeynmanReduce"],
  Cell[2527804, 101817, 288, 9, 25, "Output",
   CellTags->"FeynmanReduce"],
  Cell[2528141, 101832, 61, 1, 33, "Subsubsection",
   CellTags->"FeynmanReduce"],
  Cell[2528205, 101835, 80, 2, 27, "Input",
   CellTags->"FeynmanReduce"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"ClickSave", 2531315, 101949},
 {"Functions", 2531406, 101952},
 {"Abbreviation", 2531492, 101955},
 {"Amplitude", 2532036, 101971},
 {"Amputate", 2533208, 102006},
 {"AnomalousDimension", 2533994, 102029},
 {"AntiCommutator", 2537370, 102116},
 {"AntiQuarkField", 2539462, 102173},
 {"AntiSymmetrize", 2540012, 102188},
 {"Anti5", 2540702, 102207},
 {"Apart2", 2542345, 102258},
 {"A0", 2543094, 102281},
 {"A0ToB0", 2544313, 102321},
 {"BackgroundGluonVertex", 2544769, 102335},
 {"Bracket", 2546026, 102366},
 {"BReduce", 2546317, 102375},
 {"B0", 2547107, 102399},
 {"B0Real", 2548136, 102432},
 {"B0Unique", 2549050, 102460},
 {"B00", 2549985, 102488},
 {"B1", 2551284, 102529},
 {"B11", 2552692, 102574},
 {"CA", 2554245, 102623},
 {"Calc", 2554955, 102646},
 {"CalcColorFactor", 2556222, 102685},
 {"Collecting", 2556550, 102694},
 {"CalculateCounterTerm", 2556942, 102705},
 {"Info3522790126-4590919", 2557497, 102718},
 {"CancelQP", 2557621, 102721},
 {"Cases2", 2558832, 102756},
 {"CF", 2559661, 102781},
 {"ChangeDimension", 2560509, 102808},
 {"ChargeConjugationMatrix", 2563270, 102881},
 {"ChargeConjugationMatrixInv", 2564571, 102912},
 {"CheckContext", 2566249, 102951},
 {"CheckDB", 2567216, 102978},
 {"ChiralityProjector", 2567997, 103001},
 {"Chisholm", 2568893, 103024},
 {"ChisholmSpinor", 2571271, 103093},
 {"ClearScalarProducts", 2571986, 103112},
 {"Collect2", 2573143, 103141},
 {"Collect3", 2574853, 103190},
 {"Combine", 2575654, 103213},
 {"CombineGraphs", 2576719, 103244},
 {"Commutator", 2577041, 103253},
 {"CommutatorExplicit", 2578581, 103296},
 {"CompleteSquare", 2579971, 103331},
 {"ComplexConjugate", 2580844, 103354},
 {"Contract", 2582894, 103407},
 {"Contract1", 2586267, 103504},
 {"Convolute", 2587219, 103531},
 {"ConvoluteTable", 2591437, 103650},
 {"CovariantFieldDerivative", 2592466, 103677},
 {"CounterT", 2593096, 103692},
 {"CounterTerm", 2593619, 103707},
 {"CouplingConstant", 2594167, 103722},
 {"CovariantD", 2594504, 103731},
 {"CrossProduct", 2597556, 103816},
 {"C0", 2598096, 103831},
 {"DataType", 2598827, 103854},
 {"DB0", 2601696, 103937},
 {"DB1", 2602173, 103952},
 {"DeclareNonCommutative", 2602670, 103967},
 {"DeltaFunction", 2603940, 103998},
 {"DeltaFunctionDoublePrime", 2605107, 104029},
 {"DeltaFunctionPrime", 2605482, 104038},
 {"DenominatorOrder", 2606397, 104061},
 {"Dimension", 2606732, 104070},
 {"DimensionalReduction", 2607968, 104105},
 {"DiracBasis", 2608320, 104114},
 {"DiracCanonical", 2608635, 104123},
 {"DiracEquation", 2608965, 104132},
 {"DiracGamma", 2609668, 104151},
 {"DiracGammaCombine", 2611645, 104206},
 {"DiracGammaExpand", 2612863, 104237},
 {"DiracGammaT", 2614598, 104282},
 {"DiracMatrix", 2615428, 104305},
 {"DiracOrder", 2617350, 104358},
 {"DiracReduce", 2619602, 104421},
 {"DiracSigma", 2621378, 104470},
 {"DiracSigmaExplicit", 2622563, 104503},
 {"DiracSimpCombine", 2623317, 104522},
 {"DiracSimplify", 2623655, 104531},
 {"DiracSimplify2", 2627424, 104632},
 {"DiracSlash", 2628137, 104651},
 {"DiracSpinor", 2629602, 104692},
 {"DiracSubstitute67", 2629924, 104701},
 {"DiracTrace", 2630264, 104710},
 {"DiracTraceEvaluate", 2632027, 104759},
 {"DiracTrick", 2632371, 104768},
 {"Divideout", 2634978, 104841},
 {"DOT", 2635279, 104850},
 {"DotExpand", 2635561, 104859},
 {"DotPower", 2636512, 104886},
 {"DotProduct", 2636815, 104895},
 {"DotSimplifyRelations", 2637359, 104910},
 {"DotSimplify", 2637711, 104919},
 {"DummyIndex", 2640357, 104992},
 {"D0", 2640660, 105001},
 {"D0Convention", 2641398, 105024},
 {"Eps", 2641711, 105033},
 {"EpsChisholm", 2644076, 105106},
 {"EpsContract", 2644764, 105125},
 {"EpsDiscard", 2645598, 105148},
 {"EpsEvaluate", 2645910, 105157},
 {"EpsUncontract", 2646747, 105180},
 {"Epsilon", 2647068, 105189},
 {"EpsilonOrder", 2647785, 105210},
 {"Expanding", 2648105, 105219},
 {"ExpandPartialD", 2648417, 105228},
 {"ScalarProductCancel", 2650663, 105287},
 {"ExpandScalarProduct", 2655227, 105384},
 {"Expand2", 2657691, 105431},
 {"Explicit", 2658135, 105444},
 {"ExplicitLorentzIndex", 2659368, 105479},
 {"ExplicitPartialD", 2660140, 105498},
 {"ExplicitSUNIndex", 2661345, 105529},
 {"ExtraFactor", 2661921, 105544},
 {"ExtraVariables", 2662240, 105553},
 {"FactorFull", 2662568, 105562},
 {"Factoring", 2662879, 105571},
 {"Factorout", 2663186, 105580},
 {"FactorTime", 2663492, 105589},
 {"Factor1", 2663800, 105598},
 {"Factor2", 2664925, 105631},
 {"FAD", 2666320, 105672},
 {"FC", 2667316, 105703},
 {"FCE", 2668038, 105726},
 {"FCI", 2669356, 105767},
 {"FCIntegral", 2670361, 105798},
 {"FCIntegrate", 2670674, 105807},
 {"FCNIntegrate", 2670991, 105816},
 {"FC2RHI", 2671306, 105825},
 {"FC2TLI", 2671872, 105842},
 {"Info3522790263-4590919", 2672454, 105859},
 {"FDS", 2672549, 105862},
 {"FermionSpinSum", 2672835, 105871},
 {"FeynAmp", 2675137, 105932},
 {"FeynAmpDenominator", 2675998, 105957},
 {"FeynAmpDenominatorCombine", 2677238, 105988},
 {"FeynAmpDenominatorSimplify", 2678238, 106011},
 {"FeynAmpDenominatorSplit", 2680654, 106066},
 {"FeynAmpList", 2682211, 106103},
 {"FeynCalc", 2682595, 106114},
 {"Info3522790274-4590919", 2683008, 106125},
 {"FeynCalcExternal", 2683131, 106128},
 {"FeynCalcForm", 2684643, 106167},
 {"FeynCalcInternal", 2685854, 106200},
 {"FeynCalc2FORM", 2687373, 106239},
 {"FeynCalcToLaTeX", 2689873, 106306},
 {"FeynmanParameterNames", 2690140, 106313},
 {"FeynmanParametrize", 2690504, 106322},
 {"FeynRule", 2691090, 106337},
 {"FI", 2695735, 106470},
 {"FieldDerivative", 2696020, 106479},
 {"FieldStrength", 2696904, 106502},
 {"FinalFunction", 2698513, 106545},
 {"FinalSubstitutions", 2698843, 106554},
 {"FORM", 2699181, 106563},
 {"FORMEpilog", 2699469, 106572},
 {"FORMProlog", 2699781, 106581},
 {"FORM2FeynCalc", 2700096, 106590},
 {"FourDivergence", 2702224, 106647},
 {"FourLaplacian", 2703316, 106676},
 {"FourVector", 2704471, 106707},
 {"FreeIndex", 2705791, 106744},
 {"FreeQ2", 2706095, 106753},
 {"FRH", 2706998, 106780},
 {"FromTFi", 2707865, 106807},
 {"FromTFI", 2708587, 106828},
 {"FUNCTION", 2708671, 106831},
 {"FunctionalD", 2708975, 106840},
 {"FV", 2715732, 107025},
 {"FVD", 2716902, 107062},
 {"GA", 2718088, 107099},
 {"GAD", 2719195, 107134},
 {"GammaEpsilon", 2720336, 107169},
 {"GammaExpand", 2721489, 107200},
 {"Gamma1", 2722327, 107223},
 {"Gamma2", 2722623, 107232},
 {"Gamma3", 2722919, 107241},
 {"Gauge", 2723214, 107250},
 {"GaugeField", 2723510, 107259},
 {"GaugeXi", 2724192, 107278},
 {"GA5", 2724488, 107287},
 {"GGV", 2725099, 107306},
 {"GhostPropagator", 2725390, 107315},
 {"GHP", 2726580, 107346},
 {"GluonField", 2727464, 107373},
 {"GluonGhostVertex", 2728153, 107392},
 {"GluonPropagator", 2729216, 107419},
 {"GluonSelfEnergy", 2731826, 107486},
 {"GluonVertex", 2732718, 107509},
 {"GO", 2734961, 107570},
 {"GP", 2735235, 107579},
 {"GrassmannParity", 2735522, 107588},
 {"GS", 2735849, 107597},
 {"GSD", 2736844, 107628},
 {"Gstrong", 2737858, 107659},
 {"GTI", 2738436, 107676},
 {"GV", 2738714, 107685},
 {"Hill", 2738990, 107694},
 {"HypergeometricAC", 2739895, 107721},
 {"HypergeometricIR", 2741513, 107762},
 {"HypergeometricSE", 2742576, 107789},
 {"HypExplicit", 2743476, 107812},
 {"HypInt", 2744464, 107839},
 {"IFPD", 2745040, 107856},
 {"IFPDOff", 2745327, 107865},
 {"IFPDOn", 2746260, 107892},
 {"IncludePair", 2746561, 107901},
 {"IndexPosition", 2746883, 107910},
 {"Indices", 2747206, 107919},
 {"InitialFunction", 2747514, 107928},
 {"InitialSubstitutions", 2747859, 107937},
 {"InsideDiracTrace", 2748221, 107946},
 {"IntegralTable", 2748564, 107955},
 {"IntegrateByParts", 2748898, 107964},
 {"Integratedx", 2749562, 107981},
 {"Integrate2", 2749882, 107990},
 {"Integrate3", 2755176, 108135},
 {"IntermediateSubstitutions", 2756465, 108170},
 {"InverseMellin", 2756843, 108179},
 {"Isolate", 2761196, 108294},
 {"Info3522790362-4590919", 2762970, 108343},
 {"IsolateHead", 2763184, 108348},
 {"IsolateNames", 2763504, 108357},
 {"IsolatePrint", 2763830, 108366},
 {"IsolateSplit", 2764155, 108375},
 {"KeepOnly", 2764476, 108384},
 {"KK", 2764776, 108393},
 {"Kummer", 2765056, 108402},
 {"Lagrangian", 2770428, 108557},
 {"LC", 2771615, 108590},
 {"LCD", 2772740, 108625},
 {"LeftPartialD", 2774152, 108668},
 {"LeftRightPartialD", 2775614, 108707},
 {"LeftRightPartialD2", 2777013, 108742},
 {"LeviCivita", 2778421, 108777},
 {"LeviCivitaSign", 2780495, 108834},
 {"ListIntegrals", 2780830, 108843},
 {"Li2", 2781232, 108854},
 {"Li3", 2781977, 108877},
 {"Loop", 2782854, 108904},
 {"LorentzIndex", 2783081, 108911},
 {"Lower", 2784743, 108956},
 {"MakeContext", 2785040, 108965},
 {"Mandelstam", 2785360, 108974},
 {"Map2", 2785672, 108983},
 {"MemoryAvailable", 2786573, 109010},
 {"MemSet", 2786905, 109019},
 {"MetricTensor", 2787206, 109028},
 {"MLimit", 2788799, 109071},
 {"Momentum", 2789242, 109084},
 {"MomentumCombine", 2791317, 109143},
 {"MomentumCombine2", 2792752, 109180},
 {"MomentumExpand", 2793497, 109199},
 {"MT", 2795132, 109242},
 {"MTD", 2796124, 109273},
 {"NegativeInteger", 2797144, 109304},
 {"Nf", 2797471, 109313},
 {"Nielsen", 2797751, 109322},
 {"NonCommFreeQ", 2799244, 109365},
 {"NonCommQ", 2799566, 109374},
 {"NonCommutative", 2799947, 109385},
 {"NTerms", 2800275, 109394},
 {"NumberOfMetricTensors", 2801141, 109419},
 {"NumericalFactor", 2801422, 109426},
 {"NumericQ1", 2801680, 109433},
 {"OneLoop", 2802426, 109454},
 {"OneLoopSimplify", 2804422, 109511},
 {"OneLoopSum", 2806100, 109554},
 {"OPE", 2806408, 109563},
 {"OPEDelta", 2806693, 109572},
 {"OPEi", 2807494, 109595},
 {"OPEInsert", 2808661, 109630},
 {"OPEInt", 2809116, 109643},
 {"OPEIntDelta", 2809558, 109656},
 {"OPEIntegrate", 2810032, 109669},
 {"OPEIntegrateDelta", 2810516, 109682},
 {"OPESumExplicit", 2811028, 109695},
 {"OPESum", 2812133, 109724},
 {"OPESumSimplify", 2813136, 109753},
 {"OPE1Loop", 2814320, 109784},
 {"OPE2TID", 2814770, 109797},
 {"OptionsSelect", 2815360, 109814},
 {"Pair", 2815607, 109821},
 {"PairCollect", 2817569, 109880},
 {"PairContract", 2817891, 109889},
 {"PairContract2", 2818218, 109898},
 {"PairContract3", 2818549, 109907},
 {"PartialD", 2818875, 109916},
 {"PartialDRelations", 2819693, 109939},
 {"PartialFourVector", 2820451, 109958},
 {"PartialIntegrate", 2821048, 109973},
 {"PartitHead", 2822423, 110008},
 {"PauliSigma", 2822667, 110015},
 {"PaVe", 2823054, 110026},
 {"PaVeOrderList", 2823818, 110049},
 {"PaVeOrder", 2824145, 110058},
 {"PaVeReduce", 2824970, 110081},
 {"Info3522790398-4590919", 2827016, 110136},
 {"PD", 2827126, 110139},
 {"PlusDistribution", 2827415, 110148},
 {"Polarization", 2828788, 110183},
 {"PolarizationSum", 2830242, 110222},
 {"PolarizationUncontract", 2831454, 110253},
 {"PolarizationVector", 2831826, 110262},
 {"PositiveInteger", 2834040, 110317},
 {"PositiveNumber", 2834379, 110326},
 {"PowerFactor", 2834711, 110335},
 {"PowerSimplify", 2835408, 110354},
 {"Power2", 2836421, 110381},
 {"PostFortranFile", 2837075, 110400},
 {"Prefactor", 2837410, 110409},
 {"PreFortranFile", 2837726, 110418},
 {"PropagatorDenominator", 2838069, 110427},
 {"PropagatorDenominatorExplicit", 2839792, 110468},
 {"QGV", 2840828, 110491},
 {"QO", 2841106, 110500},
 {"QP", 2841380, 110509},
 {"QuantumField", 2841665, 110518},
 {"QuarkField", 2844447, 110593},
 {"QuarkGluonVertex", 2844992, 110608},
 {"QuarkMass", 2846517, 110647},
 {"QuarkPropagator", 2846832, 110656},
 {"ReduceGamma", 2847874, 110683},
 {"ReduceToScalars", 2848198, 110692},
 {"Rename", 2848530, 110701},
 {"RHI", 2848822, 110710},
 {"RHI2FC", 2849243, 110723},
 {"RHM", 2849679, 110736},
 {"RHO", 2850094, 110749},
 {"RHP", 2850510, 110762},
 {"RTL", 2850926, 110775},
 {"RightPartialD", 2851353, 110788},
 {"RussianTrick", 2852523, 110819},
 {"ScalarGluonVertex", 2853839, 110854},
 {"ScalarProduct", 2854512, 110871},
 {"Info3522766000-2743550", 2856371, 110920},
 {"ScaleMu", 2856495, 110923},
 {"Schouten", 2856866, 110934},
 {"SD", 2857533, 110953},
 {"SelectFree", 2858274, 110976},
 {"SelectGraphs", 2859756, 111017},
 {"SelectNotFree", 2860082, 111026},
 {"SelectSplit", 2861697, 111069},
 {"Select1", 2862319, 111086},
 {"Select2", 2862619, 111095},
 {"Series2", 2862919, 111104},
 {"Series3", 2864909, 111161},
 {"SetMandelstam", 2865710, 111184},
 {"SimplifyDeltaFunction", 2866199, 111197},
 {"SimplifyGTI", 2868661, 111256},
 {"SimplifyPolyLog", 2869136, 111269},
 {"Simplify2", 2872519, 111356},
 {"SmallDelta", 2872907, 111367},
 {"SmallEpsilon", 2873152, 111374},
 {"SmallVariable", 2873404, 111381},
 {"SmallVariables", 2873736, 111390},
 {"SMP", 2874060, 111399},
 {"SMVertex", 2874743, 111420},
 {"Smu", 2875335, 111437},
 {"Sn", 2875549, 111444},
 {"SO", 2875762, 111451},
 {"SOD", 2876498, 111474},
 {"Solve2", 2877249, 111497},
 {"Solve3", 2878447, 111532},
 {"SP", 2879023, 111549},
 {"SPC", 2880279, 111588},
 {"SPD", 2880558, 111597},
 {"Spinor", 2881967, 111640},
 {"SpinorCollect", 2883644, 111689},
 {"SpinorUBar", 2883972, 111698},
 {"SpinorU", 2885159, 111731},
 {"SpinorVBar", 2886233, 111762},
 {"SpinorV", 2887350, 111793},
 {"SpinPolarizationSum", 2888433, 111824},
 {"SPL", 2888777, 111833},
 {"SplittingFunction", 2889070, 111842},
 {"StandardMatrixElement", 2893829, 111961},
 {"SubContext", 2894188, 111970},
 {"SubLoop", 2894501, 111979},
 {"SumP", 2894798, 111988},
 {"SumS", 2896091, 112027},
 {"SumT", 2898316, 112094},
 {"SUND", 2900676, 112165},
 {"SUNDelta", 2902442, 112218},
 {"SUNDeltaContract", 2904317, 112271},
 {"SUNF", 2904651, 112280},
 {"SUNFJacobi", 2906954, 112349},
 {"SUNIndex", 2907642, 112368},
 {"SUNIndexRename", 2908454, 112391},
 {"SUNN", 2908780, 112400},
 {"SUNNToCACF", 2909278, 112415},
 {"SUNSimplify", 2909819, 112430},
 {"SUNT", 2914130, 112547},
 {"SUNTrace", 2916293, 112612},
 {"SymbolicSum2", 2918527, 112675},
 {"SymbolicSum3", 2918779, 112682},
 {"Symmetrize", 2919029, 112689},
 {"TBox", 2919709, 112708},
 {"Tbox", 2919959, 112715},
 {"Tdec", 2920209, 112722},
 {"TensorFunction", 2921518, 112761},
 {"Tf", 2923226, 112806},
 {"TFi", 2923504, 112815},
 {"ThreeVector", 2924260, 112838},
 {"TID", 2924572, 112847},
 {"TIDL", 2925720, 112882},
 {"TimedIntegrate", 2928046, 112949},
 {"TLI", 2928988, 112974},
 {"TLIFP", 2929539, 112991},
 {"TLIHYP", 2930105, 113008},
 {"TLI2", 2930677, 113025},
 {"TLI2FC", 2930963, 113034},
 {"ToDistribution", 2931547, 113051},
 {"ToHypergeometric", 2933199, 113094},
 {"ToLarin", 2934259, 113121},
 {"ToTFi", 2934915, 113140},
 {"TR", 2935825, 113167},
 {"Info3522766033-2743550", 2938660, 113254},
 {"TraceDimension", 2938768, 113257},
 {"TraceOfOne", 2939099, 113266},
 {"Trick", 2939779, 113285},
 {"TrickIntegrate", 2940901, 113318},
 {"TrickMandelstam", 2941400, 113331},
 {"Tr2", 2942050, 113348},
 {"Twist2AlienOperator", 2942681, 113367},
 {"Twist2CounterOperator", 2943382, 113384},
 {"Twist2GluonOperator", 2944267, 113405},
 {"Twist2QuarkOperator", 2952068, 113594},
 {"Twist3QuarkOperator", 2956953, 113713},
 {"Twist4GluonOperator", 2957731, 113732},
 {"TwoLoopSimplify", 2958348, 113747},
 {"Uncontract", 2958844, 113760},
 {"UnDeclareNonCommutative", 2960777, 113813},
 {"Upper", 2962424, 113852},
 {"UVPart", 2962716, 113861},
 {"Vectors", 2963087, 113872},
 {"WriteOut", 2963388, 113881},
 {"WriteOutPaVe", 2963697, 113890},
 {"Write2", 2964017, 113899},
 {"XYT", 2966237, 113964},
 {"ZeroMomentumInsertion", 2966471, 113971},
 {"Zeta2", 2966826, 113980},
 {"$Abbreviations", 2967602, 114003},
 {"$AL", 2968081, 114016},
 {"$BreitMaison", 2968830, 114039},
 {"$Color", 2969150, 114048},
 {"$Covariant", 2969385, 114055},
 {"$FCS", 2970212, 114078},
 {"$FCT", 2970570, 114089},
 {"$FeynCalcStuff", 2971207, 114108},
 {"$FeynCalcVersion", 2971472, 114115},
 {"$FortranContinuationCharacter", 2971914, 114126},
 {"$Gauge", 2972490, 114139},
 {"$Larin", 2972789, 114148},
 {"$LimitTo4", 2973232, 114161},
 {"$LorentzIndices", 2973697, 114174},
 {"$MIntegrate", 2974748, 114201},
 {"$MU", 2975212, 114214},
 {"$MemoryAvailable", 2975641, 114227},
 {"$NonComm", 2976063, 114238},
 {"$PairBrackets", 2976521, 114251},
 {"$SpinorMinimal", 2977547, 114278},
 {"$VeryVerbose", 2978038, 114291},
 {"$V0", 2978885, 114314},
 {"$West", 2978963, 114317},
 {"Experimental", 2979265, 114326},
 {"DoPolarizationSums", 2979817, 114341},
 {"FeynmanDoIntegrals", 2982958, 114418},
 {"FeynmanParametrize1", 2983655, 114435},
 {"FeynmanReduce", 2984270, 114450}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 94, 2, 103, "Title"],
Cell[664, 26, 87, 1, 62, "Subtitle"],
Cell[754, 29, 123, 3, 64, "Subtitle",
 PageBreakBelow->True],
Cell[880, 34, 80, 1, 51, "Subsubtitle"],
Cell[963, 37, 244, 8, 51, "Subsubtitle"],
Cell[1210, 47, 799, 21, 29, NotebookDefault,
 CellTags->"ClickSave"],
Cell[CellGroupData[{
Cell[2034, 72, 147, 4, 27, "Input"],
Cell[2184, 78, 350, 10, 25, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2571, 93, 52, 1, 63, "Section",
 CellTags->"Functions"],
Cell[2626, 96, 54, 0, 29, "Commentary"],
Cell[2683, 98, 87, 2, 23, "Text"],
Cell[CellGroupData[{
Cell[2795, 104, 122, 3, 27, "Input"],
Cell[2920, 109, 114, 2, 27, "Output"]
}, Open  ]],
Cell[3049, 114, 69, 1, 27, "Input"],
Cell[3121, 117, 169, 3, 16, "Text"],
Cell[3293, 122, 652, 22, 16, "Text"],
Cell[3948, 146, 329, 11, 16, "Text"],
Cell[4280, 159, 154, 3, 16, "Text"],
Cell[4437, 164, 84, 2, 39, "ObjectName",
 PageBreakAbove->True,
 CellTags->"Abbreviation"],
Cell[CellGroupData[{
Cell[4546, 170, 63, 1, 33, "Subsubsection",
 CellTags->"Abbreviation"],
Cell[4612, 173, 329, 6, 39, "Text",
 CellTags->"Abbreviation"],
Cell[4944, 181, 1032, 43, 39, "Text",
 CellTags->"Abbreviation"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6013, 229, 60, 1, 33, "Subsubsection",
 CellTags->"Abbreviation"],
Cell[CellGroupData[{
Cell[6098, 234, 264, 8, 27, "Input",
 CellTags->"Abbreviation"],
Cell[6365, 244, 228, 8, 28, "Output",
 CellTags->"Abbreviation"]
}, Open  ]]
}, Open  ]],
Cell[6620, 256, 55, 1, 39, "ObjectName",
 CellTags->"Amplitude"],
Cell[CellGroupData[{
Cell[6700, 261, 60, 1, 33, "Subsubsection",
 CellTags->"Amplitude"],
Cell[6763, 264, 529, 9, 71, "Text",
 CellTags->"Amplitude"],
Cell[CellGroupData[{
Cell[7317, 277, 115, 3, 27, "Input",
 CellTags->"Amplitude"],
Cell[7435, 282, 328, 10, 25, "Output",
 CellTags->"Amplitude"]
}, Open  ]],
Cell[7778, 295, 177, 9, 23, "Text",
 CellTags->"Amplitude"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7992, 309, 57, 1, 33, "Subsubsection",
 CellTags->"Amplitude"],
Cell[CellGroupData[{
Cell[8074, 314, 133, 4, 27, "Input",
 CellTags->"Amplitude"],
Cell[8210, 320, 104, 3, 25, "Output",
 CellTags->"Amplitude"]
}, Open  ]],
Cell[8329, 326, 93, 1, 23, "Text",
 CellTags->"Amplitude"],
Cell[CellGroupData[{
Cell[8447, 331, 121, 3, 27, "Input",
 CellTags->"Amplitude"],
Cell[8571, 336, 2216, 95, 31, "Output",
 CellTags->"Amplitude"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10824, 436, 108, 3, 27, "Input",
 CellTags->"Amplitude"],
Cell[10935, 441, 5133, 189, 71, "Output",
 CellTags->"Amplitude"]
}, Open  ]],
Cell[16083, 633, 211, 8, 23, "Text",
 CellTags->"Amplitude"],
Cell[CellGroupData[{
Cell[16319, 645, 306, 9, 27, "Input",
 CellTags->"Amplitude"],
Cell[16628, 656, 13529, 441, 128, "Output",
 CellTags->"Amplitude"]
}, Open  ]]
}, Open  ]],
Cell[30184, 1101, 53, 1, 39, "ObjectName",
 CellTags->"Amputate"],
Cell[CellGroupData[{
Cell[30262, 1106, 59, 1, 33, "Subsubsection",
 CellTags->"Amputate"],
Cell[30324, 1109, 215, 5, 39, "Text",
 CellTags->"Amputate"],
Cell[CellGroupData[{
Cell[30564, 1118, 114, 3, 27, "Input",
 CellTags->"Amputate"],
Cell[30681, 1123, 296, 10, 25, "Output",
 CellTags->"Amputate"]
}, Open  ]],
Cell[30992, 1136, 656, 28, 23, "Text",
 CellTags->"Amputate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31685, 1169, 56, 1, 33, "Subsubsection",
 CellTags->"Amputate"],
Cell[CellGroupData[{
Cell[31766, 1174, 170, 5, 27, "Input",
 CellTags->"Amputate"],
Cell[31939, 1181, 428, 16, 25, "Output",
 CellTags->"Amputate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32404, 1202, 131, 4, 27, "Input",
 CellTags->"Amputate"],
Cell[32538, 1208, 721, 27, 27, "Output",
 CellTags->"Amputate"]
}, Open  ]]
}, Open  ]],
Cell[33286, 1239, 73, 1, 39, "ObjectName",
 CellTags->"AnomalousDimension"],
Cell[CellGroupData[{
Cell[33384, 1244, 69, 1, 33, "Subsubsection",
 CellTags->"AnomalousDimension"],
Cell[33456, 1247, 143, 4, 23, "Text",
 CellTags->"AnomalousDimension"],
Cell[CellGroupData[{
Cell[33624, 1255, 134, 3, 27, "Input",
 CellTags->"AnomalousDimension"],
Cell[33761, 1260, 254, 8, 25, "Output",
 CellTags->"AnomalousDimension"]
}, Open  ]],
Cell[34030, 1271, 406, 18, 23, "Text",
 CellTags->"AnomalousDimension"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34473, 1294, 66, 1, 33, "Subsubsection",
 CellTags->"AnomalousDimension"],
Cell[34542, 1297, 63, 1, 23, "Text",
 CellTags->"AnomalousDimension"],
Cell[CellGroupData[{
Cell[34630, 1302, 206, 5, 27, "Input",
 CellTags->"AnomalousDimension"],
Cell[34839, 1309, 254, 8, 25, "Output",
 CellTags->"AnomalousDimension"]
}, Open  ]],
Cell[35108, 1320, 241, 9, 30, "Text",
 CellTags->"AnomalousDimension"],
Cell[CellGroupData[{
Cell[35374, 1333, 133, 3, 27, "Input",
 CellTags->"AnomalousDimension"],
Cell[35510, 1338, 462, 17, 43, "Output",
 CellTags->"AnomalousDimension"]
}, Open  ]],
Cell[35987, 1358, 240, 9, 30, "Text",
 CellTags->"AnomalousDimension"],
Cell[CellGroupData[{
Cell[36252, 1371, 132, 3, 27, "Input",
 CellTags->"AnomalousDimension"],
Cell[36387, 1376, 284, 10, 43, "Output",
 CellTags->"AnomalousDimension"]
}, Open  ]],
Cell[36686, 1389, 240, 9, 30, "Text",
 CellTags->"AnomalousDimension"],
Cell[CellGroupData[{
Cell[36951, 1402, 132, 3, 27, "Input",
 CellTags->"AnomalousDimension"],
Cell[37086, 1407, 283, 10, 43, "Output",
 CellTags->"AnomalousDimension"]
}, Open  ]],
Cell[37384, 1420, 240, 9, 30, "Text",
 CellTags->"AnomalousDimension"],
Cell[CellGroupData[{
Cell[37649, 1433, 132, 3, 27, "Input",
 CellTags->"AnomalousDimension"],
Cell[37784, 1438, 594, 21, 45, "Output",
 CellTags->"AnomalousDimension"]
}, Open  ]],
Cell[38393, 1462, 241, 9, 30, "Text",
 CellTags->"AnomalousDimension"],
Cell[CellGroupData[{
Cell[38659, 1475, 133, 3, 27, "Input",
 CellTags->"AnomalousDimension"],
Cell[38795, 1480, 689, 23, 47, "Output",
 CellTags->"AnomalousDimension"]
}, Open  ]],
Cell[39499, 1506, 241, 9, 30, "Text",
 CellTags->"AnomalousDimension"],
Cell[CellGroupData[{
Cell[39765, 1519, 133, 3, 27, "Input",
 CellTags->"AnomalousDimension"],
Cell[39901, 1524, 6606, 218, 242, "Output",
 CellTags->"AnomalousDimension"]
}, Open  ]],
Cell[46522, 1745, 240, 9, 30, "Text",
 CellTags->"AnomalousDimension"],
Cell[CellGroupData[{
Cell[46787, 1758, 132, 3, 27, "Input",
 CellTags->"AnomalousDimension"],
Cell[46922, 1763, 4116, 140, 151, "Output",
 CellTags->"AnomalousDimension"]
}, Open  ]],
Cell[51053, 1906, 240, 9, 30, "Text",
 CellTags->"AnomalousDimension"],
Cell[CellGroupData[{
Cell[51318, 1919, 132, 3, 27, "Input",
 CellTags->"AnomalousDimension"],
Cell[51453, 1924, 6222, 212, 241, "Output",
 CellTags->"AnomalousDimension"]
}, Open  ]],
Cell[57690, 2139, 240, 9, 30, "Text",
 CellTags->"AnomalousDimension"],
Cell[CellGroupData[{
Cell[57955, 2152, 132, 3, 27, "Input",
 CellTags->"AnomalousDimension"],
Cell[58090, 2157, 4910, 166, 187, "Output",
 CellTags->"AnomalousDimension"]
}, Open  ]],
Cell[63015, 2326, 267, 9, 30, "Text",
 CellTags->"AnomalousDimension"],
Cell[CellGroupData[{
Cell[63307, 2339, 132, 3, 27, "Input",
 CellTags->"AnomalousDimension"],
Cell[63442, 2344, 4379, 139, 147, "Output",
 CellTags->"AnomalousDimension"]
}, Open  ]],
Cell[67836, 2486, 326, 10, 30, "Text",
 CellTags->"AnomalousDimension"],
Cell[CellGroupData[{
Cell[68187, 2500, 295, 9, 27, "Input",
 CellTags->"AnomalousDimension"],
Cell[68485, 2511, 239, 7, 25, "Output",
 CellTags->"AnomalousDimension"]
}, Open  ]]
}, Open  ]],
Cell[68751, 2522, 65, 1, 39, "ObjectName",
 CellTags->"AntiCommutator"],
Cell[CellGroupData[{
Cell[68841, 2527, 65, 1, 33, "Subsubsection",
 CellTags->"AntiCommutator"],
Cell[68909, 2530, 145, 4, 23, "Text",
 CellTags->"AntiCommutator"],
Cell[69057, 2536, 599, 24, 23, "Text",
 CellTags->"AntiCommutator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69693, 2565, 62, 1, 33, "Subsubsection",
 CellTags->"AntiCommutator"],
Cell[69758, 2568, 200, 9, 23, "Text",
 CellTags->"AntiCommutator"],
Cell[69961, 2579, 150, 4, 27, "Input",
 CellTags->"AntiCommutator"],
Cell[CellGroupData[{
Cell[70136, 2587, 143, 4, 27, "Input",
 CellTags->"AntiCommutator"],
Cell[70282, 2593, 163, 5, 25, "Output",
 CellTags->"AntiCommutator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[70482, 2603, 124, 3, 27, "Input",
 CellTags->"AntiCommutator"],
Cell[70609, 2608, 180, 6, 25, "Output",
 CellTags->"AntiCommutator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[70826, 2619, 265, 8, 27, "Input",
 CellTags->"AntiCommutator"],
Cell[71094, 2629, 438, 16, 25, "Output",
 CellTags->"AntiCommutator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71569, 2650, 258, 8, 27, "Input",
 CellTags->"AntiCommutator"],
Cell[71830, 2660, 318, 11, 25, "Output",
 CellTags->"AntiCommutator"]
}, Open  ]],
Cell[72163, 2674, 218, 6, 29, "Input",
 CellTags->"AntiCommutator"],
Cell[72384, 2682, 104, 1, 23, "Text",
 CellTags->"AntiCommutator"],
Cell[CellGroupData[{
Cell[72513, 2687, 177, 5, 27, "Input",
 CellTags->"AntiCommutator"],
Cell[72693, 2694, 109, 3, 25, "Output",
 CellTags->"AntiCommutator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72839, 2702, 182, 5, 27, "Input",
 CellTags->"AntiCommutator"],
Cell[73024, 2709, 190, 6, 25, "Output",
 CellTags->"AntiCommutator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73251, 2720, 250, 8, 29, "Input",
 CellTags->"AntiCommutator"],
Cell[73504, 2730, 132, 4, 25, "Output",
 CellTags->"AntiCommutator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73673, 2739, 252, 7, 29, "Input",
 CellTags->"AntiCommutator"],
Cell[73928, 2748, 315, 11, 27, "Output",
 CellTags->"AntiCommutator"]
}, Open  ]],
Cell[74258, 2762, 240, 6, 29, "Input",
 CellTags->"AntiCommutator"],
Cell[74501, 2770, 176, 5, 27, "Input",
 CellTags->"AntiCommutator"],
Cell[74680, 2777, 226, 7, 29, "Input",
 CellTags->"AntiCommutator"]
}, Open  ]],
Cell[74921, 2787, 65, 1, 59, "ObjectName",
 CellTags->"AntiQuarkField"],
Cell[CellGroupData[{
Cell[75011, 2792, 65, 1, 49, "Subsubsection",
 CellTags->"AntiQuarkField"],
Cell[75079, 2795, 197, 4, 34, "Text",
 CellTags->"AntiQuarkField"],
Cell[75279, 2801, 313, 14, 23, "Text",
 CellTags->"AntiQuarkField"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75629, 2820, 62, 1, 33, "Subsubsection",
 CellTags->"AntiQuarkField"],
Cell[CellGroupData[{
Cell[75716, 2825, 93, 2, 27, "Input",
 CellTags->"AntiQuarkField"],
Cell[75812, 2829, 137, 4, 25, "Output",
 CellTags->"AntiQuarkField"]
}, Open  ]]
}, Open  ]],
Cell[75976, 2837, 65, 1, 39, "ObjectName",
 CellTags->"AntiSymmetrize"],
Cell[CellGroupData[{
Cell[76066, 2842, 65, 1, 33, "Subsubsection",
 CellTags->"AntiSymmetrize"],
Cell[76134, 2845, 153, 4, 23, "Text",
 CellTags->"AntiSymmetrize"],
Cell[76290, 2851, 185, 8, 23, "Text",
 CellTags->"AntiSymmetrize"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76512, 2864, 62, 1, 33, "Subsubsection",
 CellTags->"AntiSymmetrize"],
Cell[CellGroupData[{
Cell[76599, 2869, 246, 8, 27, "Input",
 CellTags->"AntiSymmetrize"],
Cell[76848, 2879, 319, 11, 43, "Output",
 CellTags->"AntiSymmetrize"]
}, Open  ]],
Cell[CellGroupData[{
Cell[77204, 2895, 266, 8, 27, "Input",
 CellTags->"AntiSymmetrize"],
Cell[77473, 2905, 654, 20, 43, "Output",
 CellTags->"AntiSymmetrize"]
}, Open  ]]
}, Open  ]],
Cell[78154, 2929, 47, 1, 39, "ObjectName",
 CellTags->"Anti5"],
Cell[CellGroupData[{
Cell[78226, 2934, 56, 1, 33, "Subsubsection",
 CellTags->"Anti5"],
Cell[78285, 2937, 487, 16, 39, "Text",
 CellTags->"Anti5"],
Cell[78775, 2955, 163, 7, 23, "Text",
 CellTags->"Anti5"],
Cell[78941, 2964, 423, 19, 23, "Text",
 CellTags->"Anti5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79401, 2988, 53, 1, 33, "Subsubsection",
 CellTags->"Anti5"],
Cell[CellGroupData[{
Cell[79479, 2993, 154, 5, 27, "Input",
 CellTags->"Anti5"],
Cell[79636, 3000, 186, 6, 27, "Output",
 CellTags->"Anti5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79859, 3011, 102, 3, 27, "Input",
 CellTags->"Anti5"],
Cell[79964, 3016, 290, 11, 27, "Output",
 CellTags->"Anti5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80291, 3032, 144, 5, 27, "Input",
 CellTags->"Anti5"],
Cell[80438, 3039, 265, 10, 27, "Output",
 CellTags->"Anti5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[80740, 3054, 194, 6, 27, "Input",
 CellTags->"Anti5"],
Cell[80937, 3062, 320, 9, 27, "Output",
 CellTags->"Anti5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81294, 3076, 125, 4, 27, "Input",
 CellTags->"Anti5"],
Cell[81422, 3082, 320, 9, 27, "Output",
 CellTags->"Anti5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81779, 3096, 133, 4, 27, "Input",
 CellTags->"Anti5"],
Cell[81915, 3102, 320, 9, 27, "Output",
 CellTags->"Anti5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82272, 3116, 151, 5, 27, "Input",
 CellTags->"Anti5"],
Cell[82426, 3123, 320, 9, 27, "Output",
 CellTags->"Anti5"]
}, Open  ]],
Cell[82761, 3135, 351, 14, 23, "Text",
 CellTags->"Anti5"],
Cell[CellGroupData[{
Cell[83137, 3153, 127, 4, 27, "Input",
 CellTags->"Anti5"],
Cell[83267, 3159, 191, 6, 27, "Output",
 CellTags->"Anti5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83495, 3170, 102, 3, 27, "Input",
 CellTags->"Anti5"],
Cell[83600, 3175, 290, 11, 27, "Output",
 CellTags->"Anti5"]
}, Open  ]]
}, Open  ]],
Cell[83917, 3190, 49, 1, 39, "ObjectName",
 CellTags->"Apart2"],
Cell[CellGroupData[{
Cell[83991, 3195, 57, 1, 33, "Subsubsection",
 CellTags->"Apart2"],
Cell[84051, 3198, 108, 3, 23, "Text",
 CellTags->"Apart2"],
Cell[84162, 3203, 302, 14, 23, "Text",
 CellTags->"Apart2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84501, 3222, 54, 1, 33, "Subsubsection",
 CellTags->"Apart2"],
Cell[CellGroupData[{
Cell[84580, 3227, 256, 9, 27, "Input",
 CellTags->"Apart2"],
Cell[84839, 3238, 1188, 30, 49, "Output",
 CellTags->"Apart2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86064, 3273, 104, 3, 27, "Input",
 CellTags->"Apart2"],
Cell[86171, 3278, 720, 26, 55, "Output",
 CellTags->"Apart2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86928, 3309, 140, 4, 27, "Input",
 CellTags->"Apart2"],
Cell[87071, 3315, 517, 19, 56, "Output",
 CellTags->"Apart2"]
}, Open  ]]
}, Open  ]],
Cell[87615, 3338, 64, 2, 39, "ObjectName",
 PageBreakAbove->True,
 CellTags->"A0"],
Cell[CellGroupData[{
Cell[87704, 3344, 53, 1, 33, "Subsubsection",
 CellTags->"A0"],
Cell[87760, 3347, 291, 11, 25, "Text",
 CellTags->"A0"],
Cell[CellGroupData[{
Cell[88076, 3362, 107, 3, 27, "Input",
 CellTags->"A0"],
Cell[88186, 3367, 161, 6, 25, "Output",
 CellTags->"A0"]
}, Open  ]],
Cell[88362, 3376, 437, 24, 23, "Text",
 CellTags->"A0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[88836, 3405, 50, 1, 33, "Subsubsection",
 CellTags->"A0"],
Cell[88889, 3408, 246, 11, 23, "Text",
 CellTags->"A0"],
Cell[CellGroupData[{
Cell[89160, 3423, 120, 4, 29, "Input",
 CellTags->"A0"],
Cell[89283, 3429, 259, 10, 29, "Output",
 CellTags->"A0"]
}, Open  ]],
Cell[89557, 3442, 186, 6, 27, "Input",
 CellTags->"A0"],
Cell[CellGroupData[{
Cell[89768, 3452, 120, 4, 29, "Input",
 CellTags->"A0"],
Cell[89891, 3458, 324, 11, 29, "Output",
 CellTags->"A0"]
}, Open  ]],
Cell[90230, 3472, 187, 6, 27, "Input",
 CellTags->"A0"],
Cell[90420, 3480, 222, 8, 23, "Text",
 CellTags->"A0"],
Cell[CellGroupData[{
Cell[90667, 3492, 96, 3, 27, "Input",
 CellTags->"A0"],
Cell[90766, 3497, 97, 3, 25, "Output",
 CellTags->"A0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[90900, 3505, 160, 5, 27, "Input",
 CellTags->"A0"],
Cell[91063, 3512, 97, 3, 25, "Output",
 CellTags->"A0"]
}, Open  ]]
}, Open  ]],
Cell[91187, 3519, 72, 2, 39, "ObjectName",
 PageBreakAbove->True,
 CellTags->"A0ToB0"],
Cell[CellGroupData[{
Cell[91284, 3525, 57, 1, 33, "Subsubsection",
 CellTags->"A0ToB0"],
Cell[91344, 3528, 614, 27, 23, "Text",
 CellTags->"A0ToB0"],
Cell[CellGroupData[{
Cell[91983, 3559, 111, 3, 27, "Input",
 CellTags->"A0ToB0"],
Cell[92097, 3564, 165, 6, 25, "Output",
 CellTags->"A0ToB0"]
}, Open  ]],
Cell[92277, 3573, 533, 29, 23, "Text",
 CellTags->"A0ToB0"]
}, Open  ]],
Cell[92825, 3605, 79, 1, 39, "ObjectName",
 CellTags->"BackgroundGluonVertex"],
Cell[CellGroupData[{
Cell[92929, 3610, 72, 1, 33, "Subsubsection",
 CellTags->"BackgroundGluonVertex"],
Cell[93004, 3613, 1042, 19, 119, "Text",
 CellTags->"BackgroundGluonVertex"],
Cell[CellGroupData[{
Cell[94071, 3636, 140, 3, 27, "Input",
 CellTags->"BackgroundGluonVertex"],
Cell[94214, 3641, 318, 9, 25, "Output",
 CellTags->"BackgroundGluonVertex"]
}, Open  ]],
Cell[94547, 3653, 201, 9, 23, "Text",
 CellTags->"BackgroundGluonVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[94785, 3667, 69, 1, 33, "Subsubsection",
 CellTags->"BackgroundGluonVertex"],
Cell[CellGroupData[{
Cell[94879, 3672, 360, 10, 27, "Input",
 CellTags->"BackgroundGluonVertex"],
Cell[95242, 3684, 1486, 58, 27, "Output",
 CellTags->"BackgroundGluonVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[96765, 3747, 436, 12, 27, "Input",
 CellTags->"BackgroundGluonVertex"],
Cell[97204, 3761, 3846, 142, 50, "Output",
 CellTags->"BackgroundGluonVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101087, 3908, 411, 11, 27, "Input",
 CellTags->"BackgroundGluonVertex"],
Cell[101501, 3921, 1559, 60, 45, "Output",
 CellTags->"BackgroundGluonVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103097, 3986, 487, 13, 27, "Input",
 CellTags->"BackgroundGluonVertex"],
Cell[103587, 4001, 3954, 145, 86, "Output",
 CellTags->"BackgroundGluonVertex"]
}, Open  ]]
}, Open  ]],
Cell[107568, 4150, 51, 1, 39, "ObjectName",
 CellTags->"Bracket"],
Cell[CellGroupData[{
Cell[107644, 4155, 58, 1, 33, "Subsubsection",
 CellTags->"Bracket"],
Cell[107705, 4158, 72, 1, 23, "Text",
 CellTags->"Bracket"],
Cell[107780, 4161, 181, 9, 23, "Text",
 CellTags->"Bracket"]
}, Open  ]],
Cell[107976, 4173, 74, 2, 39, "ObjectName",
 PageBreakAbove->True,
 CellTags->"BReduce"],
Cell[CellGroupData[{
Cell[108075, 4179, 58, 1, 33, "Subsubsection",
 CellTags->"BReduce"],
Cell[108136, 4182, 148, 4, 23, "Text",
 CellTags->"BReduce"],
Cell[108287, 4188, 534, 29, 23, "Text",
 CellTags->"BReduce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[108858, 4222, 55, 1, 33, "Subsubsection",
 CellTags->"BReduce"],
Cell[108916, 4225, 251, 11, 23, "Text",
 CellTags->"BReduce"],
Cell[CellGroupData[{
Cell[109192, 4240, 134, 4, 27, "Input",
 CellTags->"BReduce"],
Cell[109329, 4246, 176, 6, 25, "Output",
 CellTags->"BReduce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[109542, 4257, 81, 2, 27, "Input"],
Cell[109626, 4261, 263, 8, 25, "Output"]
}, Open  ]],
Cell[109904, 4272, 94, 3, 23, "Text",
 CellTags->"BReduce"],
Cell[CellGroupData[{
Cell[110023, 4279, 183, 5, 27, "Input",
 CellTags->"BReduce"],
Cell[110209, 4286, 260, 10, 43, "Output",
 CellTags->"BReduce"]
}, Open  ]]
}, Open  ]],
Cell[110496, 4300, 41, 1, 39, "ObjectName",
 CellTags->"B0"],
Cell[CellGroupData[{
Cell[110562, 4305, 53, 1, 33, "Subsubsection",
 CellTags->"B0"],
Cell[110618, 4308, 390, 9, 39, "Text",
 CellTags->"B0"],
Cell[CellGroupData[{
Cell[111033, 4321, 102, 3, 27, "Input",
 CellTags->"B0"],
Cell[111138, 4326, 280, 9, 25, "Output",
 CellTags->"B0"]
}, Open  ]],
Cell[111433, 4338, 443, 24, 23, "Text",
 CellTags->"B0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[111913, 4367, 50, 1, 33, "Subsubsection",
 CellTags->"B0"],
Cell[CellGroupData[{
Cell[111988, 4372, 234, 8, 29, "Input",
 CellTags->"B0"],
Cell[112225, 4382, 316, 12, 29, "Output",
 CellTags->"B0"]
}, Open  ]],
Cell[112556, 4397, 237, 7, 27, "Input",
 CellTags->"B0"],
Cell[CellGroupData[{
Cell[112818, 4408, 154, 5, 29, "Input",
 CellTags->"B0"],
Cell[112975, 4415, 245, 8, 29, "Output",
 CellTags->"B0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113257, 4428, 179, 6, 29, "Input",
 CellTags->"B0"],
Cell[113439, 4436, 245, 8, 29, "Output",
 CellTags->"B0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113721, 4449, 177, 6, 27, "Input",
 CellTags->"B0"],
Cell[113901, 4457, 218, 7, 29, "Output",
 CellTags->"B0"]
}, Open  ]]
}, Open  ]],
Cell[114146, 4468, 72, 2, 39, "ObjectName",
 PageBreakAbove->True,
 CellTags->"B0Real"],
Cell[CellGroupData[{
Cell[114243, 4474, 57, 1, 33, "Subsubsection",
 CellTags->"B0Real"],
Cell[114303, 4477, 186, 4, 23, "Text",
 CellTags->"B0Real"],
Cell[114492, 4483, 153, 8, 23, "Text",
 CellTags->"B0Real"]
}, Open  ]],
Cell[CellGroupData[{
Cell[114682, 4496, 54, 1, 33, "Subsubsection",
 CellTags->"B0Real"],
Cell[114739, 4499, 83, 1, 23, "Text",
 CellTags->"B0Real"],
Cell[CellGroupData[{
Cell[114847, 4504, 133, 4, 27, "Input",
 CellTags->"B0Real"],
Cell[114983, 4510, 200, 7, 25, "Output",
 CellTags->"B0Real"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115220, 4522, 102, 3, 27, "Input",
 CellTags->"B0Real"],
Cell[115325, 4527, 282, 9, 25, "Output",
 CellTags->"B0Real"]
}, Open  ]],
Cell[115622, 4539, 92, 3, 23, "Text",
 CellTags->"B0Real"],
Cell[CellGroupData[{
Cell[115739, 4546, 181, 5, 27, "Input",
 CellTags->"B0Real"],
Cell[115923, 4553, 200, 7, 25, "Output",
 CellTags->"B0Real"]
}, Open  ]]
}, Open  ]],
Cell[116150, 4564, 76, 2, 58, "ObjectName",
 PageBreakAbove->True,
 CellTags->"B0Unique"],
Cell[CellGroupData[{
Cell[116251, 4570, 59, 1, 39, "Subsubsection",
 CellTags->"B0Unique"],
Cell[116313, 4573, 184, 4, 54, "Text",
 CellTags->"B0Unique"],
Cell[116500, 4579, 155, 8, 33, "Text",
 CellTags->"B0Unique"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116692, 4592, 56, 1, 48, "Subsubsection",
 CellTags->"B0Unique"],
Cell[116751, 4595, 73, 1, 23, "Text",
 CellTags->"B0Unique"],
Cell[CellGroupData[{
Cell[116849, 4600, 135, 4, 27, "Input",
 CellTags->"B0Unique"],
Cell[116987, 4606, 202, 7, 25, "Output",
 CellTags->"B0Unique"]
}, Open  ]],
Cell[CellGroupData[{
Cell[117226, 4618, 104, 3, 27, "Input",
 CellTags->"B0Unique"],
Cell[117333, 4623, 284, 9, 25, "Output",
 CellTags->"B0Unique"]
}, Open  ]],
Cell[117632, 4635, 88, 3, 23, "Text",
 CellTags->"B0Unique"],
Cell[CellGroupData[{
Cell[117745, 4642, 186, 5, 27, "Input",
 CellTags->"B0Unique"],
Cell[117934, 4649, 177, 6, 25, "Output",
 CellTags->"B0Unique"]
}, Open  ]]
}, Open  ]],
Cell[118138, 4659, 43, 1, 39, "ObjectName",
 CellTags->"B00"],
Cell[CellGroupData[{
Cell[118206, 4664, 54, 1, 33, "Subsubsection",
 CellTags->"B00"],
Cell[118263, 4667, 290, 8, 39, "Text",
 CellTags->"B00"],
Cell[CellGroupData[{
Cell[118578, 4679, 104, 3, 27, "Input",
 CellTags->"B00"],
Cell[118685, 4684, 162, 6, 25, "Output",
 CellTags->"B00"]
}, Open  ]],
Cell[118862, 4693, 346, 19, 23, "Text",
 CellTags->"B00"]
}, Open  ]],
Cell[CellGroupData[{
Cell[119245, 4717, 51, 1, 33, "Subsubsection",
 CellTags->"B00"],
Cell[119299, 4720, 202, 7, 23, "Text",
 CellTags->"B00"],
Cell[CellGroupData[{
Cell[119526, 4731, 97, 3, 27, "Input",
 CellTags->"B00"],
Cell[119626, 4736, 156, 6, 27, "Output",
 CellTags->"B00"]
}, Open  ]],
Cell[CellGroupData[{
Cell[119819, 4747, 211, 7, 29, "Input",
 CellTags->"B00"],
Cell[120033, 4756, 2675, 90, 92, "Output",
 CellTags->"B00"]
}, Open  ]],
Cell[CellGroupData[{
Cell[122745, 4851, 211, 7, 29, "Input",
 CellTags->"B00"],
Cell[122959, 4860, 1452, 54, 43, "Output",
 CellTags->"B00"]
}, Open  ]],
Cell[CellGroupData[{
Cell[124448, 4919, 261, 8, 29, "Input",
 CellTags->"B00"],
Cell[124712, 4929, 516, 22, 29, "Output",
 CellTags->"B00"]
}, Open  ]],
Cell[CellGroupData[{
Cell[125265, 4956, 181, 6, 29, "Input",
 CellTags->"B00"],
Cell[125449, 4964, 614, 22, 46, "Output",
 CellTags->"B00"]
}, Open  ]],
Cell[CellGroupData[{
Cell[126100, 4991, 248, 8, 29, "Input",
 CellTags->"B00"],
Cell[126351, 5001, 641, 23, 46, "Output",
 CellTags->"B00"]
}, Open  ]]
}, Open  ]],
Cell[127019, 5028, 41, 1, 39, "ObjectName",
 CellTags->"B1"],
Cell[CellGroupData[{
Cell[127085, 5033, 53, 1, 33, "Subsubsection",
 CellTags->"B1"],
Cell[127141, 5036, 230, 7, 23, "Text",
 CellTags->"B1"],
Cell[CellGroupData[{
Cell[127396, 5047, 102, 3, 27, "Input",
 CellTags->"B1"],
Cell[127501, 5052, 161, 6, 25, "Output",
 CellTags->"B1"]
}, Open  ]],
Cell[127677, 5061, 559, 29, 23, "Text",
 CellTags->"B1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[128273, 5095, 50, 1, 33, "Subsubsection",
 CellTags->"B1"],
Cell[CellGroupData[{
Cell[128348, 5100, 209, 7, 29, "Input",
 CellTags->"B1"],
Cell[128560, 5109, 1153, 42, 50, "Output",
 CellTags->"B1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[129750, 5156, 259, 8, 29, "Input",
 CellTags->"B1"],
Cell[130012, 5166, 316, 12, 29, "Output",
 CellTags->"B1"]
}, Open  ]],
Cell[130343, 5181, 187, 6, 27, "Input",
 CellTags->"B1"],
Cell[CellGroupData[{
Cell[130555, 5191, 209, 7, 29, "Input",
 CellTags->"B1"],
Cell[130767, 5200, 390, 15, 43, "Output",
 CellTags->"B1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[131194, 5220, 179, 6, 29, "Input",
 CellTags->"B1"],
Cell[131376, 5228, 403, 14, 43, "Output",
 CellTags->"B1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[131816, 5247, 154, 5, 29, "Input",
 CellTags->"B1"],
Cell[131973, 5254, 403, 14, 43, "Output",
 CellTags->"B1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[132413, 5273, 238, 7, 29, "Input",
 CellTags->"B1"],
Cell[132654, 5282, 791, 25, 50, "Output",
 CellTags->"B1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[133482, 5312, 279, 8, 29, "Input",
 CellTags->"B1"],
Cell[133764, 5322, 419, 14, 43, "Output",
 CellTags->"B1"]
}, Open  ]]
}, Open  ]],
Cell[134210, 5340, 43, 1, 39, "ObjectName",
 CellTags->"B11"],
Cell[CellGroupData[{
Cell[134278, 5345, 54, 1, 33, "Subsubsection",
 CellTags->"B11"],
Cell[134335, 5348, 495, 17, 39, "Text",
 CellTags->"B11"],
Cell[CellGroupData[{
Cell[134855, 5369, 104, 3, 27, "Input",
 CellTags->"B11"],
Cell[134962, 5374, 162, 6, 25, "Output",
 CellTags->"B11"]
}, Open  ]],
Cell[135139, 5383, 441, 24, 23, "Text",
 CellTags->"B11"]
}, Open  ]],
Cell[CellGroupData[{
Cell[135617, 5412, 51, 1, 33, "Subsubsection",
 CellTags->"B11"],
Cell[135671, 5415, 215, 7, 23, "Text",
 CellTags->"B11"],
Cell[CellGroupData[{
Cell[135911, 5426, 97, 3, 27, "Input",
 CellTags->"B11"],
Cell[136011, 5431, 156, 6, 27, "Output",
 CellTags->"B11"]
}, Open  ]],
Cell[CellGroupData[{
Cell[136204, 5442, 212, 7, 29, "Input",
 CellTags->"B11"],
Cell[136419, 5451, 2848, 97, 99, "Output",
 CellTags->"B11"]
}, Open  ]],
Cell[CellGroupData[{
Cell[139304, 5553, 212, 7, 29, "Input",
 CellTags->"B11"],
Cell[139519, 5562, 1206, 47, 54, "Output",
 CellTags->"B11"]
}, Open  ]],
Cell[CellGroupData[{
Cell[140762, 5614, 171, 5, 27, "Input",
 CellTags->"B11"],
Cell[140936, 5621, 164, 6, 25, "Output",
 CellTags->"B11"]
}, Open  ]],
Cell[CellGroupData[{
Cell[141137, 5632, 212, 7, 29, "Input",
 CellTags->"B11"],
Cell[141352, 5641, 517, 22, 29, "Output",
 CellTags->"B11"]
}, Open  ]],
Cell[CellGroupData[{
Cell[141906, 5668, 170, 5, 27, "Input",
 CellTags->"B11"],
Cell[142079, 5675, 163, 6, 25, "Output",
 CellTags->"B11"]
}, Open  ]],
Cell[CellGroupData[{
Cell[142279, 5686, 182, 6, 29, "Input",
 CellTags->"B11"],
Cell[142464, 5694, 269, 9, 43, "Output",
 CellTags->"B11"]
}, Open  ]],
Cell[CellGroupData[{
Cell[142770, 5708, 249, 8, 29, "Input",
 CellTags->"B11"],
Cell[143022, 5718, 295, 10, 43, "Output",
 CellTags->"B11"]
}, Open  ]]
}, Open  ]],
Cell[143344, 5732, 41, 1, 39, "ObjectName",
 CellTags->"CA"],
Cell[CellGroupData[{
Cell[143410, 5737, 53, 1, 33, "Subsubsection",
 CellTags->"CA"],
Cell[143466, 5740, 198, 9, 23, "Text",
 CellTags->"CA"],
Cell[143667, 5751, 274, 14, 23, "Text",
 CellTags->"CA"]
}, Open  ]],
Cell[CellGroupData[{
Cell[143978, 5770, 50, 1, 33, "Subsubsection",
 CellTags->"CA"],
Cell[CellGroupData[{
Cell[144053, 5775, 70, 2, 27, "Input",
 CellTags->"CA"],
Cell[144126, 5779, 120, 4, 25, "Output",
 CellTags->"CA"]
}, Open  ]],
Cell[CellGroupData[{
Cell[144283, 5788, 173, 5, 27, "Input",
 CellTags->"CA"],
Cell[144459, 5795, 98, 3, 25, "Output",
 CellTags->"CA"]
}, Open  ]],
Cell[CellGroupData[{
Cell[144594, 5803, 72, 2, 27, "Input",
 CellTags->"CA"],
Cell[144669, 5807, 98, 3, 25, "Output",
 CellTags->"CA"]
}, Open  ]]
}, Open  ]],
Cell[144794, 5814, 45, 1, 39, "ObjectName",
 CellTags->"Calc"],
Cell[CellGroupData[{
Cell[144864, 5819, 55, 1, 33, "Subsubsection",
 CellTags->"Calc"],
Cell[144922, 5822, 233, 5, 39, "Text",
 CellTags->"Calc"],
Cell[145158, 5829, 407, 19, 23, "Text",
 CellTags->"Calc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[145602, 5853, 61, 1, 34, "Subsubsection",
 CellTags->"Calc"],
Cell[145666, 5856, 346, 13, 26, "Text",
 CellTags->"Calc"],
Cell[CellGroupData[{
Cell[146037, 5873, 284, 9, 27, "Input",
 CellTags->"Calc"],
Cell[146324, 5884, 147, 5, 25, "Output",
 CellTags->"Calc"]
}, Open  ]],
Cell[146486, 5892, 213, 9, 23, "Text",
 CellTags->"Calc"],
Cell[CellGroupData[{
Cell[146724, 5905, 258, 8, 27, "Input",
 CellTags->"Calc"],
Cell[146985, 5915, 352, 15, 27, "Output",
 CellTags->"Calc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[147374, 5935, 328, 11, 27, "Input",
 CellTags->"Calc"],
Cell[147705, 5948, 424, 16, 27, "Output",
 CellTags->"Calc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[148166, 5969, 101, 3, 27, "Input",
 CellTags->"Calc"],
Cell[148270, 5974, 525, 22, 27, "Output",
 CellTags->"Calc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[148832, 6001, 215, 6, 27, "Input",
 CellTags->"Calc"],
Cell[149050, 6009, 985, 44, 29, "Output",
 CellTags->"Calc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[150072, 6058, 382, 13, 27, "Input",
 CellTags->"Calc"],
Cell[150457, 6073, 100, 3, 25, "Output",
 CellTags->"Calc"]
}, Open  ]]
}, Open  ]],
Cell[150584, 6080, 67, 1, 39, "ObjectName",
 CellTags->"CalcColorFactor"],
Cell[CellGroupData[{
Cell[150676, 6085, 66, 1, 33, "Subsubsection",
 CellTags->"CalcColorFactor"],
Cell[150745, 6088, 470, 9, 103, "Text",
 CellTags->"CalcColorFactor"],
Cell[151218, 6099, 195, 9, 23, "Text",
 CellTags->"CalcColorFactor"],
Cell[CellGroupData[{
Cell[151438, 6112, 250, 7, 27, "Input"],
Cell[151691, 6121, 333, 14, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[152061, 6140, 99, 2, 27, "Input"],
Cell[152163, 6144, 1707, 55, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[153907, 6204, 118, 3, 27, "Input"],
Cell[154028, 6209, 2279, 77, 62, "Output"]
}, Open  ]],
Cell[156322, 6289, 411, 18, 23, "Text",
 CellTags->"Collecting"]
}, Open  ]],
Cell[156748, 6310, 94, 1, 39, "ObjectName",
 CellTags->"CalculateCounterTerm"],
Cell[CellGroupData[{
Cell[156867, 6315, 71, 1, 33, "Subsubsection",
 CellTags->"CalculateCounterTerm"],
Cell[156941, 6318, 110, 1, 23, "Text",
 CellTags->"CalculateCounterTerm"]
}, Open  ]],
Cell[CellGroupData[{
Cell[157088, 6324, 77, 1, 34, "Subsubsection",
 CellTags->"CalculateCounterTerm"],
Cell[CellGroupData[{
Cell[157190, 6329, 123, 3, 27, "Input",
 CellTags->"CalculateCounterTerm"],
Cell[157316, 6334, 191, 3, 38, "Print",
 CellTags->{"CalculateCounterTerm", "Info3522790126-4590919"}]
}, Open  ]]
}, Open  ]],
Cell[157534, 6341, 53, 1, 39, "ObjectName",
 CellTags->"CancelQP"],
Cell[CellGroupData[{
Cell[157612, 6346, 59, 1, 33, "Subsubsection",
 CellTags->"CancelQP"],
Cell[157674, 6349, 314, 13, 23, "Text",
 CellTags->"CancelQP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[158025, 6367, 65, 1, 34, "Subsubsection",
 CellTags->"CancelQP"],
Cell[CellGroupData[{
Cell[158115, 6372, 549, 19, 27, "Input",
 CellTags->"CancelQP"],
Cell[158667, 6393, 667, 24, 49, "Output",
 CellTags->"CancelQP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[159371, 6422, 182, 5, 27, "Input",
 CellTags->"CancelQP"],
Cell[159556, 6429, 2183, 73, 51, "Output",
 CellTags->"CancelQP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[161776, 6507, 183, 5, 27, "Input",
 CellTags->"CancelQP"],
Cell[161962, 6514, 6421, 209, 209, "Output",
 CellTags->"CancelQP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[168420, 6728, 555, 18, 27, "Input",
 CellTags->"CancelQP"],
Cell[168978, 6748, 886, 33, 49, "Output",
 CellTags->"CancelQP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[169901, 6786, 182, 5, 27, "Input",
 CellTags->"CancelQP"],
Cell[170086, 6793, 6471, 225, 100, "Output",
 CellTags->"CancelQP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[176594, 7023, 183, 5, 27, "Input",
 CellTags->"CancelQP"],
Cell[176780, 7030, 3734, 126, 51, "Output",
 CellTags->"CancelQP"]
}, Open  ]],
Cell[180529, 7159, 106, 3, 27, "Input",
 CellTags->"CancelQP"]
}, Open  ]],
Cell[180650, 7165, 49, 1, 39, "ObjectName",
 CellTags->"Cases2"],
Cell[CellGroupData[{
Cell[180724, 7170, 57, 1, 33, "Subsubsection",
 CellTags->"Cases2"],
Cell[180784, 7173, 293, 6, 39, "Text",
 CellTags->"Cases2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[181114, 7184, 63, 1, 34, "Subsubsection",
 CellTags->"Cases2"],
Cell[CellGroupData[{
Cell[181202, 7189, 305, 10, 29, "Input",
 CellTags->"Cases2"],
Cell[181510, 7201, 275, 9, 25, "Output",
 CellTags->"Cases2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[181822, 7215, 312, 10, 27, "Input",
 CellTags->"Cases2"],
Cell[182137, 7227, 279, 9, 25, "Output",
 CellTags->"Cases2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[182453, 7241, 427, 14, 27, "Input",
 CellTags->"Cases2"],
Cell[182883, 7257, 355, 11, 25, "Output",
 CellTags->"Cases2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[183275, 7273, 327, 10, 27, "Input",
 CellTags->"Cases2"],
Cell[183605, 7285, 463, 17, 25, "Output",
 CellTags->"Cases2"]
}, Open  ]]
}, Open  ]],
Cell[184095, 7306, 41, 1, 39, "ObjectName",
 CellTags->"CF"],
Cell[CellGroupData[{
Cell[184161, 7311, 53, 1, 33, "Subsubsection",
 CellTags->"CF"],
Cell[184217, 7314, 287, 13, 23, "Text",
 CellTags->"CF"],
Cell[184507, 7329, 274, 14, 23, "Text",
 CellTags->"CF"]
}, Open  ]],
Cell[CellGroupData[{
Cell[184818, 7348, 50, 1, 33, "Subsubsection",
 CellTags->"CF"],
Cell[CellGroupData[{
Cell[184893, 7353, 70, 2, 27, "Input",
 CellTags->"CF"],
Cell[184966, 7357, 120, 4, 25, "Output",
 CellTags->"CF"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185123, 7366, 178, 5, 27, "Input",
 CellTags->"CF"],
Cell[185304, 7373, 193, 7, 47, "Output",
 CellTags->"CF"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185534, 7385, 83, 2, 27, "Input"],
Cell[185620, 7389, 76, 1, 39, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185733, 7395, 72, 2, 27, "Input",
 CellTags->"CF"],
Cell[185808, 7399, 98, 3, 25, "Output",
 CellTags->"CF"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185943, 7407, 233, 7, 27, "Input",
 CellTags->"CF"],
Cell[186179, 7416, 177, 6, 25, "Output",
 CellTags->"CF"]
}, Open  ]]
}, Open  ]],
Cell[186383, 7426, 67, 1, 39, "ObjectName",
 CellTags->"ChangeDimension"],
Cell[CellGroupData[{
Cell[186475, 7431, 66, 1, 33, "Subsubsection",
 CellTags->"ChangeDimension"],
Cell[186544, 7434, 210, 5, 39, "Text",
 CellTags->"ChangeDimension"],
Cell[186757, 7441, 519, 24, 23, "Text",
 CellTags->"ChangeDimension"]
}, Open  ]],
Cell[CellGroupData[{
Cell[187313, 7470, 63, 1, 33, "Subsubsection",
 CellTags->"ChangeDimension"],
Cell[187379, 7473, 219, 5, 39, "Text",
 CellTags->"ChangeDimension"],
Cell[CellGroupData[{
Cell[187623, 7482, 212, 6, 27, "Input",
 CellTags->"ChangeDimension"],
Cell[187838, 7490, 198, 7, 25, "Output",
 CellTags->"ChangeDimension"]
}, Open  ]],
Cell[CellGroupData[{
Cell[188073, 7502, 151, 4, 27, "Input",
 CellTags->"ChangeDimension"],
Cell[188227, 7508, 198, 7, 25, "Output",
 CellTags->"ChangeDimension"]
}, Open  ]],
Cell[CellGroupData[{
Cell[188462, 7520, 116, 3, 27, "Input",
 CellTags->"ChangeDimension"],
Cell[188581, 7525, 272, 8, 39, "Output",
 CellTags->"ChangeDimension"]
}, Open  ]],
Cell[188868, 7536, 119, 3, 23, "Text",
 CellTags->"ChangeDimension"],
Cell[CellGroupData[{
Cell[189012, 7543, 201, 6, 27, "Input",
 CellTags->"ChangeDimension"],
Cell[189216, 7551, 222, 6, 39, "Output",
 CellTags->"ChangeDimension"]
}, Open  ]],
Cell[189453, 7560, 105, 1, 23, "Text",
 CellTags->"ChangeDimension"],
Cell[CellGroupData[{
Cell[189583, 7565, 482, 15, 27, "Input",
 CellTags->"ChangeDimension"],
Cell[190068, 7582, 571, 18, 27, "Output",
 CellTags->"ChangeDimension"]
}, Open  ]],
Cell[CellGroupData[{
Cell[190676, 7605, 153, 4, 27, "Input",
 CellTags->"ChangeDimension"],
Cell[190832, 7611, 755, 29, 27, "Output",
 CellTags->"ChangeDimension"]
}, Open  ]],
Cell[CellGroupData[{
Cell[191624, 7645, 222, 6, 27, "Input",
 CellTags->"ChangeDimension"],
Cell[191849, 7653, 755, 29, 27, "Output",
 CellTags->"ChangeDimension"]
}, Open  ]],
Cell[192619, 7685, 132, 3, 23, "Text",
 CellTags->"ChangeDimension"],
Cell[192754, 7690, 208, 6, 27, "Input",
 CellTags->"ChangeDimension"],
Cell[192965, 7698, 219, 5, 39, "Text",
 CellTags->"ChangeDimension"],
Cell[193187, 7705, 201, 6, 27, "Input",
 CellTags->"ChangeDimension"],
Cell[CellGroupData[{
Cell[193413, 7715, 220, 6, 27, "Input",
 CellTags->"ChangeDimension"],
Cell[193636, 7723, 489, 21, 25, "Output",
 CellTags->"ChangeDimension"]
}, Open  ]],
Cell[CellGroupData[{
Cell[194162, 7749, 182, 5, 27, "Input",
 CellTags->"ChangeDimension"],
Cell[194347, 7756, 489, 21, 25, "Output",
 CellTags->"ChangeDimension"]
}, Open  ]],
Cell[CellGroupData[{
Cell[194873, 7782, 176, 5, 29, "Input",
 CellTags->"ChangeDimension"],
Cell[195052, 7789, 301, 10, 25, "Output",
 CellTags->"ChangeDimension"]
}, Open  ]],
Cell[CellGroupData[{
Cell[195390, 7804, 141, 4, 29, "Input",
 CellTags->"ChangeDimension"],
Cell[195534, 7810, 130, 4, 25, "Output",
 CellTags->"ChangeDimension"]
}, Open  ]],
Cell[195679, 7817, 201, 6, 27, "Input",
 CellTags->"ChangeDimension"],
Cell[195883, 7825, 157, 5, 27, "Input",
 CellTags->"ChangeDimension"]
}, Open  ]],
Cell[196055, 7833, 83, 1, 39, "ObjectName",
 CellTags->"ChargeConjugationMatrix"],
Cell[CellGroupData[{
Cell[196163, 7838, 74, 1, 33, "Subsubsection",
 CellTags->"ChargeConjugationMatrix"],
Cell[196240, 7841, 176, 6, 23, "Text",
 CellTags->"ChargeConjugationMatrix"],
Cell[196419, 7849, 248, 9, 23, "Text",
 CellTags->"ChargeConjugationMatrix"]
}, Open  ]],
Cell[CellGroupData[{
Cell[196704, 7863, 71, 1, 33, "Subsubsection",
 CellTags->"ChargeConjugationMatrix"],
Cell[CellGroupData[{
Cell[196800, 7868, 214, 5, 27, "Input",
 CellTags->"ChargeConjugationMatrix"],
Cell[197017, 7875, 306, 11, 25, "Output",
 CellTags->"ChargeConjugationMatrix"]
}, Open  ]],
Cell[CellGroupData[{
Cell[197360, 7891, 120, 3, 27, "Input",
 CellTags->"ChargeConjugationMatrix"],
Cell[197483, 7896, 255, 9, 31, "Output",
 CellTags->"ChargeConjugationMatrix"]
}, Open  ]],
Cell[CellGroupData[{
Cell[197775, 7910, 209, 5, 27, "Input",
 CellTags->"ChargeConjugationMatrix"],
Cell[197987, 7917, 228, 7, 27, "Output",
 CellTags->"ChargeConjugationMatrix"]
}, Open  ]],
Cell[CellGroupData[{
Cell[198252, 7929, 120, 3, 27, "Input",
 CellTags->"ChargeConjugationMatrix"],
Cell[198375, 7934, 192, 6, 29, "Output",
 CellTags->"ChargeConjugationMatrix"]
}, Open  ]],
Cell[CellGroupData[{
Cell[198604, 7945, 134, 3, 27, "Input",
 CellTags->"ChargeConjugationMatrix"],
Cell[198741, 7950, 137, 4, 25, "Output",
 CellTags->"ChargeConjugationMatrix"]
}, Open  ]]
}, Open  ]],
Cell[198905, 7958, 89, 1, 39, "ObjectName",
 CellTags->"ChargeConjugationMatrixInv"],
Cell[CellGroupData[{
Cell[199019, 7963, 77, 1, 33, "Subsubsection",
 CellTags->"ChargeConjugationMatrixInv"],
Cell[199099, 7966, 195, 4, 23, "Text",
 CellTags->"ChargeConjugationMatrixInv"],
Cell[199297, 7972, 242, 9, 23, "Text",
 CellTags->"ChargeConjugationMatrixInv"]
}, Open  ]],
Cell[CellGroupData[{
Cell[199576, 7986, 74, 1, 33, "Subsubsection",
 CellTags->"ChargeConjugationMatrixInv"],
Cell[CellGroupData[{
Cell[199675, 7991, 217, 5, 27, "Input",
 CellTags->"ChargeConjugationMatrixInv"],
Cell[199895, 7998, 309, 11, 25, "Output",
 CellTags->"ChargeConjugationMatrixInv"]
}, Open  ]],
Cell[CellGroupData[{
Cell[200241, 8014, 123, 3, 27, "Input",
 CellTags->"ChargeConjugationMatrixInv"],
Cell[200367, 8019, 258, 9, 31, "Output",
 CellTags->"ChargeConjugationMatrixInv"]
}, Open  ]],
Cell[CellGroupData[{
Cell[200662, 8033, 212, 5, 27, "Input",
 CellTags->"ChargeConjugationMatrixInv"],
Cell[200877, 8040, 231, 7, 27, "Output",
 CellTags->"ChargeConjugationMatrixInv"]
}, Open  ]],
Cell[CellGroupData[{
Cell[201145, 8052, 123, 3, 27, "Input",
 CellTags->"ChargeConjugationMatrixInv"],
Cell[201271, 8057, 195, 6, 29, "Output",
 CellTags->"ChargeConjugationMatrixInv"]
}, Open  ]],
Cell[CellGroupData[{
Cell[201503, 8068, 165, 4, 27, "Input",
 CellTags->"ChargeConjugationMatrixInv"],
Cell[201671, 8074, 189, 6, 25, "Output",
 CellTags->"ChargeConjugationMatrixInv"]
}, Open  ]],
Cell[CellGroupData[{
Cell[201897, 8085, 119, 3, 27, "Input",
 CellTags->"ChargeConjugationMatrixInv"],
Cell[202019, 8090, 164, 5, 25, "Output",
 CellTags->"ChargeConjugationMatrixInv"]
}, Open  ]],
Cell[CellGroupData[{
Cell[202220, 8100, 140, 3, 27, "Input",
 CellTags->"ChargeConjugationMatrixInv"],
Cell[202363, 8105, 140, 4, 25, "Output",
 CellTags->"ChargeConjugationMatrixInv"]
}, Open  ]]
}, Open  ]],
Cell[202530, 8113, 61, 1, 39, "ObjectName",
 CellTags->"CheckContext"],
Cell[CellGroupData[{
Cell[202616, 8118, 63, 1, 33, "Subsubsection",
 CellTags->"CheckContext"],
Cell[202682, 8121, 164, 4, 23, "Text",
 CellTags->"CheckContext"],
Cell[202849, 8127, 320, 14, 23, "Text",
 CellTags->"CheckContext"]
}, Open  ]],
Cell[CellGroupData[{
Cell[203206, 8146, 60, 1, 33, "Subsubsection",
 CellTags->"CheckContext"],
Cell[203269, 8149, 142, 4, 23, "Text",
 CellTags->"CheckContext"],
Cell[CellGroupData[{
Cell[203436, 8157, 138, 3, 27, "Input",
 CellTags->"CheckContext"],
Cell[203577, 8162, 112, 3, 25, "Output",
 CellTags->"CheckContext"]
}, Open  ]],
Cell[203704, 8168, 87, 1, 23, "Text",
 CellTags->"CheckContext"],
Cell[CellGroupData[{
Cell[203816, 8173, 92, 2, 27, "Input",
 CellTags->"CheckContext"],
Cell[203911, 8177, 121, 3, 25, "Output",
 CellTags->"CheckContext"]
}, Open  ]],
Cell[CellGroupData[{
Cell[204069, 8185, 138, 3, 27, "Input",
 CellTags->"CheckContext"],
Cell[204210, 8190, 111, 3, 25, "Output",
 CellTags->"CheckContext"]
}, Open  ]]
}, Open  ]],
Cell[204348, 8197, 51, 1, 39, "ObjectName",
 CellTags->"CheckDB"],
Cell[CellGroupData[{
Cell[204424, 8202, 106, 3, 33, "Subsubsection",
 CellTags->"CheckDB"],
Cell[204533, 8207, 1081, 15, 119, "Text"],
Cell[CellGroupData[{
Cell[205639, 8226, 113, 3, 27, "Input",
 CellTags->"CheckDB"],
Cell[205755, 8231, 471, 14, 25, "Output",
 CellTags->"CheckDB"]
}, Open  ]],
Cell[CellGroupData[{
Cell[206263, 8250, 116, 3, 27, "Input",
 CellTags->"CheckDB"],
Cell[206382, 8255, 134, 4, 25, "Output",
 CellTags->"CheckDB"]
}, Open  ]],
Cell[206531, 8262, 115, 3, 23, "Text"],
Cell[CellGroupData[{
Cell[206671, 8269, 337, 11, 27, "Input"],
Cell[207011, 8282, 178, 5, 21, "Print"],
Cell[207192, 8289, 178, 5, 21, "Print"],
Cell[207373, 8296, 128, 4, 25, "Output"]
}, Open  ]],
Cell[207516, 8303, 133, 3, 23, "Text"],
Cell[CellGroupData[{
Cell[207674, 8310, 383, 13, 27, "Input",
 CellTags->"CheckDB"],
Cell[208060, 8325, 150, 5, 25, "Output",
 CellTags->"CheckDB"]
}, Open  ]],
Cell[208225, 8333, 60, 0, 23, "Text"],
Cell[CellGroupData[{
Cell[208310, 8337, 303, 9, 27, "Input",
 CellTags->"CheckDB"],
Cell[208616, 8348, 116, 3, 25, "Output",
 CellTags->"CheckDB"]
}, Open  ]],
Cell[208747, 8354, 268, 8, 27, "Input",
 CellTags->"CheckDB"]
}, Open  ]],
Cell[209030, 8365, 73, 1, 39, "ObjectName",
 CellTags->"ChiralityProjector"],
Cell[CellGroupData[{
Cell[209128, 8370, 69, 1, 33, "Subsubsection",
 CellTags->"ChiralityProjector"],
Cell[209200, 8373, 499, 19, 25, "Text",
 CellTags->"ChiralityProjector"],
Cell[209702, 8394, 409, 19, 23, "Text",
 CellTags->"ChiralityProjector"]
}, Open  ]],
Cell[CellGroupData[{
Cell[210148, 8418, 66, 1, 33, "Subsubsection",
 CellTags->"ChiralityProjector"],
Cell[CellGroupData[{
Cell[210239, 8423, 262, 8, 27, "Input",
 CellTags->"ChiralityProjector"],
Cell[210504, 8433, 227, 7, 29, "Output",
 CellTags->"ChiralityProjector"]
}, Open  ]],
Cell[CellGroupData[{
Cell[210768, 8445, 114, 3, 27, "Input",
 CellTags->"ChiralityProjector"],
Cell[210885, 8450, 227, 7, 29, "Output",
 CellTags->"ChiralityProjector"]
}, Open  ]],
Cell[CellGroupData[{
Cell[211149, 8462, 196, 5, 27, "Input",
 CellTags->"ChiralityProjector"],
Cell[211348, 8469, 380, 14, 46, "Output",
 CellTags->"ChiralityProjector"]
}, Open  ]]
}, Open  ]],
Cell[211755, 8487, 53, 1, 39, "ObjectName",
 CellTags->"Chisholm"],
Cell[CellGroupData[{
Cell[211833, 8492, 59, 1, 33, "Subsubsection",
 CellTags->"Chisholm"],
Cell[211895, 8495, 142, 4, 23, "Text",
 CellTags->"Chisholm"],
Cell[212040, 8501, 316, 14, 23, "Text",
 CellTags->"Chisholm"]
}, Open  ]],
Cell[CellGroupData[{
Cell[212393, 8520, 56, 1, 33, "Subsubsection",
 CellTags->"Chisholm"],
Cell[CellGroupData[{
Cell[212474, 8525, 206, 6, 27, "Input",
 CellTags->"Chisholm"],
Cell[212683, 8533, 2020, 78, 27, "Output",
 CellTags->"Chisholm"]
}, Open  ]],
Cell[CellGroupData[{
Cell[214740, 8616, 183, 5, 27, "Input",
 CellTags->"Chisholm"],
Cell[214926, 8623, 236, 7, 25, "Output",
 CellTags->"Chisholm"]
}, Open  ]],
Cell[CellGroupData[{
Cell[215199, 8635, 139, 4, 27, "Input",
 CellTags->"Chisholm"],
Cell[215341, 8641, 1374, 54, 27, "Output",
 CellTags->"Chisholm"]
}, Open  ]],
Cell[216730, 8698, 77, 1, 23, "Text",
 CellTags->"Chisholm"],
Cell[CellGroupData[{
Cell[216832, 8703, 130, 4, 27, "Input",
 CellTags->"Chisholm"],
Cell[216965, 8709, 105, 3, 25, "Output",
 CellTags->"Chisholm"]
}, Open  ]],
Cell[CellGroupData[{
Cell[217107, 8717, 139, 4, 27, "Input",
 CellTags->"Chisholm"],
Cell[217249, 8723, 1374, 54, 27, "Output",
 CellTags->"Chisholm"]
}, Open  ]],
Cell[CellGroupData[{
Cell[218660, 8782, 130, 4, 27, "Input",
 CellTags->"Chisholm"],
Cell[218793, 8788, 105, 3, 25, "Output",
 CellTags->"Chisholm"]
}, Open  ]],
Cell[CellGroupData[{
Cell[218935, 8796, 169, 5, 27, "Input",
 CellTags->"Chisholm"],
Cell[219107, 8803, 590, 22, 25, "Output",
 CellTags->"Chisholm"]
}, Open  ]],
Cell[CellGroupData[{
Cell[219734, 8830, 110, 3, 27, "Input",
 CellTags->"Chisholm"],
Cell[219847, 8835, 1439, 57, 27, "Output",
 CellTags->"Chisholm"]
}, Open  ]],
Cell[CellGroupData[{
Cell[221323, 8897, 232, 7, 27, "Input",
 CellTags->"Chisholm"],
Cell[221558, 8906, 391, 10, 25, "Output",
 CellTags->"Chisholm"]
}, Open  ]],
Cell[CellGroupData[{
Cell[221986, 8921, 139, 4, 27, "Input",
 CellTags->"Chisholm"],
Cell[222128, 8927, 11544, 439, 87, "Output",
 CellTags->"Chisholm"]
}, Open  ]],
Cell[CellGroupData[{
Cell[233709, 9371, 139, 4, 27, "Input",
 CellTags->"Chisholm"],
Cell[233851, 9377, 11544, 439, 87, "Output",
 CellTags->"Chisholm"]
}, Open  ]],
Cell[245410, 9819, 85, 1, 23, "Text",
 CellTags->"Chisholm"],
Cell[CellGroupData[{
Cell[245520, 9824, 130, 4, 27, "Input",
 CellTags->"Chisholm"],
Cell[245653, 9830, 125, 4, 25, "Output",
 CellTags->"Chisholm"]
}, Open  ]],
Cell[CellGroupData[{
Cell[245815, 9839, 130, 4, 27, "Input",
 CellTags->"Chisholm"],
Cell[245948, 9845, 125, 4, 25, "Output",
 CellTags->"Chisholm"]
}, Open  ]],
Cell[246088, 9852, 192, 6, 27, "Input",
 CellTags->"Chisholm"]
}, Open  ]],
Cell[246295, 9861, 65, 1, 39, "ObjectName",
 CellTags->"ChisholmSpinor"],
Cell[CellGroupData[{
Cell[246385, 9866, 65, 1, 33, "Subsubsection",
 CellTags->"ChisholmSpinor"],
Cell[246453, 9869, 296, 6, 39, "Text",
 CellTags->"ChisholmSpinor"],
Cell[246752, 9877, 304, 14, 23, "Text",
 CellTags->"ChisholmSpinor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[247093, 9896, 62, 1, 33, "Subsubsection",
 CellTags->"ChisholmSpinor"],
Cell[CellGroupData[{
Cell[247180, 9901, 312, 9, 27, "Input",
 CellTags->"ChisholmSpinor"],
Cell[247495, 9912, 427, 15, 25, "Output",
 CellTags->"ChisholmSpinor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[247959, 9932, 117, 3, 27, "Input",
 CellTags->"ChisholmSpinor"],
Cell[248079, 9937, 2686, 99, 93, "Output",
 CellTags->"ChisholmSpinor"]
}, Open  ]]
}, Open  ]],
Cell[250792, 10040, 75, 1, 39, "ObjectName",
 CellTags->"ClearScalarProducts"],
Cell[CellGroupData[{
Cell[250892, 10045, 70, 1, 33, "Subsubsection",
 CellTags->"ClearScalarProducts"],
Cell[250965, 10048, 145, 4, 23, "Text",
 CellTags->"ClearScalarProducts"],
Cell[251113, 10054, 484, 23, 23, "Text",
 CellTags->"ClearScalarProducts"]
}, Open  ]],
Cell[CellGroupData[{
Cell[251634, 10082, 67, 1, 33, "Subsubsection",
 CellTags->"ClearScalarProducts"],
Cell[CellGroupData[{
Cell[251726, 10087, 195, 6, 27, "Input",
 CellTags->"ClearScalarProducts"],
Cell[251924, 10095, 139, 4, 27, "Output",
 CellTags->"ClearScalarProducts"]
}, Open  ]],
Cell[CellGroupData[{
Cell[252100, 10104, 211, 6, 27, "Input",
 CellTags->"ClearScalarProducts"],
Cell[252314, 10112, 139, 4, 27, "Output",
 CellTags->"ClearScalarProducts"]
}, Open  ]],
Cell[252468, 10119, 104, 2, 27, "Input",
 CellTags->"ClearScalarProducts"],
Cell[CellGroupData[{
Cell[252597, 10125, 211, 6, 27, "Input",
 CellTags->"ClearScalarProducts"],
Cell[252811, 10133, 173, 6, 27, "Output",
 CellTags->"ClearScalarProducts"]
}, Open  ]],
Cell[CellGroupData[{
Cell[253021, 10144, 148, 4, 27, "Input",
 CellTags->"ClearScalarProducts"],
Cell[253172, 10150, 173, 6, 27, "Output",
 CellTags->"ClearScalarProducts"]
}, Open  ]]
}, Open  ]],
Cell[253372, 10160, 57, 1, 39, "ObjectName",
 CellTags->"Collecting"],
Cell[CellGroupData[{
Cell[253454, 10165, 61, 1, 33, "Subsubsection",
 CellTags->"Collecting"],
Cell[253518, 10168, 207, 5, 23, "Text",
 CellTags->"Collecting"],
Cell[253728, 10175, 411, 18, 23, "Text",
 CellTags->"Collecting"]
}, Open  ]],
Cell[254154, 10196, 53, 1, 39, "ObjectName",
 CellTags->"Collect2"],
Cell[CellGroupData[{
Cell[254232, 10201, 59, 1, 33, "Subsubsection",
 CellTags->"Collect2"],
Cell[254294, 10204, 613, 10, 71, "Text",
 CellTags->"Collect2"],
Cell[CellGroupData[{
Cell[254932, 10218, 115, 3, 27, "Input",
 CellTags->"Collect2"],
Cell[255050, 10223, 398, 11, 25, "Output",
 CellTags->"Collect2"]
}, Open  ]],
Cell[255463, 10237, 176, 9, 23, "Text",
 CellTags->"Collect2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[255676, 10251, 56, 1, 33, "Subsubsection",
 CellTags->"Collect2"],
Cell[CellGroupData[{
Cell[255757, 10256, 440, 14, 40, "Input",
 CellTags->"Collect2"],
Cell[256200, 10272, 451, 16, 44, "Output",
 CellTags->"Collect2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[256688, 10293, 185, 5, 27, "Input",
 CellTags->"Collect2"],
Cell[256876, 10300, 399, 14, 40, "Output",
 CellTags->"Collect2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[257312, 10319, 186, 5, 27, "Input",
 CellTags->"Collect2"],
Cell[257501, 10326, 451, 16, 44, "Output",
 CellTags->"Collect2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[257989, 10347, 525, 18, 29, "Input",
 CellTags->"Collect2"],
Cell[258517, 10367, 537, 18, 27, "Output",
 CellTags->"Collect2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[259091, 10390, 320, 10, 29, "Input",
 CellTags->"Collect2"],
Cell[259414, 10402, 820, 31, 27, "Output",
 CellTags->"Collect2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[260271, 10438, 112, 3, 27, "Input",
 CellTags->"Collect2"],
Cell[260386, 10443, 825, 27, 27, "Output",
 CellTags->"Collect2"]
}, Open  ]],
Cell[261226, 10473, 130, 4, 27, "Input",
 CellTags->"Collect2"],
Cell[CellGroupData[{
Cell[261381, 10481, 305, 9, 29, "Input",
 CellTags->"Collect2"],
Cell[261689, 10492, 935, 31, 29, "Output",
 CellTags->"Collect2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[262661, 10528, 149, 4, 27, "Input",
 CellTags->"Collect2"],
Cell[262813, 10534, 671, 21, 29, "Output",
 CellTags->"Collect2"]
}, Open  ]]
}, Open  ]],
Cell[263511, 10559, 53, 1, 39, "ObjectName",
 CellTags->"Collect3"],
Cell[CellGroupData[{
Cell[263589, 10564, 59, 1, 33, "Subsubsection",
 CellTags->"Collect3"],
Cell[263651, 10567, 719, 23, 39, "Text",
 CellTags->"Collect3"],
Cell[CellGroupData[{
Cell[264395, 10594, 115, 3, 27, "Input",
 CellTags->"Collect3"],
Cell[264513, 10599, 233, 8, 25, "Output",
 CellTags->"Collect3"]
}, Open  ]],
Cell[264761, 10610, 286, 14, 23, "Text",
 CellTags->"Collect3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[265084, 10629, 56, 1, 33, "Subsubsection",
 CellTags->"Collect3"],
Cell[CellGroupData[{
Cell[265165, 10634, 525, 18, 29, "Input",
 CellTags->"Collect3"],
Cell[265693, 10654, 548, 19, 27, "Output",
 CellTags->"Collect3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[266278, 10678, 289, 9, 29, "Input",
 CellTags->"Collect3"],
Cell[266570, 10689, 4614, 134, 136, "Output",
 CellTags->"Collect3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[271221, 10828, 314, 9, 29, "Input"],
Cell[271538, 10839, 802, 26, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[272367, 10869, 51, 1, 39, "ObjectName",
 CellTags->"Combine"],
Cell[CellGroupData[{
Cell[272443, 10874, 58, 1, 33, "Subsubsection",
 CellTags->"Combine"],
Cell[272504, 10877, 315, 6, 39, "Text",
 CellTags->"Combine"],
Cell[CellGroupData[{
Cell[272844, 10887, 113, 3, 27, "Input",
 CellTags->"Combine"],
Cell[272960, 10892, 171, 6, 25, "Output",
 CellTags->"Combine"]
}, Open  ]],
Cell[273146, 10901, 175, 9, 23, "Text",
 CellTags->"Combine"]
}, Open  ]],
Cell[CellGroupData[{
Cell[273358, 10915, 55, 1, 33, "Subsubsection",
 CellTags->"Combine"],
Cell[CellGroupData[{
Cell[273438, 10920, 283, 10, 42, "Input",
 CellTags->"Combine"],
Cell[273724, 10932, 304, 11, 43, "Output",
 CellTags->"Combine"]
}, Open  ]],
Cell[274043, 10946, 122, 3, 23, "Text",
 CellTags->"Combine"],
Cell[CellGroupData[{
Cell[274190, 10953, 284, 10, 42, "Input",
 CellTags->"Combine"],
Cell[274477, 10965, 303, 10, 43, "Output",
 CellTags->"Combine"]
}, Open  ]],
Cell[274795, 10978, 175, 4, 23, "Text",
 CellTags->"Combine"],
Cell[CellGroupData[{
Cell[274995, 10986, 354, 12, 42, "Input",
 CellTags->"Combine"],
Cell[275352, 11000, 303, 10, 43, "Output",
 CellTags->"Combine"]
}, Open  ]]
}, Open  ]],
Cell[275682, 11014, 63, 1, 39, "ObjectName",
 CellTags->"CombineGraphs"],
Cell[CellGroupData[{
Cell[275770, 11019, 64, 1, 33, "Subsubsection",
 CellTags->"CombineGraphs"],
Cell[275837, 11022, 86, 1, 23, "Text",
 CellTags->"CombineGraphs"],
Cell[275926, 11025, 185, 8, 23, "Text",
 CellTags->"CombineGraphs"]
}, Open  ]],
Cell[276126, 11036, 57, 1, 39, "ObjectName",
 CellTags->"Commutator"],
Cell[CellGroupData[{
Cell[276208, 11041, 61, 1, 33, "Subsubsection",
 CellTags->"Commutator"],
Cell[276272, 11044, 138, 4, 23, "Text",
 CellTags->"Commutator"],
Cell[276413, 11050, 607, 24, 23, "Text",
 CellTags->"Commutator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[277057, 11079, 58, 1, 33, "Subsubsection",
 CellTags->"Commutator"],
Cell[277118, 11082, 167, 4, 27, "Input",
 CellTags->"Commutator"],
Cell[CellGroupData[{
Cell[277310, 11090, 136, 4, 27, "Input",
 CellTags->"Commutator"],
Cell[277449, 11096, 184, 5, 25, "Output",
 CellTags->"Commutator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[277670, 11106, 121, 3, 27, "Input",
 CellTags->"Commutator"],
Cell[277794, 11111, 177, 6, 25, "Output",
 CellTags->"Commutator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[278008, 11122, 247, 8, 27, "Input",
 CellTags->"Commutator"],
Cell[278258, 11132, 381, 12, 25, "Output",
 CellTags->"Commutator"]
}, Open  ]],
Cell[278654, 11147, 169, 4, 27, "Input",
 CellTags->"Commutator"],
Cell[278826, 11153, 68, 1, 23, "Text",
 CellTags->"Commutator"],
Cell[278897, 11156, 228, 6, 27, "Input",
 CellTags->"Commutator"],
Cell[CellGroupData[{
Cell[279150, 11166, 463, 15, 27, "Input",
 CellTags->"Commutator"],
Cell[279616, 11183, 727, 19, 25, "Output",
 CellTags->"Commutator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[280380, 11207, 114, 3, 27, "Input",
 CellTags->"Commutator"],
Cell[280497, 11212, 106, 3, 25, "Output",
 CellTags->"Commutator"]
}, Open  ]],
Cell[280618, 11218, 113, 3, 27, "Input",
 CellTags->"Commutator"],
Cell[280734, 11223, 159, 4, 27, "Input",
 CellTags->"Commutator"]
}, Open  ]],
Cell[280908, 11230, 73, 1, 39, "ObjectName",
 CellTags->"CommutatorExplicit"],
Cell[CellGroupData[{
Cell[281006, 11235, 69, 1, 33, "Subsubsection",
 CellTags->"CommutatorExplicit"],
Cell[281078, 11238, 157, 4, 23, "Text",
 CellTags->"CommutatorExplicit"],
Cell[281238, 11244, 296, 14, 23, "Text",
 CellTags->"CommutatorExplicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[281571, 11263, 66, 1, 33, "Subsubsection",
 CellTags->"CommutatorExplicit"],
Cell[281640, 11266, 175, 4, 27, "Input",
 CellTags->"CommutatorExplicit"],
Cell[CellGroupData[{
Cell[281840, 11274, 144, 4, 27, "Input",
 CellTags->"CommutatorExplicit"],
Cell[281987, 11280, 192, 5, 25, "Output",
 CellTags->"CommutatorExplicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[282216, 11290, 129, 3, 27, "Input",
 CellTags->"CommutatorExplicit"],
Cell[282348, 11295, 185, 6, 25, "Output",
 CellTags->"CommutatorExplicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[282570, 11306, 196, 6, 27, "Input",
 CellTags->"CommutatorExplicit"],
Cell[282769, 11314, 283, 10, 25, "Output",
 CellTags->"CommutatorExplicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[283089, 11329, 129, 3, 27, "Input",
 CellTags->"CommutatorExplicit"],
Cell[283221, 11334, 389, 14, 25, "Output",
 CellTags->"CommutatorExplicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[283647, 11353, 167, 5, 27, "Input",
 CellTags->"CommutatorExplicit"],
Cell[283817, 11360, 389, 12, 25, "Output",
 CellTags->"CommutatorExplicit"]
}, Open  ]],
Cell[284221, 11375, 177, 4, 27, "Input",
 CellTags->"CommutatorExplicit"]
}, Open  ]],
Cell[284413, 11382, 65, 1, 39, "ObjectName",
 CellTags->"CompleteSquare"],
Cell[CellGroupData[{
Cell[284503, 11387, 65, 1, 33, "Subsubsection",
 CellTags->"CompleteSquare"],
Cell[284571, 11390, 1107, 82, 39, "Text",
 CellTags->"CompleteSquare"]
}, Open  ]],
Cell[CellGroupData[{
Cell[285715, 11477, 62, 1, 33, "Subsubsection",
 CellTags->"CompleteSquare"],
Cell[CellGroupData[{
Cell[285802, 11482, 277, 10, 27, "Input"],
Cell[286082, 11494, 337, 12, 25, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[286456, 11511, 170, 5, 27, "Input",
 CellTags->"CompleteSquare"],
Cell[286629, 11518, 685, 27, 46, "Output",
 CellTags->"CompleteSquare"]
}, Open  ]],
Cell[CellGroupData[{
Cell[287351, 11550, 180, 6, 27, "Input",
 CellTags->"CompleteSquare"],
Cell[287534, 11558, 110, 3, 25, "Output",
 CellTags->"CompleteSquare"]
}, Open  ]],
Cell[CellGroupData[{
Cell[287681, 11566, 155, 4, 27, "Input",
 CellTags->"CompleteSquare"],
Cell[287839, 11572, 515, 20, 46, "Output",
 CellTags->"CompleteSquare"]
}, Open  ]],
Cell[288369, 11595, 137, 4, 27, "Input",
 CellTags->"CompleteSquare"]
}, Open  ]],
Cell[288521, 11602, 69, 1, 39, "ObjectName",
 CellTags->"ComplexConjugate"],
Cell[CellGroupData[{
Cell[288615, 11607, 67, 1, 33, "Subsubsection",
 CellTags->"ComplexConjugate"],
Cell[288685, 11610, 414, 7, 55, "Text",
 CellTags->"ComplexConjugate"],
Cell[289102, 11619, 449, 19, 23, "Text",
 CellTags->"ComplexConjugate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[289588, 11643, 64, 1, 33, "Subsubsection",
 CellTags->"ComplexConjugate"],
Cell[CellGroupData[{
Cell[289677, 11648, 196, 5, 27, "Input",
 CellTags->"ComplexConjugate"],
Cell[289876, 11655, 163, 5, 25, "Output",
 CellTags->"ComplexConjugate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[290076, 11665, 121, 3, 27, "Input",
 CellTags->"ComplexConjugate"],
Cell[290200, 11670, 239, 6, 39, "Output",
 CellTags->"ComplexConjugate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[290476, 11681, 152, 4, 27, "Input",
 CellTags->"ComplexConjugate"],
Cell[290631, 11687, 249, 7, 27, "Output",
 CellTags->"ComplexConjugate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[290917, 11699, 125, 3, 27, "Input",
 CellTags->"ComplexConjugate"],
Cell[291045, 11704, 427, 16, 27, "Output",
 CellTags->"ComplexConjugate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[291509, 11725, 182, 5, 27, "Input",
 CellTags->"ComplexConjugate"],
Cell[291694, 11732, 531, 22, 25, "Output",
 CellTags->"ComplexConjugate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[292262, 11759, 125, 3, 27, "Input",
 CellTags->"ComplexConjugate"],
Cell[292390, 11764, 531, 22, 25, "Output",
 CellTags->"ComplexConjugate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[292958, 11791, 190, 5, 27, "Input",
 CellTags->"ComplexConjugate"],
Cell[293151, 11798, 380, 17, 27, "Output",
 CellTags->"ComplexConjugate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[293568, 11820, 270, 7, 27, "Input",
 CellTags->"ComplexConjugate"],
Cell[293841, 11829, 157, 4, 39, "Output",
 CellTags->"ComplexConjugate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[294035, 11838, 273, 8, 27, "Input",
 CellTags->"ComplexConjugate"],
Cell[294311, 11848, 335, 10, 25, "Output",
 CellTags->"ComplexConjugate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[294683, 11863, 125, 3, 27, "Input",
 CellTags->"ComplexConjugate"],
Cell[294811, 11868, 431, 15, 25, "Output",
 CellTags->"ComplexConjugate"]
}, Open  ]],
Cell[295257, 11886, 166, 4, 23, "Text",
 CellTags->"ComplexConjugate"]
}, Open  ]],
Cell[295438, 11893, 53, 1, 39, "ObjectName",
 CellTags->"Contract"],
Cell[CellGroupData[{
Cell[295516, 11898, 59, 1, 33, "Subsubsection",
 CellTags->"Contract"],
Cell[295578, 11901, 411, 7, 55, "Text",
 CellTags->"Contract"],
Cell[CellGroupData[{
Cell[296014, 11912, 115, 3, 27, "Input",
 CellTags->"Contract"],
Cell[296132, 11917, 612, 15, 45, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[296759, 11935, 138, 3, 23, "Text"],
Cell[296900, 11940, 423, 19, 23, "Text",
 CellTags->"Contract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[297360, 11964, 56, 1, 33, "Subsubsection",
 CellTags->"Contract"],
Cell[CellGroupData[{
Cell[297441, 11969, 233, 7, 27, "Input",
 CellTags->"Contract"],
Cell[297677, 11978, 207, 7, 28, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[297921, 11990, 109, 3, 27, "Input",
 CellTags->"Contract"],
Cell[298033, 11995, 236, 10, 25, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[298306, 12010, 199, 6, 27, "Input",
 CellTags->"Contract"],
Cell[298508, 12018, 264, 10, 28, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[298809, 12033, 109, 3, 27, "Input",
 CellTags->"Contract"],
Cell[298921, 12038, 221, 8, 25, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[299179, 12051, 144, 4, 27, "Input",
 CellTags->"Contract"],
Cell[299326, 12057, 155, 5, 25, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[299496, 12065, 83, 1, 23, "Text",
 CellTags->"Contract"],
Cell[CellGroupData[{
Cell[299604, 12070, 109, 3, 27, "Input",
 CellTags->"Contract"],
Cell[299716, 12075, 104, 3, 25, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[299835, 12081, 208, 5, 39, "Text",
 CellTags->"Contract"],
Cell[CellGroupData[{
Cell[300068, 12090, 231, 7, 27, "Input",
 CellTags->"Contract"],
Cell[300302, 12099, 233, 8, 25, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[300572, 12112, 109, 3, 27, "Input",
 CellTags->"Contract"],
Cell[300684, 12117, 104, 3, 25, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[300825, 12125, 231, 7, 27, "Input",
 CellTags->"Contract"],
Cell[301059, 12134, 233, 8, 25, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[301329, 12147, 227, 7, 27, "Input",
 CellTags->"Contract"],
Cell[301559, 12156, 181, 6, 28, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[301777, 12167, 114, 3, 27, "Input",
 CellTags->"Contract"],
Cell[301894, 12172, 206, 8, 25, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[302137, 12185, 277, 9, 27, "Input",
 CellTags->"Contract"],
Cell[302417, 12196, 427, 18, 28, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[302881, 12219, 109, 3, 27, "Input",
 CellTags->"Contract"],
Cell[302993, 12224, 575, 24, 25, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[303605, 12253, 271, 8, 27, "Input",
 CellTags->"Contract"],
Cell[303879, 12263, 555, 23, 25, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[304471, 12291, 109, 3, 27, "Input",
 CellTags->"Contract"],
Cell[304583, 12296, 439, 19, 25, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[305059, 12320, 313, 9, 27, "Input",
 CellTags->"Contract"],
Cell[305375, 12331, 922, 40, 25, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[306334, 12376, 109, 3, 27, "Input",
 CellTags->"Contract"],
Cell[306446, 12381, 204, 7, 25, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[306687, 12393, 426, 13, 27, "Input",
 CellTags->"Contract"],
Cell[307116, 12408, 301, 9, 25, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[307454, 12422, 139, 4, 27, "Input",
 CellTags->"Contract"],
Cell[307596, 12428, 352, 12, 25, "Output",
 CellTags->"Contract"]
}, Open  ]],
Cell[307963, 12443, 194, 6, 27, "Input",
 CellTags->"Contract"]
}, Open  ]],
Cell[308172, 12452, 55, 1, 39, "ObjectName",
 CellTags->"Contract1"],
Cell[CellGroupData[{
Cell[308252, 12457, 60, 1, 33, "Subsubsection",
 CellTags->"Contract1"],
Cell[308315, 12460, 459, 8, 95, "Text",
 CellTags->"Contract1"],
Cell[308777, 12470, 389, 18, 23, "Text",
 CellTags->"Contract1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[309203, 12493, 57, 1, 33, "Subsubsection",
 CellTags->"Contract1"],
Cell[CellGroupData[{
Cell[309285, 12498, 349, 12, 27, "Input",
 CellTags->"Contract1"],
Cell[309637, 12512, 207, 8, 25, "Output",
 CellTags->"Contract1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[309881, 12525, 349, 12, 27, "Input",
 CellTags->"Contract1"],
Cell[310233, 12539, 478, 20, 27, "Output",
 CellTags->"Contract1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[310748, 12564, 269, 9, 27, "Input",
 CellTags->"Contract1"],
Cell[311020, 12575, 105, 3, 25, "Output",
 CellTags->"Contract1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[311162, 12583, 269, 9, 27, "Input",
 CellTags->"Contract1"],
Cell[311434, 12594, 298, 11, 27, "Output",
 CellTags->"Contract1"]
}, Open  ]]
}, Open  ]],
Cell[311759, 12609, 55, 1, 39, "ObjectName",
 CellTags->"Convolute"],
Cell[CellGroupData[{
Cell[311839, 12614, 60, 1, 33, "Subsubsection",
 CellTags->"Convolute"],
Cell[311902, 12617, 1363, 49, 61, "Text",
 CellTags->"Convolute"],
Cell[CellGroupData[{
Cell[313290, 12670, 117, 3, 27, "Input",
 CellTags->"Convolute"],
Cell[313410, 12675, 400, 13, 25, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[313825, 12691, 332, 14, 23, "Text",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[314194, 12710, 57, 1, 33, "Subsubsection",
 CellTags->"Convolute"],
Cell[CellGroupData[{
Cell[314276, 12715, 134, 4, 27, "Input",
 CellTags->"Convolute"],
Cell[314413, 12721, 154, 5, 25, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[314604, 12731, 134, 4, 27, "Input",
 CellTags->"Convolute"],
Cell[314741, 12737, 178, 6, 25, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[314956, 12748, 134, 4, 27, "Input",
 CellTags->"Convolute"],
Cell[315093, 12754, 128, 4, 25, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[315258, 12763, 181, 6, 42, "Input",
 CellTags->"Convolute"],
Cell[315442, 12771, 215, 7, 25, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[315694, 12783, 227, 7, 42, "Input",
 CellTags->"Convolute"],
Cell[315924, 12792, 215, 7, 25, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[316176, 12804, 181, 6, 42, "Input",
 CellTags->"Convolute"],
Cell[316360, 12812, 307, 11, 25, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[316704, 12828, 228, 8, 42, "Input",
 CellTags->"Convolute"],
Cell[316935, 12838, 536, 19, 43, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[317508, 12862, 190, 6, 27, "Input",
 CellTags->"Convolute"],
Cell[317701, 12870, 321, 11, 25, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[318059, 12886, 216, 7, 27, "Input",
 CellTags->"Convolute"],
Cell[318278, 12895, 273, 10, 25, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[318588, 12910, 237, 8, 42, "Input",
 CellTags->"Convolute"],
Cell[318828, 12920, 389, 13, 27, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[319254, 12938, 263, 9, 42, "Input",
 CellTags->"Convolute"],
Cell[319520, 12949, 617, 21, 27, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[320174, 12975, 239, 8, 42, "Input",
 CellTags->"Convolute"],
Cell[320416, 12985, 717, 24, 43, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[321170, 13014, 190, 6, 27, "Input",
 CellTags->"Convolute"],
Cell[321363, 13022, 245, 9, 25, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[321645, 13036, 190, 6, 27, "Input",
 CellTags->"Convolute"],
Cell[321838, 13044, 317, 11, 25, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[322192, 13060, 260, 9, 42, "Input",
 CellTags->"Convolute"],
Cell[322455, 13071, 452, 16, 48, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[322944, 13092, 165, 5, 27, "Input",
 CellTags->"Convolute"],
Cell[323112, 13099, 229, 9, 43, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[323378, 13113, 195, 6, 27, "Input",
 CellTags->"Convolute"],
Cell[323576, 13121, 239, 9, 43, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[323852, 13135, 212, 7, 42, "Input",
 CellTags->"Convolute"],
Cell[324067, 13144, 416, 14, 43, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[324520, 13163, 213, 7, 42, "Input",
 CellTags->"Convolute"],
Cell[324736, 13172, 316, 12, 43, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[325089, 13189, 237, 8, 42, "Input",
 CellTags->"Convolute"],
Cell[325329, 13199, 550, 18, 43, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[325916, 13222, 213, 7, 42, "Input",
 CellTags->"Convolute"],
Cell[326132, 13231, 409, 13, 43, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[326578, 13249, 190, 6, 27, "Input",
 CellTags->"Convolute"],
Cell[326771, 13257, 245, 9, 25, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[327053, 13271, 165, 5, 27, "Input",
 CellTags->"Convolute"],
Cell[327221, 13278, 188, 6, 25, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[327446, 13289, 286, 10, 42, "Input",
 CellTags->"Convolute"],
Cell[327735, 13301, 790, 29, 48, "Output",
 CellTags->"Convolute"]
}, Open  ]],
Cell[CellGroupData[{
Cell[328562, 13335, 295, 10, 42, "Input",
 CellTags->"Convolute"],
Cell[328860, 13347, 1193, 41, 64, "Output",
 CellTags->"Convolute"]
}, Open  ]]
}, Open  ]],
Cell[330080, 13392, 66, 1, 39, "ObjectName",
 CellTags->"ConvoluteTable"],
Cell[CellGroupData[{
Cell[330171, 13397, 65, 1, 33, "Subsubsection",
 CellTags->"ConvoluteTable"],
Cell[330239, 13400, 152, 4, 23, "Text",
 CellTags->"ConvoluteTable"],
Cell[CellGroupData[{
Cell[330416, 13408, 122, 3, 27, "Input",
 CellTags->"ConvoluteTable"],
Cell[330541, 13413, 405, 13, 25, "Output",
 CellTags->"ConvoluteTable"]
}, Open  ]],
Cell[330961, 13429, 322, 14, 23, "Text",
 CellTags->"ConvoluteTable"]
}, Open  ]],
Cell[CellGroupData[{
Cell[331320, 13448, 62, 1, 33, "Subsubsection",
 CellTags->"ConvoluteTable"],
Cell[CellGroupData[{
Cell[331407, 13453, 144, 4, 27, "Input",
 CellTags->"ConvoluteTable"],
Cell[331554, 13459, 159, 5, 25, "Output",
 CellTags->"ConvoluteTable"]
}, Open  ]],
Cell[CellGroupData[{
Cell[331750, 13469, 144, 4, 27, "Input",
 CellTags->"ConvoluteTable"],
Cell[331897, 13475, 183, 6, 25, "Output",
 CellTags->"ConvoluteTable"]
}, Open  ]],
Cell[CellGroupData[{
Cell[332117, 13486, 144, 4, 27, "Input",
 CellTags->"ConvoluteTable"],
Cell[332264, 13492, 133, 4, 25, "Output",
 CellTags->"ConvoluteTable"]
}, Open  ]],
Cell[CellGroupData[{
Cell[332434, 13501, 244, 8, 42, "Input",
 CellTags->"Convolute"],
Cell[332681, 13511, 463, 16, 43, "Output",
 CellTags->"Convolute"]
}, Open  ]]
}, Open  ]],
Cell[333171, 13531, 85, 1, 39, "ObjectName",
 CellTags->"CovariantFieldDerivative"],
Cell[CellGroupData[{
Cell[333281, 13536, 75, 1, 33, "Subsubsection",
 CellTags->"CovariantFieldDerivative"],
Cell[333359, 13539, 372, 6, 39, "Text",
 CellTags->"CovariantFieldDerivative"],
Cell[333734, 13547, 460, 19, 23, "Text",
 CellTags->"CovariantFieldDerivative"]
}, Open  ]],
Cell[CellGroupData[{
Cell[334231, 13571, 72, 1, 33, "Subsubsection",
 CellTags->"CovariantFieldDerivative"],
Cell[CellGroupData[{
Cell[334328, 13576, 329, 9, 27, "Input",
 CellTags->"CovariantFieldDerivative"],
Cell[334660, 13587, 543, 21, 28, "Output",
 CellTags->"CovariantFieldDerivative"]
}, Open  ]]
}, Open  ]],
Cell[335230, 13612, 53, 1, 39, "ObjectName",
 CellTags->"CounterT"],
Cell[CellGroupData[{
Cell[335308, 13617, 59, 1, 33, "Subsubsection",
 CellTags->"CounterT"],
Cell[335370, 13620, 146, 4, 23, "Text",
 CellTags->"CounterT"],
Cell[335519, 13626, 450, 19, 23, "Text",
 CellTags->"CounterT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[336006, 13650, 56, 1, 33, "Subsubsection",
 CellTags->"CounterT"],
Cell[CellGroupData[{
Cell[336087, 13655, 284, 6, 27, "Input",
 CellTags->"CounterT"],
Cell[336374, 13663, 3127, 106, 59, "Output",
 CellTags->"CounterT"]
}, Open  ]]
}, Open  ]],
Cell[339528, 13773, 59, 1, 39, "ObjectName",
 CellTags->"CounterTerm"],
Cell[CellGroupData[{
Cell[339612, 13778, 62, 1, 33, "Subsubsection",
 CellTags->"CounterTerm"],
Cell[339677, 13781, 216, 5, 39, "Text",
 CellTags->"CounterTerm"],
Cell[339896, 13788, 578, 24, 23, "Text",
 CellTags->"CounterTerm"]
}, Open  ]],
Cell[CellGroupData[{
Cell[340511, 13817, 59, 1, 33, "Subsubsection",
 CellTags->"CounterTerm"],
Cell[CellGroupData[{
Cell[340595, 13822, 116, 3, 27, "Input",
 CellTags->"CounterTerm"],
Cell[340714, 13827, 1632, 52, 63, "Output",
 CellTags->"CounterTerm"]
}, Open  ]]
}, Open  ]],
Cell[342373, 13883, 69, 1, 39, "ObjectName",
 CellTags->"CouplingConstant"],
Cell[CellGroupData[{
Cell[342467, 13888, 67, 1, 33, "Subsubsection",
 CellTags->"CouplingConstant"],
Cell[342537, 13891, 657, 11, 95, "Text",
 CellTags->"CouplingConstant"],
Cell[343197, 13904, 318, 14, 23, "Text",
 CellTags->"CouplingConstant"]
}, Open  ]],
Cell[343530, 13921, 57, 1, 39, "ObjectName",
 CellTags->"CovariantD"],
Cell[CellGroupData[{
Cell[343612, 13926, 61, 1, 33, "Subsubsection",
 CellTags->"CovariantD"],
Cell[343676, 13929, 1210, 18, 175, "Text",
 CellTags->"CovariantD"],
Cell[CellGroupData[{
Cell[344911, 13951, 119, 3, 27, "Input",
 CellTags->"CovariantD"],
Cell[345033, 13956, 439, 12, 25, "Output",
 CellTags->"CovariantD"]
}, Open  ]],
Cell[345487, 13971, 185, 4, 23, "Text",
 CellTags->"CovariantD"],
Cell[345675, 13977, 455, 19, 23, "Text",
 CellTags->"CovariantD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[346167, 14001, 58, 1, 33, "Subsubsection",
 CellTags->"CovariantD"],
Cell[CellGroupData[{
Cell[346250, 14006, 117, 3, 27, "Input",
 CellTags->"CovariantD"],
Cell[346370, 14011, 132, 4, 28, "Output",
 CellTags->"CovariantD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[346539, 14020, 150, 4, 27, "Input",
 CellTags->"CovariantD"],
Cell[346692, 14026, 161, 5, 31, "Output",
 CellTags->"CovariantD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[346890, 14036, 180, 5, 27, "Input",
 CellTags->"CovariantD"],
Cell[347073, 14043, 992, 39, 33, "Output",
 CellTags->"CovariantD"]
}, Open  ]],
Cell[348080, 14085, 164, 4, 23, "Text",
 CellTags->"CovariantD"],
Cell[CellGroupData[{
Cell[348269, 14093, 120, 3, 27, "Input",
 CellTags->"CovariantD"],
Cell[348392, 14098, 176, 6, 25, "Output",
 CellTags->"CovariantD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[348605, 14109, 153, 4, 27, "Input",
 CellTags->"CovariantD"],
Cell[348761, 14115, 205, 7, 29, "Output",
 CellTags->"CovariantD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[349003, 14127, 203, 5, 27, "Input",
 CellTags->"CovariantD"],
Cell[349209, 14134, 939, 36, 32, "Output",
 CellTags->"CovariantD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[350185, 14175, 183, 5, 27, "Input",
 CellTags->"CovariantD"],
Cell[350371, 14182, 932, 35, 32, "Output",
 CellTags->"CovariantD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[351340, 14222, 187, 5, 27, "Input",
 CellTags->"CovariantD"],
Cell[351530, 14229, 1345, 49, 34, "Output",
 CellTags->"CovariantD"]
}, Open  ]],
Cell[352890, 14281, 602, 22, 30, "Text",
 CellTags->"CovariantD"],
Cell[CellGroupData[{
Cell[353517, 14307, 215, 6, 27, "Input",
 CellTags->"CovariantD"],
Cell[353735, 14315, 513, 20, 31, "Output",
 CellTags->"CovariantD"]
}, Open  ]],
Cell[354263, 14338, 285, 10, 23, "Text",
 CellTags->"CovariantD"],
Cell[CellGroupData[{
Cell[354573, 14352, 215, 6, 27, "Input",
 CellTags->"CovariantD"],
Cell[354791, 14360, 2287, 81, 53, "Output",
 CellTags->"CovariantD"]
}, Open  ]],
Cell[357093, 14444, 189, 7, 23, "Text",
 CellTags->"CovariantD"],
Cell[CellGroupData[{
Cell[357307, 14455, 215, 6, 27, "Input",
 CellTags->"CovariantD"],
Cell[357525, 14463, 6316, 201, 55, "Output",
 CellTags->"CovariantD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[363878, 14669, 181, 5, 27, "Input",
 CellTags->"CovariantD"],
Cell[364062, 14676, 261, 9, 29, "Output",
 CellTags->"CovariantD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[364360, 14690, 195, 6, 27, "Input",
 CellTags->"CovariantD"],
Cell[364558, 14698, 4816, 151, 55, "Output",
 CellTags->"CovariantD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[369411, 14854, 223, 7, 27, "Input",
 CellTags->"CovariantD"],
Cell[369637, 14863, 788, 24, 59, "Output",
 CellTags->"CovariantD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[370462, 14892, 240, 7, 27, "Input",
 CellTags->"CovariantD"],
Cell[370705, 14901, 803, 25, 59, "Output",
 CellTags->"CovariantD"]
}, Open  ]]
}, Open  ]],
Cell[371535, 14930, 61, 1, 39, "ObjectName",
 CellTags->"CrossProduct"],
Cell[CellGroupData[{
Cell[371621, 14935, 63, 1, 33, "Subsubsection",
 CellTags->"CrossProduct"],
Cell[371687, 14938, 145, 4, 23, "Text",
 CellTags->"CrossProduct"],
Cell[371835, 14944, 308, 14, 23, "Text",
 CellTags->"CrossProduct"]
}, Open  ]],
Cell[CellGroupData[{
Cell[372180, 14963, 60, 1, 33, "Subsubsection",
 CellTags->"CrossProduct"],
Cell[CellGroupData[{
Cell[372265, 14968, 326, 9, 27, "Input",
 CellTags->"CrossProduct"],
Cell[372594, 14979, 639, 22, 28, "Output",
 CellTags->"CrossProduct"]
}, Open  ]]
}, Open  ]],
Cell[373260, 15005, 41, 1, 39, "ObjectName",
 CellTags->"C0"],
Cell[CellGroupData[{
Cell[373326, 15010, 53, 1, 33, "Subsubsection",
 CellTags->"C0"],
Cell[373382, 15013, 448, 10, 55, "Text",
 CellTags->"C0"],
Cell[373833, 15025, 458, 24, 23, "Text",
 CellTags->"C0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[374328, 15054, 50, 1, 33, "Subsubsection",
 CellTags->"C0"],
Cell[CellGroupData[{
Cell[374403, 15059, 174, 5, 27, "Input",
 CellTags->"C0"],
Cell[374580, 15066, 260, 8, 25, "Output",
 CellTags->"C0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[374877, 15079, 203, 6, 27, "Input",
 CellTags->"C0"],
Cell[375083, 15087, 260, 8, 25, "Output",
 CellTags->"C0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[375380, 15100, 326, 10, 27, "Input",
 CellTags->"C0"],
Cell[375709, 15112, 260, 8, 25, "Output",
 CellTags->"C0"]
}, Open  ]]
}, Open  ]],
Cell[375996, 15124, 53, 1, 39, "ObjectName",
 CellTags->"DataType"],
Cell[CellGroupData[{
Cell[376074, 15129, 59, 1, 33, "Subsubsection",
 CellTags->"DataType"],
Cell[376136, 15132, 344, 6, 39, "Text",
 CellTags->"DataType"],
Cell[376483, 15140, 835, 32, 39, "Text",
 CellTags->"DataType"],
Cell[377321, 15174, 291, 13, 23, "Text",
 CellTags->"DataType"],
Cell[377615, 15189, 218, 9, 23, "Text",
 CellTags->"DataType"]
}, Open  ]],
Cell[CellGroupData[{
Cell[377870, 15203, 56, 1, 33, "Subsubsection",
 CellTags->"DataType"],
Cell[377929, 15206, 74, 1, 23, "Text",
 CellTags->"DataType"],
Cell[378006, 15209, 221, 7, 27, "Input",
 CellTags->"DataType"],
Cell[CellGroupData[{
Cell[378252, 15220, 224, 8, 27, "Input",
 CellTags->"DataType"],
Cell[378479, 15230, 238, 9, 25, "Output",
 CellTags->"DataType"]
}, Open  ]],
Cell[378732, 15242, 179, 4, 23, "Text",
 CellTags->"DataType"],
Cell[CellGroupData[{
Cell[378936, 15250, 112, 3, 27, "Input",
 CellTags->"DataType"],
Cell[379051, 15255, 210, 7, 25, "Output",
 CellTags->"DataType"]
}, Open  ]],
Cell[379276, 15265, 271, 9, 27, "Input",
 CellTags->"DataType"],
Cell[379550, 15276, 412, 14, 27, "Input",
 CellTags->"DataType"],
Cell[379965, 15292, 395, 14, 27, "Input",
 CellTags->"DataType"],
Cell[CellGroupData[{
Cell[380385, 15310, 340, 13, 27, "Input",
 CellTags->"DataType"],
Cell[380728, 15325, 350, 13, 25, "Output",
 CellTags->"DataType"]
}, Open  ]],
Cell[CellGroupData[{
Cell[381115, 15343, 107, 3, 27, "Input",
 CellTags->"DataType"],
Cell[381225, 15348, 281, 11, 25, "Output",
 CellTags->"DataType"]
}, Open  ]],
Cell[CellGroupData[{
Cell[381543, 15364, 107, 3, 27, "Input",
 CellTags->"DataType"],
Cell[381653, 15369, 172, 6, 25, "Output",
 CellTags->"DataType"]
}, Open  ]],
Cell[381840, 15378, 191, 6, 27, "Input",
 CellTags->"DataType"],
Cell[382034, 15386, 187, 6, 27, "Input",
 CellTags->"DataType"],
Cell[382224, 15394, 429, 15, 27, "Input",
 CellTags->"DataType"],
Cell[CellGroupData[{
Cell[382678, 15413, 290, 11, 27, "Input",
 CellTags->"DataType"],
Cell[382971, 15426, 299, 12, 25, "Output",
 CellTags->"DataType"]
}, Open  ]],
Cell[CellGroupData[{
Cell[383307, 15443, 105, 3, 27, "Input",
 CellTags->"DataType"],
Cell[383415, 15448, 228, 9, 25, "Output",
 CellTags->"DataType"]
}, Open  ]],
Cell[383658, 15460, 151, 5, 27, "Input",
 CellTags->"DataType"],
Cell[383812, 15467, 222, 7, 27, "Input",
 CellTags->"DataType"],
Cell[384037, 15476, 272, 9, 27, "Input",
 CellTags->"DataType"],
Cell[384312, 15487, 114, 3, 23, "Text",
 CellTags->"DataType"],
Cell[CellGroupData[{
Cell[384451, 15494, 149, 4, 27, "Input",
 CellTags->"DataType"],
Cell[384603, 15500, 107, 3, 25, "Output",
 CellTags->"DataType"]
}, Open  ]],
Cell[384725, 15506, 83, 1, 23, "Text",
 CellTags->"DataType"],
Cell[CellGroupData[{
Cell[384833, 15511, 233, 8, 27, "Input",
 CellTags->"DataType"],
Cell[385069, 15521, 104, 3, 25, "Output",
 CellTags->"DataType"]
}, Open  ]],
Cell[CellGroupData[{
Cell[385210, 15529, 226, 7, 27, "Input",
 CellTags->"DataType"],
Cell[385439, 15538, 435, 16, 25, "Output",
 CellTags->"DataType"]
}, Open  ]]
}, Open  ]],
Cell[385901, 15558, 43, 1, 39, "ObjectName",
 CellTags->"DB0"],
Cell[CellGroupData[{
Cell[385969, 15563, 54, 1, 33, "Subsubsection",
 CellTags->"DB0"],
Cell[386026, 15566, 146, 4, 23, "Text",
 CellTags->"DB0"],
Cell[386175, 15572, 156, 9, 23, "Text",
 CellTags->"DB0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[386368, 15586, 51, 1, 33, "Subsubsection",
 CellTags->"DB0"],
Cell[CellGroupData[{
Cell[386444, 15591, 339, 12, 29, "Input",
 CellTags->"DB0"],
Cell[386786, 15605, 255, 8, 29, "Output",
 CellTags->"DB0"]
}, Open  ]]
}, Open  ]],
Cell[387068, 15617, 43, 1, 39, "ObjectName",
 CellTags->"DB1"],
Cell[CellGroupData[{
Cell[387136, 15622, 54, 1, 33, "Subsubsection",
 CellTags->"DB1"],
Cell[387193, 15625, 117, 3, 23, "Text",
 CellTags->"DB1"],
Cell[387313, 15630, 156, 9, 23, "Text",
 CellTags->"DB1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[387506, 15644, 51, 1, 33, "Subsubsection",
 CellTags->"DB1"],
Cell[CellGroupData[{
Cell[387582, 15649, 339, 12, 29, "Input",
 CellTags->"DB1"],
Cell[387924, 15663, 1410, 45, 51, "Output",
 CellTags->"DB1"]
}, Open  ]]
}, Open  ]],
Cell[389361, 15712, 79, 1, 39, "ObjectName",
 CellTags->"DeclareNonCommutative"],
Cell[CellGroupData[{
Cell[389465, 15717, 72, 1, 33, "Subsubsection",
 CellTags->"DeclareNonCommutative"],
Cell[389540, 15720, 192, 4, 23, "Text",
 CellTags->"DeclareNonCommutative"],
Cell[389735, 15726, 347, 14, 23, "Text",
 CellTags->"DeclareNonCommutative"]
}, Open  ]],
Cell[CellGroupData[{
Cell[390119, 15745, 69, 1, 33, "Subsubsection",
 CellTags->"DeclareNonCommutative"],
Cell[390191, 15748, 135, 3, 27, "Input",
 CellTags->"DeclareNonCommutative"],
Cell[390329, 15753, 152, 4, 23, "Text",
 CellTags->"DeclareNonCommutative"],
Cell[CellGroupData[{
Cell[390506, 15761, 158, 4, 27, "Input",
 CellTags->"DeclareNonCommutative"],
Cell[390667, 15767, 120, 3, 25, "Output",
 CellTags->"DeclareNonCommutative"]
}, Open  ]],
Cell[390802, 15773, 158, 4, 27, "Input",
 CellTags->"DeclareNonCommutative"],
Cell[CellGroupData[{
Cell[390985, 15781, 191, 5, 27, "Input",
 CellTags->"DeclareNonCommutative"],
Cell[391179, 15788, 199, 6, 25, "Output",
 CellTags->"DeclareNonCommutative"]
}, Open  ]],
Cell[391393, 15797, 170, 4, 27, "Input",
 CellTags->"DeclareNonCommutative"],
Cell[CellGroupData[{
Cell[391588, 15805, 191, 5, 27, "Input",
 CellTags->"DeclareNonCommutative"],
Cell[391782, 15812, 199, 6, 25, "Output",
 CellTags->"DeclareNonCommutative"]
}, Open  ]]
}, Open  ]],
Cell[392008, 15822, 63, 1, 39, "ObjectName",
 CellTags->"DeltaFunction"],
Cell[CellGroupData[{
Cell[392096, 15827, 64, 1, 33, "Subsubsection",
 CellTags->"DeltaFunction"],
Cell[392163, 15830, 353, 11, 47, "Text",
 CellTags->"DeltaFunction"],
Cell[392519, 15843, 592, 24, 23, "Text",
 CellTags->"DeltaFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[393148, 15872, 61, 1, 33, "Subsubsection",
 CellTags->"DeltaFunction"],
Cell[CellGroupData[{
Cell[393234, 15877, 142, 4, 27, "Input",
 CellTags->"DeltaFunction"],
Cell[393379, 15883, 203, 7, 25, "Output",
 CellTags->"DeltaFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[393619, 15895, 320, 10, 27, "Input",
 CellTags->"DeltaFunction"],
Cell[393942, 15907, 137, 4, 25, "Output",
 CellTags->"DeltaFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[394116, 15916, 294, 9, 27, "Input",
 CellTags->"DeltaFunction"],
Cell[394413, 15927, 137, 4, 25, "Output",
 CellTags->"DeltaFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[394587, 15936, 320, 10, 27, "Input",
 CellTags->"DeltaFunction"],
Cell[394910, 15948, 137, 4, 25, "Output",
 CellTags->"DeltaFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[395084, 15957, 204, 6, 27, "Input",
 CellTags->"DeltaFunction"],
Cell[395291, 15965, 109, 3, 25, "Output",
 CellTags->"DeltaFunction"]
}, Open  ]]
}, Open  ]],
Cell[395427, 15972, 85, 1, 39, "ObjectName",
 CellTags->"DeltaFunctionDoublePrime"],
Cell[CellGroupData[{
Cell[395537, 15977, 75, 1, 33, "Subsubsection",
 CellTags->"DeltaFunctionDoublePrime"],
Cell[395615, 15980, 248, 8, 23, "Text",
 CellTags->"DeltaFunctionDoublePrime"],
Cell[395866, 15990, 219, 8, 23, "Text",
 CellTags->"DeltaFunctionDoublePrime"]
}, Open  ]],
Cell[396100, 16001, 73, 1, 39, "ObjectName",
 CellTags->"DeltaFunctionPrime"],
Cell[CellGroupData[{
Cell[396198, 16006, 69, 1, 33, "Subsubsection",
 CellTags->"DeltaFunctionPrime"],
Cell[396270, 16009, 227, 7, 23, "Text",
 CellTags->"DeltaFunctionPrime"],
Cell[396500, 16018, 576, 23, 23, "Text",
 CellTags->"DeltaFunctionPrime"]
}, Open  ]],
Cell[CellGroupData[{
Cell[397113, 16046, 66, 1, 33, "Subsubsection",
 CellTags->"DeltaFunctionPrime"],
Cell[CellGroupData[{
Cell[397204, 16051, 152, 4, 27, "Input",
 CellTags->"DeltaFunctionPrime"],
Cell[397359, 16057, 240, 8, 25, "Output",
 CellTags->"DeltaFunctionPrime"]
}, Open  ]],
Cell[CellGroupData[{
Cell[397636, 16070, 330, 10, 27, "Input",
 CellTags->"DeltaFunctionPrime"],
Cell[397969, 16082, 203, 6, 25, "Output",
 CellTags->"DeltaFunctionPrime"]
}, Open  ]],
Cell[CellGroupData[{
Cell[398209, 16093, 326, 10, 29, "Input",
 CellTags->"DeltaFunctionPrime"],
Cell[398538, 16105, 114, 3, 25, "Output",
 CellTags->"DeltaFunctionPrime"]
}, Open  ]]
}, Open  ]],
Cell[398679, 16112, 69, 1, 39, "ObjectName",
 CellTags->"DenominatorOrder"],
Cell[CellGroupData[{
Cell[398773, 16117, 67, 1, 33, "Subsubsection",
 CellTags->"DenominatorOrder"],
Cell[398843, 16120, 175, 4, 23, "Text",
 CellTags->"DenominatorOrder"],
Cell[399021, 16126, 327, 13, 23, "Text",
 CellTags->"DenominatorOrder"]
}, Open  ]],
Cell[399363, 16142, 55, 1, 39, "ObjectName",
 CellTags->"Dimension"],
Cell[CellGroupData[{
Cell[399443, 16147, 60, 1, 33, "Subsubsection",
 CellTags->"Dimension"],
Cell[399506, 16150, 246, 5, 39, "Text",
 CellTags->"Dimension"],
Cell[CellGroupData[{
Cell[399777, 16159, 120, 3, 27, "Input",
 CellTags->"Dimension"],
Cell[399900, 16164, 244, 8, 25, "Output",
 CellTags->"Dimension"]
}, Open  ]],
Cell[CellGroupData[{
Cell[400181, 16177, 313, 9, 27, "Input",
 CellTags->"Dimension"],
Cell[400497, 16188, 286, 11, 25, "Output",
 CellTags->"Dimension"]
}, Open  ]],
Cell[400798, 16202, 131, 4, 23, "Text",
 CellTags->"Dimension"],
Cell[CellGroupData[{
Cell[400954, 16210, 357, 11, 27, "Input",
 CellTags->"Dimension"],
Cell[401314, 16223, 360, 10, 39, "Output",
 CellTags->"Dimension"]
}, Open  ]],
Cell[401689, 16236, 166, 4, 23, "Text",
 CellTags->"Dimension"],
Cell[401858, 16242, 133, 4, 27, "Input",
 CellTags->"Dimension"],
Cell[CellGroupData[{
Cell[402016, 16250, 326, 9, 27, "Input",
 CellTags->"Dimension"],
Cell[402345, 16261, 662, 28, 25, "Output",
 CellTags->"Dimension"]
}, Open  ]],
Cell[CellGroupData[{
Cell[403044, 16294, 110, 3, 27, "Input",
 CellTags->"Dimension"],
Cell[403157, 16299, 373, 10, 39, "Output",
 CellTags->"Dimension"]
}, Open  ]],
Cell[403545, 16312, 134, 4, 27, "Input",
 CellTags->"Dimension"]
}, Open  ]],
Cell[403694, 16319, 77, 1, 39, "ObjectName",
 CellTags->"DimensionalReduction"],
Cell[CellGroupData[{
Cell[403796, 16324, 71, 1, 33, "Subsubsection",
 CellTags->"DimensionalReduction"],
Cell[403870, 16327, 121, 3, 23, "Text",
 CellTags->"DimensionalReduction"],
Cell[403994, 16332, 301, 13, 23, "Text",
 CellTags->"DimensionalReduction"]
}, Open  ]],
Cell[404310, 16348, 57, 1, 39, "ObjectName",
 CellTags->"DiracBasis"],
Cell[CellGroupData[{
Cell[404392, 16353, 61, 1, 33, "Subsubsection",
 CellTags->"DiracBasis"],
Cell[404456, 16356, 299, 6, 39, "Text",
 CellTags->"DiracBasis"],
Cell[404758, 16364, 184, 8, 23, "Text",
 CellTags->"DiracBasis"]
}, Open  ]],
Cell[404957, 16375, 65, 1, 39, "ObjectName",
 CellTags->"DiracCanonical"],
Cell[CellGroupData[{
Cell[405047, 16380, 65, 1, 33, "Subsubsection",
 CellTags->"DiracCanonical"],
Cell[405115, 16383, 171, 4, 23, "Text",
 CellTags->"DiracCanonical"],
Cell[405289, 16389, 194, 8, 23, "Text",
 CellTags->"DiracCanonical"]
}, Open  ]],
Cell[405498, 16400, 63, 1, 39, "ObjectName",
 CellTags->"DiracEquation"],
Cell[CellGroupData[{
Cell[405586, 16405, 64, 1, 33, "Subsubsection",
 CellTags->"DiracEquation"],
Cell[405653, 16408, 160, 4, 23, "Text",
 CellTags->"DiracEquation"],
Cell[405816, 16414, 199, 9, 23, "Text",
 CellTags->"DiracEquation"]
}, Open  ]],
Cell[CellGroupData[{
Cell[406052, 16428, 61, 1, 33, "Subsubsection",
 CellTags->"DiracEquation"],
Cell[CellGroupData[{
Cell[406138, 16433, 279, 8, 27, "Input",
 CellTags->"DiracEquation"],
Cell[406420, 16443, 368, 13, 25, "Output",
 CellTags->"DiracEquation"]
}, Open  ]],
Cell[CellGroupData[{
Cell[406825, 16461, 119, 3, 27, "Input",
 CellTags->"DiracEquation"],
Cell[406947, 16466, 217, 7, 25, "Output",
 CellTags->"DiracEquation"]
}, Open  ]]
}, Open  ]],
Cell[407191, 16477, 57, 1, 39, "ObjectName",
 CellTags->"DiracGamma"],
Cell[CellGroupData[{
Cell[407273, 16482, 61, 1, 33, "Subsubsection",
 CellTags->"DiracGamma"],
Cell[407337, 16485, 762, 24, 59, "Text",
 CellTags->"DiracGamma"],
Cell[408102, 16511, 681, 29, 23, "Text",
 CellTags->"DiracGamma"]
}, Open  ]],
Cell[CellGroupData[{
Cell[408820, 16545, 58, 1, 33, "Subsubsection",
 CellTags->"DiracGamma"],
Cell[CellGroupData[{
Cell[408903, 16550, 113, 3, 27, "Input",
 CellTags->"DiracGamma"],
Cell[409019, 16555, 137, 4, 27, "Output",
 CellTags->"DiracGamma"]
}, Open  ]],
Cell[CellGroupData[{
Cell[409193, 16564, 159, 4, 27, "Input",
 CellTags->"DiracGamma"],
Cell[409355, 16570, 214, 8, 25, "Output",
 CellTags->"DiracGamma"]
}, Open  ]],
Cell[409584, 16581, 332, 13, 26, "Text",
 CellTags->"DiracGamma"],
Cell[CellGroupData[{
Cell[409941, 16598, 167, 5, 27, "Input",
 CellTags->"DiracGamma"],
Cell[410111, 16605, 223, 8, 25, "Output",
 CellTags->"DiracGamma"]
}, Open  ]],
Cell[CellGroupData[{
Cell[410371, 16618, 280, 8, 27, "Input",
 CellTags->"DiracGamma"],
Cell[410654, 16628, 468, 17, 25, "Output",
 CellTags->"DiracGamma"]
}, Open  ]],
Cell[CellGroupData[{
Cell[411159, 16650, 218, 7, 27, "Input",
 CellTags->"DiracGamma"],
Cell[411380, 16659, 223, 8, 25, "Output",
 CellTags->"DiracGamma"]
}, Open  ]],
Cell[CellGroupData[{
Cell[411640, 16672, 208, 7, 27, "Input",
 CellTags->"DiracGamma"],
Cell[411851, 16681, 341, 12, 25, "Output",
 CellTags->"DiracGamma"]
}, Open  ]],
Cell[CellGroupData[{
Cell[412229, 16698, 144, 4, 27, "Input",
 CellTags->"DiracGamma"],
Cell[412376, 16704, 593, 22, 25, "Output",
 CellTags->"DiracGamma"]
}, Open  ]],
Cell[CellGroupData[{
Cell[413006, 16731, 300, 9, 27, "Input",
 CellTags->"DiracGamma"],
Cell[413309, 16742, 430, 13, 25, "Output",
 CellTags->"DiracGamma"]
}, Open  ]],
Cell[CellGroupData[{
Cell[413776, 16760, 138, 4, 27, "Input",
 CellTags->"DiracGamma"],
Cell[413917, 16766, 430, 13, 25, "Output",
 CellTags->"DiracGamma"]
}, Open  ]],
Cell[CellGroupData[{
Cell[414384, 16784, 141, 4, 27, "Input",
 CellTags->"DiracGamma"],
Cell[414528, 16790, 1123, 42, 27, "Output",
 CellTags->"DiracGamma"]
}, Open  ]],
Cell[415666, 16835, 168, 5, 27, "Input",
 CellTags->"DiracGamma"]
}, Open  ]],
Cell[415849, 16843, 71, 1, 39, "ObjectName",
 CellTags->"DiracGammaCombine"],
Cell[CellGroupData[{
Cell[415945, 16848, 68, 1, 33, "Subsubsection",
 CellTags->"DiracGammaCombine"],
Cell[416016, 16851, 135, 4, 23, "Text",
 CellTags->"DiracGammaCombine"],
Cell[416154, 16857, 804, 34, 23, "Text",
 CellTags->"DiracGammaCombine"]
}, Open  ]],
Cell[CellGroupData[{
Cell[416995, 16896, 65, 1, 33, "Subsubsection",
 CellTags->"DiracGammaCombine"],
Cell[CellGroupData[{
Cell[417085, 16901, 220, 6, 27, "Input",
 CellTags->"DiracGammaCombine"],
Cell[417308, 16909, 265, 9, 25, "Output",
 CellTags->"DiracGammaCombine"]
}, Open  ]],
Cell[CellGroupData[{
Cell[417610, 16923, 122, 3, 27, "Input",
 CellTags->"DiracGammaCombine"],
Cell[417735, 16928, 194, 5, 39, "Output",
 CellTags->"DiracGammaCombine"]
}, Open  ]],
Cell[CellGroupData[{
Cell[417966, 16938, 270, 8, 27, "Input",
 CellTags->"DiracGammaCombine"],
Cell[418239, 16948, 317, 11, 25, "Output",
 CellTags->"DiracGammaCombine"]
}, Open  ]],
Cell[CellGroupData[{
Cell[418593, 16964, 122, 3, 27, "Input",
 CellTags->"DiracGammaCombine"],
Cell[418718, 16969, 244, 7, 39, "Output",
 CellTags->"DiracGammaCombine"]
}, Open  ]],
Cell[CellGroupData[{
Cell[418999, 16981, 127, 3, 27, "Input",
 CellTags->"DiracGammaCombine"],
Cell[419129, 16986, 438, 16, 25, "Output",
 CellTags->"DiracGammaCombine"]
}, Open  ]]
}, Open  ]],
Cell[419594, 17006, 69, 1, 39, "ObjectName",
 CellTags->"DiracGammaExpand"],
Cell[CellGroupData[{
Cell[419688, 17011, 67, 1, 33, "Subsubsection",
 CellTags->"DiracGammaExpand"],
Cell[419758, 17014, 190, 4, 39, "Text",
 CellTags->"DiracGammaExpand"],
Cell[419951, 17020, 806, 34, 23, "Text",
 CellTags->"DiracGammaExpand"]
}, Open  ]],
Cell[CellGroupData[{
Cell[420794, 17059, 64, 1, 33, "Subsubsection",
 CellTags->"DiracGammaExpand"],
Cell[CellGroupData[{
Cell[420883, 17064, 314, 9, 27, "Input",
 CellTags->"DiracGammaExpand"],
Cell[421200, 17075, 474, 17, 25, "Output",
 CellTags->"DiracGammaExpand"]
}, Open  ]],
Cell[421689, 17095, 125, 3, 23, "Text",
 CellTags->"DiracGammaExpand"],
Cell[CellGroupData[{
Cell[421839, 17102, 121, 3, 27, "Input",
 CellTags->"DiracGammaExpand"],
Cell[421963, 17107, 291, 8, 39, "Output",
 CellTags->"DiracGammaExpand"]
}, Open  ]],
Cell[422269, 17118, 101, 1, 23, "Text",
 CellTags->"DiracGammaExpand"],
Cell[CellGroupData[{
Cell[422395, 17123, 125, 3, 27, "Input",
 CellTags->"DiracGammaExpand"],
Cell[422523, 17128, 599, 22, 25, "Output",
 CellTags->"DiracGammaExpand"]
}, Open  ]],
Cell[423137, 17153, 90, 1, 23, "Text",
 CellTags->"DiracGammaExpand"],
Cell[CellGroupData[{
Cell[423252, 17158, 209, 5, 27, "Input",
 CellTags->"DiracGammaExpand"],
Cell[423464, 17165, 291, 8, 39, "Output",
 CellTags->"DiracGammaExpand"]
}, Open  ]],
Cell[CellGroupData[{
Cell[423792, 17178, 164, 4, 27, "Input",
 CellTags->"DiracGammaExpand"],
Cell[423959, 17184, 394, 11, 39, "Output",
 CellTags->"DiracGammaExpand"]
}, Open  ]],
Cell[424368, 17198, 106, 1, 23, "Text",
 CellTags->"DiracGammaExpand"],
Cell[CellGroupData[{
Cell[424499, 17203, 122, 3, 27, "Input",
 CellTags->"DiracGammaExpand"],
Cell[424624, 17208, 534, 20, 27, "Output",
 CellTags->"DiracGammaExpand"]
}, Open  ]],
Cell[425173, 17231, 114, 3, 27, "Input",
 CellTags->"DiracGammaExpand"]
}, Open  ]],
Cell[425302, 17237, 59, 1, 39, "ObjectName",
 CellTags->"DiracGammaT"],
Cell[CellGroupData[{
Cell[425386, 17242, 62, 1, 33, "Subsubsection",
 CellTags->"DiracGammaT"],
Cell[425451, 17245, 208, 5, 39, "Text",
 CellTags->"DiracGammaT"],
Cell[425662, 17252, 188, 9, 23, "Text",
 CellTags->"DiracGammaT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[425887, 17266, 59, 1, 33, "Subsubsection",
 CellTags->"DiracGammaT"],
Cell[CellGroupData[{
Cell[425971, 17271, 158, 4, 27, "Input",
 CellTags->"DiracGammaT"],
Cell[426132, 17277, 220, 8, 31, "Output",
 CellTags->"DiracGammaT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[426389, 17290, 113, 3, 27, "Input",
 CellTags->"DiracGammaT"],
Cell[426505, 17295, 212, 8, 25, "Output",
 CellTags->"DiracGammaT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[426754, 17308, 167, 6, 27, "Input",
 CellTags->"DiracGammaT"],
Cell[426924, 17316, 219, 7, 27, "Output",
 CellTags->"DiracGammaT"]
}, Open  ]]
}, Open  ]],
Cell[427170, 17327, 59, 1, 39, "ObjectName",
 CellTags->"DiracMatrix"],
Cell[CellGroupData[{
Cell[427254, 17332, 62, 1, 33, "Subsubsection",
 CellTags->"DiracMatrix"],
Cell[427319, 17335, 1220, 46, 41, "Text",
 CellTags->"DiracMatrix"],
Cell[428542, 17383, 1053, 49, 23, "Text",
 CellTags->"DiracMatrix"]
}, Open  ]],
Cell[CellGroupData[{
Cell[429632, 17437, 59, 1, 33, "Subsubsection",
 CellTags->"DiracMatrix"],
Cell[CellGroupData[{
Cell[429716, 17442, 119, 3, 27, "Input",
 CellTags->"DiracMatrix"],
Cell[429838, 17447, 212, 8, 25, "Output",
 CellTags->"DiracMatrix"]
}, Open  ]],
Cell[430065, 17458, 539, 20, 23, "Text",
 CellTags->"DiracMatrix"],
Cell[CellGroupData[{
Cell[430629, 17482, 184, 5, 27, "Input",
 CellTags->"DiracMatrix"],
Cell[430816, 17489, 350, 14, 25, "Output",
 CellTags->"DiracMatrix"]
}, Open  ]],
Cell[CellGroupData[{
Cell[431203, 17508, 160, 5, 27, "Input",
 CellTags->"DiracMatrix"],
Cell[431366, 17515, 175, 4, 39, "Output",
 CellTags->"DiracMatrix"]
}, Open  ]],
Cell[CellGroupData[{
Cell[431578, 17524, 145, 4, 27, "Input",
 CellTags->"DiracMatrix"],
Cell[431726, 17530, 142, 4, 25, "Output",
 CellTags->"DiracMatrix"]
}, Open  ]],
Cell[CellGroupData[{
Cell[431905, 17539, 112, 3, 27, "Input",
 CellTags->"DiracMatrix"],
Cell[432020, 17544, 125, 3, 39, "Output",
 CellTags->"DiracMatrix"]
}, Open  ]],
Cell[CellGroupData[{
Cell[432182, 17552, 111, 3, 27, "Input",
 CellTags->"DiracMatrix"],
Cell[432296, 17557, 142, 4, 25, "Output",
 CellTags->"DiracMatrix"]
}, Open  ]],
Cell[CellGroupData[{
Cell[432475, 17566, 138, 4, 27, "Input",
 CellTags->"DiracMatrix"],
Cell[432616, 17572, 221, 6, 39, "Output",
 CellTags->"DiracMatrix"]
}, Open  ]],
Cell[CellGroupData[{
Cell[432874, 17583, 152, 4, 27, "Input",
 CellTags->"DiracMatrix"],
Cell[433029, 17589, 249, 7, 25, "Output",
 CellTags->"DiracMatrix"]
}, Open  ]],
Cell[CellGroupData[{
Cell[433315, 17601, 166, 5, 27, "Input",
 CellTags->"DiracMatrix"],
Cell[433484, 17608, 342, 14, 27, "Output",
 CellTags->"DiracMatrix"]
}, Open  ]],
Cell[CellGroupData[{
Cell[433863, 17627, 112, 3, 27, "Input",
 CellTags->"DiracMatrix"],
Cell[433978, 17632, 269, 7, 39, "Output",
 CellTags->"DiracMatrix"]
}, Open  ]]
}, Open  ]],
Cell[434274, 17643, 57, 1, 39, "ObjectName",
 CellTags->"DiracOrder"],
Cell[CellGroupData[{
Cell[434356, 17648, 61, 1, 33, "Subsubsection",
 CellTags->"DiracOrder"],
Cell[434420, 17651, 204, 5, 23, "Text",
 CellTags->"DiracOrder"],
Cell[434627, 17658, 312, 14, 23, "Text",
 CellTags->"DiracOrder"]
}, Open  ]],
Cell[CellGroupData[{
Cell[434976, 17677, 58, 1, 33, "Subsubsection",
 CellTags->"DiracOrder"],
Cell[CellGroupData[{
Cell[435059, 17682, 176, 5, 27, "Input",
 CellTags->"DiracOrder"],
Cell[435238, 17689, 206, 6, 25, "Output",
 CellTags->"DiracOrder"]
}, Open  ]],
Cell[CellGroupData[{
Cell[435481, 17700, 114, 3, 27, "Input",
 CellTags->"DiracOrder"],
Cell[435598, 17705, 472, 18, 25, "Output",
 CellTags->"DiracOrder"]
}, Open  ]],
Cell[436085, 17726, 93, 1, 23, "Text",
 CellTags->"DiracOrder"],
Cell[CellGroupData[{
Cell[436203, 17731, 176, 5, 27, "Input",
 CellTags->"DiracOrder"],
Cell[436382, 17738, 247, 7, 25, "Output",
 CellTags->"DiracOrder"]
}, Open  ]],
Cell[CellGroupData[{
Cell[436666, 17750, 114, 3, 27, "Input",
 CellTags->"DiracOrder"],
Cell[436783, 17755, 472, 18, 25, "Output",
 CellTags->"DiracOrder"]
}, Open  ]],
Cell[CellGroupData[{
Cell[437292, 17778, 171, 5, 27, "Input",
 CellTags->"DiracOrder"],
Cell[437466, 17785, 243, 7, 27, "Output",
 CellTags->"DiracOrder"]
}, Open  ]],
Cell[437724, 17795, 196, 8, 23, "Text",
 CellTags->"DiracOrder"],
Cell[CellGroupData[{
Cell[437945, 17807, 114, 3, 27, "Input",
 CellTags->"DiracOrder"],
Cell[438062, 17812, 391, 15, 27, "Output",
 CellTags->"DiracOrder"]
}, Open  ]],
Cell[CellGroupData[{
Cell[438490, 17832, 167, 5, 27, "Input",
 CellTags->"DiracOrder"],
Cell[438660, 17839, 239, 7, 27, "Output",
 CellTags->"DiracOrder"]
}, Open  ]],
Cell[CellGroupData[{
Cell[438936, 17851, 114, 3, 27, "Input",
 CellTags->"DiracOrder"],
Cell[439053, 17856, 271, 10, 27, "Output",
 CellTags->"DiracOrder"]
}, Open  ]],
Cell[CellGroupData[{
Cell[439361, 17871, 183, 5, 27, "Input",
 CellTags->"DiracOrder"],
Cell[439547, 17878, 255, 7, 25, "Output",
 CellTags->"DiracOrder"]
}, Open  ]],
Cell[439817, 17888, 288, 10, 23, "Text",
 CellTags->"DiracOrder"],
Cell[CellGroupData[{
Cell[440130, 17902, 219, 7, 27, "Input",
 CellTags->"DiracOrder"],
Cell[440352, 17911, 1207, 45, 25, "Output",
 CellTags->"DiracOrder"]
}, Open  ]],
Cell[CellGroupData[{
Cell[441596, 17961, 113, 3, 27, "Input",
 CellTags->"DiracOrder"],
Cell[441712, 17966, 477, 19, 25, "Output",
 CellTags->"DiracOrder"]
}, Open  ]],
Cell[442204, 17988, 188, 6, 27, "Input",
 CellTags->"DiracOrder"]
}, Open  ]],
Cell[442407, 17997, 59, 1, 39, "ObjectName",
 CellTags->"DiracReduce"],
Cell[CellGroupData[{
Cell[442491, 18002, 62, 1, 33, "Subsubsection",
 CellTags->"DiracReduce"],
Cell[442556, 18005, 662, 11, 87, "Text",
 CellTags->"DiracReduce"],
Cell[CellGroupData[{
Cell[443243, 18020, 121, 3, 27, "Input",
 CellTags->"DiracReduce"],
Cell[443367, 18025, 323, 10, 25, "Output",
 CellTags->"DiracReduce"]
}, Open  ]],
Cell[443705, 18038, 197, 9, 23, "Text",
 CellTags->"DiracReduce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[443939, 18052, 59, 1, 33, "Subsubsection",
 CellTags->"DiracReduce"],
Cell[CellGroupData[{
Cell[444023, 18057, 172, 5, 27, "Input",
 CellTags->"DiracReduce"],
Cell[444198, 18064, 202, 6, 25, "Output",
 CellTags->"DiracReduce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[444437, 18075, 116, 3, 27, "Input",
 CellTags->"DiracReduce"],
Cell[444556, 18080, 281, 9, 25, "Output",
 CellTags->"DiracReduce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[444874, 18094, 186, 5, 27, "Input",
 CellTags->"DiracReduce"],
Cell[445063, 18101, 239, 7, 25, "Output",
 CellTags->"DiracReduce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[445339, 18113, 116, 3, 27, "Input",
 CellTags->"DiracReduce"],
Cell[445458, 18118, 919, 28, 27, "Output",
 CellTags->"DiracReduce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[446414, 18151, 207, 6, 27, "Input",
 CellTags->"DiracReduce"],
Cell[446624, 18159, 283, 8, 25, "Output",
 CellTags->"DiracReduce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[446944, 18172, 140, 4, 27, "Input",
 CellTags->"DiracReduce"],
Cell[447087, 18178, 1814, 54, 27, "Output",
 CellTags->"DiracReduce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[448938, 18237, 253, 7, 27, "Input",
 CellTags->"DiracReduce"],
Cell[449194, 18246, 127, 4, 25, "Output",
 CellTags->"DiracReduce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[449358, 18255, 133, 4, 27, "Input",
 CellTags->"DiracReduce"],
Cell[449494, 18261, 127, 4, 25, "Output",
 CellTags->"DiracReduce"]
}, Open  ]],
Cell[449636, 18268, 156, 4, 27, "Input",
 CellTags->"DiracReduce"]
}, Open  ]],
Cell[449807, 18275, 57, 1, 39, "ObjectName",
 CellTags->"DiracSigma"],
Cell[CellGroupData[{
Cell[449889, 18280, 61, 1, 33, "Subsubsection",
 CellTags->"DiracSigma"],
Cell[449953, 18283, 213, 5, 39, "Text",
 CellTags->"DiracSigma"],
Cell[450169, 18290, 211, 9, 23, "Text",
 CellTags->"DiracSigma"]
}, Open  ]],
Cell[CellGroupData[{
Cell[450417, 18304, 58, 1, 33, "Subsubsection",
 CellTags->"DiracSigma"],
Cell[CellGroupData[{
Cell[450500, 18309, 236, 7, 27, "Input",
 CellTags->"DiracSigma"],
Cell[450739, 18318, 169, 5, 25, "Output",
 CellTags->"DiracSigma"]
}, Open  ]],
Cell[CellGroupData[{
Cell[450945, 18328, 122, 3, 27, "Input",
 CellTags->"DiracSigma"],
Cell[451070, 18333, 784, 29, 43, "Output",
 CellTags->"DiracSigma"]
}, Open  ]],
Cell[CellGroupData[{
Cell[451891, 18367, 236, 7, 27, "Input",
 CellTags->"DiracSigma"],
Cell[452130, 18376, 189, 6, 25, "Output",
 CellTags->"DiracSigma"]
}, Open  ]],
Cell[CellGroupData[{
Cell[452356, 18387, 223, 7, 27, "Input",
 CellTags->"DiracSigma"],
Cell[452582, 18396, 156, 5, 25, "Output",
 CellTags->"DiracSigma"]
}, Open  ]],
Cell[CellGroupData[{
Cell[452775, 18406, 122, 3, 27, "Input",
 CellTags->"DiracSigma"],
Cell[452900, 18411, 950, 33, 43, "Output",
 CellTags->"DiracSigma"]
}, Open  ]],
Cell[453865, 18447, 144, 4, 27, "Input",
 CellTags->"DiracSigma"]
}, Open  ]],
Cell[454024, 18454, 73, 1, 39, "ObjectName",
 CellTags->"DiracSigmaExplicit"],
Cell[CellGroupData[{
Cell[454122, 18459, 69, 1, 33, "Subsubsection",
 CellTags->"DiracSigmaExplicit"],
Cell[454194, 18462, 186, 4, 23, "Text",
 CellTags->"DiracSigmaExplicit"],
Cell[454383, 18468, 195, 9, 23, "Text",
 CellTags->"DiracSigmaExplicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[454615, 18482, 66, 1, 33, "Subsubsection",
 CellTags->"DiracSigmaExplicit"],
Cell[CellGroupData[{
Cell[454706, 18487, 217, 6, 27, "Input",
 CellTags->"DiracSigmaExplicit"],
Cell[454926, 18495, 177, 5, 25, "Output",
 CellTags->"DiracSigmaExplicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[455140, 18505, 129, 3, 27, "Input",
 CellTags->"DiracSigmaExplicit"],
Cell[455272, 18510, 792, 29, 43, "Output",
 CellTags->"DiracSigmaExplicit"]
}, Open  ]]
}, Open  ]],
Cell[456091, 18543, 69, 1, 39, "ObjectName",
 CellTags->"DiracSimpCombine"],
Cell[CellGroupData[{
Cell[456185, 18548, 67, 1, 33, "Subsubsection",
 CellTags->"DiracSimpCombine"],
Cell[456255, 18551, 209, 5, 39, "Text",
 CellTags->"DiracSimpCombine"],
Cell[456467, 18558, 196, 8, 23, "Text",
 CellTags->"DiracSimpCombine"]
}, Open  ]],
Cell[456678, 18569, 63, 1, 39, "ObjectName",
 CellTags->"DiracSimplify"],
Cell[CellGroupData[{
Cell[456766, 18574, 64, 1, 33, "Subsubsection",
 CellTags->"DiracSimplify"],
Cell[456833, 18577, 382, 7, 55, "Text",
 CellTags->"DiracSimplify"],
Cell[CellGroupData[{
Cell[457240, 18588, 125, 3, 27, "Input",
 CellTags->"DiracSimplify"],
Cell[457368, 18593, 604, 14, 45, "Output",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[457987, 18610, 422, 19, 23, "Text",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[458446, 18634, 61, 1, 33, "Subsubsection",
 CellTags->"DiracSimplify"],
Cell[458510, 18637, 99, 1, 23, "Text",
 CellTags->"DiracSimplify"],
Cell[CellGroupData[{
Cell[458634, 18642, 178, 5, 27, "Input",
 CellTags->"DiracSimplify"],
Cell[458815, 18649, 250, 7, 25, "Output",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[459102, 18661, 120, 3, 27, "Input",
 CellTags->"DiracSimplify"],
Cell[459225, 18666, 261, 10, 25, "Output",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[459501, 18679, 96, 1, 23, "Text",
 CellTags->"DiracSimplify"],
Cell[CellGroupData[{
Cell[459622, 18684, 179, 5, 27, "Input",
 CellTags->"DiracSimplify"],
Cell[459804, 18691, 250, 7, 25, "Output",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[460091, 18703, 120, 3, 27, "Input",
 CellTags->"DiracSimplify"],
Cell[460214, 18708, 261, 10, 25, "Output",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[460512, 18723, 174, 5, 27, "Input",
 CellTags->"DiracSimplify"],
Cell[460689, 18730, 246, 7, 27, "Output",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[460950, 18740, 179, 7, 23, "Text",
 CellTags->"DiracSimplify"],
Cell[CellGroupData[{
Cell[461154, 18751, 120, 3, 27, "Input",
 CellTags->"DiracSimplify"],
Cell[461277, 18756, 394, 15, 27, "Output",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[461708, 18776, 170, 5, 27, "Input",
 CellTags->"DiracSimplify"],
Cell[461881, 18783, 242, 7, 27, "Output",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[462160, 18795, 120, 3, 27, "Input",
 CellTags->"DiracSimplify"],
Cell[462283, 18800, 274, 10, 27, "Output",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[462594, 18815, 326, 10, 27, "Input",
 CellTags->"DiracSimplify"],
Cell[462923, 18827, 570, 18, 25, "Output",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[463508, 18848, 120, 3, 23, "Text",
 CellTags->"DiracSimplify"],
Cell[CellGroupData[{
Cell[463653, 18855, 120, 3, 27, "Input",
 CellTags->"DiracSimplify"],
Cell[463776, 18860, 1908, 72, 27, "Output",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[465721, 18937, 117, 3, 27, "Input",
 CellTags->"DiracSimplify"],
Cell[465841, 18942, 570, 18, 25, "Output",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[466448, 18965, 272, 7, 27, "Input",
 CellTags->"DiracSimplify"],
Cell[466723, 18974, 407, 14, 25, "Output",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[467167, 18993, 120, 3, 27, "Input",
 CellTags->"DiracSimplify"],
Cell[467290, 18998, 109, 3, 25, "Output",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[467436, 19006, 373, 12, 27, "Input",
 CellTags->"DiracSimplify"],
Cell[467812, 19020, 624, 18, 25, "Output",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[468473, 19043, 119, 3, 27, "Input",
 CellTags->"DiracSimplify"],
Cell[468595, 19048, 13964, 531, 83, "Output",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[482574, 19582, 115, 3, 23, "Text",
 CellTags->"DiracSimplify"],
Cell[CellGroupData[{
Cell[482714, 19589, 251, 7, 27, "Input",
 CellTags->"DiracSimplify"],
Cell[482968, 19598, 465, 18, 25, "Output",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[483448, 19619, 141, 4, 23, "Text",
 CellTags->"DiracSimplify"],
Cell[CellGroupData[{
Cell[483614, 19627, 289, 8, 27, "Input",
 CellTags->"DiracSimplify"],
Cell[483906, 19637, 556, 19, 25, "Output",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[484499, 19661, 268, 7, 27, "Input",
 CellTags->"DiracSimplify"],
Cell[484770, 19670, 109, 3, 25, "Output",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[484894, 19676, 183, 5, 27, "Input",
 CellTags->"DiracSimplify"]
}, Open  ]],
Cell[485092, 19684, 65, 1, 39, "ObjectName",
 CellTags->"DiracSimplify2"],
Cell[CellGroupData[{
Cell[485182, 19689, 65, 1, 33, "Subsubsection",
 CellTags->"DiracSimplify2"],
Cell[485250, 19692, 224, 7, 23, "Text",
 CellTags->"DiracSimplify2"],
Cell[485477, 19701, 200, 9, 23, "Text",
 CellTags->"DiracSimplify2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[485714, 19715, 62, 1, 33, "Subsubsection",
 CellTags->"DiracSimplify2"],
Cell[CellGroupData[{
Cell[485801, 19720, 222, 6, 27, "Input",
 CellTags->"DiracSimplify2"],
Cell[486026, 19728, 439, 11, 27, "Output",
 CellTags->"DiracSimplify2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[486502, 19744, 121, 3, 27, "Input",
 CellTags->"DiracSimplify2"],
Cell[486626, 19749, 883, 35, 27, "Output",
 CellTags->"DiracSimplify2"]
}, Open  ]]
}, Open  ]],
Cell[487536, 19788, 57, 1, 39, "ObjectName",
 CellTags->"DiracSlash"],
Cell[CellGroupData[{
Cell[487618, 19793, 61, 1, 33, "Subsubsection",
 CellTags->"DiracSlash"],
Cell[487682, 19796, 469, 16, 26, "Text",
 CellTags->"DiracSlash"],
Cell[CellGroupData[{
Cell[488176, 19816, 119, 3, 27, "Input",
 CellTags->"DiracSlash"],
Cell[488298, 19821, 245, 8, 25, "Output",
 CellTags->"DiracSlash"]
}, Open  ]],
Cell[488558, 19832, 868, 39, 23, "Text",
 CellTags->"DiracSlash"]
}, Open  ]],
Cell[CellGroupData[{
Cell[489463, 19876, 58, 1, 33, "Subsubsection",
 CellTags->"DiracSlash"],
Cell[489524, 19879, 234, 9, 26, "Text",
 CellTags->"DiracSlash"],
Cell[CellGroupData[{
Cell[489783, 19892, 113, 3, 27, "Input",
 CellTags->"DiracSlash"],
Cell[489899, 19897, 223, 8, 25, "Output",
 CellTags->"DiracSlash"]
}, Open  ]],
Cell[CellGroupData[{
Cell[490159, 19910, 173, 5, 27, "Input",
 CellTags->"DiracSlash"],
Cell[490335, 19917, 431, 16, 25, "Output",
 CellTags->"DiracSlash"]
}, Open  ]],
Cell[CellGroupData[{
Cell[490803, 19938, 136, 4, 27, "Input",
 CellTags->"DiracSlash"],
Cell[490942, 19944, 431, 16, 25, "Output",
 CellTags->"DiracSlash"]
}, Open  ]],
Cell[CellGroupData[{
Cell[491410, 19965, 105, 3, 27, "Input",
 CellTags->"DiracSlash"],
Cell[491518, 19970, 147, 4, 25, "Output",
 CellTags->"DiracSlash"]
}, Open  ]],
Cell[CellGroupData[{
Cell[491702, 19979, 148, 4, 27, "Input",
 CellTags->"DiracSlash"],
Cell[491853, 19985, 128, 3, 39, "Output",
 CellTags->"DiracSlash"]
}, Open  ]],
Cell[CellGroupData[{
Cell[492018, 19993, 214, 7, 27, "Input",
 CellTags->"DiracSlash"],
Cell[492235, 20002, 189, 5, 39, "Output",
 CellTags->"DiracSlash"]
}, Open  ]]
}, Open  ]],
Cell[492451, 20011, 59, 1, 39, "ObjectName",
 CellTags->"DiracSpinor"],
Cell[CellGroupData[{
Cell[492535, 20016, 62, 1, 33, "Subsubsection",
 CellTags->"DiracSpinor"],
Cell[492600, 20019, 288, 6, 39, "Text",
 CellTags->"DiracSpinor"],
Cell[492891, 20027, 170, 8, 23, "Text",
 CellTags->"DiracSpinor"]
}, Open  ]],
Cell[493076, 20038, 71, 1, 39, "ObjectName",
 CellTags->"DiracSubstitute67"],
Cell[CellGroupData[{
Cell[493172, 20043, 68, 1, 33, "Subsubsection",
 CellTags->"DiracSubstitute67"],
Cell[493243, 20046, 219, 5, 39, "Text",
 CellTags->"DiracSubstitute67"],
Cell[493465, 20053, 313, 13, 23, "Text",
 CellTags->"DiracSubstitute67"]
}, Open  ]],
Cell[493793, 20069, 57, 1, 39, "ObjectName",
 CellTags->"DiracTrace"],
Cell[CellGroupData[{
Cell[493875, 20074, 61, 1, 33, "Subsubsection",
 CellTags->"DiracTrace"],
Cell[493939, 20077, 336, 6, 39, "Text",
 CellTags->"DiracTrace"],
Cell[CellGroupData[{
Cell[494300, 20087, 119, 3, 27, "Input",
 CellTags->"DiracTrace"],
Cell[494422, 20092, 668, 16, 45, "Output",
 CellTags->"DiracTrace"]
}, Open  ]],
Cell[495105, 20111, 283, 12, 23, "Text",
 CellTags->"DiracTrace"],
Cell[495391, 20125, 163, 9, 23, "Text",
 CellTags->"DiracTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[495591, 20139, 58, 1, 33, "Subsubsection",
 CellTags->"DiracTrace"],
Cell[CellGroupData[{
Cell[495674, 20144, 174, 5, 27, "Input",
 CellTags->"DiracTrace"],
Cell[495851, 20151, 270, 9, 27, "Output",
 CellTags->"DiracTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[496158, 20165, 209, 6, 27, "Input",
 CellTags->"DiracTrace"],
Cell[496370, 20173, 370, 11, 27, "Output",
 CellTags->"DiracTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[496777, 20189, 149, 4, 27, "Input",
 CellTags->"DiracTrace"],
Cell[496929, 20195, 635, 22, 27, "Output",
 CellTags->"DiracTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[497601, 20222, 296, 8, 27, "Input",
 CellTags->"DiracTrace"],
Cell[497900, 20232, 566, 23, 25, "Output",
 CellTags->"DiracTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[498503, 20260, 334, 9, 27, "Input",
 CellTags->"DiracTrace"],
Cell[498840, 20271, 8415, 321, 47, "Output",
 CellTags->"DiracTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[507292, 20597, 186, 5, 27, "Input",
 CellTags->"DiracTrace"],
Cell[507481, 20604, 498, 15, 25, "Output",
 CellTags->"DiracTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[508016, 20624, 294, 8, 27, "Input",
 CellTags->"DiracTrace"],
Cell[508313, 20634, 182, 6, 25, "Output",
 CellTags->"DiracTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[508532, 20645, 111, 3, 27, "Input",
 CellTags->"DiracTrace"],
Cell[508646, 20650, 175, 5, 39, "Output",
 CellTags->"DiracTrace"]
}, Open  ]]
}, Open  ]],
Cell[508848, 20659, 73, 1, 39, "ObjectName",
 CellTags->"DiracTraceEvaluate"],
Cell[CellGroupData[{
Cell[508946, 20664, 69, 1, 33, "Subsubsection",
 CellTags->"DiracTraceEvaluate"],
Cell[509018, 20667, 162, 4, 23, "Text",
 CellTags->"DiracTraceEvaluate"],
Cell[509183, 20673, 281, 13, 23, "Text",
 CellTags->"DiracTraceEvaluate"]
}, Open  ]],
Cell[509479, 20689, 57, 1, 39, "ObjectName",
 CellTags->"DiracTrick"],
Cell[CellGroupData[{
Cell[509561, 20694, 61, 1, 33, "Subsubsection",
 CellTags->"DiracTrick"],
Cell[509625, 20697, 222, 5, 39, "Text",
 CellTags->"DiracTrick"],
Cell[CellGroupData[{
Cell[509872, 20706, 119, 3, 27, "Input",
 CellTags->"DiracTrick"],
Cell[509994, 20711, 174, 6, 25, "Output",
 CellTags->"DiracTrick"]
}, Open  ]],
Cell[510183, 20720, 428, 19, 23, "Text",
 CellTags->"DiracTrick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[510648, 20744, 58, 1, 33, "Subsubsection",
 CellTags->"DiracTrick"],
Cell[510709, 20747, 96, 1, 23, "Text",
 CellTags->"DiracTrick"],
Cell[CellGroupData[{
Cell[510830, 20752, 175, 5, 27, "Input",
 CellTags->"DiracTrick"],
Cell[511008, 20759, 247, 7, 25, "Output",
 CellTags->"DiracTrick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[511292, 20771, 114, 3, 27, "Input",
 CellTags->"DiracTrick"],
Cell[511409, 20776, 247, 7, 25, "Output",
 CellTags->"DiracTrick"]
}, Open  ]],
Cell[511671, 20786, 93, 1, 23, "Text",
 CellTags->"DiracTrick"],
Cell[CellGroupData[{
Cell[511789, 20791, 176, 5, 27, "Input",
 CellTags->"DiracTrick"],
Cell[511968, 20798, 247, 7, 25, "Output",
 CellTags->"DiracTrick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[512252, 20810, 114, 3, 27, "Input",
 CellTags->"DiracTrick"],
Cell[512369, 20815, 247, 7, 25, "Output",
 CellTags->"DiracTrick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[512653, 20827, 171, 5, 27, "Input",
 CellTags->"DiracTrick"],
Cell[512827, 20834, 243, 7, 27, "Output",
 CellTags->"DiracTrick"]
}, Open  ]],
Cell[513085, 20844, 176, 7, 23, "Text",
 CellTags->"DiracTrick"],
Cell[CellGroupData[{
Cell[513286, 20855, 114, 3, 27, "Input",
 CellTags->"DiracTrick"],
Cell[513403, 20860, 243, 7, 27, "Output",
 CellTags->"DiracTrick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[513683, 20872, 167, 5, 27, "Input",
 CellTags->"DiracTrick"],
Cell[513853, 20879, 239, 7, 27, "Output",
 CellTags->"DiracTrick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[514129, 20891, 114, 3, 27, "Input",
 CellTags->"DiracTrick"],
Cell[514246, 20896, 239, 7, 27, "Output",
 CellTags->"DiracTrick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[514522, 20908, 323, 10, 27, "Input",
 CellTags->"DiracTrick"],
Cell[514848, 20920, 567, 18, 25, "Output",
 CellTags->"DiracTrick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[515452, 20943, 114, 3, 27, "Input",
 CellTags->"DiracTrick"],
Cell[515569, 20948, 567, 18, 25, "Output",
 CellTags->"DiracTrick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[516173, 20971, 108, 3, 27, "Input",
 CellTags->"DiracTrick"],
Cell[516284, 20976, 1905, 72, 27, "Output",
 CellTags->"DiracTrick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[518226, 21053, 370, 12, 27, "Input",
 CellTags->"DiracTrick"],
Cell[518599, 21067, 621, 18, 25, "Output",
 CellTags->"DiracTrick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[519257, 21090, 113, 3, 27, "Input",
 CellTags->"DiracTrick"],
Cell[519373, 21095, 621, 18, 25, "Output",
 CellTags->"DiracTrick"]
}, Open  ]]
}, Open  ]],
Cell[520021, 21117, 55, 1, 39, "ObjectName",
 CellTags->"Divideout"],
Cell[CellGroupData[{
Cell[520101, 21122, 60, 1, 33, "Subsubsection",
 CellTags->"Divideout"],
Cell[520164, 21125, 137, 4, 23, "Text",
 CellTags->"Divideout"],
Cell[520304, 21131, 281, 13, 23, "Text",
 CellTags->"Divideout"]
}, Open  ]],
Cell[520600, 21147, 43, 1, 39, "ObjectName",
 CellTags->"DOT"],
Cell[CellGroupData[{
Cell[520668, 21152, 54, 1, 33, "Subsubsection",
 CellTags->"DOT"],
Cell[520725, 21155, 348, 8, 87, "Text",
 CellTags->"DOT"],
Cell[521076, 21165, 177, 8, 23, "Text",
 CellTags->"DOT"]
}, Open  ]],
Cell[521268, 21176, 55, 1, 39, "ObjectName",
 CellTags->"DotExpand"],
Cell[CellGroupData[{
Cell[521348, 21181, 60, 1, 33, "Subsubsection",
 CellTags->"DotExpand"],
Cell[521411, 21184, 85, 1, 23, "Text",
 CellTags->"DotExpand"],
Cell[521499, 21187, 582, 23, 23, "Text",
 CellTags->"DotExpand"]
}, Open  ]],
Cell[CellGroupData[{
Cell[522118, 21215, 57, 1, 33, "Subsubsection",
 CellTags->"DotExpand"],
Cell[CellGroupData[{
Cell[522200, 21220, 313, 10, 27, "Input",
 CellTags->"DotExpand"],
Cell[522516, 21232, 504, 13, 25, "Output",
 CellTags->"DotExpand"]
}, Open  ]],
Cell[523035, 21248, 229, 7, 27, "Input",
 CellTags->"DotExpand"],
Cell[CellGroupData[{
Cell[523289, 21259, 313, 10, 27, "Input",
 CellTags->"DotExpand"],
Cell[523605, 21271, 639, 22, 25, "Output",
 CellTags->"DotExpand"]
}, Open  ]],
Cell[524259, 21296, 231, 7, 27, "Input",
 CellTags->"DotExpand"],
Cell[CellGroupData[{
Cell[524515, 21307, 313, 10, 27, "Input",
 CellTags->"DotExpand"],
Cell[524831, 21319, 504, 13, 25, "Output",
 CellTags->"DotExpand"]
}, Open  ]]
}, Open  ]],
Cell[525362, 21336, 53, 1, 39, "ObjectName",
 CellTags->"DotPower"],
Cell[CellGroupData[{
Cell[525440, 21341, 59, 1, 33, "Subsubsection",
 CellTags->"DotPower"],
Cell[525502, 21344, 189, 4, 23, "Text",
 CellTags->"DotPower"],
Cell[525694, 21350, 182, 8, 23, "Text",
 CellTags->"DotPower"]
}, Open  ]],
Cell[525891, 21361, 57, 1, 39, "ObjectName",
 CellTags->"DotProduct"],
Cell[CellGroupData[{
Cell[525973, 21366, 61, 1, 33, "Subsubsection",
 CellTags->"DotProduct"],
Cell[526037, 21369, 219, 5, 39, "Text",
 CellTags->"DotProduct"],
Cell[526259, 21376, 312, 14, 23, "Text",
 CellTags->"DotProduct"]
}, Open  ]],
Cell[CellGroupData[{
Cell[526608, 21395, 58, 1, 33, "Subsubsection",
 CellTags->"DotProduct"],
Cell[CellGroupData[{
Cell[526691, 21400, 234, 7, 27, "Input",
 CellTags->"DotProduct"],
Cell[526928, 21409, 314, 11, 28, "Output",
 CellTags->"DotProduct"]
}, Open  ]]
}, Open  ]],
Cell[527269, 21424, 77, 1, 39, "ObjectName",
 CellTags->"DotSimplifyRelations"],
Cell[CellGroupData[{
Cell[527371, 21429, 71, 1, 33, "Subsubsection",
 CellTags->"DotSimplifyRelations"],
Cell[527445, 21432, 241, 5, 39, "Text",
 CellTags->"DotSimplifyRelations"],
Cell[527689, 21439, 194, 8, 23, "Text",
 CellTags->"DotSimplifyRelations"]
}, Open  ]],
Cell[527898, 21450, 59, 1, 39, "ObjectName",
 CellTags->"DotSimplify"],
Cell[CellGroupData[{
Cell[527982, 21455, 62, 1, 33, "Subsubsection",
 CellTags->"DotSimplify"],
Cell[528047, 21458, 322, 6, 39, "Text",
 CellTags->"DotSimplify"],
Cell[CellGroupData[{
Cell[528394, 21468, 121, 3, 27, "Input",
 CellTags->"DotSimplify"],
Cell[528518, 21473, 381, 11, 25, "Output",
 CellTags->"DotSimplify"]
}, Open  ]],
Cell[528914, 21487, 414, 19, 23, "Text",
 CellTags->"DotSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[529365, 21511, 59, 1, 33, "Subsubsection",
 CellTags->"DotSimplify"],
Cell[CellGroupData[{
Cell[529449, 21516, 342, 11, 27, "Input",
 CellTags->"DotSimplify"],
Cell[529794, 21529, 376, 11, 25, "Output",
 CellTags->"DotSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[530207, 21545, 116, 3, 27, "Input",
 CellTags->"DotSimplify"],
Cell[530326, 21550, 1013, 39, 25, "Output",
 CellTags->"DotSimplify"]
}, Open  ]],
Cell[531354, 21592, 158, 4, 27, "Input",
 CellTags->"DotSimplify"],
Cell[CellGroupData[{
Cell[531537, 21600, 209, 7, 27, "Input",
 CellTags->"DotSimplify"],
Cell[531749, 21609, 217, 8, 25, "Output",
 CellTags->"DotSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[532003, 21622, 116, 3, 27, "Input",
 CellTags->"DotSimplify"],
Cell[532122, 21627, 223, 7, 25, "Output",
 CellTags->"DotSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[532382, 21639, 161, 5, 27, "Input",
 CellTags->"DotSimplify"],
Cell[532546, 21646, 107, 3, 25, "Output",
 CellTags->"DotSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[532690, 21654, 116, 3, 27, "Input",
 CellTags->"DotSimplify"],
Cell[532809, 21659, 279, 10, 25, "Output",
 CellTags->"DotSimplify"]
}, Open  ]],
Cell[533103, 21672, 161, 5, 27, "Input",
 CellTags->"DotSimplify"],
Cell[CellGroupData[{
Cell[533289, 21681, 116, 3, 27, "Input",
 CellTags->"DotSimplify"],
Cell[533408, 21686, 223, 7, 25, "Output",
 CellTags->"DotSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[533668, 21698, 165, 5, 27, "Input",
 CellTags->"DotSimplify"],
Cell[533836, 21705, 107, 3, 25, "Output",
 CellTags->"DotSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[533980, 21713, 116, 3, 27, "Input",
 CellTags->"DotSimplify"],
Cell[534099, 21718, 277, 9, 25, "Output",
 CellTags->"DotSimplify"]
}, Open  ]],
Cell[534391, 21730, 165, 5, 27, "Input",
 CellTags->"DotSimplify"],
Cell[CellGroupData[{
Cell[534581, 21739, 299, 9, 27, "Input",
 CellTags->"DotSimplify"],
Cell[534883, 21750, 166, 6, 25, "Output",
 CellTags->"DotSimplify"]
}, Open  ]],
Cell[535064, 21759, 125, 3, 27, "Input",
 CellTags->"DotSimplify"],
Cell[CellGroupData[{
Cell[535214, 21766, 148, 4, 27, "Input",
 CellTags->"DotSimplify"],
Cell[535365, 21772, 140, 4, 25, "Output",
 CellTags->"DotSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[535542, 21781, 213, 6, 27, "Input",
 CellTags->"DotSimplify"],
Cell[535758, 21789, 140, 4, 25, "Output",
 CellTags->"DotSimplify"]
}, Open  ]],
Cell[535913, 21796, 170, 4, 27, "Input",
 CellTags->"DotSimplify"]
}, Open  ]],
Cell[536098, 21803, 57, 1, 39, "ObjectName",
 CellTags->"DummyIndex"],
Cell[CellGroupData[{
Cell[536180, 21808, 61, 1, 33, "Subsubsection",
 CellTags->"DummyIndex"],
Cell[536244, 21811, 191, 4, 23, "Text",
 CellTags->"DummyIndex"],
Cell[536438, 21817, 181, 8, 23, "Text",
 CellTags->"DummyIndex"]
}, Open  ]],
Cell[536634, 21828, 41, 1, 39, "ObjectName",
 CellTags->"D0"],
Cell[CellGroupData[{
Cell[536700, 21833, 53, 1, 33, "Subsubsection",
 CellTags->"D0"],
Cell[536756, 21836, 524, 12, 55, "Text",
 CellTags->"D0"],
Cell[537283, 21850, 458, 24, 23, "Text",
 CellTags->"D0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[537778, 21879, 50, 1, 33, "Subsubsection",
 CellTags->"D0"],
Cell[CellGroupData[{
Cell[537853, 21884, 315, 9, 27, "Input",
 CellTags->"D0"],
Cell[538171, 21895, 550, 20, 29, "Output",
 CellTags->"D0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[538758, 21920, 484, 14, 27, "Input",
 CellTags->"D0"],
Cell[539245, 21936, 550, 20, 29, "Output",
 CellTags->"D0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[539832, 21961, 104, 3, 27, "Input",
 CellTags->"D0"],
Cell[539939, 21966, 550, 20, 29, "Output",
 CellTags->"D0"]
}, Open  ]]
}, Open  ]],
Cell[540516, 21990, 61, 1, 39, "ObjectName",
 CellTags->"D0Convention"],
Cell[CellGroupData[{
Cell[540602, 21995, 63, 1, 33, "Subsubsection",
 CellTags->"D0Convention"],
Cell[540668, 21998, 307, 6, 39, "Text",
 CellTags->"D0Convention"],
Cell[540978, 22006, 263, 13, 23, "Text",
 CellTags->"D0Convention"]
}, Open  ]],
Cell[541256, 22022, 43, 1, 39, "ObjectName",
 CellTags->"Eps"],
Cell[CellGroupData[{
Cell[541324, 22027, 54, 1, 33, "Subsubsection",
 CellTags->"Eps"],
Cell[541381, 22030, 345, 8, 39, "Text",
 CellTags->"Eps"],
Cell[CellGroupData[{
Cell[541751, 22042, 105, 3, 27, "Input",
 CellTags->"Eps"],
Cell[541859, 22047, 160, 5, 25, "Output",
 CellTags->"Eps"]
}, Open  ]],
Cell[542034, 22055, 486, 24, 23, "Text",
 CellTags->"Eps"]
}, Open  ]],
Cell[CellGroupData[{
Cell[542557, 22084, 51, 1, 33, "Subsubsection",
 CellTags->"Eps"],
Cell[CellGroupData[{
Cell[542633, 22089, 322, 8, 27, "Input",
 CellTags->"Eps"],
Cell[542958, 22099, 477, 21, 25, "Output",
 CellTags->"Eps"]
}, Open  ]],
Cell[CellGroupData[{
Cell[543472, 22125, 314, 8, 27, "Input",
 CellTags->"Eps"],
Cell[543789, 22135, 435, 19, 25, "Output",
 CellTags->"Eps"]
}, Open  ]],
Cell[CellGroupData[{
Cell[544261, 22159, 181, 6, 27, "Input",
 CellTags->"Eps"],
Cell[544445, 22167, 176, 5, 39, "Output",
 CellTags->"Eps"]
}, Open  ]],
Cell[CellGroupData[{
Cell[544658, 22177, 142, 4, 27, "Input",
 CellTags->"Eps"],
Cell[544803, 22183, 99, 3, 25, "Output",
 CellTags->"Eps"]
}, Open  ]],
Cell[CellGroupData[{
Cell[544939, 22191, 142, 4, 27, "Input",
 CellTags->"Eps"],
Cell[545084, 22197, 117, 4, 25, "Output",
 CellTags->"Eps"]
}, Open  ]],
Cell[545216, 22204, 189, 6, 27, "Input",
 CellTags->"Eps"],
Cell[CellGroupData[{
Cell[545430, 22214, 460, 13, 27, "Input",
 CellTags->"Eps"],
Cell[545893, 22229, 477, 21, 25, "Output",
 CellTags->"Eps"]
}, Open  ]],
Cell[CellGroupData[{
Cell[546407, 22255, 107, 3, 27, "Input",
 CellTags->"Eps"],
Cell[546517, 22260, 102, 3, 25, "Output",
 CellTags->"Eps"]
}, Open  ]],
Cell[546634, 22266, 189, 6, 27, "Input",
 CellTags->"Eps"],
Cell[CellGroupData[{
Cell[546848, 22276, 460, 13, 27, "Input",
 CellTags->"Eps"],
Cell[547311, 22291, 477, 21, 25, "Output",
 CellTags->"Eps"]
}, Open  ]],
Cell[CellGroupData[{
Cell[547825, 22317, 137, 4, 27, "Input",
 CellTags->"Eps"],
Cell[547965, 22323, 102, 3, 25, "Output",
 CellTags->"Eps"]
}, Open  ]],
Cell[CellGroupData[{
Cell[548104, 22331, 293, 9, 27, "Input"],
Cell[548400, 22342, 366, 9, 25, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[548803, 22356, 77, 2, 27, "Input"],
Cell[548883, 22360, 974, 41, 25, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[549894, 22406, 433, 14, 43, "Input",
 CellTags->"Eps"],
Cell[550330, 22422, 1119, 45, 43, "Output",
 CellTags->"Eps"]
}, Open  ]],
Cell[CellGroupData[{
Cell[551486, 22472, 978, 28, 43, "Input",
 CellTags->"Eps"],
Cell[552467, 22502, 1679, 61, 43, "Output",
 CellTags->"Eps"]
}, Open  ]],
Cell[CellGroupData[{
Cell[554183, 22568, 188, 6, 27, "Input",
 CellTags->"Eps"],
Cell[554374, 22576, 342, 12, 43, "Output",
 CellTags->"Eps"]
}, Open  ]],
Cell[CellGroupData[{
Cell[554753, 22593, 124, 4, 27, "Input",
 CellTags->"Eps"],
Cell[554880, 22599, 99, 3, 25, "Output",
 CellTags->"Eps"]
}, Open  ]],
Cell[554994, 22605, 164, 5, 27, "Input",
 CellTags->"Eps"]
}, Open  ]],
Cell[555173, 22613, 59, 1, 39, "ObjectName",
 CellTags->"EpsChisholm"],
Cell[CellGroupData[{
Cell[555257, 22618, 62, 1, 33, "Subsubsection",
 CellTags->"EpsChisholm"],
Cell[555322, 22621, 166, 4, 23, "Text",
 CellTags->"EpsChisholm"],
Cell[555491, 22627, 182, 9, 23, "Text",
 CellTags->"EpsChisholm"]
}, Open  ]],
Cell[CellGroupData[{
Cell[555710, 22641, 59, 1, 33, "Subsubsection",
 CellTags->"EpsChisholm"],
Cell[CellGroupData[{
Cell[555794, 22646, 208, 6, 27, "Input",
 CellTags->"EpsChisholm"],
Cell[556005, 22654, 2019, 78, 27, "Output",
 CellTags->"EpsChisholm"]
}, Open  ]],
Cell[CellGroupData[{
Cell[558061, 22737, 115, 3, 27, "Input",
 CellTags->"EpsChisholm"],
Cell[558179, 22742, 594, 24, 25, "Output",
 CellTags->"EpsChisholm"]
}, Open  ]]
}, Open  ]],
Cell[558800, 22770, 59, 1, 39, "ObjectName",
 CellTags->"EpsContract"],
Cell[CellGroupData[{
Cell[558884, 22775, 62, 1, 33, "Subsubsection",
 CellTags->"EpsContract"],
Cell[558949, 22778, 227, 5, 39, "Text",
 CellTags->"EpsContract"],
Cell[559179, 22785, 277, 14, 23, "Text",
 CellTags->"EpsContract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[559493, 22804, 59, 1, 33, "Subsubsection",
 CellTags->"EpsContract"],
Cell[CellGroupData[{
Cell[559577, 22809, 468, 13, 27, "Input",
 CellTags->"EpsContract"],
Cell[560048, 22824, 485, 21, 25, "Output",
 CellTags->"EpsContract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[560570, 22850, 205, 6, 27, "Input",
 CellTags->"EpsContract"],
Cell[560778, 22858, 569, 23, 30, "Output",
 CellTags->"EpsContract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[561384, 22886, 204, 6, 27, "Input",
 CellTags->"EpsContract"],
Cell[561591, 22894, 320, 11, 27, "Output",
 CellTags->"EpsContract"]
}, Open  ]],
Cell[561926, 22908, 84, 2, 27, "Input"]
}, Open  ]],
Cell[562025, 22913, 57, 1, 39, "ObjectName",
 CellTags->"EpsDiscard"],
Cell[CellGroupData[{
Cell[562107, 22918, 61, 1, 33, "Subsubsection",
 CellTags->"EpsDiscard"],
Cell[562171, 22921, 169, 4, 23, "Text",
 CellTags->"EpsDiscard"],
Cell[562343, 22927, 196, 9, 23, "Text",
 CellTags->"EpsDiscard"]
}, Open  ]],
Cell[562554, 22939, 59, 1, 39, "ObjectName",
 CellTags->"EpsEvaluate"],
Cell[CellGroupData[{
Cell[562638, 22944, 62, 1, 33, "Subsubsection",
 CellTags->"EpsEvaluate"],
Cell[562703, 22947, 173, 4, 23, "Text",
 CellTags->"EpsEvaluate"],
Cell[562879, 22953, 494, 24, 23, "Text",
 CellTags->"EpsEvaluate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[563410, 22982, 59, 1, 33, "Subsubsection",
 CellTags->"EpsEvaluate"],
Cell[CellGroupData[{
Cell[563494, 22987, 335, 10, 27, "Input",
 CellTags->"EpsEvaluate"],
Cell[563832, 22999, 466, 20, 25, "Output",
 CellTags->"EpsEvaluate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[564335, 23024, 115, 3, 27, "Input",
 CellTags->"EpsEvaluate"],
Cell[564453, 23029, 466, 20, 25, "Output",
 CellTags->"EpsEvaluate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[564956, 23054, 116, 3, 27, "Input",
 CellTags->"EpsEvaluate"],
Cell[565075, 23059, 434, 12, 39, "Output",
 CellTags->"EpsEvaluate"]
}, Open  ]]
}, Open  ]],
Cell[565536, 23075, 63, 1, 39, "ObjectName",
 CellTags->"EpsUncontract"],
Cell[CellGroupData[{
Cell[565624, 23080, 64, 1, 33, "Subsubsection",
 CellTags->"EpsUncontract"],
Cell[565691, 23083, 115, 3, 23, "Text",
 CellTags->"EpsUncontract"],
Cell[565809, 23088, 285, 14, 23, "Text",
 CellTags->"EpsUncontract"]
}, Open  ]],
Cell[566109, 23105, 51, 1, 39, "ObjectName",
 CellTags->"Epsilon"],
Cell[CellGroupData[{
Cell[566185, 23110, 58, 1, 33, "Subsubsection",
 CellTags->"Epsilon"],
Cell[566246, 23113, 237, 9, 23, "Text",
 CellTags->"Epsilon"],
Cell[566486, 23124, 175, 9, 23, "Text",
 CellTags->"Epsilon"]
}, Open  ]],
Cell[CellGroupData[{
Cell[566698, 23138, 55, 1, 33, "Subsubsection",
 CellTags->"Epsilon"],
Cell[CellGroupData[{
Cell[566778, 23143, 80, 2, 27, "Input",
 CellTags->"Epsilon"],
Cell[566861, 23147, 148, 5, 25, "Output",
 CellTags->"Epsilon"]
}, Open  ]],
Cell[567024, 23155, 114, 3, 23, "Text",
 CellTags->"Epsilon"],
Cell[CellGroupData[{
Cell[567163, 23162, 587, 19, 27, "Input",
 CellTags->"Epsilon"],
Cell[567753, 23183, 199, 6, 25, "Output",
 CellTags->"Epsilon"]
}, Open  ]]
}, Open  ]],
Cell[567979, 23193, 61, 1, 39, "ObjectName",
 CellTags->"EpsilonOrder"],
Cell[CellGroupData[{
Cell[568065, 23198, 63, 1, 33, "Subsubsection",
 CellTags->"EpsilonOrder"],
Cell[568131, 23201, 305, 12, 23, "Text",
 CellTags->"EpsilonOrder"],
Cell[568439, 23215, 287, 14, 23, "Text",
 CellTags->"EpsilonOrder"]
}, Open  ]],
Cell[568741, 23232, 55, 1, 39, "ObjectName",
 CellTags->"Expanding"],
Cell[CellGroupData[{
Cell[568821, 23237, 60, 1, 33, "Subsubsection",
 CellTags->"Expanding"],
Cell[568884, 23240, 378, 7, 55, "Text",
 CellTags->"Expanding"],
Cell[569265, 23249, 641, 29, 23, "Text",
 CellTags->"Expanding"]
}, Open  ]],
Cell[569921, 23281, 65, 1, 39, "ObjectName",
 CellTags->"ExpandPartialD"],
Cell[CellGroupData[{
Cell[570011, 23286, 65, 1, 33, "Subsubsection",
 CellTags->"ExpandPartialD"],
Cell[570079, 23289, 188, 4, 23, "Text",
 CellTags->"ExpandPartialD"],
Cell[CellGroupData[{
Cell[570292, 23297, 98, 2, 27, "Input"],
Cell[570393, 23301, 1041, 36, 29, "Output"]
}, Open  ]],
Cell[571449, 23340, 724, 28, 23, "Text",
 CellTags->"ExpandPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[572210, 23373, 62, 1, 33, "Subsubsection",
 CellTags->"ExpandPartialD"],
Cell[CellGroupData[{
Cell[572297, 23378, 373, 10, 27, "Input",
 CellTags->"ExpandPartialD"],
Cell[572673, 23390, 345, 12, 32, "Output",
 CellTags->"ExpandPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[573055, 23407, 121, 3, 27, "Input",
 CellTags->"ExpandPartialD"],
Cell[573179, 23412, 773, 30, 29, "Output",
 CellTags->"ExpandPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[573989, 23447, 115, 3, 27, "Input",
 CellTags->"ExpandPartialD"],
Cell[574107, 23452, 798, 21, 59, "Output",
 CellTags->"ExpandPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[574942, 23478, 259, 7, 27, "Input",
 CellTags->"ExpandPartialD"],
Cell[575204, 23487, 312, 11, 32, "Output",
 CellTags->"ExpandPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[575553, 23503, 121, 3, 27, "Input",
 CellTags->"ExpandPartialD"],
Cell[575677, 23508, 704, 26, 43, "Output",
 CellTags->"ExpandPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[576418, 23539, 433, 13, 27, "Input",
 CellTags->"ExpandPartialD"],
Cell[576854, 23554, 332, 10, 35, "Output",
 CellTags->"ExpandPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[577223, 23569, 121, 3, 27, "Input",
 CellTags->"ExpandPartialD"],
Cell[577347, 23574, 1940, 67, 43, "Output",
 CellTags->"ExpandPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[579324, 23646, 180, 6, 27, "Input",
 CellTags->"ExpandPartialD"],
Cell[579507, 23654, 267, 8, 34, "Output",
 CellTags->"ExpandPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[579811, 23667, 123, 3, 27, "Input",
 CellTags->"ExpandPartialD"],
Cell[579937, 23672, 438, 14, 36, "Output",
 CellTags->"ExpandPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[580412, 23691, 121, 3, 27, "Input",
 CellTags->"ExpandPartialD"],
Cell[580536, 23696, 1877, 59, 29, "Output",
 CellTags->"ExpandPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[582450, 23760, 314, 9, 27, "Input",
 CellTags->"ExpandPartialD"],
Cell[582767, 23771, 1192, 47, 32, "Output",
 CellTags->"ExpandPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[583996, 23823, 121, 3, 27, "Input",
 CellTags->"ExpandPartialD"],
Cell[584120, 23828, 110, 3, 25, "Output",
 CellTags->"ExpandPartialD"]
}, Open  ]]
}, Open  ]],
Cell[584257, 23835, 121, 1, 39, "ObjectName",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
Cell[CellGroupData[{
Cell[584403, 23840, 95, 1, 33, "Subsubsection",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
Cell[584501, 23843, 252, 5, 47, "Text",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
Cell[CellGroupData[{
Cell[584778, 23852, 158, 3, 27, "Input",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
Cell[584939, 23857, 214, 6, 25, "Output",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}]
}, Open  ]],
Cell[585168, 23866, 462, 19, 23, "Text",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[585667, 23890, 92, 1, 33, "Subsubsection",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
Cell[CellGroupData[{
Cell[585784, 23895, 257, 7, 27, "Input",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
Cell[586044, 23904, 338, 10, 25, "Output",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[586419, 23919, 152, 3, 27, "Input",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
Cell[586574, 23924, 1214, 49, 25, "Output",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[587825, 23978, 186, 5, 27, "Input",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
Cell[588014, 23985, 277, 9, 25, "Output",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[588328, 23999, 156, 3, 27, "Input",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
Cell[588487, 24004, 331, 12, 27, "Output",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[588855, 24021, 190, 5, 27, "Input",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
Cell[589048, 24028, 227, 7, 25, "Output",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[589312, 24040, 156, 3, 27, "Input",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
Cell[589471, 24045, 441, 18, 25, "Output",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[589949, 24068, 239, 7, 27, "Input",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
Cell[590191, 24077, 312, 10, 25, "Output",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[590540, 24092, 184, 4, 27, "Input",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}],
Cell[590727, 24098, 565, 22, 27, "Output",
 CellTags->{"ScalarProductCancel", "ExpandScalarProduct"}]
}, Open  ]]
}, Open  ]],
Cell[591319, 24124, 51, 1, 39, "ObjectName",
 CellTags->"Expand2"],
Cell[CellGroupData[{
Cell[591395, 24129, 58, 1, 33, "Subsubsection",
 CellTags->"Expand2"],
Cell[591456, 24132, 164, 4, 23, "Text",
 CellTags->"Expand2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[591657, 24141, 55, 1, 33, "Subsubsection",
 CellTags->"Expand2"],
Cell[CellGroupData[{
Cell[591737, 24146, 579, 21, 27, "Input",
 CellTags->"Expand2"],
Cell[592319, 24169, 574, 19, 27, "Output",
 CellTags->"Expand2"]
}, Open  ]]
}, Open  ]],
Cell[592920, 24192, 53, 1, 39, "ObjectName",
 CellTags->"Explicit"],
Cell[CellGroupData[{
Cell[592998, 24197, 59, 1, 33, "Subsubsection",
 CellTags->"Explicit"],
Cell[593060, 24200, 401, 9, 39, "Text",
 CellTags->"Explicit"],
Cell[593464, 24211, 331, 14, 23, "Text",
 CellTags->"Explicit"],
Cell[CellGroupData[{
Cell[593820, 24229, 88, 2, 27, "Input"],
Cell[593911, 24233, 345, 10, 25, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[594305, 24249, 56, 1, 33, "Subsubsection",
 CellTags->"Explicit"],
Cell[CellGroupData[{
Cell[594386, 24254, 134, 3, 27, "Input"],
Cell[594523, 24259, 183, 6, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[594743, 24270, 86, 2, 27, "Input"],
Cell[594832, 24274, 241, 8, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[595110, 24287, 233, 6, 27, "Input"],
Cell[595346, 24295, 776, 28, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[596159, 24328, 230, 6, 27, "Input",
 CellTags->"Explicit"],
Cell[596392, 24336, 940, 42, 27, "Output",
 CellTags->"Explicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[597369, 24383, 109, 3, 27, "Input",
 CellTags->"Explicit"],
Cell[597481, 24388, 1971, 79, 27, "Output",
 CellTags->"Explicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[599489, 24472, 184, 5, 27, "Input",
 CellTags->"Explicit"],
Cell[599676, 24479, 892, 36, 43, "Output",
 CellTags->"Explicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[600605, 24520, 109, 3, 27, "Input",
 CellTags->"Explicit"],
Cell[600717, 24525, 2644, 102, 43, "Output",
 CellTags->"Explicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[603398, 24632, 155, 4, 27, "Input",
 CellTags->"Explicit"],
Cell[603556, 24638, 163, 5, 29, "Output",
 CellTags->"Explicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[603756, 24648, 109, 3, 27, "Input",
 CellTags->"Explicit"],
Cell[603868, 24653, 1744, 77, 31, "Output",
 CellTags->"Explicit"]
}, Open  ]]
}, Open  ]],
Cell[605639, 24734, 77, 1, 39, "ObjectName",
 CellTags->"ExplicitLorentzIndex"],
Cell[CellGroupData[{
Cell[605741, 24739, 71, 1, 33, "Subsubsection",
 CellTags->"ExplicitLorentzIndex"],
Cell[605815, 24742, 141, 4, 23, "Text",
 CellTags->"ExplicitLorentzIndex"],
Cell[605959, 24748, 295, 13, 23, "Text",
 CellTags->"ExplicitLorentzIndex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[606291, 24766, 68, 1, 33, "Subsubsection",
 CellTags->"ExplicitLorentzIndex"],
Cell[CellGroupData[{
Cell[606384, 24771, 224, 6, 27, "Input",
 CellTags->"ExplicitLorentzIndex"],
Cell[606611, 24779, 199, 7, 27, "Output",
 CellTags->"ExplicitLorentzIndex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[606847, 24791, 121, 3, 27, "Input",
 CellTags->"ExplicitLorentzIndex"],
Cell[606971, 24796, 247, 6, 39, "Output",
 CellTags->"ExplicitLorentzIndex"]
}, Open  ]]
}, Open  ]],
Cell[607245, 24806, 69, 1, 39, "ObjectName",
 CellTags->"ExplicitPartialD"],
Cell[CellGroupData[{
Cell[607339, 24811, 67, 1, 33, "Subsubsection",
 CellTags->"ExplicitPartialD"],
Cell[607409, 24814, 162, 4, 23, "Text",
 CellTags->"ExplicitPartialD"],
Cell[607574, 24820, 476, 18, 23, "Text",
 CellTags->"ExplicitPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[608087, 24843, 64, 1, 33, "Subsubsection",
 CellTags->"ExplicitPartialD"],
Cell[CellGroupData[{
Cell[608176, 24848, 183, 4, 27, "Input",
 CellTags->"ExplicitPartialD"],
Cell[608362, 24854, 525, 19, 43, "Output",
 CellTags->"ExplicitPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[608924, 24878, 184, 4, 27, "Input",
 CellTags->"ExplicitPartialD"],
Cell[609111, 24884, 430, 16, 32, "Output",
 CellTags->"ExplicitPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[609578, 24905, 186, 4, 27, "Input",
 CellTags->"ExplicitPartialD"],
Cell[609767, 24911, 461, 15, 43, "Output",
 CellTags->"ExplicitPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[610265, 24931, 183, 6, 27, "Input",
 CellTags->"ExplicitPartialD"],
Cell[610451, 24939, 270, 8, 34, "Output",
 CellTags->"ExplicitPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[610758, 24952, 125, 3, 27, "Input",
 CellTags->"ExplicitPartialD"],
Cell[610886, 24957, 440, 14, 36, "Output",
 CellTags->"ExplicitPartialD"]
}, Open  ]]
}, Open  ]],
Cell[611353, 24975, 69, 1, 39, "ObjectName",
 CellTags->"ExplicitSUNIndex"],
Cell[CellGroupData[{
Cell[611447, 24980, 67, 1, 33, "Subsubsection",
 CellTags->"ExplicitSUNIndex"],
Cell[611517, 24983, 178, 6, 23, "Text",
 CellTags->"ExplicitSUNIndex"],
Cell[611698, 24991, 484, 23, 23, "Text",
 CellTags->"ExplicitSUNIndex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[612219, 25019, 64, 1, 33, "Subsubsection",
 CellTags->"ExplicitSUNIndex"],
Cell[CellGroupData[{
Cell[612308, 25024, 125, 3, 27, "Input",
 CellTags->"ExplicitSUNIndex"],
Cell[612436, 25029, 112, 3, 25, "Output",
 CellTags->"ExplicitSUNIndex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[612585, 25037, 176, 6, 27, "Input"],
Cell[612764, 25045, 204, 5, 39, "Output"]
}, Open  ]]
}, Open  ]],
Cell[612995, 25054, 59, 1, 39, "ObjectName",
 CellTags->"ExtraFactor"],
Cell[CellGroupData[{
Cell[613079, 25059, 62, 1, 33, "Subsubsection",
 CellTags->"ExtraFactor"],
Cell[613144, 25062, 199, 4, 23, "Text",
 CellTags->"ExtraFactor"],
Cell[613346, 25068, 194, 8, 23, "Text",
 CellTags->"ExtraFactor"]
}, Open  ]],
Cell[613555, 25079, 65, 1, 39, "ObjectName",
 CellTags->"ExtraVariables"],
Cell[CellGroupData[{
Cell[613645, 25084, 65, 1, 33, "Subsubsection",
 CellTags->"ExtraVariables"],
Cell[613713, 25087, 213, 5, 39, "Text",
 CellTags->"ExtraVariables"],
Cell[613929, 25094, 298, 14, 23, "Text",
 CellTags->"ExtraVariables"]
}, Open  ]],
Cell[614242, 25111, 57, 1, 39, "ObjectName",
 CellTags->"FactorFull"],
Cell[CellGroupData[{
Cell[614324, 25116, 61, 1, 33, "Subsubsection",
 CellTags->"FactorFull"],
Cell[614388, 25119, 509, 24, 23, "Text",
 CellTags->"FactorFull"],
Cell[614900, 25145, 178, 9, 23, "Text",
 CellTags->"FactorFull"]
}, Open  ]],
Cell[615093, 25157, 55, 1, 39, "ObjectName",
 CellTags->"Factoring"],
Cell[CellGroupData[{
Cell[615173, 25162, 60, 1, 33, "Subsubsection",
 CellTags->"Factoring"],
Cell[615236, 25165, 235, 5, 39, "Text",
 CellTags->"Factoring"],
Cell[615474, 25172, 382, 19, 23, "Text",
 CellTags->"Factoring"]
}, Open  ]],
Cell[615871, 25194, 55, 1, 39, "ObjectName",
 CellTags->"Factorout"],
Cell[CellGroupData[{
Cell[615951, 25199, 60, 1, 33, "Subsubsection",
 CellTags->"Factorout"],
Cell[616014, 25202, 74, 1, 23, "Text",
 CellTags->"Factorout"],
Cell[616091, 25205, 174, 9, 23, "Text",
 CellTags->"Factorout"]
}, Open  ]],
Cell[616280, 25217, 57, 1, 39, "ObjectName",
 CellTags->"FactorTime"],
Cell[CellGroupData[{
Cell[616362, 25222, 61, 1, 33, "Subsubsection",
 CellTags->"FactorTime"],
Cell[616426, 25225, 166, 4, 23, "Text",
 CellTags->"FactorTime"],
Cell[616595, 25231, 178, 9, 23, "Text",
 CellTags->"FactorTime"]
}, Open  ]],
Cell[616788, 25243, 51, 1, 39, "ObjectName",
 CellTags->"Factor1"],
Cell[CellGroupData[{
Cell[616864, 25248, 58, 1, 33, "Subsubsection",
 CellTags->"Factor1"],
Cell[616925, 25251, 144, 4, 23, "Text",
 CellTags->"Factor1"],
Cell[617072, 25257, 175, 9, 23, "Text",
 CellTags->"Factor1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[617284, 25271, 55, 1, 33, "Subsubsection",
 CellTags->"Factor1"],
Cell[CellGroupData[{
Cell[617364, 25276, 213, 8, 27, "Input",
 CellTags->"Factor1"],
Cell[617580, 25286, 224, 8, 25, "Output",
 CellTags->"Factor1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[617841, 25299, 222, 7, 27, "Input",
 CellTags->"Factor1"],
Cell[618066, 25308, 435, 16, 25, "Output",
 CellTags->"Factor1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[618538, 25329, 251, 9, 27, "Input",
 CellTags->"Factor1"],
Cell[618792, 25340, 176, 6, 27, "Output",
 CellTags->"Factor1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[619005, 25351, 107, 3, 27, "Input",
 CellTags->"Factor1"],
Cell[619115, 25356, 224, 8, 25, "Output",
 CellTags->"Factor1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[619376, 25369, 108, 3, 27, "Input",
 CellTags->"Factor1"],
Cell[619487, 25374, 176, 6, 27, "Output",
 CellTags->"Factor1"]
}, Open  ]],
Cell[619678, 25383, 141, 4, 27, "Input",
 CellTags->"Factor1"]
}, Open  ]],
Cell[619834, 25390, 51, 1, 39, "ObjectName",
 CellTags->"Factor2"],
Cell[CellGroupData[{
Cell[619910, 25395, 58, 1, 33, "Subsubsection",
 CellTags->"Factor2"],
Cell[619971, 25398, 398, 7, 55, "Text",
 CellTags->"Factor2"],
Cell[CellGroupData[{
Cell[620394, 25409, 113, 3, 27, "Input",
 CellTags->"Factor2"],
Cell[620510, 25414, 230, 7, 25, "Output",
 CellTags->"Factor2"]
}, Open  ]],
Cell[620755, 25424, 178, 9, 23, "Text",
 CellTags->"Factor2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[620970, 25438, 55, 1, 33, "Subsubsection",
 CellTags->"Factor2"],
Cell[CellGroupData[{
Cell[621050, 25443, 213, 8, 27, "Input",
 CellTags->"Factor2"],
Cell[621266, 25453, 224, 8, 25, "Output",
 CellTags->"Factor2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[621527, 25466, 222, 7, 27, "Input",
 CellTags->"Factor2"],
Cell[621752, 25475, 435, 16, 25, "Output",
 CellTags->"Factor2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[622224, 25496, 251, 9, 27, "Input",
 CellTags->"Factor2"],
Cell[622478, 25507, 176, 6, 27, "Output",
 CellTags->"Factor2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[622691, 25518, 107, 3, 27, "Input",
 CellTags->"Factor2"],
Cell[622801, 25523, 224, 8, 25, "Output",
 CellTags->"Factor2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[623062, 25536, 108, 3, 27, "Input",
 CellTags->"Factor2"],
Cell[623173, 25541, 176, 6, 27, "Output",
 CellTags->"Factor2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[623386, 25552, 173, 5, 27, "Input",
 CellTags->"Factor2"],
Cell[623562, 25559, 224, 8, 25, "Output",
 CellTags->"Factor2"]
}, Open  ]],
Cell[623801, 25570, 141, 4, 27, "Input",
 CellTags->"Factor2"]
}, Open  ]],
Cell[623957, 25577, 43, 1, 39, "ObjectName",
 CellTags->"FAD"],
Cell[CellGroupData[{
Cell[624025, 25582, 54, 1, 33, "Subsubsection",
 CellTags->"FAD"],
Cell[624082, 25585, 335, 6, 55, "Text",
 CellTags->"FAD"],
Cell[624420, 25593, 802, 34, 23, "Text",
 CellTags->"FAD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[625259, 25632, 51, 1, 33, "Subsubsection",
 CellTags->"FAD"],
Cell[CellGroupData[{
Cell[625335, 25637, 146, 5, 27, "Input",
 CellTags->"FAD"],
Cell[625484, 25644, 700, 20, 49, "Output",
 CellTags->"FAD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[626221, 25669, 197, 7, 27, "Input",
 CellTags->"FAD"],
Cell[626421, 25678, 819, 22, 49, "Output",
 CellTags->"FAD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[627277, 25705, 245, 9, 27, "Input",
 CellTags->"FAD"],
Cell[627525, 25716, 161, 5, 39, "Output",
 CellTags->"FAD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[627723, 25726, 215, 8, 27, "Input",
 CellTags->"FAD"],
Cell[627941, 25736, 525, 15, 59, "Output",
 CellTags->"FAD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[628503, 25756, 280, 9, 27, "Input",
 CellTags->"FAD"],
Cell[628786, 25767, 527, 16, 59, "Output",
 CellTags->"FAD"]
}, Open  ]]
}, Open  ]],
Cell[629340, 25787, 41, 1, 39, "ObjectName",
 CellTags->"FC"],
Cell[CellGroupData[{
Cell[629406, 25792, 53, 1, 33, "Subsubsection",
 CellTags->"FC"],
Cell[629462, 25795, 117, 3, 23, "Text",
 CellTags->"FC"],
Cell[629582, 25800, 545, 24, 23, "Text",
 CellTags->"FC"]
}, Open  ]],
Cell[CellGroupData[{
Cell[630164, 25829, 50, 1, 33, "Subsubsection",
 CellTags->"FC"],
Cell[630217, 25832, 70, 2, 27, "Input",
 CellTags->"FC"],
Cell[CellGroupData[{
Cell[630312, 25838, 227, 7, 27, "Input",
 CellTags->"FC"],
Cell[630542, 25847, 100, 2, 25, "Output",
 CellTags->"FC"]
}, Open  ]],
Cell[630657, 25852, 70, 2, 27, "Input",
 CellTags->"FC"],
Cell[CellGroupData[{
Cell[630752, 25858, 227, 7, 27, "Input",
 CellTags->"FC"],
Cell[630982, 25867, 305, 11, 29, "Output",
 CellTags->"FC"]
}, Open  ]]
}, Open  ]],
Cell[631314, 25882, 43, 1, 39, "ObjectName",
 CellTags->"FCE"],
Cell[CellGroupData[{
Cell[631382, 25887, 54, 1, 33, "Subsubsection",
 CellTags->"FCE"],
Cell[631439, 25890, 126, 4, 23, "Text",
 CellTags->"FCE"],
Cell[631568, 25896, 72, 1, 23, "Text",
 CellTags->"FCE"],
Cell[631643, 25899, 427, 19, 23, "Text",
 CellTags->"FCE"]
}, Open  ]],
Cell[CellGroupData[{
Cell[632107, 25923, 51, 1, 33, "Subsubsection",
 CellTags->"FCE"],
Cell[CellGroupData[{
Cell[632183, 25928, 262, 8, 27, "Input",
 CellTags->"FCE"],
Cell[632448, 25938, 225, 8, 29, "Output",
 CellTags->"FCE"]
}, Open  ]],
Cell[CellGroupData[{
Cell[632710, 25951, 104, 3, 27, "Input",
 CellTags->"FCE"],
Cell[632817, 25956, 190, 6, 39, "Output",
 CellTags->"FCE"]
}, Open  ]],
Cell[CellGroupData[{
Cell[633044, 25967, 437, 13, 27, "Input",
 CellTags->"FCE"],
Cell[633484, 25982, 547, 18, 27, "Output",
 CellTags->"FCE"]
}, Open  ]],
Cell[CellGroupData[{
Cell[634068, 26005, 104, 3, 27, "Input",
 CellTags->"FCE"],
Cell[634175, 26010, 452, 13, 39, "Output",
 CellTags->"FCE"]
}, Open  ]],
Cell[CellGroupData[{
Cell[634664, 26028, 95, 3, 27, "Input",
 CellTags->"FCE"],
Cell[634762, 26033, 862, 34, 27, "Output",
 CellTags->"FCE"]
}, Open  ]],
Cell[CellGroupData[{
Cell[635661, 26072, 104, 3, 27, "Input",
 CellTags->"FCE"],
Cell[635768, 26077, 893, 24, 78, "Output",
 CellTags->"FCE"]
}, Open  ]],
Cell[CellGroupData[{
Cell[636698, 26106, 134, 4, 27, "Input",
 CellTags->"FCE"],
Cell[636835, 26112, 452, 13, 39, "Output",
 CellTags->"FCE"]
}, Open  ]]
}, Open  ]],
Cell[637314, 26129, 43, 1, 39, "ObjectName",
 CellTags->"FCI"],
Cell[CellGroupData[{
Cell[637382, 26134, 54, 1, 33, "Subsubsection",
 CellTags->"FCI"],
Cell[637439, 26137, 159, 4, 23, "Text",
 CellTags->"FCI"],
Cell[637601, 26143, 427, 19, 23, "Text",
 CellTags->"FCI"]
}, Open  ]],
Cell[CellGroupData[{
Cell[638065, 26167, 51, 1, 33, "Subsubsection",
 CellTags->"FCI"],
Cell[CellGroupData[{
Cell[638141, 26172, 437, 13, 27, "Input",
 CellTags->"FCI"],
Cell[638581, 26187, 547, 18, 27, "Output",
 CellTags->"FCI"]
}, Open  ]],
Cell[CellGroupData[{
Cell[639165, 26210, 104, 3, 27, "Input",
 CellTags->"FCI"],
Cell[639272, 26215, 452, 13, 39, "Output",
 CellTags->"FCI"]
}, Open  ]],
Cell[CellGroupData[{
Cell[639761, 26233, 95, 3, 27, "Input",
 CellTags->"FCI"],
Cell[639859, 26238, 862, 34, 27, "Output",
 CellTags->"FCI"]
}, Open  ]],
Cell[CellGroupData[{
Cell[640758, 26277, 104, 3, 27, "Input",
 CellTags->"FCI"],
Cell[640865, 26282, 893, 24, 78, "Output",
 CellTags->"FCI"]
}, Open  ]],
Cell[CellGroupData[{
Cell[641795, 26311, 134, 4, 27, "Input",
 CellTags->"FCI"],
Cell[641932, 26317, 452, 13, 39, "Output",
 CellTags->"FCI"]
}, Open  ]]
}, Open  ]],
Cell[642411, 26334, 57, 1, 39, "ObjectName",
 CellTags->"FCIntegral"],
Cell[CellGroupData[{
Cell[642493, 26339, 61, 1, 33, "Subsubsection",
 CellTags->"FCIntegral"],
Cell[642557, 26342, 209, 5, 39, "Text",
 CellTags->"FCIntegral"],
Cell[642769, 26349, 360, 14, 23, "Text",
 CellTags->"FCIntegral"]
}, Open  ]],
Cell[643144, 26366, 59, 1, 39, "ObjectName",
 CellTags->"FCIntegrate"],
Cell[CellGroupData[{
Cell[643228, 26371, 62, 1, 33, "Subsubsection",
 CellTags->"FCIntegrate"],
Cell[643293, 26374, 285, 5, 39, "Text",
 CellTags->"FCIntegrate"],
Cell[643581, 26381, 194, 9, 23, "Text",
 CellTags->"FCIntegrate"]
}, Open  ]],
Cell[643790, 26393, 61, 1, 39, "ObjectName",
 CellTags->"FCNIntegrate"],
Cell[CellGroupData[{
Cell[643876, 26398, 63, 1, 33, "Subsubsection",
 CellTags->"FCNIntegrate"],
Cell[643942, 26401, 418, 7, 55, "Text",
 CellTags->"FCNIntegrate"],
Cell[644363, 26410, 192, 9, 23, "Text",
 CellTags->"FCNIntegrate"]
}, Open  ]],
Cell[644570, 26422, 50, 1, 39, "ObjectName",
 CellTags->"FC2RHI"],
Cell[CellGroupData[{
Cell[644645, 26427, 57, 1, 33, "Subsubsection",
 CellTags->"FC2RHI"],
Cell[644705, 26430, 306, 6, 39, "Text",
 CellTags->"FC2RHI"],
Cell[CellGroupData[{
Cell[645036, 26440, 111, 3, 27, "Input",
 CellTags->"FC2RHI"],
Cell[645150, 26445, 277, 8, 25, "Output",
 CellTags->"FC2RHI"]
}, Open  ]],
Cell[CellGroupData[{
Cell[645464, 26458, 349, 12, 27, "Input"],
Cell[645816, 26472, 506, 18, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[646359, 26495, 119, 3, 27, "Input"],
Cell[646481, 26500, 473, 20, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[646991, 26525, 83, 2, 27, "Input"],
Cell[647077, 26529, 94, 1, 39, "Output"]
}, Open  ]],
Cell[647186, 26533, 162, 9, 23, "Text",
 CellTags->"FC2RHI"]
}, Open  ]],
Cell[CellGroupData[{
Cell[647385, 26547, 54, 1, 33, "Subsubsection",
 CellTags->"FC2RHI"],
Cell[647442, 26550, 72, 2, 27, "Input",
 CellTags->"FC2RHI"]
}, Open  ]],
Cell[647529, 26555, 50, 1, 39, "ObjectName",
 CellTags->"FC2TLI"],
Cell[CellGroupData[{
Cell[647604, 26560, 57, 1, 33, "Subsubsection",
 CellTags->"FC2TLI"],
Cell[647664, 26563, 256, 5, 39, "Text",
 CellTags->"FC2TLI"],
Cell[CellGroupData[{
Cell[647945, 26572, 111, 3, 27, "Input",
 CellTags->"FC2TLI"],
Cell[648059, 26577, 277, 8, 25, "Output",
 CellTags->"FC2TLI"]
}, Open  ]],
Cell[CellGroupData[{
Cell[648373, 26590, 71, 2, 27, "Input"],
Cell[648447, 26594, 321, 5, 107, "Print",
 CellTags->"Info3522790263-4590919"]
}, Open  ]],
Cell[CellGroupData[{
Cell[648805, 26604, 365, 12, 27, "Input"],
Cell[649173, 26618, 1483, 42, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[650693, 26665, 119, 3, 27, "Input"],
Cell[650815, 26670, 699, 29, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[651551, 26704, 83, 2, 27, "Input"],
Cell[651637, 26708, 100, 1, 39, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[651774, 26714, 84, 2, 27, "Input"],
Cell[651861, 26718, 588, 21, 50, "Output"]
}, Open  ]],
Cell[652464, 26742, 162, 9, 23, "Text",
 CellTags->"FC2TLI"]
}, Open  ]],
Cell[CellGroupData[{
Cell[652663, 26756, 54, 1, 33, "Subsubsection",
 CellTags->"FC2TLI"],
Cell[652720, 26759, 72, 2, 27, "Input",
 CellTags->"FC2TLI"]
}, Open  ]],
Cell[652807, 26764, 43, 1, 39, "ObjectName",
 CellTags->"FDS"],
Cell[CellGroupData[{
Cell[652875, 26769, 54, 1, 33, "Subsubsection",
 CellTags->"FDS"],
Cell[652932, 26772, 82, 1, 23, "Text",
 CellTags->"FDS"],
Cell[653017, 26775, 228, 9, 23, "Text",
 CellTags->"FDS"]
}, Open  ]],
Cell[653260, 26787, 65, 1, 39, "ObjectName",
 CellTags->"FermionSpinSum"],
Cell[CellGroupData[{
Cell[653350, 26792, 65, 1, 33, "Subsubsection",
 CellTags->"FermionSpinSum"],
Cell[653418, 26795, 118, 3, 23, "Text",
 CellTags->"FermionSpinSum"],
Cell[CellGroupData[{
Cell[653561, 26802, 127, 3, 27, "Input",
 CellTags->"FermionSpinSum"],
Cell[653691, 26807, 314, 9, 25, "Output",
 CellTags->"FermionSpinSum"]
}, Open  ]],
Cell[654020, 26819, 521, 24, 23, "Text",
 CellTags->"FermionSpinSum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[654578, 26848, 62, 1, 33, "Subsubsection",
 CellTags->"FermionSpinSum"],
Cell[654643, 26851, 261, 12, 23, "Text",
 CellTags->"FermionSpinSum"],
Cell[CellGroupData[{
Cell[654929, 26867, 296, 9, 27, "Input",
 CellTags->"FermionSpinSum"],
Cell[655228, 26878, 353, 13, 25, "Output",
 CellTags->"FermionSpinSum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[655618, 26896, 143, 4, 27, "Input",
 CellTags->"FermionSpinSum"],
Cell[655764, 26902, 330, 12, 25, "Output",
 CellTags->"FermionSpinSum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[656131, 26919, 143, 4, 27, "Input",
 CellTags->"FermionSpinSum"],
Cell[656277, 26925, 133, 4, 25, "Output",
 CellTags->"FermionSpinSum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[656447, 26934, 296, 9, 27, "Input",
 CellTags->"FermionSpinSum"],
Cell[656746, 26945, 353, 13, 25, "Output",
 CellTags->"FermionSpinSum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[657136, 26963, 143, 4, 27, "Input",
 CellTags->"FermionSpinSum"],
Cell[657282, 26969, 330, 12, 25, "Output",
 CellTags->"FermionSpinSum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[657649, 26986, 143, 4, 27, "Input",
 CellTags->"FermionSpinSum"],
Cell[657795, 26992, 152, 5, 25, "Output",
 CellTags->"FermionSpinSum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[657984, 27002, 334, 10, 27, "Input",
 CellTags->"FermionSpinSum"],
Cell[658321, 27014, 508, 17, 27, "Output",
 CellTags->"FermionSpinSum"]
}, Open  ]],
Cell[658844, 27034, 164, 4, 23, "Text",
 CellTags->"FermionSpinSum"],
Cell[CellGroupData[{
Cell[659033, 27042, 147, 4, 27, "Input",
 CellTags->"FermionSpinSum"],
Cell[659183, 27048, 540, 18, 27, "Output",
 CellTags->"FermionSpinSum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[659760, 27071, 145, 4, 27, "Input",
 CellTags->"FermionSpinSum"],
Cell[659908, 27077, 1074, 36, 29, "Output",
 CellTags->"FermionSpinSum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[661019, 27118, 148, 4, 27, "Input",
 CellTags->"FermionSpinSum"],
Cell[661170, 27124, 837, 32, 29, "Output",
 CellTags->"FermionSpinSum"]
}, Open  ]],
Cell[662022, 27159, 141, 4, 27, "Input",
 CellTags->"FermionSpinSum"]
}, Open  ]],
Cell[662178, 27166, 51, 1, 39, "ObjectName",
 CellTags->"FeynAmp"],
Cell[CellGroupData[{
Cell[662254, 27171, 58, 1, 33, "Subsubsection",
 CellTags->"FeynAmp"],
Cell[662315, 27174, 243, 5, 39, "Text",
 CellTags->"FeynAmp"],
Cell[662561, 27181, 165, 4, 23, "Text",
 CellTags->"FeynAmp"],
Cell[662729, 27187, 181, 9, 23, "Text",
 CellTags->"FeynAmp"]
}, Open  ]],
Cell[CellGroupData[{
Cell[662947, 27201, 55, 1, 33, "Subsubsection",
 CellTags->"FeynAmp"],
Cell[663005, 27204, 125, 4, 23, "Text",
 CellTags->"FeynAmp"],
Cell[CellGroupData[{
Cell[663155, 27212, 846, 22, 48, "Input",
 CellTags->"FeynAmp"],
Cell[664004, 27236, 2586, 102, 39, "Output",
 CellTags->"FeynAmp"]
}, Open  ]],
Cell[666605, 27341, 73, 1, 23, "Text",
 CellTags->"FeynAmp"],
Cell[CellGroupData[{
Cell[666703, 27346, 198, 6, 27, "Input",
 CellTags->"FeynAmp"],
Cell[666904, 27354, 414, 14, 39, "Output",
 CellTags->"FeynAmp"]
}, Open  ]]
}, Open  ]],
Cell[667345, 27372, 73, 1, 39, "ObjectName",
 CellTags->"FeynAmpDenominator"],
Cell[CellGroupData[{
Cell[667443, 27377, 69, 1, 33, "Subsubsection",
 CellTags->"FeynAmpDenominator"],
Cell[667515, 27380, 256, 5, 39, "Text",
 CellTags->"FeynAmpDenominator"],
Cell[667774, 27387, 338, 14, 23, "Text",
 CellTags->"FeynAmpDenominator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[668149, 27406, 66, 1, 33, "Subsubsection",
 CellTags->"FeynAmpDenominator"],
Cell[CellGroupData[{
Cell[668240, 27411, 201, 5, 27, "Input",
 CellTags->"FeynAmpDenominator"],
Cell[668444, 27418, 211, 7, 48, "Output",
 CellTags->"FeynAmpDenominator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[668692, 27430, 326, 9, 27, "Input",
 CellTags->"FeynAmpDenominator"],
Cell[669021, 27441, 430, 15, 49, "Output",
 CellTags->"FeynAmpDenominator"]
}, Open  ]],
Cell[669466, 27459, 247, 7, 27, "Input",
 CellTags->"FeynAmpDenominator"],
Cell[CellGroupData[{
Cell[669738, 27470, 149, 4, 27, "Input",
 CellTags->"FeynAmpDenominator"],
Cell[669890, 27476, 279, 7, 39, "Output",
 CellTags->"FeynAmpDenominator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[670206, 27488, 149, 4, 27, "Input",
 CellTags->"FeynAmpDenominator"],
Cell[670358, 27494, 176, 5, 39, "Output",
 CellTags->"FeynAmpDenominator"]
}, Open  ]],
Cell[670549, 27502, 134, 4, 27, "Input",
 CellTags->"FeynAmpDenominator"]
}, Open  ]],
Cell[670698, 27509, 87, 1, 39, "ObjectName",
 CellTags->"FeynAmpDenominatorCombine"],
Cell[CellGroupData[{
Cell[670810, 27514, 76, 1, 33, "Subsubsection",
 CellTags->"FeynAmpDenominatorCombine"],
Cell[670889, 27517, 228, 5, 39, "Text",
 CellTags->"FeynAmpDenominatorCombine"],
Cell[671120, 27524, 241, 9, 23, "Text",
 CellTags->"FeynAmpDenominatorCombine"]
}, Open  ]],
Cell[CellGroupData[{
Cell[671398, 27538, 73, 1, 33, "Subsubsection",
 CellTags->"FeynAmpDenominatorCombine"],
Cell[CellGroupData[{
Cell[671496, 27543, 234, 7, 27, "Input",
 CellTags->"FeynAmpDenominatorCombine"],
Cell[671733, 27552, 765, 23, 48, "Output",
 CellTags->"FeynAmpDenominatorCombine"]
}, Open  ]],
Cell[CellGroupData[{
Cell[672535, 27580, 208, 6, 27, "Input",
 CellTags->"FeynAmpDenominatorCombine"],
Cell[672746, 27588, 203, 6, 39, "Output",
 CellTags->"FeynAmpDenominatorCombine"]
}, Open  ]],
Cell[CellGroupData[{
Cell[672986, 27599, 206, 6, 27, "Input",
 CellTags->"FeynAmpDenominatorCombine"],
Cell[673195, 27607, 233, 7, 39, "Output",
 CellTags->"FeynAmpDenominatorCombine"]
}, Open  ]]
}, Open  ]],
Cell[673455, 27618, 89, 1, 39, "ObjectName",
 CellTags->"FeynAmpDenominatorSimplify"],
Cell[CellGroupData[{
Cell[673569, 27623, 77, 1, 33, "Subsubsection",
 CellTags->"FeynAmpDenominatorSimplify"],
Cell[673649, 27626, 398, 7, 55, "Text",
 CellTags->"FeynAmpDenominatorSimplify"],
Cell[674050, 27635, 85, 1, 23, "Text",
 CellTags->"FeynAmpDenominatorSimplify"],
Cell[CellGroupData[{
Cell[674160, 27640, 95, 2, 27, "Input",
 CellTags->"FeynAmpDenominatorSimplify"],
Cell[674258, 27644, 147, 3, 25, "Output",
 CellTags->"FeynAmpDenominatorSimplify"]
}, Open  ]],
Cell[674420, 27650, 218, 9, 23, "Text",
 CellTags->"FeynAmpDenominatorSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[674675, 27664, 74, 1, 33, "Subsubsection",
 CellTags->"FeynAmpDenominatorSimplify"],
Cell[674752, 27667, 432, 14, 25, "Text",
 CellTags->"FeynAmpDenominatorSimplify"],
Cell[CellGroupData[{
Cell[675209, 27685, 280, 8, 27, "Input",
 CellTags->"FeynAmpDenominatorSimplify"],
Cell[675492, 27695, 122, 3, 25, "Output",
 CellTags->"FeynAmpDenominatorSimplify"]
}, Open  ]],
Cell[675629, 27701, 468, 18, 25, "Text",
 CellTags->"FeynAmpDenominatorSimplify"],
Cell[CellGroupData[{
Cell[676122, 27723, 328, 10, 27, "Input",
 CellTags->"FeynAmpDenominatorSimplify"],
Cell[676453, 27735, 336, 11, 48, "Output",
 CellTags->"FeynAmpDenominatorSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[676826, 27751, 260, 7, 27, "Input",
 CellTags->"FeynAmpDenominatorSimplify"],
Cell[677089, 27760, 308, 10, 48, "Output",
 CellTags->"FeynAmpDenominatorSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[677434, 27775, 339, 10, 27, "Input",
 CellTags->"FeynAmpDenominatorSimplify"],
Cell[677776, 27787, 362, 12, 48, "Output",
 CellTags->"FeynAmpDenominatorSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[678175, 27804, 449, 14, 27, "Input",
 CellTags->"FeynAmpDenominatorSimplify"],
Cell[678627, 27820, 1091, 40, 50, "Output",
 CellTags->"FeynAmpDenominatorSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[679755, 27865, 215, 6, 27, "Input",
 CellTags->"FeynAmpDenominatorSimplify"],
Cell[679973, 27873, 1959, 70, 50, "Output",
 CellTags->"FeynAmpDenominatorSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[681969, 27948, 157, 4, 27, "Input",
 CellTags->"FeynAmpDenominatorSimplify"],
Cell[682129, 27954, 493, 18, 45, "Output",
 CellTags->"FeynAmpDenominatorSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[682659, 27977, 373, 13, 27, "Input",
 CellTags->"FeynAmpDenominatorSimplify"],
Cell[683035, 27992, 1361, 50, 51, "Output",
 CellTags->"FeynAmpDenominatorSimplify"]
}, Open  ]],
Cell[684411, 28045, 147, 4, 27, "Input",
 CellTags->"FeynAmpDenominatorSimplify"]
}, Open  ]],
Cell[684573, 28052, 83, 1, 39, "ObjectName",
 CellTags->"FeynAmpDenominatorSplit"],
Cell[CellGroupData[{
Cell[684681, 28057, 74, 1, 33, "Subsubsection",
 CellTags->"FeynAmpDenominatorSplit"],
Cell[684758, 28060, 357, 7, 55, "Text",
 CellTags->"FeynAmpDenominatorSplit"],
Cell[685118, 28069, 245, 9, 23, "Text",
 CellTags->"FeynAmpDenominatorSplit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[685400, 28083, 71, 1, 33, "Subsubsection",
 CellTags->"FeynAmpDenominatorSplit"],
Cell[CellGroupData[{
Cell[685496, 28088, 308, 9, 27, "Input",
 CellTags->"FeynAmpDenominatorSplit"],
Cell[685807, 28099, 489, 16, 48, "Output",
 CellTags->"FeynAmpDenominatorSplit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[686333, 28120, 116, 3, 27, "Input",
 CellTags->"FeynAmpDenominatorSplit"],
Cell[686452, 28125, 136, 3, 25, "Output",
 CellTags->"FeynAmpDenominatorSplit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[686625, 28133, 139, 3, 27, "Input",
 CellTags->"FeynAmpDenominatorSplit"],
Cell[686767, 28138, 489, 16, 48, "Output",
 CellTags->"FeynAmpDenominatorSplit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[687293, 28159, 150, 4, 27, "Input",
 CellTags->"FeynAmpDenominatorSplit"],
Cell[687446, 28165, 425, 13, 39, "Output",
 CellTags->"FeynAmpDenominatorSplit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[687908, 28183, 230, 7, 27, "Input",
 CellTags->"FeynAmpDenominatorSplit"],
Cell[688141, 28192, 368, 12, 39, "Output",
 CellTags->"FeynAmpDenominatorSplit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[688546, 28209, 206, 6, 27, "Input",
 CellTags->"FeynAmpDenominatorSplit"],
Cell[688755, 28217, 305, 9, 39, "Output",
 CellTags->"FeynAmpDenominatorSplit"]
}, Open  ]],
Cell[689075, 28229, 121, 3, 27, "Input",
 CellTags->"FeynAmpDenominatorSplit"]
}, Open  ]],
Cell[689211, 28235, 59, 1, 39, "ObjectName",
 CellTags->"FeynAmpList"],
Cell[CellGroupData[{
Cell[689295, 28240, 62, 1, 33, "Subsubsection",
 CellTags->"FeynAmpList"],
Cell[689360, 28243, 145, 4, 23, "Text",
 CellTags->"FeynAmpList"],
Cell[689508, 28249, 117, 3, 23, "Text",
 CellTags->"FeynAmpList"],
Cell[689628, 28254, 179, 9, 23, "Text",
 CellTags->"FeynAmpList"]
}, Open  ]],
Cell[689822, 28266, 53, 1, 39, "ObjectName",
 CellTags->"FeynCalc"],
Cell[CellGroupData[{
Cell[689900, 28271, 59, 1, 33, "Subsubsection",
 CellTags->"FeynCalc"],
Cell[689962, 28274, 91, 1, 23, "Text",
 CellTags->"FeynCalc"],
Cell[CellGroupData[{
Cell[690078, 28279, 99, 3, 27, "Input",
 CellTags->"FeynCalc"],
Cell[690180, 28284, 703, 11, 311, "Print",
 CellTags->{"FeynCalc", "Info3522790274-4590919"}]
}, Open  ]]
}, Open  ]],
Cell[690910, 28299, 69, 1, 39, "ObjectName",
 CellTags->"FeynCalcExternal"],
Cell[CellGroupData[{
Cell[691004, 28304, 67, 1, 33, "Subsubsection",
 CellTags->"FeynCalcExternal"],
Cell[691074, 28307, 156, 4, 23, "Text",
 CellTags->"FeynCalcExternal"],
Cell[691233, 28313, 211, 9, 23, "Text",
 CellTags->"FeynCalcExternal"]
}, Open  ]],
Cell[CellGroupData[{
Cell[691481, 28327, 64, 1, 33, "Subsubsection",
 CellTags->"FeynCalcExternal"],
Cell[CellGroupData[{
Cell[691570, 28332, 162, 4, 27, "Input",
 CellTags->"FeynCalcExternal"],
Cell[691735, 28338, 143, 4, 27, "Output",
 CellTags->"FeynCalcExternal"]
}, Open  ]],
Cell[CellGroupData[{
Cell[691915, 28347, 117, 3, 27, "Input",
 CellTags->"FeynCalcExternal"],
Cell[692035, 28352, 126, 3, 39, "Output",
 CellTags->"FeynCalcExternal"]
}, Open  ]],
Cell[CellGroupData[{
Cell[692198, 28360, 450, 13, 27, "Input",
 CellTags->"FeynCalcExternal"],
Cell[692651, 28375, 560, 18, 27, "Output",
 CellTags->"FeynCalcExternal"]
}, Open  ]],
Cell[CellGroupData[{
Cell[693248, 28398, 117, 3, 27, "Input",
 CellTags->"FeynCalcExternal"],
Cell[693368, 28403, 465, 13, 39, "Output",
 CellTags->"FeynCalcExternal"]
}, Open  ]],
Cell[CellGroupData[{
Cell[693870, 28421, 121, 3, 27, "Input",
 CellTags->"FeynCalcExternal"],
Cell[693994, 28426, 875, 34, 27, "Output",
 CellTags->"FeynCalcExternal"]
}, Open  ]],
Cell[CellGroupData[{
Cell[694906, 28465, 117, 3, 27, "Input",
 CellTags->"FeynCalcExternal"],
Cell[695026, 28470, 906, 24, 78, "Output",
 CellTags->"FeynCalcExternal"]
}, Open  ]],
Cell[CellGroupData[{
Cell[695969, 28499, 163, 5, 27, "Input",
 CellTags->"FeynCalcExternal"],
Cell[696135, 28506, 465, 13, 39, "Output",
 CellTags->"FeynCalcExternal"]
}, Open  ]]
}, Open  ]],
Cell[696627, 28523, 61, 1, 39, "ObjectName",
 CellTags->"FeynCalcForm"],
Cell[CellGroupData[{
Cell[696713, 28528, 63, 1, 33, "Subsubsection",
 CellTags->"FeynCalcForm"],
Cell[696779, 28531, 534, 10, 55, "Text",
 CellTags->"FeynCalcForm"],
Cell[697316, 28543, 433, 19, 23, "Text",
 CellTags->"FeynCalcForm"]
}, Open  ]],
Cell[CellGroupData[{
Cell[697786, 28567, 60, 1, 33, "Subsubsection",
 CellTags->"FeynCalcForm"],
Cell[697849, 28570, 79, 1, 23, "Text",
 CellTags->"FeynCalcForm"],
Cell[CellGroupData[{
Cell[697953, 28575, 242, 7, 27, "Input",
 CellTags->"FeynCalcForm"],
Cell[698198, 28584, 527, 22, 25, "Output",
 CellTags->"FeynCalcForm"]
}, Open  ]],
Cell[698740, 28609, 112, 3, 23, "Text",
 CellTags->"FeynCalcForm"],
Cell[698855, 28614, 148, 4, 27, "Input",
 CellTags->"FeynCalcForm"],
Cell[699006, 28620, 647, 19, 68, "Input",
 CellTags->"FeynCalcForm"],
Cell[CellGroupData[{
Cell[699678, 28643, 242, 7, 27, "Input",
 CellTags->"FeynCalcForm"],
Cell[699923, 28652, 564, 17, 25, "Output",
 CellTags->"FeynCalcForm"]
}, Open  ]],
Cell[700502, 28672, 76, 1, 23, "Text",
 CellTags->"FeynCalcForm"],
Cell[700581, 28675, 123, 4, 27, "Input",
 CellTags->"FeynCalcForm"],
Cell[700707, 28681, 652, 19, 68, "Input",
 CellTags->"FeynCalcForm"]
}, Open  ]],
Cell[701374, 28703, 69, 1, 39, "ObjectName",
 CellTags->"FeynCalcInternal"],
Cell[CellGroupData[{
Cell[701468, 28708, 67, 1, 33, "Subsubsection",
 CellTags->"FeynCalcInternal"],
Cell[701538, 28711, 157, 4, 23, "Text",
 CellTags->"FeynCalcInternal"],
Cell[701698, 28717, 401, 19, 23, "Text",
 CellTags->"FeynCalcInternal"]
}, Open  ]],
Cell[CellGroupData[{
Cell[702136, 28741, 64, 1, 33, "Subsubsection",
 CellTags->"FeynCalcInternal"],
Cell[CellGroupData[{
Cell[702225, 28746, 450, 13, 27, "Input",
 CellTags->"FeynCalcInternal"],
Cell[702678, 28761, 560, 18, 27, "Output",
 CellTags->"FeynCalcInternal"]
}, Open  ]],
Cell[CellGroupData[{
Cell[703275, 28784, 117, 3, 27, "Input",
 CellTags->"FeynCalcInternal"],
Cell[703395, 28789, 465, 13, 39, "Output",
 CellTags->"FeynCalcInternal"]
}, Open  ]],
Cell[CellGroupData[{
Cell[703897, 28807, 121, 3, 27, "Input",
 CellTags->"FeynCalcInternal"],
Cell[704021, 28812, 875, 34, 27, "Output",
 CellTags->"FeynCalcInternal"]
}, Open  ]],
Cell[CellGroupData[{
Cell[704933, 28851, 117, 3, 27, "Input",
 CellTags->"FeynCalcInternal"],
Cell[705053, 28856, 906, 24, 78, "Output",
 CellTags->"FeynCalcInternal"]
}, Open  ]],
Cell[CellGroupData[{
Cell[705996, 28885, 163, 5, 27, "Input",
 CellTags->"FeynCalcInternal"],
Cell[706162, 28892, 465, 13, 39, "Output",
 CellTags->"FeynCalcInternal"]
}, Open  ]],
Cell[CellGroupData[{
Cell[706664, 28910, 517, 15, 27, "Input",
 CellTags->"FeynCalcInternal"],
Cell[707184, 28927, 1461, 63, 48, "Output",
 CellTags->"FeynCalcInternal"]
}, Open  ]],
Cell[CellGroupData[{
Cell[708682, 28995, 117, 3, 27, "Input",
 CellTags->"FeynCalcInternal"],
Cell[708802, 29000, 1128, 30, 97, "Output",
 CellTags->"FeynCalcInternal"]
}, Open  ]]
}, Open  ]],
Cell[709957, 29034, 63, 1, 39, "ObjectName",
 CellTags->"FeynCalc2FORM"],
Cell[CellGroupData[{
Cell[710045, 29039, 64, 1, 33, "Subsubsection",
 CellTags->"FeynCalc2FORM"],
Cell[710112, 29042, 226, 5, 39, "Text",
 CellTags->"FeynCalc2FORM"],
Cell[710341, 29049, 199, 9, 23, "Text",
 CellTags->"FeynCalc2FORM"],
Cell[CellGroupData[{
Cell[710565, 29062, 125, 3, 27, "Input",
 CellTags->"FeynCalc2FORM"],
Cell[710693, 29067, 1022, 22, 45, "Output",
 CellTags->"FeynCalc2FORM"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[711764, 29095, 61, 1, 33, "Subsubsection",
 CellTags->"FeynCalc2FORM"],
Cell[CellGroupData[{
Cell[711850, 29100, 273, 9, 27, "Input",
 CellTags->"FeynCalc2FORM"],
Cell[712126, 29111, 276, 9, 46, "Output",
 CellTags->"FeynCalc2FORM"]
}, Open  ]],
Cell[CellGroupData[{
Cell[712439, 29125, 137, 4, 27, "Input",
 CellTags->"FeynCalc2FORM"],
Cell[712579, 29131, 68, 1, 21, "Print",
 CellTags->"FeynCalc2FORM"]
}, Open  ]],
Cell[CellGroupData[{
Cell[712684, 29137, 199, 6, 27, "Input",
 CellTags->"FeynCalc2FORM"],
Cell[712886, 29145, 199, 6, 25, "Output",
 CellTags->"FeynCalc2FORM"]
}, Open  ]],
Cell[CellGroupData[{
Cell[713122, 29156, 137, 4, 27, "Input",
 CellTags->"FeynCalc2FORM"],
Cell[713262, 29162, 66, 1, 21, "Print",
 CellTags->"FeynCalc2FORM"]
}, Open  ]],
Cell[CellGroupData[{
Cell[713365, 29168, 212, 6, 27, "Input",
 CellTags->"FeynCalc2FORM"],
Cell[713580, 29176, 373, 11, 27, "Output",
 CellTags->"FeynCalc2FORM"]
}, Open  ]],
Cell[CellGroupData[{
Cell[713990, 29192, 137, 4, 27, "Input",
 CellTags->"FeynCalc2FORM"],
Cell[714130, 29198, 88, 3, 21, "Print",
 CellTags->"FeynCalc2FORM"]
}, Open  ]],
Cell[CellGroupData[{
Cell[714255, 29206, 298, 9, 27, "Input",
 CellTags->"FeynCalc2FORM"],
Cell[714556, 29217, 473, 16, 27, "Output",
 CellTags->"FeynCalc2FORM"]
}, Open  ]],
Cell[CellGroupData[{
Cell[715066, 29238, 137, 4, 27, "Input",
 CellTags->"FeynCalc2FORM"],
Cell[715206, 29244, 88, 3, 21, "Print",
 CellTags->"FeynCalc2FORM"]
}, Open  ]],
Cell[715309, 29250, 328, 10, 27, "Input",
 CellTags->"FeynCalc2FORM"],
Cell[CellGroupData[{
Cell[715662, 29264, 332, 10, 27, "Input",
 CellTags->"FeynCalc2FORM"],
Cell[715997, 29276, 154, 4, 25, "Output",
 CellTags->"FeynCalc2FORM"]
}, Open  ]],
Cell[CellGroupData[{
Cell[716188, 29285, 314, 10, 27, "Input",
 CellTags->"FeynCalc2FORM"],
Cell[716505, 29297, 6179, 240, 47, "Output",
 CellTags->"FeynCalc2FORM"]
}, Open  ]],
Cell[722699, 29540, 209, 6, 27, "Input",
 CellTags->"FeynCalc2FORM"],
Cell[CellGroupData[{
Cell[722933, 29550, 376, 11, 27, "Input",
 CellTags->"FeynCalc2FORM"],
Cell[723312, 29563, 1338, 36, 225, "Output",
 CellTags->"FeynCalc2FORM"]
}, Open  ]],
Cell[724665, 29602, 313, 10, 27, "Input",
 CellTags->"FeynCalc2FORM"],
Cell[724981, 29614, 129, 4, 27, "Input",
 CellTags->"FeynCalc2FORM"]
}, Open  ]],
Cell[725125, 29621, 67, 1, 39, "ObjectName",
 CellTags->"FeynCalcToLaTeX"],
Cell[CellGroupData[{
Cell[725217, 29626, 66, 1, 33, "Subsubsection",
 CellTags->"FeynCalcToLaTeX"],
Cell[725286, 29629, 300, 6, 63, "Text",
 CellTags->"FeynCalcToLaTeX"],
Cell[CellGroupData[{
Cell[725611, 29639, 158, 4, 27, "Input"],
Cell[725772, 29645, 477, 18, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[726286, 29668, 93, 2, 27, "Input"],
Cell[726382, 29672, 531, 9, 121, "Output"]
}, Open  ]]
}, Open  ]],
Cell[726940, 29685, 79, 1, 39, "ObjectName",
 CellTags->"FeynmanParameterNames"],
Cell[CellGroupData[{
Cell[727044, 29690, 72, 1, 33, "Subsubsection",
 CellTags->"FeynmanParameterNames"],
Cell[727119, 29693, 143, 4, 23, "Text",
 CellTags->"FeynmanParameterNames"],
Cell[727265, 29699, 362, 14, 23, "Text",
 CellTags->"FeynmanParameterNames"]
}, Open  ]],
Cell[727642, 29716, 90, 1, 39, "ObjectName",
 CellTags->"FeynmanParametrize"],
Cell[CellGroupData[{
Cell[727757, 29721, 69, 1, 33, "Subsubsection",
 CellTags->"FeynmanParametrize"],
Cell[727829, 29724, 176, 4, 23, "Text",
 CellTags->"FeynmanParametrize"],
Cell[CellGroupData[{
Cell[728030, 29732, 135, 3, 27, "Input",
 CellTags->"FeynmanParametrize"],
Cell[728168, 29737, 251, 8, 25, "Output",
 CellTags->"FeynmanParametrize"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[728468, 29751, 66, 1, 33, "Subsubsection",
 CellTags->"FeynmanParametrize"],
Cell[728537, 29754, 84, 2, 27, "Input",
 CellTags->"FeynmanParametrize"]
}, Open  ]],
Cell[728636, 29759, 53, 1, 39, "ObjectName",
 CellTags->"FeynRule"],
Cell[CellGroupData[{
Cell[728714, 29764, 59, 1, 33, "Subsubsection",
 CellTags->"FeynRule"],
Cell[728776, 29767, 168, 4, 23, "Text",
 CellTags->"FeynRule"],
Cell[CellGroupData[{
Cell[728969, 29775, 115, 3, 27, "Input",
 CellTags->"FeynRule"],
Cell[729087, 29780, 630, 16, 45, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[729732, 29799, 92, 1, 23, "Text",
 CellTags->"FeynRule"],
Cell[729827, 29802, 133, 4, 23, "Text",
 CellTags->"FeynRule"],
Cell[729963, 29808, 185, 9, 23, "Text",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[CellGroupData[{
Cell[730185, 29822, 56, 1, 33, "Subsubsection",
 CellTags->"FeynRule"],
Cell[CellGroupData[{
Cell[730266, 29827, 146, 4, 27, "Input",
 CellTags->"FeynRule"],
Cell[730415, 29833, 680, 23, 43, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[CellGroupData[{
Cell[731132, 29861, 146, 4, 27, "Input",
 CellTags->"FeynRule"],
Cell[731281, 29867, 1003, 36, 43, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[CellGroupData[{
Cell[732321, 29908, 111, 3, 27, "Input",
 CellTags->"FeynRule"],
Cell[732435, 29913, 4554, 176, 43, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[CellGroupData[{
Cell[737026, 30094, 141, 4, 27, "Input",
 CellTags->"FeynRule"],
Cell[737170, 30100, 2656, 113, 31, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[739841, 30216, 74, 1, 23, "Text",
 CellTags->"FeynRule"],
Cell[CellGroupData[{
Cell[739940, 30221, 503, 16, 27, "Input",
 CellTags->"FeynRule"],
Cell[740446, 30239, 700, 30, 31, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[CellGroupData[{
Cell[741183, 30274, 307, 9, 27, "Input",
 CellTags->"FeynRule"],
Cell[741493, 30285, 3795, 138, 50, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[745303, 30426, 72, 1, 23, "Text",
 CellTags->"FeynRule"],
Cell[CellGroupData[{
Cell[745400, 30431, 503, 16, 27, "Input",
 CellTags->"FeynRule"],
Cell[745906, 30449, 700, 30, 31, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[CellGroupData[{
Cell[746643, 30484, 307, 9, 27, "Input",
 CellTags->"FeynRule"],
Cell[746953, 30495, 4465, 151, 50, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[CellGroupData[{
Cell[751455, 30651, 218, 7, 27, "Input",
 CellTags->"FeynRule"],
Cell[751676, 30660, 1044, 42, 29, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[752735, 30705, 110, 3, 23, "Text",
 CellTags->"FeynRule"],
Cell[CellGroupData[{
Cell[752870, 30712, 360, 10, 27, "Input",
 CellTags->"FeynRule"],
Cell[753233, 30724, 1108, 45, 29, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[754356, 30772, 77, 1, 23, "Text",
 CellTags->"FeynRule"],
Cell[CellGroupData[{
Cell[754458, 30777, 145, 4, 27, "Input",
 CellTags->"FeynRule"],
Cell[754606, 30783, 618, 22, 27, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[755239, 30808, 90, 1, 23, "Text",
 CellTags->"FeynRule"],
Cell[CellGroupData[{
Cell[755354, 30813, 145, 4, 27, "Input",
 CellTags->"FeynRule"],
Cell[755502, 30819, 618, 22, 27, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[CellGroupData[{
Cell[756157, 30846, 696, 21, 48, "Input",
 CellTags->"FeynRule"],
Cell[756856, 30869, 893, 37, 31, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[CellGroupData[{
Cell[757786, 30911, 227, 7, 27, "Input",
 CellTags->"FeynRule"],
Cell[758016, 30920, 4957, 177, 109, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[CellGroupData[{
Cell[763010, 31102, 420, 12, 27, "Input",
 CellTags->"FeynRule"],
Cell[763433, 31116, 4764, 159, 78, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[CellGroupData[{
Cell[768234, 31280, 362, 12, 27, "Input",
 CellTags->"FeynRule"],
Cell[768599, 31294, 104, 3, 25, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[768718, 31300, 210, 5, 39, "Text",
 CellTags->"FeynRule"],
Cell[768931, 31307, 144, 4, 27, "Input",
 CellTags->"FeynRule"],
Cell[769078, 31313, 51, 1, 23, "Text",
 CellTags->"FeynRule"],
Cell[CellGroupData[{
Cell[769154, 31318, 693, 21, 48, "Input",
 CellTags->"FeynRule"],
Cell[769850, 31341, 984, 42, 31, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[CellGroupData[{
Cell[770871, 31388, 212, 7, 27, "Input",
 CellTags->"FeynRule"],
Cell[771086, 31397, 1971, 79, 27, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[CellGroupData[{
Cell[773094, 31481, 385, 11, 27, "Input",
 CellTags->"FeynRule"],
Cell[773482, 31494, 1419, 57, 27, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[CellGroupData[{
Cell[774938, 31556, 197, 6, 27, "Input",
 CellTags->"FeynRule"],
Cell[775138, 31564, 104, 3, 25, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[CellGroupData[{
Cell[775279, 31572, 884, 26, 48, "Input",
 CellTags->"FeynRule"],
Cell[776166, 31600, 1270, 54, 31, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[CellGroupData[{
Cell[777473, 31659, 212, 7, 27, "Input",
 CellTags->"FeynRule"],
Cell[777688, 31668, 3305, 131, 29, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[CellGroupData[{
Cell[781030, 31804, 461, 13, 27, "Input",
 CellTags->"FeynRule"],
Cell[781494, 31819, 3470, 132, 29, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[CellGroupData[{
Cell[785001, 31956, 197, 6, 27, "Input",
 CellTags->"FeynRule"],
Cell[785201, 31964, 104, 3, 25, "Output",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[785320, 31970, 418, 9, 48, "Input",
 CellTags->"FeynRule"]
}, Open  ]],
Cell[785753, 31982, 41, 1, 39, "ObjectName",
 CellTags->"FI"],
Cell[CellGroupData[{
Cell[785819, 31987, 53, 1, 33, "Subsubsection",
 CellTags->"FI"],
Cell[785875, 31990, 195, 4, 39, "Text",
 CellTags->"FI"],
Cell[786073, 31996, 545, 24, 23, "Text",
 CellTags->"FI"]
}, Open  ]],
Cell[786633, 32023, 67, 1, 39, "ObjectName",
 CellTags->"FieldDerivative"],
Cell[CellGroupData[{
Cell[786725, 32028, 66, 1, 33, "Subsubsection",
 CellTags->"FieldDerivative"],
Cell[786794, 32031, 549, 9, 71, "Text",
 CellTags->"FieldDerivative"],
Cell[787346, 32042, 314, 14, 23, "Text",
 CellTags->"FieldDerivative"]
}, Open  ]],
Cell[CellGroupData[{
Cell[787697, 32061, 63, 1, 33, "Subsubsection",
 CellTags->"FieldDerivative"],
Cell[CellGroupData[{
Cell[787785, 32066, 620, 19, 27, "Input",
 CellTags->"FieldDerivative"],
Cell[788408, 32087, 465, 17, 28, "Output",
 CellTags->"FieldDerivative"]
}, Open  ]],
Cell[CellGroupData[{
Cell[788910, 32109, 218, 6, 27, "Input",
 CellTags->"FieldDerivative"],
Cell[789131, 32117, 1529, 55, 29, "Output",
 CellTags->"FieldDerivative"]
}, Open  ]],
Cell[CellGroupData[{
Cell[790697, 32177, 218, 6, 27, "Input",
 CellTags->"FieldDerivative"],
Cell[790918, 32185, 4269, 153, 52, "Output",
 CellTags->"FieldDerivative"]
}, Open  ]]
}, Open  ]],
Cell[795214, 32342, 63, 1, 39, "ObjectName",
 CellTags->"FieldStrength"],
Cell[CellGroupData[{
Cell[795302, 32347, 64, 1, 33, "Subsubsection",
 CellTags->"FieldStrength"],
Cell[795369, 32350, 1285, 37, 59, "Text",
 CellTags->"FieldStrength"],
Cell[CellGroupData[{
Cell[796679, 32391, 125, 3, 27, "Input",
 CellTags->"FieldStrength"],
Cell[796807, 32396, 529, 15, 45, "Output",
 CellTags->"FieldStrength"]
}, Open  ]],
Cell[797351, 32414, 196, 9, 23, "Text",
 CellTags->"FieldStrength"]
}, Open  ]],
Cell[CellGroupData[{
Cell[797584, 32428, 61, 1, 33, "Subsubsection",
 CellTags->"FieldStrength"],
Cell[CellGroupData[{
Cell[797670, 32433, 150, 4, 27, "Input",
 CellTags->"FieldStrength"],
Cell[797823, 32439, 174, 5, 29, "Output",
 CellTags->"FieldStrength"]
}, Open  ]],
Cell[CellGroupData[{
Cell[798034, 32449, 160, 4, 27, "Input",
 CellTags->"FieldStrength"],
Cell[798197, 32455, 168, 5, 29, "Output",
 CellTags->"FieldStrength"]
}, Open  ]],
Cell[CellGroupData[{
Cell[798402, 32465, 200, 5, 27, "Input",
 CellTags->"FieldStrength"],
Cell[798605, 32472, 722, 30, 29, "Output",
 CellTags->"FieldStrength"]
}, Open  ]],
Cell[CellGroupData[{
Cell[799364, 32507, 210, 5, 27, "Input",
 CellTags->"FieldStrength"],
Cell[799577, 32514, 1507, 65, 31, "Output",
 CellTags->"FieldStrength"]
}, Open  ]],
Cell[CellGroupData[{
Cell[801121, 32584, 241, 6, 27, "Input",
 CellTags->"FieldStrength"],
Cell[801365, 32592, 547, 15, 59, "Output",
 CellTags->"FieldStrength"]
}, Open  ]],
Cell[CellGroupData[{
Cell[801949, 32612, 244, 6, 27, "Input",
 CellTags->"FieldStrength"],
Cell[802196, 32620, 545, 15, 59, "Output",
 CellTags->"FieldStrength"]
}, Open  ]],
Cell[CellGroupData[{
Cell[802778, 32640, 291, 7, 27, "Input",
 CellTags->"FieldStrength"],
Cell[803072, 32649, 1553, 66, 31, "Output",
 CellTags->"FieldStrength"]
}, Open  ]]
}, Open  ]],
Cell[804652, 32719, 63, 1, 39, "ObjectName",
 CellTags->"FinalFunction"],
Cell[CellGroupData[{
Cell[804740, 32724, 64, 1, 33, "Subsubsection",
 CellTags->"FinalFunction"],
Cell[804807, 32727, 86, 1, 23, "Text",
 CellTags->"FinalFunction"],
Cell[804896, 32730, 190, 9, 23, "Text",
 CellTags->"FinalFunction"]
}, Open  ]],
Cell[805101, 32742, 73, 1, 39, "ObjectName",
 CellTags->"FinalSubstitutions"],
Cell[CellGroupData[{
Cell[805199, 32747, 69, 1, 33, "Subsubsection",
 CellTags->"FinalSubstitutions"],
Cell[805271, 32750, 204, 4, 23, "Text",
 CellTags->"FinalSubstitutions"],
Cell[805478, 32756, 406, 19, 23, "Text",
 CellTags->"FinalSubstitutions"]
}, Open  ]],
Cell[805899, 32778, 45, 1, 39, "ObjectName",
 CellTags->"FORM"],
Cell[CellGroupData[{
Cell[805969, 32783, 55, 1, 33, "Subsubsection",
 CellTags->"FORM"],
Cell[806027, 32786, 204, 5, 39, "Text",
 CellTags->"FORM"],
Cell[806234, 32793, 285, 14, 23, "Text",
 CellTags->"FORM"]
}, Open  ]],
Cell[806534, 32810, 57, 1, 39, "ObjectName",
 CellTags->"FORMEpilog"],
Cell[CellGroupData[{
Cell[806616, 32815, 61, 1, 33, "Subsubsection",
 CellTags->"FORMEpilog"],
Cell[806680, 32818, 161, 4, 23, "Text",
 CellTags->"FORMEpilog"],
Cell[806844, 32824, 312, 14, 23, "Text",
 CellTags->"FORMEpilog"]
}, Open  ]],
Cell[807171, 32841, 57, 1, 39, "ObjectName",
 CellTags->"FORMProlog"],
Cell[CellGroupData[{
Cell[807253, 32846, 61, 1, 33, "Subsubsection",
 CellTags->"FORMProlog"],
Cell[807317, 32849, 178, 4, 23, "Text",
 CellTags->"FORMProlog"],
Cell[807498, 32855, 312, 14, 23, "Text",
 CellTags->"FORMProlog"]
}, Open  ]],
Cell[807825, 32872, 63, 1, 39, "ObjectName",
 CellTags->"FORM2FeynCalc"],
Cell[CellGroupData[{
Cell[807913, 32877, 64, 1, 33, "Subsubsection",
 CellTags->"FORM2FeynCalc"],
Cell[807980, 32880, 470, 8, 55, "Text",
 CellTags->"FORM2FeynCalc"],
Cell[808453, 32890, 199, 9, 23, "Text",
 CellTags->"FORM2FeynCalc"],
Cell[CellGroupData[{
Cell[808677, 32903, 125, 3, 27, "Input",
 CellTags->"FORM2FeynCalc"],
Cell[808805, 32908, 662, 18, 45, "Output",
 CellTags->"FORM2FeynCalc"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[809516, 32932, 61, 1, 33, "Subsubsection",
 CellTags->"FORM2FeynCalc"],
Cell[CellGroupData[{
Cell[809602, 32937, 139, 3, 27, "Input",
 CellTags->"FORM2FeynCalc"],
Cell[809744, 32942, 354, 14, 27, "Output",
 CellTags->"FORM2FeynCalc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[810135, 32961, 114, 3, 27, "Input",
 CellTags->"FORM2FeynCalc"],
Cell[810252, 32966, 243, 8, 39, "Output",
 CellTags->"FORM2FeynCalc"]
}, Open  ]],
Cell[810510, 32977, 159, 4, 23, "Text",
 CellTags->"FORM2FeynCalc"],
Cell[CellGroupData[{
Cell[810694, 32985, 314, 8, 27, "Input",
 CellTags->"FORM2FeynCalc"],
Cell[811011, 32995, 298, 10, 27, "Output",
 CellTags->"FORM2FeynCalc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[811346, 33010, 114, 3, 27, "Input",
 CellTags->"FORM2FeynCalc"],
Cell[811463, 33015, 303, 9, 39, "Output",
 CellTags->"FORM2FeynCalc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[811803, 33029, 150, 4, 27, "Input",
 CellTags->"FORM2FeynCalc"],
Cell[811956, 33035, 331, 12, 27, "Output",
 CellTags->"FORM2FeynCalc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[812324, 33052, 117, 3, 27, "Input",
 CellTags->"FORM2FeynCalc"],
Cell[812444, 33057, 259, 9, 25, "Output",
 CellTags->"FORM2FeynCalc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[812740, 33071, 150, 4, 27, "Input",
 CellTags->"FORM2FeynCalc"],
Cell[812893, 33077, 257, 9, 25, "Output",
 CellTags->"FORM2FeynCalc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[813187, 33091, 114, 3, 27, "Input",
 CellTags->"FORM2FeynCalc"],
Cell[813304, 33096, 307, 10, 39, "Output",
 CellTags->"FORM2FeynCalc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[813648, 33111, 333, 9, 27, "Input",
 CellTags->"FORM2FeynCalc"],
Cell[813984, 33122, 269, 9, 25, "Output",
 CellTags->"FORM2FeynCalc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[814290, 33136, 195, 5, 27, "Input",
 CellTags->"FORM2FeynCalc"],
Cell[814488, 33143, 3922, 121, 68, "Output",
 CellTags->"FORM2FeynCalc"]
}, Open  ]]
}, Open  ]],
Cell[818437, 33268, 65, 1, 39, "ObjectName",
 CellTags->"FourDivergence"],
Cell[CellGroupData[{
Cell[818527, 33273, 65, 1, 33, "Subsubsection",
 CellTags->"FourDivergence"],
Cell[818595, 33276, 242, 5, 39, "Text",
 CellTags->"FourDivergence"],
Cell[818840, 33283, 197, 9, 23, "Text",
 CellTags->"FourDivergence"]
}, Open  ]],
Cell[CellGroupData[{
Cell[819074, 33297, 62, 1, 33, "Subsubsection",
 CellTags->"FourDivergence"],
Cell[CellGroupData[{
Cell[819161, 33302, 167, 5, 27, "Input",
 CellTags->"FourDivergence"],
Cell[819331, 33309, 212, 8, 25, "Output",
 CellTags->"FourDivergence"]
}, Open  ]],
Cell[CellGroupData[{
Cell[819580, 33322, 211, 6, 27, "Input",
 CellTags->"FourDivergence"],
Cell[819794, 33330, 242, 10, 25, "Output",
 CellTags->"FourDivergence"]
}, Open  ]],
Cell[CellGroupData[{
Cell[820073, 33345, 192, 6, 27, "Input",
 CellTags->"FourDivergence"],
Cell[820268, 33353, 247, 9, 25, "Output",
 CellTags->"FourDivergence"]
}, Open  ]],
Cell[CellGroupData[{
Cell[820552, 33367, 237, 7, 27, "Input",
 CellTags->"FourDivergence"],
Cell[820792, 33376, 110, 3, 25, "Output",
 CellTags->"FourDivergence"]
}, Open  ]],
Cell[820917, 33382, 112, 3, 27, "Input",
 CellTags->"FourDivergence"]
}, Open  ]],
Cell[821044, 33388, 63, 1, 39, "ObjectName",
 CellTags->"FourLaplacian"],
Cell[CellGroupData[{
Cell[821132, 33393, 64, 1, 33, "Subsubsection",
 CellTags->"FourLaplacian"],
Cell[821199, 33396, 426, 16, 26, "Text",
 CellTags->"FourLaplacian"],
Cell[CellGroupData[{
Cell[821650, 33416, 125, 3, 27, "Input",
 CellTags->"FourLaplacian"],
Cell[821778, 33421, 170, 5, 25, "Output",
 CellTags->"FourLaplacian"]
}, Open  ]],
Cell[821963, 33429, 324, 14, 23, "Text",
 CellTags->"FourLaplacian"]
}, Open  ]],
Cell[CellGroupData[{
Cell[822324, 33448, 61, 1, 33, "Subsubsection",
 CellTags->"FourLaplacian"],
Cell[CellGroupData[{
Cell[822410, 33453, 131, 4, 27, "Input",
 CellTags->"FourLaplacian"],
Cell[822544, 33459, 167, 6, 27, "Output",
 CellTags->"FourLaplacian"]
}, Open  ]],
Cell[CellGroupData[{
Cell[822748, 33470, 152, 4, 27, "Input",
 CellTags->"FourLaplacian"],
Cell[822903, 33476, 132, 4, 25, "Output",
 CellTags->"FourLaplacian"]
}, Open  ]],
Cell[CellGroupData[{
Cell[823072, 33485, 264, 9, 27, "Input",
 CellTags->"FourLaplacian"],
Cell[823339, 33496, 440, 16, 49, "Output",
 CellTags->"FourLaplacian"]
}, Open  ]],
Cell[CellGroupData[{
Cell[823816, 33517, 157, 4, 27, "Input",
 CellTags->"FourLaplacian"],
Cell[823976, 33523, 3857, 136, 99, "Output",
 CellTags->"FourLaplacian"]
}, Open  ]]
}, Open  ]],
Cell[827860, 33663, 57, 1, 39, "ObjectName",
 CellTags->"FourVector"],
Cell[CellGroupData[{
Cell[827942, 33668, 61, 1, 33, "Subsubsection",
 CellTags->"FourVector"],
Cell[828006, 33671, 339, 10, 39, "Text",
 CellTags->"FourVector"],
Cell[828348, 33683, 356, 19, 23, "Text",
 CellTags->"FourVector"]
}, Open  ]],
Cell[CellGroupData[{
Cell[828741, 33707, 58, 1, 33, "Subsubsection",
 CellTags->"FourVector"],
Cell[CellGroupData[{
Cell[828824, 33712, 140, 4, 27, "Input",
 CellTags->"FourVector"],
Cell[828967, 33718, 132, 4, 28, "Output",
 CellTags->"FourVector"]
}, Open  ]],
Cell[CellGroupData[{
Cell[829136, 33727, 164, 5, 27, "Input",
 CellTags->"FourVector"],
Cell[829303, 33734, 249, 10, 28, "Output",
 CellTags->"FourVector"]
}, Open  ]],
Cell[CellGroupData[{
Cell[829589, 33749, 180, 5, 27, "Input",
 CellTags->"FourVector"],
Cell[829772, 33756, 155, 4, 39, "Output",
 CellTags->"FourVector"]
}, Open  ]],
Cell[CellGroupData[{
Cell[829964, 33765, 229, 6, 27, "Input",
 CellTags->"FourVector"],
Cell[830196, 33773, 203, 5, 39, "Output",
 CellTags->"FourVector"]
}, Open  ]],
Cell[CellGroupData[{
Cell[830436, 33783, 212, 6, 27, "Input",
 CellTags->"FourVector"],
Cell[830651, 33791, 155, 4, 39, "Output",
 CellTags->"FourVector"]
}, Open  ]],
Cell[830821, 33798, 193, 4, 23, "Text",
 CellTags->"FourVector"],
Cell[CellGroupData[{
Cell[831039, 33806, 212, 6, 27, "Input",
 CellTags->"FourVector"],
Cell[831254, 33814, 407, 18, 25, "Output",
 CellTags->"FourVector"]
}, Open  ]]
}, Open  ]],
Cell[831688, 33836, 55, 1, 39, "ObjectName",
 CellTags->"FreeIndex"],
Cell[CellGroupData[{
Cell[831768, 33841, 60, 1, 33, "Subsubsection",
 CellTags->"FreeIndex"],
Cell[831831, 33844, 152, 4, 23, "Text",
 CellTags->"FreeIndex"],
Cell[831986, 33850, 290, 14, 23, "Text",
 CellTags->"FreeIndex"]
}, Open  ]],
Cell[832291, 33867, 49, 1, 39, "ObjectName",
 CellTags->"FreeQ2"],
Cell[CellGroupData[{
Cell[832365, 33872, 57, 1, 33, "Subsubsection",
 CellTags->"FreeQ2"],
Cell[832425, 33875, 228, 5, 39, "Text",
 CellTags->"FreeQ2"],
Cell[832656, 33882, 308, 14, 23, "Text",
 CellTags->"FreeQ2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[833001, 33901, 54, 1, 33, "Subsubsection",
 CellTags->"FreeQ2"],
Cell[CellGroupData[{
Cell[833080, 33906, 246, 8, 27, "Input",
 CellTags->"FreeQ2"],
Cell[833329, 33916, 106, 3, 25, "Output",
 CellTags->"FreeQ2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[833472, 33924, 241, 8, 27, "Input",
 CellTags->"FreeQ2"],
Cell[833716, 33934, 105, 3, 25, "Output",
 CellTags->"FreeQ2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[833858, 33942, 133, 4, 27, "Input",
 CellTags->"FreeQ2"],
Cell[833994, 33948, 105, 3, 25, "Output",
 CellTags->"FreeQ2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[834136, 33956, 162, 5, 27, "Input",
 CellTags->"FreeQ2"],
Cell[834301, 33963, 106, 3, 25, "Output",
 CellTags->"FreeQ2"]
}, Open  ]]
}, Open  ]],
Cell[834434, 33970, 43, 1, 39, "ObjectName",
 CellTags->"FRH"],
Cell[CellGroupData[{
Cell[834502, 33975, 54, 1, 33, "Subsubsection",
 CellTags->"FRH"],
Cell[834559, 33978, 134, 4, 23, "Text",
 CellTags->"FRH"],
Cell[834696, 33984, 171, 9, 23, "Text",
 CellTags->"FRH"]
}, Open  ]],
Cell[CellGroupData[{
Cell[834904, 33998, 51, 1, 33, "Subsubsection",
 CellTags->"FRH"],
Cell[CellGroupData[{
Cell[834980, 34003, 200, 6, 27, "Input",
 CellTags->"FRH"],
Cell[835183, 34011, 248, 9, 25, "Output",
 CellTags->"FRH"]
}, Open  ]],
Cell[CellGroupData[{
Cell[835468, 34025, 99, 3, 27, "Input",
 CellTags->"FRH"],
Cell[835570, 34030, 99, 3, 25, "Output",
 CellTags->"FRH"]
}, Open  ]],
Cell[CellGroupData[{
Cell[835706, 34038, 304, 10, 27, "Input",
 CellTags->"FRH"],
Cell[836013, 34050, 531, 20, 25, "Output",
 CellTags->"FRH"]
}, Open  ]],
Cell[CellGroupData[{
Cell[836581, 34075, 128, 4, 27, "Input",
 CellTags->"FRH"],
Cell[836712, 34081, 128, 4, 25, "Output",
 CellTags->"FRH"]
}, Open  ]]
}, Open  ]],
Cell[836867, 34089, 51, 1, 39, "ObjectName",
 CellTags->"FromTFi"],
Cell[CellGroupData[{
Cell[836943, 34094, 58, 1, 33, "Subsubsection",
 CellTags->"FromTFi"],
Cell[837004, 34097, 200, 5, 39, "Text",
 CellTags->"FromTFi"],
Cell[837207, 34104, 258, 13, 23, "Text",
 CellTags->"FromTFI"]
}, Open  ]],
Cell[CellGroupData[{
Cell[837502, 34122, 55, 1, 33, "Subsubsection",
 CellTags->"FromTFi"],
Cell[CellGroupData[{
Cell[837582, 34127, 431, 14, 27, "Input",
 CellTags->"FromTFi"],
Cell[838016, 34143, 776, 24, 92, "Output",
 CellTags->"FromTFi"]
}, Open  ]],
Cell[CellGroupData[{
Cell[838829, 34172, 693, 22, 27, "Input",
 CellTags->"FromTFi"],
Cell[839525, 34196, 966, 31, 92, "Output",
 CellTags->"FromTFi"]
}, Open  ]],
Cell[CellGroupData[{
Cell[840528, 34232, 756, 24, 27, "Input",
 CellTags->"FromTFi"],
Cell[841287, 34258, 1027, 33, 92, "Output",
 CellTags->"FromTFi"]
}, Open  ]]
}, Open  ]],
Cell[842341, 34295, 53, 1, 39, "ObjectName",
 CellTags->"FUNCTION"],
Cell[CellGroupData[{
Cell[842419, 34300, 59, 1, 33, "Subsubsection",
 CellTags->"FUNCTION"],
Cell[842481, 34303, 160, 4, 23, "Text",
 CellTags->"FUNCTION"],
Cell[842644, 34309, 173, 9, 23, "Text",
 CellTags->"FUNCTION"]
}, Open  ]],
Cell[842832, 34321, 59, 1, 39, "ObjectName",
 CellTags->"FunctionalD"],
Cell[CellGroupData[{
Cell[842916, 34326, 62, 1, 33, "Subsubsection",
 CellTags->"FunctionalD"],
Cell[842981, 34329, 416, 7, 55, "Text",
 CellTags->"FunctionalD"],
Cell[843400, 34338, 95, 1, 23, "Text",
 CellTags->"FunctionalD"],
Cell[843498, 34341, 304, 14, 23, "Text",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[843839, 34360, 59, 1, 33, "Subsubsection",
 CellTags->"FunctionalD"],
Cell[843901, 34363, 610, 20, 23, "Text",
 CellTags->"FunctionalD"],
Cell[CellGroupData[{
Cell[844536, 34387, 228, 6, 27, "Input",
 CellTags->"FunctionalD"],
Cell[844767, 34395, 107, 3, 25, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[844911, 34403, 253, 7, 27, "Input",
 CellTags->"FunctionalD"],
Cell[845167, 34412, 135, 4, 25, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[845317, 34419, 1269, 44, 49, "Text",
 CellTags->"FunctionalD"],
Cell[CellGroupData[{
Cell[846611, 34467, 295, 8, 27, "Input",
 CellTags->"FunctionalD"],
Cell[846909, 34477, 273, 10, 32, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[847197, 34490, 778, 24, 26, "Text",
 CellTags->"FunctionalD"],
Cell[CellGroupData[{
Cell[848000, 34518, 668, 22, 48, "Input",
 CellTags->"FunctionalD"],
Cell[848671, 34542, 735, 26, 43, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[849443, 34573, 217, 6, 27, "Input",
 CellTags->"FunctionalD"],
Cell[849663, 34581, 652, 26, 30, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[850330, 34610, 489, 15, 30, "Text",
 CellTags->"FunctionalD"],
Cell[850822, 34627, 97, 2, 23, "Text",
 CellTags->"FunctionalD"],
Cell[CellGroupData[{
Cell[850944, 34633, 315, 8, 27, "Input",
 CellTags->"FunctionalD"],
Cell[851262, 34643, 1303, 56, 31, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[852602, 34704, 315, 8, 27, "Input",
 CellTags->"FunctionalD"],
Cell[852920, 34714, 1303, 56, 31, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[854260, 34775, 216, 8, 27, "Input",
 CellTags->"FunctionalD"],
Cell[854479, 34785, 2956, 115, 43, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[857450, 34903, 560, 13, 57, "Text",
 CellTags->"FunctionalD"],
Cell[858013, 34918, 1398, 50, 26, "Text",
 CellTags->"FunctionalD"],
Cell[859414, 34970, 445, 13, 25, "Text",
 CellTags->"FunctionalD"],
Cell[CellGroupData[{
Cell[859884, 34987, 231, 7, 27, "Input",
 CellTags->"FunctionalD"],
Cell[860118, 34996, 286, 12, 27, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[860441, 35013, 165, 5, 27, "Input",
 CellTags->"FunctionalD"],
Cell[860609, 35020, 2288, 96, 33, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[862912, 35119, 120, 3, 23, "Text",
 CellTags->"FunctionalD"],
Cell[CellGroupData[{
Cell[863057, 35126, 176, 5, 27, "Input",
 CellTags->"FunctionalD"],
Cell[863236, 35133, 2288, 96, 33, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[865539, 35232, 290, 8, 25, "Text",
 CellTags->"FunctionalD"],
Cell[865832, 35242, 523, 16, 27, "Input",
 CellTags->"FunctionalD"],
Cell[CellGroupData[{
Cell[866380, 35262, 230, 7, 27, "Input",
 CellTags->"FunctionalD"],
Cell[866613, 35271, 384, 17, 29, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[867034, 35293, 240, 7, 27, "Input",
 CellTags->"FunctionalD"],
Cell[867277, 35302, 416, 18, 29, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[867730, 35325, 579, 16, 68, "Input",
 CellTags->"FunctionalD"],
Cell[868312, 35343, 2958, 127, 43, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[871307, 35475, 184, 5, 27, "Input",
 CellTags->"FunctionalD"],
Cell[871494, 35482, 1405, 62, 29, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[872936, 35549, 352, 11, 27, "Input",
 CellTags->"FunctionalD"],
Cell[873291, 35562, 1159, 50, 29, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[874465, 35615, 269, 9, 27, "Text",
 CellTags->"FunctionalD"],
Cell[874737, 35626, 98, 2, 23, "Text",
 CellTags->"FunctionalD"],
Cell[874838, 35630, 167, 4, 23, "Text",
 CellTags->"FunctionalD"],
Cell[CellGroupData[{
Cell[875030, 35638, 105, 3, 27, "Input",
 CellTags->"FunctionalD"],
Cell[875138, 35643, 2956, 115, 43, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[878131, 35763, 194, 6, 27, "Input",
 CellTags->"FunctionalD"],
Cell[878328, 35771, 23483, 1005, 160, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[901826, 36779, 227, 5, 36, "Text",
 CellTags->"FunctionalD"],
Cell[902056, 36786, 345, 6, 39, "Text",
 CellTags->"FunctionalD"],
Cell[902404, 36794, 132, 4, 27, "Input",
 CellTags->"FunctionalD"],
Cell[902539, 36800, 2583, 67, 128, "Input",
 CellTags->"FunctionalD"],
Cell[CellGroupData[{
Cell[905147, 36871, 169, 5, 27, "Input",
 CellTags->"FunctionalD"],
Cell[905319, 36878, 12210, 526, 121, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[917566, 37409, 164, 5, 27, "Input",
 CellTags->"FunctionalD"],
Cell[917733, 37416, 6535, 286, 43, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[924283, 37705, 212, 8, 23, "Text",
 CellTags->"FunctionalD"],
Cell[CellGroupData[{
Cell[924520, 37717, 315, 11, 27, "Input",
 CellTags->"FunctionalD"],
Cell[924838, 37730, 2734, 119, 43, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[927609, 37854, 647, 20, 27, "Input",
 CellTags->"FunctionalD"],
Cell[928259, 37876, 1310, 60, 31, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[929606, 37941, 154, 4, 27, "Input",
 CellTags->"FunctionalD"],
Cell[929763, 37947, 5227, 228, 31, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[935005, 38178, 131, 4, 23, "Text",
 CellTags->"FunctionalD"],
Cell[CellGroupData[{
Cell[935161, 38186, 79, 2, 27, "Input",
 CellTags->"FunctionalD"],
Cell[935243, 38190, 1159, 50, 29, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[936439, 38245, 798, 21, 48, "Input",
 CellTags->"FunctionalD"],
Cell[937240, 38268, 1064, 41, 33, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[938341, 38314, 137, 4, 27, "Input",
 CellTags->"FunctionalD"],
Cell[938481, 38320, 4174, 167, 33, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[942692, 38492, 204, 6, 27, "Input",
 CellTags->"FunctionalD"],
Cell[942899, 38500, 6098, 267, 31, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[949034, 38772, 138, 4, 27, "Input",
 CellTags->"FunctionalD"],
Cell[949175, 38778, 11189, 491, 55, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[960401, 39274, 163, 5, 27, "Input",
 CellTags->"FunctionalD"],
Cell[960567, 39281, 10243, 451, 55, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[970825, 39735, 66, 1, 23, "Text",
 CellTags->"FunctionalD"],
Cell[970894, 39738, 539, 13, 48, "Input",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[971470, 39756, 110, 2, 32, "Subsubsection",
 CellTags->"FunctionalD"],
Cell[971583, 39760, 79, 1, 23, "Text",
 CellTags->"FunctionalD"],
Cell[CellGroupData[{
Cell[971687, 39765, 1073, 26, 88, "Input"],
Cell[972763, 39793, 1337, 59, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[974137, 39857, 765, 22, 48, "Input",
 CellTags->"FunctionalD"],
Cell[974905, 39881, 8897, 329, 90, "Output",
 CellTags->"FunctionalD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[983839, 40215, 165, 5, 27, "Input",
 CellTags->"FunctionalD"],
Cell[984007, 40222, 2097, 84, 43, "Output",
 CellTags->"FunctionalD"]
}, Open  ]]
}, Open  ]],
Cell[986131, 40310, 41, 1, 39, "ObjectName",
 CellTags->"FV"],
Cell[CellGroupData[{
Cell[986197, 40315, 53, 1, 26, "Subsubsection",
 CellTags->"FV"],
Cell[986253, 40318, 275, 13, 21, "Text",
 CellTags->"FV"],
Cell[986531, 40333, 562, 29, 22, "Text",
 CellTags->"FV"]
}, Open  ]],
Cell[CellGroupData[{
Cell[987130, 40367, 50, 1, 33, "Subsubsection",
 CellTags->"FV"],
Cell[CellGroupData[{
Cell[987205, 40372, 124, 4, 27, "Input",
 CellTags->"FV"],
Cell[987332, 40378, 126, 4, 25, "Output",
 CellTags->"FV"]
}, Open  ]],
Cell[CellGroupData[{
Cell[987495, 40387, 148, 5, 27, "Input",
 CellTags->"FV"],
Cell[987646, 40394, 185, 7, 25, "Output",
 CellTags->"FV"]
}, Open  ]],
Cell[CellGroupData[{
Cell[987868, 40406, 160, 5, 27, "Input",
 CellTags->"FV"],
Cell[988031, 40413, 139, 4, 39, "Output",
 CellTags->"FV"]
}, Open  ]],
Cell[CellGroupData[{
Cell[988207, 40422, 195, 7, 27, "Input",
 CellTags->"FV"],
Cell[988405, 40431, 217, 6, 39, "Output",
 CellTags->"FV"]
}, Open  ]],
Cell[988637, 40440, 130, 4, 23, "Text",
 CellTags->"FV"],
Cell[CellGroupData[{
Cell[988792, 40448, 196, 6, 27, "Input",
 CellTags->"FV"],
Cell[988991, 40456, 399, 18, 25, "Output",
 CellTags->"FV"]
}, Open  ]],
Cell[CellGroupData[{
Cell[989427, 40479, 107, 3, 27, "Input",
 CellTags->"FV"],
Cell[989537, 40484, 380, 11, 39, "Output",
 CellTags->"FV"]
}, Open  ]]
}, Open  ]],
Cell[989944, 40499, 43, 1, 61, "ObjectName",
 CellTags->"FVD"],
Cell[CellGroupData[{
Cell[990012, 40504, 54, 1, 54, "Subsubsection",
 CellTags->"FVD"],
Cell[990069, 40507, 312, 15, 37, "Text",
 CellTags->"FVD"],
Cell[990384, 40524, 560, 29, 37, "Text",
 CellTags->"FVD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[990981, 40558, 51, 1, 33, "Subsubsection",
 CellTags->"FVD"],
Cell[CellGroupData[{
Cell[991057, 40563, 126, 4, 27, "Input",
 CellTags->"FVD"],
Cell[991186, 40569, 127, 4, 25, "Output",
 CellTags->"FVD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[991350, 40578, 150, 5, 27, "Input",
 CellTags->"FVD"],
Cell[991503, 40585, 186, 7, 25, "Output",
 CellTags->"FVD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[991726, 40597, 162, 5, 27, "Input",
 CellTags->"FVD"],
Cell[991891, 40604, 141, 4, 39, "Output",
 CellTags->"FVD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[992069, 40613, 197, 7, 27, "Input",
 CellTags->"FVD"],
Cell[992269, 40622, 268, 8, 39, "Output",
 CellTags->"FVD"]
}, Open  ]],
Cell[992552, 40633, 88, 1, 23, "Text",
 CellTags->"FVD"],
Cell[CellGroupData[{
Cell[992665, 40638, 198, 6, 27, "Input",
 CellTags->"FVD"],
Cell[992866, 40646, 400, 18, 25, "Output",
 CellTags->"FVD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[993303, 40669, 108, 3, 27, "Input",
 CellTags->"FVD"],
Cell[993414, 40674, 485, 15, 39, "Output",
 CellTags->"FVD"]
}, Open  ]]
}, Open  ]],
Cell[993926, 40693, 41, 1, 39, "ObjectName",
 CellTags->"GA"],
Cell[CellGroupData[{
Cell[993992, 40698, 53, 1, 33, "Subsubsection",
 CellTags->"GA"],
Cell[994048, 40701, 654, 24, 42, "Text",
 CellTags->"GA"],
Cell[994705, 40727, 369, 19, 23, "Text",
 CellTags->"GA"]
}, Open  ]],
Cell[CellGroupData[{
Cell[995111, 40751, 50, 1, 33, "Subsubsection",
 CellTags->"GA"],
Cell[CellGroupData[{
Cell[995186, 40756, 101, 3, 27, "Input",
 CellTags->"GA"],
Cell[995290, 40761, 133, 4, 25, "Output",
 CellTags->"GA"]
}, Open  ]],
Cell[CellGroupData[{
Cell[995460, 40770, 213, 7, 27, "Input",
 CellTags->"GA"],
Cell[995676, 40779, 317, 10, 25, "Output",
 CellTags->"GA"]
}, Open  ]],
Cell[CellGroupData[{
Cell[996030, 40794, 171, 5, 27, "Input",
 CellTags->"GA"],
Cell[996204, 40801, 163, 4, 39, "Output",
 CellTags->"GA"]
}, Open  ]],
Cell[CellGroupData[{
Cell[996404, 40810, 163, 5, 27, "Input",
 CellTags->"GA"],
Cell[996570, 40817, 289, 8, 25, "Output",
 CellTags->"GA"]
}, Open  ]],
Cell[CellGroupData[{
Cell[996896, 40830, 203, 6, 27, "Input",
 CellTags->"GA"],
Cell[997102, 40838, 262, 7, 39, "Output",
 CellTags->"GA"]
}, Open  ]],
Cell[CellGroupData[{
Cell[997401, 40850, 250, 8, 27, "Input",
 CellTags->"GA"],
Cell[997654, 40860, 301, 9, 25, "Output",
 CellTags->"GA"]
}, Open  ]]
}, Open  ]],
Cell[997982, 40873, 43, 1, 39, "ObjectName",
 CellTags->"GAD"],
Cell[CellGroupData[{
Cell[998050, 40878, 54, 1, 33, "Subsubsection",
 CellTags->"GAD"],
Cell[998107, 40881, 671, 24, 42, "Text",
 CellTags->"GAD"],
Cell[998781, 40907, 367, 19, 23, "Text",
 CellTags->"GAD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[999185, 40931, 51, 1, 33, "Subsubsection",
 CellTags->"GAD"],
Cell[CellGroupData[{
Cell[999261, 40936, 103, 3, 27, "Input",
 CellTags->"GAD"],
Cell[999367, 40941, 134, 4, 25, "Output",
 CellTags->"GAD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[999538, 40950, 216, 7, 27, "Input",
 CellTags->"GAD"],
Cell[999757, 40959, 318, 10, 25, "Output",
 CellTags->"GAD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1000112, 40974, 173, 5, 27, "Input",
 CellTags->"GAD"],
Cell[1000288, 40981, 213, 6, 39, "Output",
 CellTags->"GAD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1000538, 40992, 165, 5, 27, "Input",
 CellTags->"GAD"],
Cell[1000706, 40999, 290, 8, 25, "Output",
 CellTags->"GAD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1001033, 41012, 205, 6, 27, "Input",
 CellTags->"GAD"],
Cell[1001241, 41020, 267, 7, 39, "Output",
 CellTags->"GAD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1001545, 41032, 254, 8, 27, "Input",
 CellTags->"GAD"],
Cell[1001802, 41042, 302, 9, 25, "Output",
 CellTags->"GAD"]
}, Open  ]]
}, Open  ]],
Cell[1002131, 41055, 61, 1, 39, "ObjectName",
 CellTags->"GammaEpsilon"],
Cell[CellGroupData[{
Cell[1002217, 41060, 63, 1, 33, "Subsubsection",
 CellTags->"GammaEpsilon"],
Cell[1002283, 41063, 167, 4, 23, "Text",
 CellTags->"GammaEpsilon"],
Cell[1002453, 41069, 299, 14, 23, "Text",
 CellTags->"GammaEpsilon"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1002789, 41088, 60, 1, 33, "Subsubsection",
 CellTags->"GammaEpsilon"],
Cell[1002852, 41091, 141, 4, 23, "Text",
 CellTags->"GammaEpsilon"],
Cell[CellGroupData[{
Cell[1003018, 41099, 170, 5, 27, "Input",
 CellTags->"GammaEpsilon"],
Cell[1003191, 41106, 1361, 48, 52, "Output",
 CellTags->"GammaEpsilon"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1004589, 41159, 170, 5, 27, "Input",
 CellTags->"GammaEpsilon"],
Cell[1004762, 41166, 1109, 41, 52, "Output",
 CellTags->"GammaEpsilon"]
}, Open  ]],
Cell[1005886, 41210, 91, 1, 23, "Text",
 CellTags->"GammaEpsilon"],
Cell[CellGroupData[{
Cell[1006002, 41215, 123, 3, 27, "Input",
 CellTags->"GammaEpsilon"],
Cell[1006128, 41220, 2148, 77, 96, "Output",
 CellTags->"GammaEpsilon"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1008313, 41302, 117, 3, 27, "Input",
 CellTags->"GammaEpsilon"],
Cell[1008433, 41307, 138, 5, 25, "Output",
 CellTags->"GammaEpsilon"]
}, Open  ]]
}, Open  ]],
Cell[1008598, 41316, 59, 1, 39, "ObjectName",
 CellTags->"GammaExpand"],
Cell[CellGroupData[{
Cell[1008682, 41321, 62, 1, 33, "Subsubsection",
 CellTags->"GammaExpand"],
Cell[1008747, 41324, 123, 3, 23, "Text",
 CellTags->"GammaExpand"],
Cell[1008873, 41329, 194, 9, 23, "Text",
 CellTags->"GammaExpand"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1009104, 41343, 59, 1, 33, "Subsubsection",
 CellTags->"GammaExpand"],
Cell[CellGroupData[{
Cell[1009188, 41348, 187, 5, 27, "Input",
 CellTags->"GammaExpand"],
Cell[1009378, 41355, 329, 11, 25, "Output",
 CellTags->"GammaExpand"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1009744, 41371, 197, 6, 27, "Input",
 CellTags->"GammaExpand"],
Cell[1009944, 41379, 632, 22, 45, "Output",
 CellTags->"GammaExpand"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1010613, 41406, 187, 5, 27, "Input",
 CellTags->"GammaExpand"],
Cell[1010803, 41413, 203, 6, 25, "Output",
 CellTags->"GammaExpand"]
}, Open  ]]
}, Open  ]],
Cell[1011033, 41423, 49, 1, 39, "ObjectName",
 CellTags->"Gamma1"],
Cell[CellGroupData[{
Cell[1011107, 41428, 57, 1, 33, "Subsubsection",
 CellTags->"Gamma1"],
Cell[1011167, 41431, 139, 4, 23, "Text",
 CellTags->"Gamma1"],
Cell[1011309, 41437, 275, 14, 23, "Text",
 CellTags->"Gamma1"]
}, Open  ]],
Cell[1011599, 41454, 49, 1, 39, "ObjectName",
 CellTags->"Gamma2"],
Cell[CellGroupData[{
Cell[1011673, 41459, 57, 1, 33, "Subsubsection",
 CellTags->"Gamma2"],
Cell[1011733, 41462, 172, 4, 23, "Text",
 CellTags->"Gamma2"],
Cell[1011908, 41468, 275, 14, 23, "Text",
 CellTags->"Gamma2"]
}, Open  ]],
Cell[1012198, 41485, 49, 1, 39, "ObjectName",
 CellTags->"Gamma3"],
Cell[CellGroupData[{
Cell[1012272, 41490, 57, 1, 33, "Subsubsection",
 CellTags->"Gamma3"],
Cell[1012332, 41493, 237, 5, 39, "Text",
 CellTags->"Gamma3"],
Cell[1012572, 41500, 275, 14, 23, "Text",
 CellTags->"Gamma3"]
}, Open  ]],
Cell[1012862, 41517, 47, 1, 39, "ObjectName",
 CellTags->"Gauge"],
Cell[CellGroupData[{
Cell[1012934, 41522, 56, 1, 33, "Subsubsection",
 CellTags->"Gauge"],
Cell[1012993, 41525, 133, 4, 23, "Text",
 CellTags->"Gauge"],
Cell[1013129, 41531, 301, 14, 23, "Text",
 CellTags->"Gauge"]
}, Open  ]],
Cell[1013445, 41548, 57, 1, 39, "ObjectName",
 CellTags->"GaugeField"],
Cell[CellGroupData[{
Cell[1013527, 41553, 61, 1, 33, "Subsubsection",
 CellTags->"GaugeField"],
Cell[1013591, 41556, 212, 5, 39, "Text",
 CellTags->"GaugeField"],
Cell[1013806, 41563, 318, 14, 23, "Text",
 CellTags->"GaugeField"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1014161, 41582, 58, 1, 33, "Subsubsection",
 CellTags->"GaugeField"],
Cell[CellGroupData[{
Cell[1014244, 41587, 86, 2, 27, "Input",
 CellTags->"GaugeField"],
Cell[1014333, 41591, 106, 3, 25, "Output",
 CellTags->"GaugeField"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1014476, 41599, 237, 6, 27, "Input",
 CellTags->"GaugeField"],
Cell[1014716, 41607, 316, 14, 29, "Output",
 CellTags->"GaugeField"]
}, Open  ]]
}, Open  ]],
Cell[1015059, 41625, 51, 1, 39, "ObjectName",
 CellTags->"GaugeXi"],
Cell[CellGroupData[{
Cell[1015135, 41630, 58, 1, 33, "Subsubsection",
 CellTags->"GaugeXi"],
Cell[1015196, 41633, 77, 1, 23, "Text",
 CellTags->"GaugeXi"],
Cell[1015276, 41636, 285, 14, 23, "Text",
 CellTags->"GaugeXi"]
}, Open  ]],
Cell[1015576, 41653, 43, 1, 39, "ObjectName",
 CellTags->"GA5"],
Cell[CellGroupData[{
Cell[1015644, 41658, 54, 1, 33, "Subsubsection",
 CellTags->"GA5"],
Cell[1015701, 41661, 88, 1, 23, "Text",
 CellTags->"GA5"],
Cell[1015792, 41664, 364, 19, 23, "Text",
 CellTags->"GA5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1016193, 41688, 51, 1, 33, "Subsubsection",
 CellTags->"GA5"],
Cell[CellGroupData[{
Cell[1016269, 41693, 72, 2, 27, "Input",
 CellTags->"GA5"],
Cell[1016344, 41697, 130, 4, 27, "Output",
 CellTags->"GA5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1016511, 41706, 94, 3, 27, "Input",
 CellTags->"GA5"],
Cell[1016608, 41711, 99, 3, 25, "Output",
 CellTags->"GA5"]
}, Open  ]]
}, Open  ]],
Cell[1016734, 41718, 43, 1, 39, "ObjectName",
 CellTags->"GGV"],
Cell[CellGroupData[{
Cell[1016802, 41723, 54, 1, 33, "Subsubsection",
 CellTags->"GGV"],
Cell[1016859, 41726, 72, 1, 23, "Text",
 CellTags->"GGV"],
Cell[1016934, 41729, 198, 9, 23, "Text",
 CellTags->"GGV"]
}, Open  ]],
Cell[1017147, 41741, 67, 1, 39, "ObjectName",
 CellTags->"GhostPropagator"],
Cell[CellGroupData[{
Cell[1017239, 41746, 66, 1, 33, "Subsubsection",
 CellTags->"GhostPropagator"],
Cell[1017308, 41749, 324, 9, 23, "Text",
 CellTags->"GhostPropagator"],
Cell[1017635, 41760, 436, 19, 23, "Text",
 CellTags->"GhostPropagator"],
Cell[CellGroupData[{
Cell[1018096, 41783, 99, 2, 27, "Input"],
Cell[1018198, 41787, 148, 5, 25, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1018395, 41798, 63, 1, 33, "Subsubsection",
 CellTags->"GhostPropagator"],
Cell[CellGroupData[{
Cell[1018483, 41803, 156, 4, 27, "Input",
 CellTags->"GhostPropagator"],
Cell[1018642, 41809, 193, 6, 27, "Output",
 CellTags->"GhostPropagator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1018872, 41820, 206, 5, 27, "Input",
 CellTags->"GhostPropagator"],
Cell[1019081, 41827, 409, 16, 46, "Output",
 CellTags->"GhostPropagator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1019527, 41848, 123, 3, 27, "Input",
 CellTags->"GhostPropagator"],
Cell[1019653, 41853, 176, 6, 25, "Output",
 CellTags->"GhostPropagator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1019866, 41864, 188, 5, 27, "Input",
 CellTags->"GhostPropagator"],
Cell[1020057, 41871, 413, 16, 46, "Output",
 CellTags->"GhostPropagator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1020507, 41892, 285, 9, 27, "Input",
 CellTags->"GhostPropagator"],
Cell[1020795, 41903, 228, 6, 39, "Output",
 CellTags->"GhostPropagator"]
}, Open  ]]
}, Open  ]],
Cell[1021050, 41913, 43, 1, 39, "ObjectName",
 CellTags->"GHP"],
Cell[CellGroupData[{
Cell[1021118, 41918, 54, 1, 33, "Subsubsection",
 CellTags->"GHP"],
Cell[1021175, 41921, 288, 9, 23, "Text",
 CellTags->"GHP"],
Cell[1021466, 41932, 460, 19, 23, "Text",
 CellTags->"GHP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1021963, 41956, 51, 1, 33, "Subsubsection",
 CellTags->"GHP"],
Cell[CellGroupData[{
Cell[1022039, 41961, 132, 4, 27, "Input",
 CellTags->"GHP"],
Cell[1022174, 41967, 181, 6, 27, "Output",
 CellTags->"GHP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1022392, 41978, 130, 4, 27, "Input",
 CellTags->"GHP"],
Cell[1022525, 41984, 157, 5, 47, "Output",
 CellTags->"GHP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1022719, 41994, 132, 4, 27, "Input",
 CellTags->"GHP"],
Cell[1022854, 42000, 185, 6, 27, "Output",
 CellTags->"GHP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1023076, 42011, 264, 9, 27, "Input",
 CellTags->"GHP"],
Cell[1023343, 42022, 216, 6, 39, "Output",
 CellTags->"GHP"]
}, Open  ]]
}, Open  ]],
Cell[1023586, 42032, 57, 1, 39, "ObjectName",
 CellTags->"GluonField"],
Cell[CellGroupData[{
Cell[1023668, 42037, 61, 1, 33, "Subsubsection",
 CellTags->"GluonField"],
Cell[1023732, 42040, 79, 1, 23, "Text",
 CellTags->"GluonField"],
Cell[1023814, 42043, 187, 9, 23, "Text",
 CellTags->"GluonField"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1024038, 42057, 58, 1, 33, "Subsubsection",
 CellTags->"GluonField"],
Cell[CellGroupData[{
Cell[1024121, 42062, 86, 2, 27, "Input",
 CellTags->"GluonField"],
Cell[1024210, 42066, 106, 3, 25, "Output",
 CellTags->"GluonField"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1024353, 42074, 237, 6, 27, "Input",
 CellTags->"GluonField"],
Cell[1024593, 42082, 316, 14, 29, "Output",
 CellTags->"GluonField"]
}, Open  ]]
}, Open  ]],
Cell[1024936, 42100, 69, 1, 39, "ObjectName",
 CellTags->"GluonGhostVertex"],
Cell[CellGroupData[{
Cell[1025030, 42105, 67, 1, 33, "Subsubsection",
 CellTags->"GluonGhostVertex"],
Cell[1025100, 42108, 422, 7, 55, "Text",
 CellTags->"GluonGhostVertex"],
Cell[1025525, 42117, 583, 23, 23, "Text",
 CellTags->"GluonGhostVertex"],
Cell[CellGroupData[{
Cell[1026133, 42144, 131, 3, 27, "Input",
 CellTags->"GluonGhostVertex"],
Cell[1026267, 42149, 324, 10, 25, "Output",
 CellTags->"GluonGhostVertex"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1026640, 42165, 64, 1, 33, "Subsubsection",
 CellTags->"GluonGhostVertex"],
Cell[CellGroupData[{
Cell[1026729, 42170, 348, 10, 27, "Input",
 CellTags->"GluonGhostVertex"],
Cell[1027080, 42182, 517, 21, 29, "Output",
 CellTags->"GluonGhostVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1027634, 42208, 86, 2, 27, "Input"],
Cell[1027723, 42212, 578, 26, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1028338, 42243, 121, 3, 27, "Input"],
Cell[1028462, 42248, 181, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1028680, 42259, 86, 2, 27, "Input"],
Cell[1028769, 42263, 286, 12, 25, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1029092, 42280, 148, 4, 27, "Input",
 CellTags->"GluonGhostVertex"],
Cell[1029243, 42286, 333, 10, 39, "Output",
 CellTags->"GluonGhostVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1029613, 42301, 191, 5, 27, "Input",
 CellTags->"GluonGhostVertex"],
Cell[1029807, 42308, 521, 21, 31, "Output",
 CellTags->"GluonGhostVertex"]
}, Open  ]]
}, Open  ]],
Cell[1030355, 42333, 67, 1, 39, "ObjectName",
 CellTags->"GluonPropagator"],
Cell[CellGroupData[{
Cell[1030447, 42338, 66, 1, 33, "Subsubsection",
 CellTags->"GluonPropagator"],
Cell[1030516, 42341, 535, 10, 55, "Text",
 CellTags->"GluonPropagator"],
Cell[1031054, 42353, 99, 1, 23, "Text",
 CellTags->"GluonPropagator"],
Cell[CellGroupData[{
Cell[1031178, 42358, 83, 2, 27, "Input",
 CellTags->"GluonPropagator"],
Cell[1031264, 42362, 125, 3, 25, "Output",
 CellTags->"GluonPropagator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1031426, 42370, 129, 3, 27, "Input",
 CellTags->"GluonPropagator"],
Cell[1031558, 42375, 482, 13, 25, "Output",
 CellTags->"GluonPropagator"]
}, Open  ]],
Cell[1032055, 42391, 591, 24, 23, "Text",
 CellTags->"GluonPropagator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1032683, 42420, 72, 1, 34, "Subsubsection",
 CellTags->"GluonPropagator"],
Cell[CellGroupData[{
Cell[1032780, 42425, 187, 5, 27, "Input",
 CellTags->"GluonPropagator"],
Cell[1032970, 42432, 233, 8, 28, "Output",
 CellTags->"GluonPropagator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1033240, 42445, 189, 5, 27, "Input"],
Cell[1033432, 42452, 477, 18, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1033946, 42475, 271, 7, 27, "Input",
 CellTags->"GluonPropagator"],
Cell[1034220, 42484, 1035, 39, 56, "Output",
 CellTags->"GluonPropagator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1035292, 42528, 357, 10, 27, "Input",
 CellTags->"GluonPropagator"],
Cell[1035652, 42540, 2748, 104, 57, "Output",
 CellTags->"GluonPropagator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1038437, 42649, 199, 6, 27, "Input",
 CellTags->"GluonPropagator"],
Cell[1038639, 42657, 271, 9, 49, "Output",
 CellTags->"GluonPropagator"]
}, Open  ]],
Cell[1038925, 42669, 149, 4, 23, "Text",
 CellTags->"GluonPropagator"],
Cell[CellGroupData[{
Cell[1039099, 42677, 242, 7, 27, "Input",
 CellTags->"GluonPropagator"],
Cell[1039344, 42686, 1028, 39, 57, "Output",
 CellTags->"GluonPropagator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1040409, 42730, 267, 9, 27, "Input",
 CellTags->"GluonPropagator"],
Cell[1040679, 42741, 314, 9, 39, "Output",
 CellTags->"GluonPropagator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1041030, 42755, 275, 7, 27, "Input",
 CellTags->"GluonPropagator"],
Cell[1041308, 42764, 1274, 46, 52, "Output",
 CellTags->"GluonPropagator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1042619, 42815, 275, 7, 27, "Input",
 CellTags->"GluonPropagator"],
Cell[1042897, 42824, 1288, 47, 51, "Output",
 CellTags->"GluonPropagator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1044222, 42876, 275, 7, 27, "Input",
 CellTags->"GluonPropagator"],
Cell[1044500, 42885, 1282, 46, 52, "Output",
 CellTags->"GluonPropagator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1045819, 42936, 275, 7, 27, "Input",
 CellTags->"GluonPropagator"],
Cell[1046097, 42945, 1274, 46, 52, "Output",
 CellTags->"GluonPropagator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1047408, 42996, 275, 7, 27, "Input",
 CellTags->"GluonPropagator"],
Cell[1047686, 43005, 2422, 88, 52, "Output",
 CellTags->"GluonPropagator"]
}, Open  ]]
}, Open  ]],
Cell[1050135, 43097, 67, 1, 39, "ObjectName",
 CellTags->"GluonSelfEnergy"],
Cell[CellGroupData[{
Cell[1050227, 43102, 66, 1, 33, "Subsubsection",
 CellTags->"GluonSelfEnergy"],
Cell[1050296, 43105, 122, 3, 23, "Text",
 CellTags->"GluonSelfEnergy"],
Cell[CellGroupData[{
Cell[1050443, 43112, 129, 3, 27, "Input",
 CellTags->"GluonSelfEnergy"],
Cell[1050575, 43117, 794, 23, 29, "Output",
 CellTags->"GluonSelfEnergy"]
}, Open  ]],
Cell[1051384, 43143, 591, 24, 23, "Text",
 CellTags->"GluonSelfEnergy"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1052012, 43172, 72, 1, 34, "Subsubsection",
 CellTags->"GluonSelfEnergy"],
Cell[CellGroupData[{
Cell[1052109, 43177, 252, 8, 27, "Input",
 CellTags->"GluonSelfEnergy"],
Cell[1052364, 43187, 2391, 92, 44, "Output",
 CellTags->"GluonSelfEnergy"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1054792, 43284, 300, 9, 27, "Input",
 CellTags->"GluonSelfEnergy"],
Cell[1055095, 43295, 2734, 103, 60, "Output",
 CellTags->"GluonSelfEnergy"]
}, Open  ]]
}, Open  ]],
Cell[1057856, 43402, 59, 1, 39, "ObjectName",
 CellTags->"GluonVertex"],
Cell[CellGroupData[{
Cell[1057940, 43407, 62, 1, 33, "Subsubsection",
 CellTags->"GluonVertex"],
Cell[1058005, 43410, 88, 1, 23, "Text",
 CellTags->"GluonVertex"],
Cell[1058096, 43413, 621, 10, 71, "Text",
 CellTags->"GluonVertex"],
Cell[1058720, 43425, 91, 1, 23, "Text",
 CellTags->"GluonVertex"],
Cell[CellGroupData[{
Cell[1058836, 43430, 79, 2, 27, "Input",
 CellTags->"GluonVertex"],
Cell[1058918, 43434, 117, 3, 25, "Output",
 CellTags->"GluonVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1059072, 43442, 121, 3, 27, "Input",
 CellTags->"GluonVertex"],
Cell[1059196, 43447, 378, 11, 25, "Output",
 CellTags->"GluonVertex"]
}, Open  ]],
Cell[1059589, 43461, 337, 14, 23, "Text",
 CellTags->"GluonVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1059963, 43480, 59, 1, 33, "Subsubsection",
 CellTags->"GluonVertex"],
Cell[CellGroupData[{
Cell[1060047, 43485, 338, 10, 27, "Input",
 CellTags->"GluonVertex"],
Cell[1060388, 43497, 943, 42, 27, "Output",
 CellTags->"GluonVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1061368, 43544, 379, 12, 27, "Input",
 CellTags->"GluonVertex"],
Cell[1061750, 43558, 1974, 79, 27, "Output",
 CellTags->"GluonVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1063761, 43642, 308, 10, 27, "Input",
 CellTags->"GluonVertex"],
Cell[1064072, 43654, 272, 9, 25, "Output",
 CellTags->"GluonVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1064381, 43668, 349, 12, 27, "Input",
 CellTags->"GluonVertex"],
Cell[1064733, 43682, 1682, 65, 27, "Output",
 CellTags->"GluonVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1066452, 43752, 414, 12, 27, "Input",
 CellTags->"GluonVertex"],
Cell[1066869, 43766, 352, 11, 28, "Output",
 CellTags->"GluonVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1067258, 43782, 431, 13, 27, "Input"],
Cell[1067692, 43797, 3453, 131, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1071182, 43933, 374, 12, 27, "Input",
 CellTags->"GluonVertex"],
Cell[1071559, 43947, 160, 5, 27, "Output",
 CellTags->"GluonVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1071756, 43957, 259, 7, 27, "Input",
 CellTags->"GluonVertex"],
Cell[1072018, 43966, 3479, 132, 29, "Output",
 CellTags->"GluonVertex"]
}, Open  ]],
Cell[1075512, 44101, 200, 4, 23, "Text",
 CellTags->"GluonVertex"],
Cell[CellGroupData[{
Cell[1075737, 44109, 172, 5, 27, "Input",
 CellTags->"GluonVertex"],
Cell[1075912, 44116, 942, 42, 29, "Output",
 CellTags->"GluonVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1076891, 44163, 230, 7, 27, "Input",
 CellTags->"GluonVertex"],
Cell[1077124, 44172, 3431, 132, 51, "Output",
 CellTags->"GluonVertex"]
}, Open  ]]
}, Open  ]],
Cell[1080582, 44308, 41, 1, 39, "ObjectName",
 CellTags->"GO"],
Cell[CellGroupData[{
Cell[1080648, 44313, 53, 1, 33, "Subsubsection",
 CellTags->"GO"],
Cell[1080704, 44316, 73, 1, 23, "Text",
 CellTags->"GO"],
Cell[1080780, 44319, 206, 9, 23, "Text",
 CellTags->"GO"]
}, Open  ]],
Cell[1081001, 44331, 41, 1, 39, "ObjectName",
 CellTags->"GP"],
Cell[CellGroupData[{
Cell[1081067, 44336, 53, 1, 33, "Subsubsection",
 CellTags->"GP"],
Cell[1081123, 44339, 69, 1, 23, "Text",
 CellTags->"GP"],
Cell[1081195, 44342, 194, 9, 23, "Text",
 CellTags->"GP"]
}, Open  ]],
Cell[1081404, 44354, 67, 1, 39, "ObjectName",
 CellTags->"GrassmannParity"],
Cell[CellGroupData[{
Cell[1081496, 44359, 66, 1, 33, "Subsubsection",
 CellTags->"GrassmannParity"],
Cell[1081565, 44362, 216, 5, 39, "Text",
 CellTags->"GrassmannParity"],
Cell[1081784, 44369, 186, 9, 23, "Text",
 CellTags->"GrassmannParity"]
}, Open  ]],
Cell[1081985, 44381, 41, 1, 39, "ObjectName",
 CellTags->"GS"],
Cell[CellGroupData[{
Cell[1082051, 44386, 53, 1, 33, "Subsubsection",
 CellTags->"GS"],
Cell[1082107, 44389, 635, 18, 42, "Text",
 CellTags->"GS"],
Cell[1082745, 44409, 482, 24, 23, "Text",
 CellTags->"GS"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1083264, 44438, 50, 1, 33, "Subsubsection",
 CellTags->"GS"],
Cell[CellGroupData[{
Cell[1083339, 44443, 97, 3, 27, "Input",
 CellTags->"GS"],
Cell[1083439, 44448, 139, 4, 25, "Output",
 CellTags->"GS"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1083615, 44457, 162, 6, 27, "Input",
 CellTags->"GS"],
Cell[1083780, 44465, 155, 4, 39, "Output",
 CellTags->"GS"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1083972, 44474, 140, 4, 27, "Input",
 CellTags->"GS"],
Cell[1084115, 44480, 412, 13, 25, "Output",
 CellTags->"GS"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1084564, 44498, 179, 6, 27, "Input",
 CellTags->"GS"],
Cell[1084746, 44506, 242, 7, 39, "Output",
 CellTags->"GS"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1085025, 44518, 237, 8, 27, "Input",
 CellTags->"GS"],
Cell[1085265, 44528, 361, 12, 25, "Output",
 CellTags->"GS"]
}, Open  ]]
}, Open  ]],
Cell[1085653, 44544, 43, 1, 39, "ObjectName",
 CellTags->"GSD"],
Cell[CellGroupData[{
Cell[1085721, 44549, 54, 1, 33, "Subsubsection",
 CellTags->"GSD"],
Cell[1085778, 44552, 644, 18, 42, "Text",
 CellTags->"GSD"],
Cell[1086425, 44572, 483, 24, 23, "Text",
 CellTags->"GSD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1086945, 44601, 51, 1, 33, "Subsubsection",
 CellTags->"GSD"],
Cell[CellGroupData[{
Cell[1087021, 44606, 99, 3, 27, "Input",
 CellTags->"GSD"],
Cell[1087123, 44611, 140, 4, 25, "Output",
 CellTags->"GSD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1087300, 44620, 164, 6, 27, "Input",
 CellTags->"GSD"],
Cell[1087467, 44628, 205, 6, 39, "Output",
 CellTags->"GSD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1087709, 44639, 142, 4, 27, "Input",
 CellTags->"GSD"],
Cell[1087854, 44645, 413, 13, 25, "Output",
 CellTags->"GSD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1088304, 44663, 181, 6, 27, "Input",
 CellTags->"GSD"],
Cell[1088488, 44671, 247, 7, 39, "Output",
 CellTags->"GSD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1088772, 44683, 241, 8, 27, "Input",
 CellTags->"GSD"],
Cell[1089016, 44693, 362, 12, 25, "Output",
 CellTags->"GSD"]
}, Open  ]]
}, Open  ]],
Cell[1089405, 44709, 51, 1, 39, "ObjectName",
 CellTags->"Gstrong"],
Cell[CellGroupData[{
Cell[1089481, 44714, 58, 1, 33, "Subsubsection",
 CellTags->"Gstrong"],
Cell[1089542, 44717, 83, 1, 23, "Text",
 CellTags->"Gstrong"],
Cell[1089628, 44720, 334, 15, 23, "Text",
 CellTags->"Gstrong"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1089999, 44740, 55, 1, 33, "Subsubsection",
 CellTags->"Gstrong"],
Cell[1090057, 44743, 119, 3, 23, "Text",
 CellTags->"Gstrong"],
Cell[CellGroupData[{
Cell[1090201, 44750, 80, 2, 27, "Input",
 CellTags->"Gstrong"],
Cell[1090284, 44754, 125, 4, 25, "Output",
 CellTags->"Gstrong"]
}, Open  ]]
}, Open  ]],
Cell[1090436, 44762, 43, 1, 39, "ObjectName",
 CellTags->"GTI"],
Cell[CellGroupData[{
Cell[1090504, 44767, 54, 1, 33, "Subsubsection",
 CellTags->"GTI"],
Cell[1090561, 44770, 85, 1, 23, "Text",
 CellTags->"GTI"],
Cell[1090649, 44773, 159, 9, 23, "Text",
 CellTags->"GTI"]
}, Open  ]],
Cell[1090823, 44785, 41, 1, 39, "ObjectName",
 CellTags->"GV"],
Cell[CellGroupData[{
Cell[1090889, 44790, 53, 1, 33, "Subsubsection",
 CellTags->"GV"],
Cell[1090945, 44793, 65, 1, 23, "Text",
 CellTags->"GV"],
Cell[1091013, 44796, 182, 9, 23, "Text",
 CellTags->"GV"]
}, Open  ]],
Cell[1091210, 44808, 45, 1, 39, "ObjectName",
 CellTags->"Hill"],
Cell[CellGroupData[{
Cell[1091280, 44813, 55, 1, 33, "Subsubsection",
 CellTags->"Hill"],
Cell[1091338, 44816, 129, 4, 23, "Text",
 CellTags->"Hill"],
Cell[1091470, 44822, 196, 9, 23, "Text",
 CellTags->"Hill"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1091703, 44836, 52, 1, 33, "Subsubsection",
 CellTags->"Hill"],
Cell[CellGroupData[{
Cell[1091780, 44841, 124, 4, 27, "Input",
 CellTags->"Hill"],
Cell[1091907, 44847, 2145, 73, 90, "Output",
 CellTags->"Hill"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1094089, 44925, 270, 8, 27, "Input",
 CellTags->"Hill"],
Cell[1094362, 44935, 100, 3, 25, "Output",
 CellTags->"Hill"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1094499, 44943, 262, 9, 27, "Input",
 CellTags->"Hill"],
Cell[1094764, 44954, 985, 32, 46, "Output",
 CellTags->"Hill"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1095786, 44991, 273, 9, 27, "Input",
 CellTags->"Hill"],
Cell[1096062, 45002, 100, 3, 25, "Output",
 CellTags->"Hill"]
}, Open  ]]
}, Open  ]],
Cell[1096189, 45009, 69, 1, 39, "ObjectName",
 CellTags->"HypergeometricAC"],
Cell[CellGroupData[{
Cell[1096283, 45014, 67, 1, 33, "Subsubsection",
 CellTags->"HypergeometricAC"],
Cell[1096353, 45017, 553, 9, 71, "Text",
 CellTags->"HypergeometricAC"],
Cell[CellGroupData[{
Cell[1096931, 45030, 131, 3, 27, "Input",
 CellTags->"HypergeometricAC"],
Cell[1097065, 45035, 177, 6, 25, "Output",
 CellTags->"HypergeometricAC"]
}, Open  ]],
Cell[1097257, 45044, 598, 24, 23, "Text",
 CellTags->"HypergeometricAC"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1097892, 45073, 64, 1, 33, "Subsubsection",
 CellTags->"HypergeometricAC"],
Cell[1097959, 45076, 101, 1, 23, "Text",
 CellTags->"HypergeometricAC"],
Cell[CellGroupData[{
Cell[1098085, 45081, 264, 7, 27, "Input",
 CellTags->"HypergeometricAC"],
Cell[1098352, 45090, 1411, 43, 47, "Output",
 CellTags->"HypergeometricAC"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1099800, 45138, 264, 7, 27, "Input",
 CellTags->"HypergeometricAC"],
Cell[1100067, 45147, 1375, 43, 53, "Output",
 CellTags->"HypergeometricAC"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1101479, 45195, 264, 7, 27, "Input",
 CellTags->"HypergeometricAC"],
Cell[1101746, 45204, 1416, 44, 53, "Output",
 CellTags->"HypergeometricAC"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1103199, 45253, 264, 7, 27, "Input",
 CellTags->"HypergeometricAC"],
Cell[1103466, 45262, 1695, 51, 104, "Output",
 CellTags->"HypergeometricAC"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1105198, 45318, 264, 7, 27, "Input",
 CellTags->"HypergeometricAC"],
Cell[1105465, 45327, 415, 13, 40, "Output",
 CellTags->"HypergeometricAC"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1105917, 45345, 265, 7, 27, "Input",
 CellTags->"HypergeometricAC"],
Cell[1106185, 45354, 416, 13, 40, "Output",
 CellTags->"HypergeometricAC"]
}, Open  ]]
}, Open  ]],
Cell[1106628, 45371, 69, 1, 39, "ObjectName",
 CellTags->"HypergeometricIR"],
Cell[CellGroupData[{
Cell[1106722, 45376, 67, 1, 33, "Subsubsection",
 CellTags->"HypergeometricIR"],
Cell[1106792, 45379, 269, 5, 39, "Text",
 CellTags->"HypergeometricIR"],
Cell[1107064, 45386, 479, 19, 23, "Text",
 CellTags->"HypergeometricIR"],
Cell[CellGroupData[{
Cell[1107568, 45409, 131, 3, 27, "Input",
 CellTags->"HypergeometricIR"],
Cell[1107702, 45414, 182, 6, 25, "Output",
 CellTags->"HypergeometricIR"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1107933, 45426, 64, 1, 33, "Subsubsection",
 CellTags->"HypergeometricIR"],
Cell[CellGroupData[{
Cell[1108022, 45431, 241, 7, 27, "Input",
 CellTags->"HypergeometricIR"],
Cell[1108266, 45440, 640, 24, 48, "Output",
 CellTags->"HypergeometricIR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1108943, 45469, 394, 14, 27, "Input",
 CellTags->"HypergeometricIR"],
Cell[1109340, 45485, 488, 15, 45, "Output",
 CellTags->"HypergeometricIR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1109865, 45505, 148, 4, 27, "Input",
 CellTags->"HypergeometricIR"],
Cell[1110016, 45511, 352, 13, 27, "Output",
 CellTags->"HypergeometricIR"]
}, Open  ]]
}, Open  ]],
Cell[1110395, 45528, 69, 1, 39, "ObjectName",
 CellTags->"HypergeometricSE"],
Cell[CellGroupData[{
Cell[1110489, 45533, 67, 1, 33, "Subsubsection",
 CellTags->"HypergeometricSE"],
Cell[1110559, 45536, 420, 13, 39, "Text",
 CellTags->"HypergeometricSE"],
Cell[CellGroupData[{
Cell[1111004, 45553, 131, 3, 27, "Input",
 CellTags->"HypergeometricSE"],
Cell[1111138, 45558, 186, 6, 25, "Output",
 CellTags->"HypergeometricSE"]
}, Open  ]],
Cell[1111339, 45567, 211, 9, 23, "Text",
 CellTags->"HypergeometricSE"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1111587, 45581, 64, 1, 33, "Subsubsection",
 CellTags->"HypergeometricSE"],
Cell[CellGroupData[{
Cell[1111676, 45586, 245, 7, 27, "Input",
 CellTags->"HypergeometricSE"],
Cell[1111924, 45595, 585, 21, 46, "Output",
 CellTags->"HypergeometricSE"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1112546, 45621, 351, 11, 27, "Input",
 CellTags->"HypergeometricSE"],
Cell[1112900, 45634, 809, 29, 46, "Output",
 CellTags->"HypergeometricSE"]
}, Open  ]]
}, Open  ]],
Cell[1113736, 45667, 59, 1, 39, "ObjectName",
 CellTags->"HypExplicit"],
Cell[CellGroupData[{
Cell[1113820, 45672, 62, 1, 33, "Subsubsection",
 CellTags->"HypExplicit"],
Cell[1113885, 45675, 325, 10, 39, "Text",
 CellTags->"HypExplicit"],
Cell[1114213, 45687, 206, 9, 37, "Text",
 CellTags->"HypExplicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1114456, 45701, 59, 1, 33, "Subsubsection",
 CellTags->"HypExplicit"],
Cell[CellGroupData[{
Cell[1114540, 45706, 164, 4, 27, "Input",
 CellTags->"HypExplicit"],
Cell[1114707, 45712, 161, 5, 25, "Output",
 CellTags->"HypExplicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1114905, 45722, 142, 4, 27, "Input",
 CellTags->"HypExplicit"],
Cell[1115050, 45728, 580, 21, 46, "Output",
 CellTags->"HypExplicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1115667, 45754, 262, 8, 27, "Input",
 CellTags->"HypExplicit"],
Cell[1115932, 45764, 1495, 55, 25, "Output",
 CellTags->"HypExplicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1117464, 45824, 142, 4, 27, "Input",
 CellTags->"HypExplicit"],
Cell[1117609, 45830, 804, 29, 46, "Output",
 CellTags->"HypExplicit"]
}, Open  ]]
}, Open  ]],
Cell[1118440, 45863, 49, 1, 61, "ObjectName",
 CellTags->"HypInt"],
Cell[CellGroupData[{
Cell[1118514, 45868, 57, 1, 54, "Subsubsection",
 CellTags->"HypInt"],
Cell[1118574, 45871, 206, 5, 36, "Text",
 CellTags->"HypInt"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1118817, 45881, 54, 1, 33, "Subsubsection",
 CellTags->"HypInt"],
Cell[CellGroupData[{
Cell[1118896, 45886, 159, 4, 27, "Input",
 CellTags->"HypInt"],
Cell[1119058, 45892, 156, 5, 25, "Output",
 CellTags->"HypInt"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1119251, 45902, 128, 4, 27, "Input",
 CellTags->"HypInt"],
Cell[1119382, 45908, 945, 36, 52, "Output",
 CellTags->"HypInt"]
}, Open  ]]
}, Open  ]],
Cell[1120354, 45948, 45, 1, 39, "ObjectName",
 CellTags->"IFPD"],
Cell[CellGroupData[{
Cell[1120424, 45953, 55, 1, 26, "Subsubsection",
 CellTags->"IFPD"],
Cell[1120482, 45956, 66, 1, 21, "Text",
 CellTags->"IFPD"],
Cell[1120551, 45959, 214, 9, 23, "Text",
 CellTags->"IFPD"]
}, Open  ]],
Cell[1120780, 45971, 51, 1, 39, "ObjectName",
 CellTags->"IFPDOff"],
Cell[CellGroupData[{
Cell[1120856, 45976, 58, 1, 33, "Subsubsection",
 CellTags->"IFPDOff"],
Cell[1120917, 45979, 182, 4, 23, "Text",
 CellTags->"IFPDOff"],
Cell[1121102, 45985, 270, 14, 23, "Text",
 CellTags->"IFPDOff"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1121409, 46004, 55, 1, 33, "Subsubsection",
 CellTags->"IFPDOff"],
Cell[CellGroupData[{
Cell[1121489, 46009, 163, 5, 27, "Input",
 CellTags->"IFPDOff"],
Cell[1121655, 46016, 384, 16, 27, "Output",
 CellTags->"IFPDOff"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1122076, 46037, 108, 3, 27, "Input",
 CellTags->"IFPDOff"],
Cell[1122187, 46042, 178, 5, 39, "Output",
 CellTags->"IFPDOff"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1122402, 46052, 130, 4, 27, "Input",
 CellTags->"IFPDOff"],
Cell[1122535, 46058, 212, 8, 27, "Output",
 CellTags->"IFPDOff"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1122784, 46071, 108, 3, 27, "Input",
 CellTags->"IFPDOff"],
Cell[1122895, 46076, 283, 9, 39, "Output",
 CellTags->"IFPDOff"]
}, Open  ]]
}, Open  ]],
Cell[1123205, 46089, 49, 1, 39, "ObjectName",
 CellTags->"IFPDOn"],
Cell[CellGroupData[{
Cell[1123279, 46094, 57, 1, 33, "Subsubsection",
 CellTags->"IFPDOn"],
Cell[1123339, 46097, 317, 6, 39, "Text",
 CellTags->"IFPDOn"],
Cell[1123659, 46105, 272, 14, 23, "Text",
 CellTags->"IFPDOn"]
}, Open  ]],
Cell[1123946, 46122, 59, 1, 39, "ObjectName",
 CellTags->"IncludePair"],
Cell[CellGroupData[{
Cell[1124030, 46127, 62, 1, 33, "Subsubsection",
 CellTags->"IncludePair"],
Cell[1124095, 46130, 124, 3, 23, "Text",
 CellTags->"IncludePair"],
Cell[1124222, 46135, 176, 9, 23, "Text",
 CellTags->"IncludePair"]
}, Open  ]],
Cell[1124413, 46147, 63, 1, 39, "ObjectName",
 CellTags->"IndexPosition"],
Cell[CellGroupData[{
Cell[1124501, 46152, 64, 1, 33, "Subsubsection",
 CellTags->"IndexPosition"],
Cell[1124568, 46155, 89, 1, 23, "Text",
 CellTags->"IndexPosition"],
Cell[1124660, 46158, 199, 9, 23, "Text",
 CellTags->"IndexPosition"]
}, Open  ]],
Cell[1124874, 46170, 51, 1, 39, "ObjectName",
 CellTags->"Indices"],
Cell[CellGroupData[{
Cell[1124950, 46175, 58, 1, 26, "Subsubsection",
 CellTags->"Indices"],
Cell[1125011, 46178, 203, 4, 36, "Text",
 CellTags->"Indices"],
Cell[1125217, 46184, 193, 9, 22, "Text",
 CellTags->"Indices"]
}, Open  ]],
Cell[1125425, 46196, 67, 1, 39, "ObjectName",
 CellTags->"InitialFunction"],
Cell[CellGroupData[{
Cell[1125517, 46201, 66, 1, 33, "Subsubsection",
 CellTags->"InitialFunction"],
Cell[1125586, 46204, 183, 4, 23, "Text",
 CellTags->"InitialFunction"],
Cell[1125772, 46210, 186, 9, 23, "Text",
 CellTags->"InitialFunction"]
}, Open  ]],
Cell[1125973, 46222, 77, 1, 39, "ObjectName",
 CellTags->"InitialSubstitutions"],
Cell[CellGroupData[{
Cell[1126075, 46227, 71, 1, 33, "Subsubsection",
 CellTags->"InitialSubstitutions"],
Cell[1126149, 46230, 208, 4, 23, "Text",
 CellTags->"InitialSubstitutions"],
Cell[1126360, 46236, 408, 19, 23, "Text",
 CellTags->"InitialSubstitutions"]
}, Open  ]],
Cell[1126783, 46258, 69, 1, 39, "ObjectName",
 CellTags->"InsideDiracTrace"],
Cell[CellGroupData[{
Cell[1126877, 46263, 67, 1, 33, "Subsubsection",
 CellTags->"InsideDiracTrace"],
Cell[1126947, 46266, 498, 9, 55, "Text",
 CellTags->"InsideDiracTrace"],
Cell[1127448, 46277, 318, 14, 23, "Text",
 CellTags->"InsideDiracTrace"]
}, Open  ]],
Cell[1127781, 46294, 63, 1, 39, "ObjectName",
 CellTags->"IntegralTable"],
Cell[CellGroupData[{
Cell[1127869, 46299, 64, 1, 33, "Subsubsection",
 CellTags->"IntegralTable"],
Cell[1127936, 46302, 233, 5, 39, "Text",
 CellTags->"IntegralTable"],
Cell[1128172, 46309, 500, 19, 23, "Text",
 CellTags->"IntegralTable"]
}, Open  ]],
Cell[1128687, 46331, 69, 1, 39, "ObjectName",
 CellTags->"IntegrateByParts"],
Cell[CellGroupData[{
Cell[1128781, 46336, 67, 1, 33, "Subsubsection",
 CellTags->"IntegrateByParts"],
Cell[1128851, 46339, 184, 4, 23, "Text",
 CellTags->"IntegrateByParts"],
Cell[CellGroupData[{
Cell[1129060, 46347, 131, 3, 27, "Input",
 CellTags->"IntegrateByParts"],
Cell[1129194, 46352, 172, 5, 25, "Output",
 CellTags->"IntegrateByParts"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1129415, 46363, 64, 1, 33, "Subsubsection",
 CellTags->"IntegrateByParts"],
Cell[CellGroupData[{
Cell[1129504, 46368, 539, 19, 27, "Input",
 CellTags->"IntegrateByParts"],
Cell[1130046, 46389, 648, 23, 45, "Output",
 CellTags->"IntegrateByParts"]
}, Open  ]]
}, Open  ]],
Cell[1130721, 46416, 59, 1, 39, "ObjectName",
 CellTags->"Integratedx"],
Cell[CellGroupData[{
Cell[1130805, 46421, 62, 1, 33, "Subsubsection",
 CellTags->"Integratedx"],
Cell[1130870, 46424, 154, 4, 23, "Text",
 CellTags->"Integratedx"],
Cell[1131027, 46430, 852, 34, 23, "Text",
 CellTags->"Integratedx"]
}, Open  ]],
Cell[1131894, 46467, 57, 1, 39, "ObjectName",
 CellTags->"Integrate2"],
Cell[CellGroupData[{
Cell[1131976, 46472, 61, 1, 33, "Subsubsection",
 CellTags->"Integrate2"],
Cell[1132040, 46475, 866, 17, 87, "Text",
 CellTags->"Integrate2"],
Cell[1132909, 46494, 508, 24, 23, "Text",
 CellTags->"Integrate2"],
Cell[1133420, 46520, 405, 7, 55, "Text",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1133862, 46532, 58, 1, 33, "Subsubsection",
 CellTags->"Integrate2"],
Cell[CellGroupData[{
Cell[1133945, 46537, 425, 15, 27, "Input",
 CellTags->"Integrate2"],
Cell[1134373, 46554, 368, 13, 43, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[1134756, 46570, 190, 6, 23, "Text",
 CellTags->"Integrate2"],
Cell[CellGroupData[{
Cell[1134971, 46580, 281, 9, 27, "Input",
 CellTags->"Integrate2"],
Cell[1135255, 46591, 230, 7, 25, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1135522, 46603, 276, 9, 27, "Input",
 CellTags->"Integrate2"],
Cell[1135801, 46614, 345, 12, 43, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1136183, 46631, 336, 11, 27, "Input",
 CellTags->"Integrate2"],
Cell[1136522, 46644, 575, 20, 46, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1137134, 46669, 317, 10, 27, "Input",
 CellTags->"Integrate2"],
Cell[1137454, 46681, 134, 4, 25, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[1137603, 46688, 1589, 53, 51, "Text",
 CellTags->"Integrate2"],
Cell[CellGroupData[{
Cell[1139217, 46745, 270, 9, 27, "Input",
 CellTags->"Integrate2"],
Cell[1139490, 46756, 106, 3, 25, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[1139611, 46762, 649, 24, 32, "Text",
 CellTags->"Integrate2"],
Cell[CellGroupData[{
Cell[1140285, 46790, 317, 10, 27, "Input",
 CellTags->"Integrate2"],
Cell[1140605, 46802, 106, 3, 25, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1140748, 46810, 386, 13, 27, "Input",
 CellTags->"Integrate2"],
Cell[1141137, 46825, 164, 5, 25, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1141338, 46835, 417, 14, 27, "Input",
 CellTags->"Integrate2"],
Cell[1141758, 46851, 179, 7, 43, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1141974, 46863, 328, 11, 27, "Input",
 CellTags->"Integrate2"],
Cell[1142305, 46876, 160, 6, 25, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1142502, 46887, 354, 12, 27, "Input",
 CellTags->"Integrate2"],
Cell[1142859, 46901, 309, 11, 43, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1143205, 46917, 313, 10, 27, "Input",
 CellTags->"Integrate2"],
Cell[1143521, 46929, 189, 6, 25, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1143747, 46940, 281, 9, 27, "Input",
 CellTags->"Integrate2"],
Cell[1144031, 46951, 296, 11, 43, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1144364, 46967, 445, 15, 27, "Input",
 CellTags->"Integrate2"],
Cell[1144812, 46984, 487, 17, 46, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1145336, 47006, 721, 24, 27, "Input",
 CellTags->"Integrate2"],
Cell[1146060, 47032, 4351, 147, 142, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1150448, 47184, 471, 16, 27, "Input",
 CellTags->"Integrate2"],
Cell[1150922, 47202, 819, 29, 45, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1151778, 47236, 567, 19, 42, "Input",
 CellTags->"Integrate2"],
Cell[1152348, 47257, 5252, 177, 158, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1157637, 47439, 142, 4, 27, "Input",
 CellTags->"Integrate2"],
Cell[1157782, 47445, 1696, 53, 81, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1159515, 47503, 104, 3, 27, "Input",
 CellTags->"Integrate2"],
Cell[1159622, 47508, 125, 3, 25, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1159784, 47516, 418, 13, 42, "Input"],
Cell[1160205, 47531, 101, 2, 25, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1160343, 47538, 684, 23, 42, "Input",
 CellTags->"Integrate2"],
Cell[1161030, 47563, 3678, 139, 86, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1164745, 47707, 107, 3, 27, "Input"],
Cell[1164855, 47712, 447, 16, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1165339, 47733, 79, 2, 27, "Input"],
Cell[1165421, 47737, 100, 2, 25, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1165558, 47744, 656, 22, 42, "Input"],
Cell[1166217, 47768, 100, 2, 25, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1166354, 47775, 151, 4, 27, "Input",
 CellTags->"Integrate2"],
Cell[1166508, 47781, 109, 3, 25, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1166654, 47789, 368, 12, 27, "Input",
 CellTags->"Integrate2"],
Cell[1167025, 47803, 106, 3, 25, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[1167146, 47809, 137, 4, 23, "Text",
 CellTags->"Integrate2"],
Cell[CellGroupData[{
Cell[1167308, 47817, 147, 4, 27, "Input",
 CellTags->"Integrate2"],
Cell[1167458, 47823, 5377, 174, 246, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1172872, 48002, 230, 8, 27, "Input",
 CellTags->"Integrate2"],
Cell[1173105, 48012, 175, 6, 25, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[1173295, 48021, 165, 4, 23, "Text",
 CellTags->"Integrate2"],
Cell[CellGroupData[{
Cell[1173485, 48029, 326, 11, 27, "Input",
 CellTags->"Integrate2"],
Cell[1173814, 48042, 175, 6, 25, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[1174004, 48051, 126, 4, 27, "Input",
 CellTags->"Integrate2"],
Cell[CellGroupData[{
Cell[1174155, 48059, 317, 10, 27, "Input",
 CellTags->"Integrate2"],
Cell[1174475, 48071, 134, 4, 25, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1174646, 48080, 325, 11, 29, "Input",
 CellTags->"Integrate2"],
Cell[1174974, 48093, 240, 8, 43, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1175251, 48106, 99, 3, 27, "Input",
 CellTags->"Integrate2"],
Cell[1175353, 48111, 125, 3, 25, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1175515, 48119, 325, 11, 29, "Input",
 CellTags->"Integrate2"],
Cell[1175843, 48132, 125, 3, 25, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1176005, 48140, 381, 13, 29, "Input",
 CellTags->"Integrate2"],
Cell[1176389, 48155, 4862, 184, 150, "Output",
 CellTags->"Integrate2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1181288, 48344, 107, 3, 27, "Input"],
Cell[1181398, 48349, 210, 7, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1181645, 48361, 79, 2, 27, "Input"],
Cell[1181727, 48365, 99, 2, 25, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1181863, 48372, 353, 12, 29, "Input"],
Cell[1182219, 48386, 99, 2, 25, "Output"]
}, Open  ]]
}, Open  ]],
Cell[1182345, 48392, 57, 1, 105, "ObjectName",
 CellTags->"Integrate3"],
Cell[CellGroupData[{
Cell[1182427, 48397, 61, 1, 105, "Subsubsection",
 CellTags->"Integrate3"],
Cell[1182491, 48400, 331, 6, 105, "Text",
 CellTags->"Integrate3"],
Cell[1182825, 48408, 187, 9, 105, "Text",
 CellTags->"Integrate3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1183049, 48422, 58, 1, 33, "Subsubsection",
 CellTags->"Integrate3"],
Cell[CellGroupData[{
Cell[1183132, 48427, 280, 9, 29, "Input",
 CellTags->"Integrate3"],
Cell[1183415, 48438, 225, 8, 47, "Output",
 CellTags->"Integrate3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1183677, 48451, 400, 13, 45, "Input",
 CellTags->"Integrate3"],
Cell[1184080, 48466, 513, 20, 25, "Output",
 CellTags->"Integrate3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1184630, 48491, 676, 23, 45, "Input",
 CellTags->"Integrate3"],
Cell[1185309, 48516, 2035, 73, 72, "Output",
 CellTags->"Integrate3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1187381, 48594, 266, 8, 27, "Input",
 CellTags->"Integrate3"],
Cell[1187650, 48604, 106, 3, 25, "Output",
 CellTags->"Integrate3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1187793, 48612, 322, 10, 27, "Input",
 CellTags->"Integrate3"],
Cell[1188118, 48624, 195, 6, 25, "Output",
 CellTags->"Integrate3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1188350, 48635, 270, 9, 27, "Input",
 CellTags->"Integrate3"],
Cell[1188623, 48646, 106, 3, 25, "Output",
 CellTags->"Integrate3"]
}, Open  ]]
}, Open  ]],
Cell[1188756, 48653, 87, 1, 39, "ObjectName",
 CellTags->"IntermediateSubstitutions"],
Cell[CellGroupData[{
Cell[1188868, 48658, 76, 1, 33, "Subsubsection",
 CellTags->"IntermediateSubstitutions"],
Cell[1188947, 48661, 206, 4, 23, "Text",
 CellTags->"IntermediateSubstitutions"],
Cell[1189156, 48667, 193, 9, 23, "Text",
 CellTags->"IntermediateSubstitutions"]
}, Open  ]],
Cell[1189364, 48679, 63, 1, 39, "ObjectName",
 CellTags->"InverseMellin"],
Cell[CellGroupData[{
Cell[1189452, 48684, 64, 1, 33, "Subsubsection",
 CellTags->"InverseMellin"],
Cell[1189519, 48687, 531, 14, 55, "Text",
 CellTags->"InverseMellin"],
Cell[1190053, 48703, 609, 29, 23, "Text",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1190699, 48737, 61, 1, 33, "Subsubsection",
 CellTags->"InverseMellin"],
Cell[CellGroupData[{
Cell[1190785, 48742, 169, 5, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1190957, 48749, 157, 5, 27, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1191151, 48759, 220, 7, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1191374, 48768, 157, 5, 27, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1191568, 48778, 142, 4, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1191713, 48784, 280, 10, 27, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1192030, 48799, 194, 6, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1192227, 48807, 293, 11, 43, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1192557, 48823, 194, 6, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1192754, 48831, 360, 13, 27, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1193151, 48849, 204, 7, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1193358, 48858, 361, 13, 27, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[1193734, 48874, 113, 3, 23, "Text",
 CellTags->"InverseMellin"],
Cell[CellGroupData[{
Cell[1193872, 48881, 294, 9, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1194169, 48892, 131, 4, 43, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[1194315, 48899, 117, 3, 23, "Text",
 CellTags->"InverseMellin"],
Cell[1194435, 48904, 3132, 100, 166, "Input",
 CellTags->"InverseMellin"],
Cell[1197570, 49006, 244, 7, 27, "Input",
 CellTags->"InverseMellin"],
Cell[CellGroupData[{
Cell[1197839, 49017, 179, 6, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1198021, 49025, 398, 14, 45, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1198456, 49044, 179, 6, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1198638, 49052, 356, 12, 45, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1199031, 49069, 172, 5, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1199206, 49076, 726, 25, 49, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[1199947, 49104, 81, 2, 27, "Input",
 CellTags->"InverseMellin"],
Cell[CellGroupData[{
Cell[1200053, 49110, 192, 6, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1200248, 49118, 529, 20, 49, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1200814, 49143, 270, 9, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1201087, 49154, 502, 18, 43, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1201626, 49177, 270, 9, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1201899, 49188, 695, 25, 43, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1202631, 49218, 267, 9, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1202901, 49229, 693, 25, 45, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1203631, 49259, 246, 9, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1203880, 49270, 549, 20, 43, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1204466, 49295, 274, 10, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1204743, 49307, 914, 31, 51, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1205694, 49343, 192, 6, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1205889, 49351, 700, 25, 46, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1206626, 49381, 221, 7, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1206850, 49390, 687, 24, 43, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1207574, 49419, 192, 6, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1207769, 49427, 793, 29, 52, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1208599, 49461, 202, 6, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1208804, 49469, 544, 20, 49, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1209385, 49494, 223, 7, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1209611, 49503, 931, 33, 50, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1210579, 49541, 223, 7, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1210805, 49550, 921, 33, 50, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1211763, 49588, 212, 6, 27, "Input",
 CellTags->"InverseMellin"],
Cell[1211978, 49596, 632, 23, 52, "Output",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[1212625, 49622, 158, 5, 27, "Input",
 CellTags->"InverseMellin"]
}, Open  ]],
Cell[1212798, 49630, 51, 1, 39, "ObjectName",
 CellTags->"Isolate"],
Cell[CellGroupData[{
Cell[1212874, 49635, 58, 1, 33, "Subsubsection",
 CellTags->"Isolate"],
Cell[1212935, 49638, 422, 7, 55, "Text",
 CellTags->"Isolate"],
Cell[CellGroupData[{
Cell[1213382, 49649, 114, 3, 27, "Input",
 CellTags->"Isolate"],
Cell[1213499, 49654, 404, 12, 45, "Output",
 CellTags->"Isolate"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1213952, 49672, 55, 1, 33, "Subsubsection",
 CellTags->"Isolate"],
Cell[CellGroupData[{
Cell[1214032, 49677, 156, 5, 27, "Input",
 CellTags->"Isolate"],
Cell[1214191, 49684, 160, 6, 25, "Output",
 CellTags->"Isolate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1214388, 49695, 378, 13, 27, "Input",
 CellTags->"Isolate"],
Cell[1214769, 49710, 309, 12, 25, "Output",
 CellTags->"Isolate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1215115, 49727, 114, 3, 27, "Input",
 CellTags->"Isolate"],
Cell[1215232, 49732, 286, 11, 39, "Output",
 CellTags->"Isolate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1215555, 49748, 182, 5, 27, "Input",
 CellTags->"Isolate"],
Cell[1215740, 49755, 646, 25, 25, "Output",
 CellTags->"Isolate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1216423, 49785, 561, 19, 27, "Input",
 CellTags->"Isolate"],
Cell[1216987, 49806, 359, 14, 25, "Output",
 CellTags->"Isolate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1217383, 49825, 94, 3, 27, "Input",
 CellTags->"Isolate"],
Cell[1217480, 49830, 90, 1, 40, "Print",
 CellTags->{"Info3522790362-4590919", "Isolate"}],
Cell[1217573, 49833, 1031, 30, 51, "Print",
 CellTags->{"Info3522790362-4590919", "Isolate"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[1218641, 49868, 278, 7, 27, "Input",
 CellTags->"Isolate"],
Cell[1218922, 49877, 159, 6, 25, "Output",
 CellTags->"Isolate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1219118, 49888, 178, 6, 27, "Input",
 CellTags->"Isolate"],
Cell[1219299, 49896, 211, 7, 25, "Output",
 CellTags->"Isolate"]
}, Open  ]],
Cell[1219525, 49906, 152, 4, 27, "Input",
 CellTags->"Isolate"]
}, Open  ]],
Cell[1219692, 49913, 59, 1, 39, "ObjectName",
 CellTags->"IsolateHead"],
Cell[CellGroupData[{
Cell[1219776, 49918, 62, 1, 33, "Subsubsection",
 CellTags->"IsolateHead"],
Cell[1219841, 49921, 84, 1, 23, "Text",
 CellTags->"IsolateHead"],
Cell[1219928, 49924, 194, 9, 23, "Text",
 CellTags->"IsolateHead"]
}, Open  ]],
Cell[1220137, 49936, 61, 1, 39, "ObjectName",
 CellTags->"IsolateNames"],
Cell[CellGroupData[{
Cell[1220223, 49941, 63, 1, 33, "Subsubsection",
 CellTags->"IsolateNames"],
Cell[1220289, 49944, 220, 5, 39, "Text",
 CellTags->"IsolateNames"],
Cell[1220512, 49951, 290, 14, 23, "Text",
 CellTags->"IsolateNames"]
}, Open  ]],
Cell[1220817, 49968, 61, 1, 39, "ObjectName",
 CellTags->"IsolatePrint"],
Cell[CellGroupData[{
Cell[1220903, 49973, 63, 1, 33, "Subsubsection",
 CellTags->"IsolatePrint"],
Cell[1220969, 49976, 284, 6, 39, "Text",
 CellTags->"IsolatePrint"],
Cell[1221256, 49984, 180, 9, 23, "Text",
 CellTags->"IsolatePrint"]
}, Open  ]],
Cell[1221451, 49996, 61, 1, 39, "ObjectName",
 CellTags->"IsolateSplit"],
Cell[CellGroupData[{
Cell[1221537, 50001, 63, 1, 33, "Subsubsection",
 CellTags->"IsolateSplit"],
Cell[1221603, 50004, 413, 7, 55, "Text",
 CellTags->"IsolateSplit"],
Cell[1222019, 50013, 180, 9, 23, "Text",
 CellTags->"IsolateSplit"]
}, Open  ]],
Cell[1222214, 50025, 53, 1, 39, "ObjectName",
 CellTags->"KeepOnly"],
Cell[CellGroupData[{
Cell[1222292, 50030, 59, 1, 33, "Subsubsection",
 CellTags->"KeepOnly"],
Cell[1222354, 50033, 293, 6, 39, "Text",
 CellTags->"KeepOnly"],
Cell[1222650, 50041, 452, 24, 23, "Text",
 CellTags->"KeepOnly"]
}, Open  ]],
Cell[1223117, 50068, 41, 1, 39, "ObjectName",
 CellTags->"KK"],
Cell[CellGroupData[{
Cell[1223183, 50073, 53, 1, 33, "Subsubsection",
 CellTags->"KK"],
Cell[1223239, 50076, 235, 5, 39, "Text",
 CellTags->"KK"],
Cell[1223477, 50083, 292, 14, 23, "Text",
 CellTags->"KK"]
}, Open  ]],
Cell[1223784, 50100, 49, 1, 39, "ObjectName",
 CellTags->"Kummer"],
Cell[CellGroupData[{
Cell[1223858, 50105, 57, 1, 33, "Subsubsection",
 CellTags->"Kummer"],
Cell[1223918, 50108, 260, 5, 39, "Text",
 CellTags->"Kummer"],
Cell[1224181, 50115, 201, 9, 23, "Text",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1224419, 50129, 54, 1, 33, "Subsubsection",
 CellTags->"Kummer"],
Cell[CellGroupData[{
Cell[1224498, 50134, 337, 9, 27, "Input",
 CellTags->"Kummer"],
Cell[1224838, 50145, 452, 14, 27, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1225327, 50164, 337, 9, 27, "Input",
 CellTags->"Kummer"],
Cell[1225667, 50175, 467, 15, 40, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1226171, 50195, 337, 9, 27, "Input",
 CellTags->"Kummer"],
Cell[1226511, 50206, 467, 15, 40, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1227015, 50226, 388, 11, 27, "Input",
 CellTags->"Kummer"],
Cell[1227406, 50239, 452, 14, 27, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1227895, 50258, 479, 13, 27, "Input",
 CellTags->"Kummer"],
Cell[1228377, 50273, 531, 15, 27, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1228945, 50293, 388, 11, 27, "Input",
 CellTags->"Kummer"],
Cell[1229336, 50306, 434, 13, 43, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1229807, 50324, 479, 13, 27, "Input",
 CellTags->"Kummer"],
Cell[1230289, 50339, 548, 17, 43, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1230874, 50361, 388, 11, 27, "Input",
 CellTags->"Kummer"],
Cell[1231265, 50374, 434, 13, 43, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1231736, 50392, 479, 13, 27, "Input",
 CellTags->"Kummer"],
Cell[1232218, 50407, 548, 17, 43, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1232803, 50429, 487, 15, 27, "Input",
 CellTags->"Kummer"],
Cell[1233293, 50446, 621, 20, 43, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1233951, 50471, 629, 19, 48, "Input",
 CellTags->"Kummer"],
Cell[1234583, 50492, 722, 22, 43, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1235342, 50519, 487, 15, 27, "Input",
 CellTags->"Kummer"],
Cell[1235832, 50536, 593, 19, 44, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1236462, 50560, 629, 19, 48, "Input",
 CellTags->"Kummer"],
Cell[1237094, 50581, 707, 23, 44, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1237838, 50609, 487, 15, 27, "Input",
 CellTags->"Kummer"],
Cell[1238328, 50626, 569, 18, 43, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1238934, 50649, 629, 19, 48, "Input",
 CellTags->"Kummer"],
Cell[1239566, 50670, 750, 23, 43, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1240353, 50698, 487, 15, 27, "Input",
 CellTags->"Kummer"],
Cell[1240843, 50715, 621, 20, 43, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1241501, 50740, 629, 19, 48, "Input",
 CellTags->"Kummer"],
Cell[1242133, 50761, 745, 20, 43, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1242915, 50786, 487, 15, 27, "Input",
 CellTags->"Kummer"],
Cell[1243405, 50803, 543, 17, 43, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1243985, 50825, 629, 19, 48, "Input",
 CellTags->"Kummer"],
Cell[1244617, 50846, 789, 22, 43, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1245443, 50873, 487, 15, 27, "Input",
 CellTags->"Kummer"],
Cell[1245933, 50890, 543, 17, 43, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1246513, 50912, 629, 19, 48, "Input",
 CellTags->"Kummer"],
Cell[1247145, 50933, 680, 19, 43, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1247862, 50957, 531, 15, 48, "Input",
 CellTags->"Kummer"],
Cell[1248396, 50974, 576, 18, 27, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1249009, 50997, 338, 9, 27, "Input",
 CellTags->"Kummer"],
Cell[1249350, 51008, 452, 14, 27, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1249839, 51027, 531, 15, 48, "Input",
 CellTags->"Kummer"],
Cell[1250373, 51044, 632, 19, 40, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1251042, 51068, 338, 9, 27, "Input",
 CellTags->"Kummer"],
Cell[1251383, 51079, 441, 14, 40, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1251861, 51098, 531, 15, 48, "Input",
 CellTags->"Kummer"],
Cell[1252395, 51115, 632, 19, 40, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1253064, 51139, 338, 9, 27, "Input",
 CellTags->"Kummer"],
Cell[1253405, 51150, 441, 14, 40, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1253883, 51169, 582, 17, 48, "Input",
 CellTags->"Kummer"],
Cell[1254468, 51188, 587, 15, 27, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1255092, 51208, 389, 11, 27, "Input",
 CellTags->"Kummer"],
Cell[1255484, 51221, 452, 14, 27, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1255973, 51240, 582, 17, 48, "Input",
 CellTags->"Kummer"],
Cell[1256558, 51259, 690, 18, 43, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1257285, 51282, 389, 11, 27, "Input",
 CellTags->"Kummer"],
Cell[1257677, 51295, 492, 15, 43, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1258206, 51315, 582, 17, 48, "Input",
 CellTags->"Kummer"],
Cell[1258791, 51334, 632, 16, 43, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1259460, 51355, 389, 11, 27, "Input",
 CellTags->"Kummer"],
Cell[1259852, 51368, 434, 13, 43, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1260323, 51386, 338, 9, 27, "Input",
 CellTags->"Kummer"],
Cell[1260664, 51397, 1310, 43, 69, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1262011, 51445, 338, 9, 27, "Input",
 CellTags->"Kummer"],
Cell[1262352, 51456, 1370, 46, 53, "Output",
 CellTags->"Kummer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1263759, 51507, 338, 9, 27, "Input",
 CellTags->"Kummer"],
Cell[1264100, 51518, 1396, 46, 53, "Output",
 CellTags->"Kummer"]
}, Open  ]]
}, Open  ]],
Cell[1265523, 51568, 57, 1, 39, "ObjectName",
 CellTags->"Lagrangian"],
Cell[CellGroupData[{
Cell[1265605, 51573, 61, 1, 26, "Subsubsection",
 CellTags->"Lagrangian"],
Cell[1265669, 51576, 454, 9, 50, "Text",
 CellTags->"Lagrangian"],
Cell[1266126, 51587, 181, 9, 37, "Text",
 CellTags->"Lagrangian"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1266344, 51601, 58, 1, 33, "Subsubsection",
 CellTags->"Lagrangian"],
Cell[CellGroupData[{
Cell[1266427, 51606, 124, 3, 27, "Input",
 CellTags->"Lagrangian"],
Cell[1266554, 51611, 332, 11, 43, "Output",
 CellTags->"Lagrangian"]
}, Open  ]],
Cell[1266901, 51625, 85, 1, 23, "Text",
 CellTags->"Lagrangian"],
Cell[CellGroupData[{
Cell[1267011, 51630, 124, 3, 27, "Input",
 CellTags->"Lagrangian"],
Cell[1267138, 51635, 683, 23, 43, "Output",
 CellTags->"Lagrangian"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1267858, 51663, 124, 3, 27, "Input",
 CellTags->"Lagrangian"],
Cell[1267985, 51668, 1006, 36, 43, "Output",
 CellTags->"Lagrangian"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1269028, 51709, 124, 3, 27, "Input",
 CellTags->"Lagrangian"],
Cell[1269155, 51714, 621, 22, 27, "Output",
 CellTags->"Lagrangian"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1269813, 51741, 124, 3, 27, "Input",
 CellTags->"Lagrangian"],
Cell[1269940, 51746, 664, 23, 27, "Output",
 CellTags->"Lagrangian"]
}, Open  ]]
}, Open  ]],
Cell[1270631, 51773, 41, 1, 58, "ObjectName",
 CellTags->"LC"],
Cell[CellGroupData[{
Cell[1270697, 51778, 53, 1, 39, "Subsubsection",
 CellTags->"LC"],
Cell[1270753, 51781, 240, 5, 54, "Text",
 CellTags->"LC"],
Cell[1270996, 51788, 274, 14, 33, "Text",
 CellTags->"LC"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1271307, 51807, 50, 1, 33, "Subsubsection",
 CellTags->"LC"],
Cell[CellGroupData[{
Cell[1271382, 51812, 164, 5, 27, "Input",
 CellTags->"LC"],
Cell[1271549, 51819, 184, 6, 25, "Output",
 CellTags->"LC"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1271770, 51830, 95, 3, 27, "Input",
 CellTags->"LC"],
Cell[1271868, 51835, 477, 21, 25, "Output",
 CellTags->"LC"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1272382, 51861, 104, 3, 27, "Input",
 CellTags->"LC"],
Cell[1272489, 51866, 337, 8, 39, "Output",
 CellTags->"LC"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1272863, 51879, 181, 6, 27, "Input",
 CellTags->"LC"],
Cell[1273047, 51887, 169, 5, 25, "Output",
 CellTags->"LC"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1273253, 51897, 130, 4, 27, "Input",
 CellTags->"LC"],
Cell[1273386, 51903, 367, 10, 39, "Output",
 CellTags->"LC"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1273790, 51918, 381, 13, 27, "Input",
 CellTags->"LC"],
Cell[1274174, 51933, 396, 16, 25, "Output",
 CellTags->"LC"]
}, Open  ]]
}, Open  ]],
Cell[1274597, 51953, 43, 1, 39, "ObjectName",
 CellTags->"LCD"],
Cell[CellGroupData[{
Cell[1274665, 51958, 54, 1, 26, "Subsubsection",
 CellTags->"LCD"],
Cell[1274722, 51961, 234, 5, 36, "Text",
 CellTags->"LCD"],
Cell[1274959, 51968, 161, 4, 21, "Text",
 CellTags->"LCD"],
Cell[1275123, 51974, 272, 14, 22, "Text",
 CellTags->"LCD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1275432, 51993, 51, 1, 33, "Subsubsection",
 CellTags->"LCD"],
Cell[1275486, 51996, 190, 6, 27, "Input",
 CellTags->"LCD"],
Cell[CellGroupData[{
Cell[1275701, 52006, 166, 5, 27, "Input",
 CellTags->"LCD"],
Cell[1275870, 52013, 185, 6, 25, "Output",
 CellTags->"LCD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1276092, 52024, 96, 3, 27, "Input",
 CellTags->"LCD"],
Cell[1276191, 52029, 478, 21, 25, "Output",
 CellTags->"LCD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1276706, 52055, 105, 3, 27, "Input",
 CellTags->"LCD"],
Cell[1276814, 52060, 438, 12, 39, "Output",
 CellTags->"LCD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1277289, 52077, 183, 6, 27, "Input",
 CellTags->"LCD"],
Cell[1277475, 52085, 170, 5, 25, "Output",
 CellTags->"LCD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1277682, 52095, 131, 4, 27, "Input",
 CellTags->"LCD"],
Cell[1277816, 52101, 418, 12, 39, "Output",
 CellTags->"LCD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1278271, 52118, 400, 13, 27, "Input",
 CellTags->"LCD"],
Cell[1278674, 52133, 397, 15, 25, "Output",
 CellTags->"LCD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1279108, 52153, 170, 5, 27, "Input",
 CellTags->"LCD"],
Cell[1279281, 52160, 161, 5, 25, "Output",
 CellTags->"LCD"]
}, Open  ]]
}, Open  ]],
Cell[1279469, 52169, 61, 1, 58, "ObjectName",
 CellTags->"LeftPartialD"],
Cell[CellGroupData[{
Cell[1279555, 52174, 63, 1, 39, "Subsubsection",
 CellTags->"LeftPartialD"],
Cell[1279621, 52177, 307, 12, 40, "Text",
 CellTags->"LeftPartialD"],
Cell[1279931, 52191, 573, 24, 33, "Text",
 CellTags->"LeftPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1280541, 52220, 69, 1, 34, "Subsubsection",
 CellTags->"LeftPartialD"],
Cell[CellGroupData[{
Cell[1280635, 52225, 253, 7, 27, "Input",
 CellTags->"LeftPartialD"],
Cell[1280891, 52234, 306, 11, 32, "Output",
 CellTags->"LeftPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1281234, 52250, 120, 3, 27, "Input",
 CellTags->"LeftPartialD"],
Cell[1281357, 52255, 355, 14, 29, "Output",
 CellTags->"LeftPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1281749, 52274, 118, 3, 27, "Input",
 CellTags->"LeftPartialD"],
Cell[1281870, 52279, 291, 7, 39, "Output",
 CellTags->"LeftPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1282198, 52291, 161, 4, 27, "Input",
 CellTags->"LeftPartialD"],
Cell[1282362, 52297, 176, 4, 39, "Output",
 CellTags->"LeftPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1282575, 52306, 372, 10, 27, "Input",
 CellTags->"LeftPartialD"],
Cell[1282950, 52318, 344, 12, 32, "Output",
 CellTags->"LeftPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1283331, 52335, 120, 3, 27, "Input",
 CellTags->"LeftPartialD"],
Cell[1283454, 52340, 774, 30, 29, "Output",
 CellTags->"LeftPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1284265, 52375, 118, 3, 27, "Input",
 CellTags->"LeftPartialD"],
Cell[1284386, 52380, 799, 21, 59, "Output",
 CellTags->"LeftPartialD"]
}, Open  ]]
}, Open  ]],
Cell[1285212, 52405, 71, 1, 58, "ObjectName",
 CellTags->"LeftRightPartialD"],
Cell[CellGroupData[{
Cell[1285308, 52410, 68, 1, 39, "Subsubsection",
 CellTags->"LeftRightPartialD"],
Cell[1285379, 52413, 592, 21, 26, "Text",
 CellTags->"LeftRightPartialD"],
Cell[1285974, 52436, 831, 33, 22, "Text",
 CellTags->"LeftRightPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1286842, 52474, 65, 1, 33, "Subsubsection",
 CellTags->"LeftRightPartialD"],
Cell[CellGroupData[{
Cell[1286932, 52479, 132, 3, 27, "Input",
 CellTags->"LeftRightPartialD"],
Cell[1287067, 52484, 260, 9, 32, "Output",
 CellTags->"LeftRightPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1287364, 52498, 127, 3, 27, "Input",
 CellTags->"LeftRightPartialD"],
Cell[1287494, 52503, 527, 19, 43, "Output",
 CellTags->"LeftRightPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1288058, 52527, 263, 7, 27, "Input",
 CellTags->"LeftRightPartialD"],
Cell[1288324, 52536, 316, 11, 32, "Output",
 CellTags->"LeftRightPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1288677, 52552, 125, 3, 27, "Input",
 CellTags->"LeftRightPartialD"],
Cell[1288805, 52557, 708, 26, 43, "Output",
 CellTags->"LeftRightPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1289550, 52588, 382, 10, 27, "Input",
 CellTags->"LeftRightPartialD"],
Cell[1289935, 52600, 354, 12, 32, "Output",
 CellTags->"LeftRightPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1290326, 52617, 125, 3, 27, "Input",
 CellTags->"LeftRightPartialD"],
Cell[1290454, 52622, 902, 33, 43, "Output",
 CellTags->"LeftRightPartialD"]
}, Open  ]]
}, Open  ]],
Cell[1291383, 52659, 73, 1, 39, "ObjectName",
 CellTags->"LeftRightPartialD2"],
Cell[CellGroupData[{
Cell[1291481, 52664, 69, 1, 26, "Subsubsection",
 CellTags->"LeftRightPartialD2"],
Cell[1291553, 52667, 591, 21, 26, "Text",
 CellTags->"LeftRightPartialD2"],
Cell[1292147, 52690, 698, 29, 22, "Text",
 CellTags->"LeftRightPartialD2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1292882, 52724, 66, 1, 33, "Subsubsection",
 CellTags->"LeftRightPartialD2"],
Cell[CellGroupData[{
Cell[1292973, 52729, 134, 3, 27, "Input",
 CellTags->"LeftRightPartialD2"],
Cell[1293110, 52734, 261, 9, 32, "Output",
 CellTags->"LeftRightPartialD2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1293408, 52748, 128, 3, 27, "Input",
 CellTags->"LeftRightPartialD2"],
Cell[1293539, 52753, 433, 16, 32, "Output",
 CellTags->"LeftRightPartialD2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1294009, 52774, 265, 7, 27, "Input",
 CellTags->"LeftRightPartialD2"],
Cell[1294277, 52783, 317, 11, 32, "Output",
 CellTags->"LeftRightPartialD2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1294631, 52799, 126, 3, 27, "Input",
 CellTags->"LeftRightPartialD2"],
Cell[1294760, 52804, 600, 23, 32, "Output",
 CellTags->"LeftRightPartialD2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1295397, 52832, 384, 10, 27, "Input",
 CellTags->"LeftRightPartialD2"],
Cell[1295784, 52844, 355, 12, 32, "Output",
 CellTags->"LeftRightPartialD2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1296176, 52861, 126, 3, 27, "Input",
 CellTags->"LeftRightPartialD2"],
Cell[1296305, 52866, 780, 30, 29, "Output",
 CellTags->"LeftRightPartialD2"]
}, Open  ]]
}, Open  ]],
Cell[1297112, 52900, 58, 1, 58, "ObjectName",
 CellTags->"LeviCivita"],
Cell[CellGroupData[{
Cell[1297195, 52905, 61, 1, 39, "Subsubsection",
 CellTags->"LeviCivita"],
Cell[1297259, 52908, 1210, 40, 55, "Text",
 CellTags->"LeviCivita"],
Cell[CellGroupData[{
Cell[1298494, 52952, 120, 3, 27, "Input",
 CellTags->"LeviCivita"],
Cell[1298617, 52957, 168, 5, 25, "Output",
 CellTags->"LeviCivita"]
}, Open  ]],
Cell[1298800, 52965, 463, 24, 33, "Text",
 CellTags->"LeviCivita"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1299300, 52994, 58, 1, 33, "Subsubsection",
 CellTags->"LeviCivita"],
Cell[CellGroupData[{
Cell[1299383, 52999, 187, 5, 27, "Input",
 CellTags->"LeviCivita"],
Cell[1299573, 53006, 492, 21, 25, "Output",
 CellTags->"LeviCivita"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1300102, 53032, 204, 6, 27, "Input",
 CellTags->"LeviCivita"],
Cell[1300309, 53040, 411, 17, 25, "Output",
 CellTags->"LeviCivita"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1300757, 53062, 180, 5, 27, "Input",
 CellTags->"LeviCivita"],
Cell[1300940, 53069, 313, 13, 25, "Output",
 CellTags->"LeviCivita"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1301290, 53087, 186, 5, 27, "Input",
 CellTags->"LeviCivita"],
Cell[1301479, 53094, 107, 3, 25, "Output",
 CellTags->"LeviCivita"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1301623, 53102, 242, 7, 27, "Input",
 CellTags->"LeviCivita"],
Cell[1301868, 53111, 332, 8, 39, "Output",
 CellTags->"LeviCivita"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1302237, 53124, 365, 10, 27, "Input",
 CellTags->"LeviCivita"],
Cell[1302605, 53136, 932, 40, 25, "Output",
 CellTags->"LeviCivita"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1303574, 53181, 113, 3, 27, "Input",
 CellTags->"LeviCivita"],
Cell[1303690, 53186, 126, 4, 25, "Output",
 CellTags->"LeviCivita"]
}, Open  ]],
Cell[1303831, 53193, 316, 9, 27, "Input",
 CellTags->"LeviCivita"],
Cell[CellGroupData[{
Cell[1304172, 53206, 403, 11, 27, "Input",
 CellTags->"LeviCivita"],
Cell[1304578, 53219, 297, 10, 25, "Output",
 CellTags->"LeviCivita"]
}, Open  ]],
Cell[1304890, 53232, 316, 9, 27, "Input",
 CellTags->"LeviCivita"],
Cell[CellGroupData[{
Cell[1305231, 53245, 179, 5, 27, "Input",
 CellTags->"LeviCivita"],
Cell[1305413, 53252, 199, 6, 25, "Output",
 CellTags->"LeviCivita"]
}, Open  ]],
Cell[1305627, 53261, 110, 3, 27, "Input",
 CellTags->"LeviCivita"]
}, Open  ]],
Cell[1305752, 53267, 65, 1, 39, "ObjectName",
 CellTags->"LeviCivitaSign"],
Cell[CellGroupData[{
Cell[1305842, 53272, 65, 1, 33, "Subsubsection",
 CellTags->"LeviCivitaSign"],
Cell[1305910, 53275, 203, 4, 23, "Text",
 CellTags->"LeviCivitaSign"],
Cell[1306116, 53281, 310, 14, 23, "Text",
 CellTags->"LeviCivitaSign"]
}, Open  ]],
Cell[1306441, 53298, 81, 1, 39, "ObjectName",
 CellTags->"ListIntegrals"],
Cell[CellGroupData[{
Cell[1306547, 53303, 64, 1, 33, "Subsubsection",
 CellTags->"ListIntegrals"],
Cell[1306614, 53306, 470, 8, 55, "Text",
 CellTags->"ListIntegrals"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1307121, 53319, 61, 1, 33, "Subsubsection",
 CellTags->"ListIntegrals"],
Cell[1307185, 53322, 80, 2, 27, "Input",
 CellTags->"ListIntegrals"]
}, Open  ]],
Cell[1307280, 53327, 44, 1, 39, "ObjectName",
 CellTags->"Li2"],
Cell[CellGroupData[{
Cell[1307349, 53332, 54, 1, 33, "Subsubsection",
 CellTags->"Li2"],
Cell[1307406, 53335, 117, 3, 23, "Text",
 CellTags->"Li2"],
Cell[1307526, 53340, 153, 8, 23, "Text",
 CellTags->"Li2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1307716, 53353, 51, 1, 33, "Subsubsection",
 CellTags->"Li2"],
Cell[CellGroupData[{
Cell[1307792, 53358, 100, 3, 27, "Input",
 CellTags->"Li2"],
Cell[1307895, 53363, 136, 5, 25, "Output",
 CellTags->"Li2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1308068, 53373, 107, 3, 27, "Input",
 CellTags->"Li2"],
Cell[1308178, 53378, 162, 5, 39, "Output",
 CellTags->"Li2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1308377, 53388, 253, 9, 42, "Input",
 CellTags->"Li2"],
Cell[1308633, 53399, 136, 5, 25, "Output",
 CellTags->"Li2"]
}, Open  ]]
}, Open  ]],
Cell[1308796, 53408, 44, 1, 58, "ObjectName",
 CellTags->"Li3"],
Cell[CellGroupData[{
Cell[1308865, 53413, 54, 1, 39, "Subsubsection",
 CellTags->"Li3"],
Cell[1308922, 53416, 118, 3, 32, "Text",
 CellTags->"Li3"],
Cell[1309043, 53421, 153, 8, 33, "Text",
 CellTags->"Li3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1309233, 53434, 51, 1, 33, "Subsubsection",
 CellTags->"Li3"],
Cell[CellGroupData[{
Cell[1309309, 53439, 100, 3, 27, "Input",
 CellTags->"Li3"],
Cell[1309412, 53444, 136, 5, 25, "Output",
 CellTags->"Li3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1309585, 53454, 107, 3, 27, "Input",
 CellTags->"Li3"],
Cell[1309695, 53459, 162, 5, 39, "Output",
 CellTags->"Li3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1309894, 53469, 152, 5, 27, "Input",
 CellTags->"Li3"],
Cell[1310049, 53476, 159, 6, 43, "Output",
 CellTags->"Li3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1310245, 53487, 204, 7, 42, "Input",
 CellTags->"Li3"],
Cell[1310452, 53496, 136, 5, 25, "Output",
 CellTags->"Li3"]
}, Open  ]]
}, Open  ]],
Cell[1310615, 53505, 45, 1, 39, "ObjectName",
 CellTags->"Loop"],
Cell[CellGroupData[{
Cell[1310685, 53510, 55, 1, 33, "Subsubsection",
 CellTags->"Loop"],
Cell[1310743, 53513, 94, 1, 23, "Text",
 CellTags->"Loop"]
}, Open  ]],
Cell[1310852, 53517, 61, 1, 39, "ObjectName",
 CellTags->"LorentzIndex"],
Cell[CellGroupData[{
Cell[1310938, 53522, 63, 1, 33, "Subsubsection",
 CellTags->"LorentzIndex"],
Cell[1311004, 53525, 243, 5, 39, "Text",
 CellTags->"LorentzIndex"],
Cell[1311250, 53532, 314, 14, 23, "Text",
 CellTags->"LorentzIndex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1311601, 53551, 60, 1, 33, "Subsubsection",
 CellTags->"LorentzIndex"],
Cell[1311664, 53554, 89, 1, 23, "Text",
 CellTags->"LorentzIndex"],
Cell[CellGroupData[{
Cell[1311778, 53559, 125, 3, 27, "Input",
 CellTags->"LorentzIndex"],
Cell[1311906, 53564, 116, 3, 25, "Output",
 CellTags->"LorentzIndex"]
}, Open  ]],
Cell[1312037, 53570, 125, 3, 23, "Text",
 CellTags->"LorentzIndex"],
Cell[CellGroupData[{
Cell[1312187, 53577, 148, 4, 27, "Input",
 CellTags->"LorentzIndex"],
Cell[1312338, 53583, 116, 3, 25, "Output",
 CellTags->"LorentzIndex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1312491, 53591, 106, 2, 27, "Input",
 CellTags->"LorentzIndex"],
Cell[1312600, 53595, 140, 4, 25, "Output",
 CellTags->"LorentzIndex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1312777, 53604, 165, 4, 27, "Input",
 CellTags->"LorentzIndex"],
Cell[1312945, 53610, 113, 3, 25, "Output",
 CellTags->"LorentzIndex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1313095, 53618, 207, 5, 27, "Input",
 CellTags->"LorentzIndex"],
Cell[1313305, 53625, 139, 4, 25, "Output",
 CellTags->"LorentzIndex"]
}, Open  ]],
Cell[1313459, 53632, 141, 4, 23, "Text",
 CellTags->"LorentzIndex"],
Cell[1313603, 53638, 137, 4, 27, "Input",
 CellTags->"LorentzIndex"],
Cell[CellGroupData[{
Cell[1313765, 53646, 347, 10, 27, "Input",
 CellTags->"LorentzIndex"],
Cell[1314115, 53658, 385, 16, 25, "Output",
 CellTags->"LorentzIndex"]
}, Open  ]],
Cell[1314515, 53677, 148, 4, 27, "Input",
 CellTags->"LorentzIndex"]
}, Open  ]],
Cell[1314678, 53684, 47, 1, 39, "ObjectName",
 CellTags->"Lower"],
Cell[CellGroupData[{
Cell[1314750, 53689, 56, 1, 33, "Subsubsection",
 CellTags->"Lower"],
Cell[1314809, 53692, 120, 3, 23, "Text",
 CellTags->"Lower"],
Cell[1314932, 53697, 402, 19, 23, "Text",
 CellTags->"Lower"]
}, Open  ]],
Cell[1315349, 53719, 59, 1, 39, "ObjectName",
 CellTags->"MakeContext"],
Cell[CellGroupData[{
Cell[1315433, 53724, 62, 1, 33, "Subsubsection",
 CellTags->"MakeContext"],
Cell[1315498, 53727, 238, 5, 39, "Text",
 CellTags->"MakeContext"],
Cell[1315739, 53734, 530, 24, 23, "Text",
 CellTags->"MakeContext"]
}, Open  ]],
Cell[1316284, 53761, 57, 1, 39, "ObjectName",
 CellTags->"Mandelstam"],
Cell[CellGroupData[{
Cell[1316366, 53766, 61, 1, 33, "Subsubsection",
 CellTags->"Mandelstam"],
Cell[1316430, 53769, 1575, 73, 75, "Text",
 CellTags->"Mandelstam"],
Cell[1318008, 53844, 758, 34, 33, "Text",
 CellTags->"Mandelstam"]
}, Open  ]],
Cell[1318781, 53881, 45, 1, 58, "ObjectName",
 CellTags->"Map2"],
Cell[CellGroupData[{
Cell[1318851, 53886, 55, 1, 39, "Subsubsection",
 CellTags->"Map2"],
Cell[1318909, 53889, 135, 4, 32, "Text",
 CellTags->"Map2"],
Cell[1319047, 53895, 169, 9, 33, "Text",
 CellTags->"Map2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1319253, 53909, 52, 1, 33, "Subsubsection",
 CellTags->"Map2"],
Cell[CellGroupData[{
Cell[1319330, 53914, 149, 5, 27, "Input",
 CellTags->"Map2"],
Cell[1319482, 53921, 202, 7, 25, "Output",
 CellTags->"Map2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1319721, 53933, 125, 4, 27, "Input",
 CellTags->"Map2"],
Cell[1319849, 53939, 129, 4, 25, "Output",
 CellTags->"Map2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1320015, 53948, 184, 6, 27, "Input",
 CellTags->"Map2"],
Cell[1320202, 53956, 191, 7, 25, "Output",
 CellTags->"Map2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1320430, 53968, 125, 4, 27, "Input",
 CellTags->"Map2"],
Cell[1320558, 53974, 129, 4, 25, "Output",
 CellTags->"Map2"]
}, Open  ]]
}, Open  ]],
Cell[1320714, 53982, 67, 1, 58, "ObjectName",
 CellTags->"MemoryAvailable"],
Cell[CellGroupData[{
Cell[1320806, 53987, 66, 1, 26, "Subsubsection",
 CellTags->"MemoryAvailable"],
Cell[1320875, 53990, 230, 5, 36, "Text",
 CellTags->"MemoryAvailable"],
Cell[1321108, 53997, 314, 14, 22, "Text",
 CellTags->"MemoryAvailable"]
}, Open  ]],
Cell[1321437, 54014, 49, 1, 39, "ObjectName",
 CellTags->"MemSet"],
Cell[CellGroupData[{
Cell[1321511, 54019, 57, 1, 26, "Subsubsection",
 CellTags->"MemSet"],
Cell[1321571, 54022, 345, 9, 36, "Text",
 CellTags->"MemSet"],
Cell[1321919, 54033, 198, 9, 22, "Text",
 CellTags->"MemSet"]
}, Open  ]],
Cell[1322132, 54045, 61, 1, 39, "ObjectName",
 CellTags->"MetricTensor"],
Cell[CellGroupData[{
Cell[1322218, 54050, 63, 1, 26, "Subsubsection",
 CellTags->"MetricTensor"],
Cell[1322284, 54053, 214, 7, 21, "Text",
 CellTags->"MetricTensor"],
Cell[1322501, 54062, 584, 29, 22, "Text",
 CellTags->"MetricTensor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1323122, 54096, 60, 1, 33, "Subsubsection",
 CellTags->"MetricTensor"],
Cell[CellGroupData[{
Cell[1323207, 54101, 154, 4, 27, "Input",
 CellTags->"MetricTensor"],
Cell[1323364, 54107, 165, 5, 25, "Output",
 CellTags->"MetricTensor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1323566, 54117, 147, 4, 27, "Input",
 CellTags->"MetricTensor"],
Cell[1323716, 54123, 109, 3, 25, "Output",
 CellTags->"MetricTensor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1323862, 54131, 202, 5, 27, "Input",
 CellTags->"MetricTensor"],
Cell[1324067, 54138, 165, 5, 25, "Output",
 CellTags->"MetricTensor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1324269, 54148, 147, 4, 27, "Input",
 CellTags->"MetricTensor"],
Cell[1324419, 54154, 109, 3, 25, "Output",
 CellTags->"MetricTensor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1324565, 54162, 181, 5, 27, "Input",
 CellTags->"MetricTensor"],
Cell[1324749, 54169, 156, 4, 39, "Output",
 CellTags->"MetricTensor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1324942, 54178, 230, 6, 27, "Input",
 CellTags->"MetricTensor"],
Cell[1325175, 54186, 204, 5, 39, "Output",
 CellTags->"MetricTensor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1325416, 54196, 213, 6, 27, "Input",
 CellTags->"MetricTensor"],
Cell[1325632, 54204, 156, 4, 39, "Output",
 CellTags->"MetricTensor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1325825, 54213, 263, 7, 27, "Input",
 CellTags->"MetricTensor"],
Cell[1326091, 54222, 204, 5, 39, "Output",
 CellTags->"MetricTensor"]
}, Open  ]]
}, Open  ]],
Cell[1326322, 54231, 49, 1, 39, "ObjectName",
 CellTags->"MLimit"],
Cell[CellGroupData[{
Cell[1326396, 54236, 57, 1, 33, "Subsubsection",
 CellTags->"MLimit"],
Cell[1326456, 54239, 116, 3, 23, "Text",
 CellTags->"MLimit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1326609, 54247, 54, 1, 33, "Subsubsection",
 CellTags->"MLimit"],
Cell[CellGroupData[{
Cell[1326688, 54252, 462, 16, 27, "Input",
 CellTags->"MLimit"],
Cell[1327153, 54270, 103, 3, 25, "Output",
 CellTags->"MLimit"]
}, Open  ]]
}, Open  ]],
Cell[1327283, 54277, 53, 1, 39, "ObjectName",
 CellTags->"Momentum"],
Cell[CellGroupData[{
Cell[1327361, 54282, 59, 1, 33, "Subsubsection",
 CellTags->"Momentum"],
Cell[1327423, 54285, 258, 5, 39, "Text",
 CellTags->"Momentum"],
Cell[1327684, 54292, 530, 24, 23, "Text",
 CellTags->"Momentum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1328251, 54321, 56, 1, 33, "Subsubsection",
 CellTags->"Momentum"],
Cell[1328310, 54324, 75, 1, 23, "Text",
 CellTags->"Momentum"],
Cell[CellGroupData[{
Cell[1328410, 54329, 110, 3, 27, "Input",
 CellTags->"Momentum"],
Cell[1328523, 54334, 105, 3, 25, "Output",
 CellTags->"Momentum"]
}, Open  ]],
Cell[1328643, 54340, 138, 4, 23, "Text",
 CellTags->"Momentum"],
Cell[CellGroupData[{
Cell[1328806, 54348, 133, 4, 27, "Input",
 CellTags->"Momentum"],
Cell[1328942, 54354, 105, 3, 25, "Output",
 CellTags->"Momentum"]
}, Open  ]],
Cell[1329062, 54360, 86, 1, 23, "Text",
 CellTags->"Momentum"],
Cell[CellGroupData[{
Cell[1329173, 54365, 169, 5, 27, "Input",
 CellTags->"Momentum"],
Cell[1329345, 54372, 148, 4, 39, "Output",
 CellTags->"Momentum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1329530, 54381, 153, 5, 27, "Input",
 CellTags->"Momentum"],
Cell[1329686, 54388, 123, 4, 25, "Output",
 CellTags->"Momentum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1329846, 54397, 111, 3, 27, "Input",
 CellTags->"Momentum"],
Cell[1329960, 54402, 143, 4, 39, "Output",
 CellTags->"Momentum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1330140, 54411, 259, 8, 27, "Input",
 CellTags->"Momentum"],
Cell[1330402, 54421, 201, 7, 25, "Output",
 CellTags->"Momentum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1330640, 54433, 111, 3, 27, "Input",
 CellTags->"Momentum"],
Cell[1330754, 54438, 231, 7, 39, "Output",
 CellTags->"Momentum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1331022, 54450, 148, 4, 27, "Input",
 CellTags->"Momentum"],
Cell[1331173, 54456, 183, 5, 39, "Output",
 CellTags->"Momentum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1331393, 54466, 149, 4, 27, "Input",
 CellTags->"Momentum"],
Cell[1331545, 54472, 231, 7, 39, "Output",
 CellTags->"Momentum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1331813, 54484, 216, 7, 27, "Input",
 CellTags->"Momentum"],
Cell[1332032, 54493, 148, 4, 39, "Output",
 CellTags->"Momentum"]
}, Open  ]],
Cell[1332195, 54500, 132, 4, 27, "Input",
 CellTags->"Momentum"]
}, Open  ]],
Cell[1332342, 54507, 67, 1, 39, "ObjectName",
 CellTags->"MomentumCombine"],
Cell[CellGroupData[{
Cell[1332434, 54512, 66, 1, 26, "Subsubsection",
 CellTags->"MomentumCombine"],
Cell[1332503, 54515, 183, 4, 21, "Text",
 CellTags->"MomentumCombine"],
Cell[1332689, 54521, 585, 23, 22, "Text",
 CellTags->"MomentumCombine"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1333311, 54549, 63, 1, 33, "Subsubsection",
 CellTags->"MomentumCombine"],
Cell[CellGroupData[{
Cell[1333399, 54554, 303, 9, 27, "Input",
 CellTags->"MomentumCombine"],
Cell[1333705, 54565, 214, 6, 39, "Output",
 CellTags->"MomentumCombine"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1333956, 54576, 288, 9, 27, "Input",
 CellTags->"MomentumCombine"],
Cell[1334247, 54587, 218, 7, 25, "Output",
 CellTags->"MomentumCombine"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1334502, 54599, 125, 3, 27, "Input",
 CellTags->"MomentumCombine"],
Cell[1334630, 54604, 218, 7, 25, "Output",
 CellTags->"MomentumCombine"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1334885, 54616, 163, 5, 27, "Input",
 CellTags->"MomentumCombine"],
Cell[1335051, 54623, 259, 8, 39, "Output",
 CellTags->"MomentumCombine"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1335347, 54636, 170, 5, 27, "Input",
 CellTags->"MomentumCombine"],
Cell[1335520, 54643, 444, 19, 25, "Output",
 CellTags->"MomentumCombine"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1336001, 54667, 121, 3, 27, "Input",
 CellTags->"MomentumCombine"],
Cell[1336125, 54672, 421, 12, 39, "Output",
 CellTags->"MomentumCombine"]
}, Open  ]],
Cell[1336561, 54687, 115, 3, 27, "Input",
 CellTags->"MomentumCombine"]
}, Open  ]],
Cell[1336691, 54693, 69, 1, 39, "ObjectName",
 CellTags->"MomentumCombine2"],
Cell[CellGroupData[{
Cell[1336785, 54698, 67, 1, 26, "Subsubsection",
 CellTags->"MomentumCombine2"],
Cell[1336855, 54701, 192, 4, 36, "Text",
 CellTags->"MomentumCombine2"],
Cell[1337050, 54707, 589, 23, 22, "Text",
 CellTags->"MomentumCombine2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1337676, 54735, 64, 1, 33, "Subsubsection",
 CellTags->"MomentumCombine2"],
Cell[CellGroupData[{
Cell[1337765, 54740, 434, 13, 27, "Input",
 CellTags->"MomentumCombine2"],
Cell[1338202, 54755, 476, 20, 25, "Output",
 CellTags->"MomentumCombine2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1338715, 54780, 164, 5, 27, "Input",
 CellTags->"MomentumCombine2"],
Cell[1338882, 54787, 309, 9, 39, "Output",
 CellTags->"MomentumCombine2"]
}, Open  ]]
}, Open  ]],
Cell[1339218, 54800, 65, 1, 39, "ObjectName",
 CellTags->"MomentumExpand"],
Cell[CellGroupData[{
Cell[1339308, 54805, 65, 1, 26, "Subsubsection",
 CellTags->"MomentumExpand"],
Cell[1339376, 54808, 149, 4, 21, "Text",
 CellTags->"MomentumExpand"],
Cell[1339528, 54814, 349, 14, 22, "Text",
 CellTags->"MomentumExpand"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1339914, 54833, 62, 1, 33, "Subsubsection",
 CellTags->"MomentumExpand"],
Cell[CellGroupData[{
Cell[1340001, 54838, 218, 6, 27, "Input",
 CellTags->"MomentumExpand"],
Cell[1340222, 54846, 189, 5, 39, "Output",
 CellTags->"MomentumExpand"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1340448, 54856, 168, 5, 27, "Input",
 CellTags->"MomentumExpand"],
Cell[1340619, 54863, 248, 9, 25, "Output",
 CellTags->"MomentumExpand"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1340904, 54877, 116, 3, 27, "Input",
 CellTags->"MomentumExpand"],
Cell[1341023, 54882, 247, 7, 39, "Output",
 CellTags->"MomentumExpand"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1341307, 54894, 211, 6, 27, "Input",
 CellTags->"MomentumExpand"],
Cell[1341521, 54902, 358, 15, 25, "Output",
 CellTags->"MomentumExpand"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1341916, 54922, 116, 3, 27, "Input",
 CellTags->"MomentumExpand"],
Cell[1342035, 54927, 284, 8, 39, "Output",
 CellTags->"MomentumExpand"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1342356, 54940, 236, 7, 27, "Input",
 CellTags->"MomentumExpand"],
Cell[1342595, 54949, 384, 16, 25, "Output",
 CellTags->"MomentumExpand"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1343016, 54970, 116, 3, 27, "Input",
 CellTags->"MomentumExpand"],
Cell[1343135, 54975, 367, 11, 39, "Output",
 CellTags->"MomentumExpand"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1343539, 54991, 112, 3, 27, "Input",
 CellTags->"MomentumExpand"],
Cell[1343654, 54996, 560, 23, 27, "Output",
 CellTags->"MomentumExpand"]
}, Open  ]]
}, Open  ]],
Cell[1344241, 55023, 41, 1, 39, "ObjectName",
 CellTags->"MT"],
Cell[CellGroupData[{
Cell[1344307, 55028, 53, 1, 33, "Subsubsection",
 CellTags->"MT"],
Cell[1344363, 55031, 182, 7, 23, "Text",
 CellTags->"MT"],
Cell[1344548, 55040, 604, 29, 23, "Text",
 CellTags->"MT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1345189, 55074, 50, 1, 33, "Subsubsection",
 CellTags->"MT"],
Cell[CellGroupData[{
Cell[1345264, 55079, 134, 4, 27, "Input",
 CellTags->"MT"],
Cell[1345401, 55085, 155, 5, 25, "Output",
 CellTags->"MT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1345593, 55095, 263, 8, 27, "Input",
 CellTags->"MT"],
Cell[1345859, 55105, 99, 3, 25, "Output",
 CellTags->"MT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1345995, 55113, 157, 5, 27, "Input",
 CellTags->"MT"],
Cell[1346155, 55120, 136, 4, 39, "Output",
 CellTags->"MT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1346328, 55129, 189, 6, 27, "Input",
 CellTags->"MT"],
Cell[1346520, 55137, 218, 6, 39, "Output",
 CellTags->"MT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1346775, 55148, 225, 8, 27, "Input",
 CellTags->"MT"],
Cell[1347003, 55158, 136, 4, 39, "Output",
 CellTags->"MT"]
}, Open  ]]
}, Open  ]],
Cell[1347166, 55166, 43, 1, 39, "ObjectName",
 CellTags->"MTD"],
Cell[CellGroupData[{
Cell[1347234, 55171, 54, 1, 33, "Subsubsection",
 CellTags->"MTD"],
Cell[1347291, 55174, 184, 7, 23, "Text",
 CellTags->"MTD"],
Cell[1347478, 55183, 602, 29, 23, "Text",
 CellTags->"MTD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1348117, 55217, 51, 1, 33, "Subsubsection",
 CellTags->"MTD"],
Cell[CellGroupData[{
Cell[1348193, 55222, 136, 4, 27, "Input",
 CellTags->"MTD"],
Cell[1348332, 55228, 156, 5, 25, "Output",
 CellTags->"MTD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1348525, 55238, 266, 8, 27, "Input",
 CellTags->"MTD"],
Cell[1348794, 55248, 100, 3, 25, "Output",
 CellTags->"MTD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1348931, 55256, 175, 6, 27, "Input",
 CellTags->"MTD"],
Cell[1349109, 55264, 151, 4, 39, "Output",
 CellTags->"MTD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1349297, 55273, 207, 7, 27, "Input",
 CellTags->"MTD"],
Cell[1349507, 55282, 282, 8, 39, "Output",
 CellTags->"MTD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1349826, 55295, 235, 8, 27, "Input",
 CellTags->"MTD"],
Cell[1350064, 55305, 146, 4, 39, "Output",
 CellTags->"MTD"]
}, Open  ]]
}, Open  ]],
Cell[1350237, 55313, 67, 1, 39, "ObjectName",
 CellTags->"NegativeInteger"],
Cell[CellGroupData[{
Cell[1350329, 55318, 66, 1, 33, "Subsubsection",
 CellTags->"NegativeInteger"],
Cell[1350398, 55321, 141, 4, 23, "Text",
 CellTags->"NegativeInteger"],
Cell[1350542, 55327, 186, 9, 23, "Text",
 CellTags->"NegativeInteger"]
}, Open  ]],
Cell[1350743, 55339, 41, 1, 39, "ObjectName",
 CellTags->"Nf"],
Cell[CellGroupData[{
Cell[1350809, 55344, 53, 1, 33, "Subsubsection",
 CellTags->"Nf"],
Cell[1350865, 55347, 66, 1, 23, "Text",
 CellTags->"Nf"],
Cell[1350934, 55350, 685, 29, 23, "Text",
 CellTags->"Nf"]
}, Open  ]],
Cell[1351634, 55382, 51, 1, 39, "ObjectName",
 CellTags->"Nielsen"],
Cell[CellGroupData[{
Cell[1351710, 55387, 58, 1, 33, "Subsubsection",
 CellTags->"Nielsen"],
Cell[1351771, 55390, 86, 1, 23, "Text",
 CellTags->"Nielsen"],
Cell[CellGroupData[{
Cell[1351882, 55395, 114, 3, 27, "Input",
 CellTags->"Nielsen"],
Cell[1351999, 55400, 169, 6, 25, "Output",
 CellTags->"Nielsen"]
}, Open  ]],
Cell[1352183, 55409, 199, 9, 23, "Text",
 CellTags->"Nielsen"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1352419, 55423, 55, 1, 33, "Subsubsection",
 CellTags->"Nielsen"],
Cell[CellGroupData[{
Cell[1352499, 55428, 141, 4, 27, "Input",
 CellTags->"Nielsen"],
Cell[1352643, 55434, 251, 10, 27, "Output",
 CellTags->"Nielsen"]
}, Open  ]],
Cell[1352909, 55447, 176, 4, 23, "Text",
 CellTags->"Nielsen"],
Cell[CellGroupData[{
Cell[1353110, 55455, 172, 5, 27, "Input",
 CellTags->"Nielsen"],
Cell[1353285, 55462, 123, 3, 25, "Output",
 CellTags->"Nielsen"]
}, Open  ]],
Cell[1353423, 55468, 71, 1, 23, "Text",
 CellTags->"Nielsen"],
Cell[CellGroupData[{
Cell[1353519, 55473, 467, 14, 27, "Input",
 CellTags->"Nielsen"],
Cell[1353989, 55489, 320, 13, 43, "Output",
 CellTags->"Nielsen"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1354346, 55507, 190, 5, 27, "Input",
 CellTags->"Nielsen"],
Cell[1354539, 55514, 573, 20, 43, "Output",
 CellTags->"Nielsen"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1355149, 55539, 190, 5, 27, "Input",
 CellTags->"Nielsen"],
Cell[1355342, 55546, 807, 27, 46, "Output",
 CellTags->"Nielsen"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1356186, 55578, 190, 5, 27, "Input",
 CellTags->"Nielsen"],
Cell[1356379, 55585, 140, 5, 25, "Output",
 CellTags->"Nielsen"]
}, Open  ]]
}, Open  ]],
Cell[1356546, 55594, 61, 1, 39, "ObjectName",
 CellTags->"NonCommFreeQ"],
Cell[CellGroupData[{
Cell[1356632, 55599, 63, 1, 33, "Subsubsection",
 CellTags->"NonCommFreeQ"],
Cell[1356698, 55602, 244, 5, 39, "Text",
 CellTags->"NonCommFreeQ"],
Cell[1356945, 55609, 519, 24, 23, "Text",
 CellTags->"NonCommFreeQ"]
}, Open  ]],
Cell[1357479, 55636, 53, 1, 39, "ObjectName",
 CellTags->"NonCommQ"],
Cell[CellGroupData[{
Cell[1357557, 55641, 59, 1, 33, "Subsubsection",
 CellTags->"NonCommQ"],
Cell[1357619, 55644, 203, 4, 39, "Text",
 CellTags->"NonCommQ"],
Cell[1357825, 55650, 527, 24, 23, "Text",
 CellTags->"NonCommQ"]
}, Open  ]],
Cell[1358367, 55677, 65, 1, 39, "ObjectName",
 CellTags->"NonCommutative"],
Cell[CellGroupData[{
Cell[1358457, 55682, 65, 1, 33, "Subsubsection",
 CellTags->"NonCommutative"],
Cell[1358525, 55685, 150, 4, 23, "Text",
 CellTags->"NonCommutative"],
Cell[1358678, 55691, 333, 14, 23, "Text",
 CellTags->"NonCommutative"]
}, Open  ]],
Cell[1359026, 55708, 49, 1, 39, "ObjectName",
 CellTags->"NTerms"],
Cell[CellGroupData[{
Cell[1359100, 55713, 57, 1, 33, "Subsubsection",
 CellTags->"NTerms"],
Cell[1359160, 55716, 154, 4, 23, "Text",
 CellTags->"NTerms"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1359351, 55725, 54, 1, 33, "Subsubsection",
 CellTags->"NTerms"],
Cell[CellGroupData[{
Cell[1359430, 55730, 129, 4, 27, "Input",
 CellTags->"NTerms"],
Cell[1359562, 55736, 103, 3, 25, "Output",
 CellTags->"NTerms"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1359702, 55744, 139, 4, 27, "Input",
 CellTags->"NTerms"],
Cell[1359844, 55750, 103, 3, 25, "Output",
 CellTags->"NTerms"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1359984, 55758, 106, 3, 27, "Input",
 CellTags->"NTerms"],
Cell[1360093, 55763, 103, 3, 25, "Output",
 CellTags->"NTerms"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1360233, 55771, 106, 3, 27, "Input",
 CellTags->"NTerms"],
Cell[1360342, 55776, 103, 3, 25, "Output",
 CellTags->"NTerms"]
}, Open  ]]
}, Open  ]],
Cell[1360472, 55783, 79, 1, 39, "ObjectName",
 CellTags->"NumberOfMetricTensors"],
Cell[CellGroupData[{
Cell[1360576, 55788, 72, 1, 33, "Subsubsection",
 CellTags->"NumberOfMetricTensors"],
Cell[1360651, 55791, 95, 1, 23, "Text",
 CellTags->"NumberOfMetricTensors"],
Cell[1360749, 55794, 167, 9, 23, "Text",
 CellTags->"NonCommQ"]
}, Open  ]],
Cell[1360931, 55806, 67, 1, 39, "ObjectName",
 CellTags->"NumericalFactor"],
Cell[CellGroupData[{
Cell[1361023, 55811, 66, 1, 33, "Subsubsection",
 CellTags->"NumericalFactor"],
Cell[1361092, 55814, 119, 3, 23, "Text",
 CellTags->"NumericalFactor"]
}, Open  ]],
Cell[1361226, 55820, 55, 1, 39, "ObjectName",
 CellTags->"NumericQ1"],
Cell[CellGroupData[{
Cell[1361306, 55825, 60, 1, 33, "Subsubsection",
 CellTags->"NumericQ1"],
Cell[1361369, 55828, 139, 4, 23, "Text",
 CellTags->"NumericQ1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1361545, 55837, 57, 1, 33, "Subsubsection",
 CellTags->"NumericQ1"],
Cell[CellGroupData[{
Cell[1361627, 55842, 224, 7, 29, "Input",
 CellTags->"NumericQ1"],
Cell[1361854, 55851, 110, 3, 25, "Output",
 CellTags->"NumericQ1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1362001, 55859, 271, 9, 29, "Input",
 CellTags->"NumericQ1"],
Cell[1362275, 55870, 110, 3, 25, "Output",
 CellTags->"NumericQ1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1362422, 55878, 311, 10, 29, "Input",
 CellTags->"NumericQ1"],
Cell[1362736, 55890, 109, 3, 25, "Output",
 CellTags->"NumericQ1"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1362894, 55899, 69, 1, 39, "ObjectName",
 CellTags->"OneLoop"],
Cell[1362966, 55902, 619, 16, 55, "Text",
 CellTags->"OneLoop"],
Cell[1363588, 55920, 968, 26, 41, "Text",
 CellTags->"OneLoop"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1364593, 55951, 58, 1, 33, "Subsubsection",
 CellTags->"OneLoop"],
Cell[1364654, 55954, 391, 12, 39, "Text",
 CellTags->"OneLoop"],
Cell[1365048, 55968, 352, 6, 55, "Text",
 CellTags->"OneLoop"],
Cell[CellGroupData[{
Cell[1365425, 55978, 114, 3, 27, "Input",
 CellTags->"OneLoop"],
Cell[1365542, 55983, 1275, 29, 83, "Output",
 CellTags->"OneLoop"]
}, Open  ]],
Cell[1366832, 56015, 781, 39, 23, "Text",
 CellTags->"OneLoop"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1367650, 56059, 55, 1, 33, "Subsubsection",
 CellTags->"OneLoop"],
Cell[CellGroupData[{
Cell[1367730, 56064, 275, 10, 27, "Input",
 CellTags->"OneLoop"],
Cell[1368008, 56076, 323, 11, 48, "Output",
 CellTags->"OneLoop"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1368368, 56092, 131, 4, 27, "Input",
 CellTags->"OneLoop"],
Cell[1368502, 56098, 266, 10, 29, "Output",
 CellTags->"OneLoop"]
}, Open  ]],
Cell[1368783, 56111, 363, 11, 27, "Input",
 CellTags->"OneLoop"],
Cell[1369149, 56124, 588, 20, 25, "Text",
 CellTags->"OneLoop"],
Cell[CellGroupData[{
Cell[1369762, 56148, 908, 30, 48, "Input",
 CellTags->"OneLoop"],
Cell[1370673, 56180, 1871, 65, 57, "Output",
 CellTags->"OneLoop"]
}, Open  ]],
Cell[1372559, 56248, 219, 5, 39, "Text",
 CellTags->"OneLoop"],
Cell[CellGroupData[{
Cell[1372803, 56257, 131, 4, 27, "Input",
 CellTags->"OneLoop"],
Cell[1372937, 56263, 2406, 79, 58, "Output",
 CellTags->"OneLoop"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1375380, 56347, 113, 3, 27, "Input",
 CellTags->"OneLoop"],
Cell[1375496, 56352, 1707, 58, 53, "Output",
 CellTags->"OneLoop"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1377240, 56415, 333, 11, 27, "Input",
 CellTags->"OneLoop"],
Cell[1377576, 56428, 442, 17, 49, "Output",
 CellTags->"OneLoop"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1378055, 56450, 131, 4, 27, "Input",
 CellTags->"OneLoop"],
Cell[1378189, 56456, 1880, 66, 51, "Output",
 CellTags->"OneLoop"]
}, Open  ]],
Cell[1380084, 56525, 106, 3, 27, "Input",
 CellTags->"OneLoop"]
}, Open  ]],
Cell[1380205, 56531, 67, 1, 39, "ObjectName",
 CellTags->"OneLoopSimplify"],
Cell[CellGroupData[{
Cell[1380297, 56536, 66, 1, 33, "Subsubsection",
 CellTags->"OneLoopSimplify"],
Cell[1380366, 56539, 172, 4, 23, "Text",
 CellTags->"OneLoopSimplify"],
Cell[CellGroupData[{
Cell[1380563, 56547, 130, 3, 27, "Input",
 CellTags->"OneLoopSimplify"],
Cell[1380696, 56552, 737, 18, 45, "Output",
 CellTags->"OneLoopSimplify"]
}, Open  ]],
Cell[1381448, 56573, 376, 19, 23, "Text",
 CellTags->"OneLoopSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1381861, 56597, 63, 1, 33, "Subsubsection",
 CellTags->"OneLoopSimplify"],
Cell[CellGroupData[{
Cell[1381949, 56602, 341, 11, 27, "Input",
 CellTags->"OneLoopSimplify"],
Cell[1382293, 56615, 450, 17, 49, "Output",
 CellTags->"OneLoopSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1382780, 56637, 147, 4, 27, "Input",
 CellTags->"OneLoopSimplify"],
Cell[1382930, 56643, 1129, 43, 51, "Output",
 CellTags->"OneLoopSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1384096, 56691, 203, 6, 27, "Input",
 CellTags->"OneLoopSimplify"],
Cell[1384302, 56699, 400, 16, 45, "Output",
 CellTags->"OneLoopSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1384739, 56720, 401, 12, 27, "Input",
 CellTags->"OneLoopSimplify"],
Cell[1385143, 56734, 580, 22, 49, "Output",
 CellTags->"OneLoopSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1385760, 56761, 152, 4, 27, "Input",
 CellTags->"OneLoopSimplify"],
Cell[1385915, 56767, 7168, 261, 100, "Output",
 CellTags->"OneLoopSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1393120, 57033, 253, 9, 27, "Input",
 CellTags->"OneLoopSimplify"],
Cell[1393376, 57044, 4274, 162, 50, "Output",
 CellTags->"OneLoopSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1397687, 57211, 424, 15, 27, "Input",
 CellTags->"OneLoopSimplify"],
Cell[1398114, 57228, 2174, 83, 50, "Output",
 CellTags->"OneLoopSimplify"]
}, Open  ]]
}, Open  ]],
Cell[1400315, 57315, 57, 1, 39, "ObjectName",
 CellTags->"OneLoopSum"],
Cell[CellGroupData[{
Cell[1400397, 57320, 61, 1, 33, "Subsubsection",
 CellTags->"OneLoopSum"],
Cell[1400461, 57323, 190, 4, 23, "Text",
 CellTags->"OneLoopSum"],
Cell[1400654, 57329, 178, 9, 23, "Text",
 CellTags->"OneLoopSum"]
}, Open  ]],
Cell[1400847, 57341, 43, 1, 39, "ObjectName",
 CellTags->"OPE"],
Cell[CellGroupData[{
Cell[1400915, 57346, 54, 1, 33, "Subsubsection",
 CellTags->"OPE"],
Cell[1400972, 57349, 170, 4, 47, "Text",
 CellTags->"OPE"],
Cell[1401145, 57355, 86, 2, 23, "Text"],
Cell[CellGroupData[{
Cell[1401256, 57361, 60, 1, 27, "Input"],
Cell[1401319, 57364, 156, 5, 25, "Output"]
}, Open  ]],
Cell[1401490, 57372, 174, 9, 23, "Text",
 CellTags->"OPE"]
}, Open  ]],
Cell[1401679, 57384, 53, 1, 39, "ObjectName",
 CellTags->"OPEDelta"],
Cell[CellGroupData[{
Cell[1401757, 57389, 59, 1, 33, "Subsubsection",
 CellTags->"OPEDelta"],
Cell[1401819, 57392, 140, 4, 23, "Text",
 CellTags->"OPEDelta"],
Cell[1401962, 57398, 212, 9, 23, "Text",
 CellTags->"OPEDelta"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1402211, 57412, 56, 1, 33, "Subsubsection",
 CellTags->"OPEDelta"],
Cell[CellGroupData[{
Cell[1402292, 57417, 146, 4, 27, "Input",
 CellTags->"OPEDelta"],
Cell[1402441, 57423, 179, 6, 28, "Output",
 CellTags->"OPEDelta"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1402657, 57434, 133, 4, 27, "Input",
 CellTags->"OPEDelta"],
Cell[1402793, 57440, 105, 3, 25, "Output",
 CellTags->"OPEDelta"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1402935, 57448, 141, 4, 27, "Input",
 CellTags->"OPEDelta"],
Cell[1403079, 57454, 105, 3, 25, "Output",
 CellTags->"OPEDelta"]
}, Open  ]]
}, Open  ]],
Cell[1403211, 57461, 81, 1, 39, "ObjectName",
 CellTags->"OPEi"],
Cell[CellGroupData[{
Cell[1403317, 57466, 55, 1, 39, "Subsubsection",
 CellTags->"OPEi"],
Cell[1403375, 57469, 171, 4, 32, "Text",
 CellTags->"OPEi"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1403583, 57478, 52, 1, 33, "Subsubsection",
 CellTags->"OPEi"],
Cell[CellGroupData[{
Cell[1403660, 57483, 75, 2, 27, "Input",
 CellTags->"OPEi"],
Cell[1403738, 57487, 101, 3, 25, "Output",
 CellTags->"OPEi"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1403876, 57495, 259, 7, 27, "Input",
 CellTags->"OPEi"],
Cell[1404138, 57504, 228, 7, 25, "Output",
 CellTags->"OPEi"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1404403, 57516, 1076, 40, 48, "Input",
 CellTags->"OPEi"],
Cell[1405482, 57558, 202, 6, 25, "Output",
 CellTags->"OPEi"]
}, Open  ]],
Cell[1405699, 57567, 55, 1, 23, "Text",
 CellTags->"OPEi"],
Cell[CellGroupData[{
Cell[1405779, 57572, 519, 17, 27, "Input",
 CellTags->"OPEi"],
Cell[1406301, 57591, 529, 19, 25, "Output",
 CellTags->"OPEi"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1406867, 57615, 534, 19, 27, "Input",
 CellTags->"OPEi"],
Cell[1407404, 57636, 413, 15, 25, "Output",
 CellTags->"OPEi"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1407854, 57656, 519, 17, 27, "Input",
 CellTags->"OPEi"],
Cell[1408376, 57675, 529, 19, 25, "Output",
 CellTags->"OPEi"]
}, Open  ]]
}, Open  ]],
Cell[1408932, 57698, 73, 1, 58, "ObjectName",
 CellTags->"OPEInsert"],
Cell[CellGroupData[{
Cell[1409030, 57703, 60, 1, 39, "Subsubsection",
 CellTags->"OPEInsert"],
Cell[1409093, 57706, 264, 5, 54, "Text",
 CellTags->"OPEInsert"],
Cell[1409360, 57713, 165, 9, 23, "Text",
 CellTags->"OPEInsert"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1409562, 57727, 57, 1, 33, "Subsubsection",
 CellTags->"OPEInsert"],
Cell[1409622, 57730, 76, 2, 27, "Input",
 CellTags->"OPEInsert"]
}, Open  ]],
Cell[1409713, 57735, 67, 1, 39, "ObjectName",
 CellTags->"OPEInt"],
Cell[CellGroupData[{
Cell[1409805, 57740, 57, 1, 33, "Subsubsection",
 CellTags->"OPEInt"],
Cell[1409865, 57743, 257, 5, 39, "Text",
 CellTags->"OPEInt"],
Cell[1410125, 57750, 162, 9, 23, "Text",
 CellTags->"OPEInt"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1410324, 57764, 54, 1, 33, "Subsubsection",
 CellTags->"OPEInt"],
Cell[1410381, 57767, 73, 2, 27, "Input",
 CellTags->"OPEInt"]
}, Open  ]],
Cell[1410469, 57772, 77, 1, 39, "ObjectName",
 CellTags->"OPEIntDelta"],
Cell[CellGroupData[{
Cell[1410571, 57777, 62, 1, 33, "Subsubsection",
 CellTags->"OPEIntDelta"],
Cell[1410636, 57780, 478, 10, 63, "Text",
 CellTags->"OPEIntDelta"],
Cell[1411117, 57792, 167, 9, 23, "Text",
 CellTags->"OPEIntDelta"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1411321, 57806, 59, 1, 33, "Subsubsection",
 CellTags->"OPEIntDelta"],
Cell[1411383, 57809, 78, 2, 27, "Input",
 CellTags->"OPEIntDelta"]
}, Open  ]],
Cell[1411476, 57814, 79, 1, 39, "ObjectName",
 CellTags->"OPEIntegrate"],
Cell[CellGroupData[{
Cell[1411580, 57819, 63, 1, 33, "Subsubsection",
 CellTags->"OPEIntegrate"],
Cell[1411646, 57822, 266, 5, 39, "Text",
 CellTags->"OPEIntegrate"],
Cell[1411915, 57829, 168, 9, 23, "Text",
 CellTags->"OPEIntegrate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1412120, 57843, 60, 1, 33, "Subsubsection",
 CellTags->"OPEIntegrate"],
Cell[1412183, 57846, 79, 2, 27, "Input",
 CellTags->"OPEIntegrate"]
}, Open  ]],
Cell[1412277, 57851, 89, 1, 39, "ObjectName",
 CellTags->"OPEIntegrateDelta"],
Cell[CellGroupData[{
Cell[1412391, 57856, 68, 1, 33, "Subsubsection",
 CellTags->"OPEIntegrateDelta"],
Cell[1412462, 57859, 499, 10, 63, "Text",
 CellTags->"OPEIntegrateDelta"],
Cell[1412964, 57871, 173, 9, 23, "Text",
 CellTags->"OPEIntegrateDelta"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1413174, 57885, 65, 1, 33, "Subsubsection",
 CellTags->"OPEIntegrateDelta"],
Cell[1413242, 57888, 84, 2, 27, "Input",
 CellTags->"OPEIntegrateDelta"]
}, Open  ]],
Cell[1413341, 57893, 65, 1, 39, "ObjectName",
 CellTags->"OPESumExplicit"],
Cell[CellGroupData[{
Cell[1413431, 57898, 65, 1, 33, "Subsubsection",
 CellTags->"OPESumExplicit"],
Cell[1413499, 57901, 85, 1, 23, "Text",
 CellTags->"OPESumExplicit"],
Cell[1413587, 57904, 307, 14, 23, "Text",
 CellTags->"OPESumExplicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1413931, 57923, 62, 1, 33, "Subsubsection",
 CellTags->"OPESumExplicit"],
Cell[CellGroupData[{
Cell[1414018, 57928, 387, 13, 27, "Input",
 CellTags->"OPESumExplicit"],
Cell[1414408, 57943, 407, 15, 53, "Output",
 CellTags->"OPESumExplicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1414852, 57963, 123, 3, 27, "Input",
 CellTags->"OPESumExplicit"],
Cell[1414978, 57968, 408, 16, 46, "Output",
 CellTags->"OPESumExplicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1415423, 57989, 554, 18, 27, "Input",
 CellTags->"OPESumExplicit"],
Cell[1415980, 58009, 702, 27, 55, "Output",
 CellTags->"OPESumExplicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1416719, 58041, 123, 3, 27, "Input",
 CellTags->"OPESumExplicit"],
Cell[1416845, 58046, 1747, 66, 48, "Output",
 CellTags->"OPESumExplicit"]
}, Open  ]],
Cell[1418607, 58115, 157, 5, 27, "Input",
 CellTags->"OPESumExplicit"]
}, Open  ]],
Cell[1418779, 58123, 49, 1, 39, "ObjectName",
 CellTags->"OPESum"],
Cell[CellGroupData[{
Cell[1418853, 58128, 57, 1, 33, "Subsubsection",
 CellTags->"OPESum"],
Cell[1418913, 58131, 127, 4, 23, "Text",
 CellTags->"OPESum"],
Cell[1419043, 58137, 323, 14, 23, "Text",
 CellTags->"OPESum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1419403, 58156, 54, 1, 33, "Subsubsection",
 CellTags->"OPESum"],
Cell[CellGroupData[{
Cell[1419482, 58161, 460, 15, 27, "Input",
 CellTags->"OPESum"],
Cell[1419945, 58178, 855, 31, 53, "Output",
 CellTags->"OPESum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1420837, 58214, 115, 3, 27, "Input",
 CellTags->"OPESum"],
Cell[1420955, 58219, 1604, 60, 49, "Output",
 CellTags->"OPESum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1422596, 58284, 546, 18, 27, "Input",
 CellTags->"OPESum"],
Cell[1423145, 58304, 694, 27, 55, "Output",
 CellTags->"OPESum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1423876, 58336, 115, 3, 27, "Input",
 CellTags->"OPESum"],
Cell[1423994, 58341, 1739, 66, 48, "Output",
 CellTags->"OPESum"]
}, Open  ]],
Cell[1425748, 58410, 149, 5, 27, "Input",
 CellTags->"OPESum"]
}, Open  ]],
Cell[1425912, 58418, 65, 1, 39, "ObjectName",
 CellTags->"OPESumSimplify"],
Cell[CellGroupData[{
Cell[1426002, 58423, 65, 1, 26, "Subsubsection",
 CellTags->"OPESumSimplify"],
Cell[1426070, 58426, 92, 1, 21, "Text",
 CellTags->"OPESumSimplify"],
Cell[1426165, 58429, 307, 14, 22, "Text",
 CellTags->"OPESumSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1426509, 58448, 62, 1, 33, "Subsubsection",
 CellTags->"OPESumSimplify"],
Cell[CellGroupData[{
Cell[1426596, 58453, 143, 4, 27, "Input",
 CellTags->"OPESumSimplify"],
Cell[1426742, 58459, 1052, 37, 51, "Output",
 CellTags->"OPESumSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1427831, 58501, 89, 2, 27, "Input",
 CellTags->"OPESumSimplify"],
Cell[1427923, 58505, 1152, 39, 52, "Output",
 CellTags->"OPESumSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1429112, 58549, 273, 8, 27, "Input",
 CellTags->"OPESumSimplify"],
Cell[1429388, 58559, 283, 11, 51, "Output",
 CellTags->"OPESumSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1429708, 58575, 439, 14, 27, "Input",
 CellTags->"OPESumSimplify"],
Cell[1430150, 58591, 553, 22, 51, "Output",
 CellTags->"OPESumSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1430740, 58618, 116, 3, 27, "Input",
 CellTags->"OPESumSimplify"],
Cell[1430859, 58623, 404, 13, 42, "Output",
 CellTags->"OPESumSimplify"]
}, Open  ]]
}, Open  ]],
Cell[1431290, 58640, 54, 1, 58, "ObjectName",
 CellTags->"OPE1Loop"],
Cell[CellGroupData[{
Cell[1431369, 58645, 59, 1, 39, "Subsubsection",
 CellTags->"OPE1Loop"],
Cell[1431431, 58648, 119, 3, 32, "Text",
 CellTags->"OPE1Loop"],
Cell[1431553, 58653, 173, 9, 33, "Text",
 CellTags->"OPE1Loop"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1431763, 58667, 56, 1, 33, "Subsubsection",
 CellTags->"OPE1Loop"],
Cell[1431822, 58670, 75, 2, 27, "Input",
 CellTags->"OPE1Loop"]
}, Open  ]],
Cell[1431912, 58675, 69, 1, 58, "ObjectName",
 CellTags->"OPE2TID"],
Cell[CellGroupData[{
Cell[1432006, 58680, 58, 1, 39, "Subsubsection",
 CellTags->"OPE2TID"],
Cell[1432067, 58683, 184, 4, 23, "Text",
 CellTags->"OPE2TID"],
Cell[CellGroupData[{
Cell[1432276, 58691, 114, 3, 27, "Input",
 CellTags->"OPE2TID"],
Cell[1432393, 58696, 343, 10, 25, "Output",
 CellTags->"OPE2TID"]
}, Open  ]],
Cell[1432751, 58709, 172, 9, 33, "Text",
 CellTags->"OPE2TID"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1432960, 58723, 55, 1, 33, "Subsubsection",
 CellTags->"OPE2TID"],
Cell[1433018, 58726, 74, 2, 27, "Input",
 CellTags->"OPE2TID"]
}, Open  ]],
Cell[1433107, 58731, 63, 1, 58, "ObjectName",
 CellTags->"OptionsSelect"],
Cell[CellGroupData[{
Cell[1433195, 58736, 64, 1, 39, "Subsubsection",
 CellTags->"OptionsSelect"],
Cell[1433262, 58739, 219, 5, 54, "Text",
 CellTags->"OptionsSelect"]
}, Open  ]],
Cell[1433496, 58747, 45, 1, 58, "ObjectName",
 CellTags->"Pair"],
Cell[CellGroupData[{
Cell[1433566, 58752, 55, 1, 33, "Subsubsection",
 CellTags->"Pair"],
Cell[1433624, 58755, 499, 11, 55, "Text",
 CellTags->"Pair"],
Cell[1434126, 58768, 989, 49, 23, "Text",
 CellTags->"Pair"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1435152, 58822, 52, 1, 33, "Subsubsection",
 CellTags->"Pair"],
Cell[1435207, 58825, 84, 1, 23, "Text",
 CellTags->"Pair"],
Cell[CellGroupData[{
Cell[1435316, 58830, 218, 6, 27, "Input",
 CellTags->"Pair"],
Cell[1435537, 58838, 157, 5, 25, "Output",
 CellTags->"Pair"]
}, Open  ]],
Cell[1435709, 58846, 73, 1, 23, "Text",
 CellTags->"Pair"],
Cell[CellGroupData[{
Cell[1435807, 58851, 268, 8, 27, "Input",
 CellTags->"Pair"],
Cell[1436078, 58861, 157, 5, 25, "Output",
 CellTags->"Pair"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1436272, 58871, 208, 6, 27, "Input",
 CellTags->"Pair"],
Cell[1436483, 58879, 236, 10, 25, "Output",
 CellTags->"Pair"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1436756, 58894, 197, 6, 27, "Input",
 CellTags->"Pair"],
Cell[1436956, 58902, 203, 8, 25, "Output",
 CellTags->"Pair"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1437196, 58915, 197, 6, 27, "Input",
 CellTags->"Pair"],
Cell[1437396, 58923, 159, 6, 27, "Output",
 CellTags->"Pair"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1437592, 58934, 222, 7, 27, "Input",
 CellTags->"Pair"],
Cell[1437817, 58943, 238, 9, 25, "Output",
 CellTags->"Pair"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1438092, 58957, 223, 7, 27, "Input",
 CellTags->"Pair"],
Cell[1438318, 58966, 223, 9, 30, "Output",
 CellTags->"Pair"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1438578, 58980, 223, 7, 27, "Input",
 CellTags->"Pair"],
Cell[1438804, 58989, 223, 9, 30, "Output",
 CellTags->"Pair"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1439064, 59003, 308, 10, 27, "Input",
 CellTags->"Pair"],
Cell[1439375, 59015, 101, 3, 25, "Output",
 CellTags->"Pair"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1439513, 59023, 272, 8, 27, "Input",
 CellTags->"Pair"],
Cell[1439788, 59033, 292, 12, 27, "Output",
 CellTags->"Pair"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1440117, 59050, 383, 12, 27, "Input",
 CellTags->"Pair"],
Cell[1440503, 59064, 101, 3, 25, "Output",
 CellTags->"Pair"]
}, Open  ]]
}, Open  ]],
Cell[1440631, 59071, 59, 1, 39, "ObjectName",
 CellTags->"PairCollect"],
Cell[CellGroupData[{
Cell[1440715, 59076, 62, 1, 33, "Subsubsection",
 CellTags->"PairCollect"],
Cell[1440780, 59079, 153, 4, 21, "Text",
 CellTags->"PairCollect"],
Cell[1440936, 59085, 286, 14, 22, "Text",
 CellTags->"PairCollect"]
}, Open  ]],
Cell[1441237, 59102, 61, 1, 39, "ObjectName",
 CellTags->"PairContract"],
Cell[CellGroupData[{
Cell[1441323, 59107, 63, 1, 26, "Subsubsection",
 CellTags->"PairContract"],
Cell[1441389, 59110, 118, 3, 21, "Text",
 CellTags->"PairContract"],
Cell[1441510, 59115, 275, 13, 22, "Text",
 CellTags->"PairContract"]
}, Open  ]],
Cell[1441800, 59131, 63, 1, 39, "ObjectName",
 CellTags->"PairContract2"],
Cell[CellGroupData[{
Cell[1441888, 59136, 64, 1, 26, "Subsubsection",
 CellTags->"PairContract2"],
Cell[1441955, 59139, 142, 4, 21, "Text",
 CellTags->"PairContract2"],
Cell[1442100, 59145, 398, 18, 22, "Text",
 CellTags->"PairContract2"]
}, Open  ]],
Cell[1442513, 59166, 63, 1, 39, "ObjectName",
 CellTags->"PairContract3"],
Cell[CellGroupData[{
Cell[1442601, 59171, 64, 1, 26, "Subsubsection",
 CellTags->"PairContract3"],
Cell[1442668, 59174, 142, 4, 21, "Text",
 CellTags->"PairContract3"],
Cell[1442813, 59180, 398, 18, 22, "Text",
 CellTags->"PairContract3"]
}, Open  ]],
Cell[1443226, 59201, 53, 1, 39, "ObjectName",
 CellTags->"PartialD"],
Cell[CellGroupData[{
Cell[1443304, 59206, 59, 1, 26, "Subsubsection",
 CellTags->"PartialD"],
Cell[1443366, 59209, 864, 35, 38, "Text",
 CellTags->"PartialD"],
Cell[1444233, 59246, 581, 24, 22, "Text",
 CellTags->"PartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1444851, 59275, 65, 1, 34, "Subsubsection",
 CellTags->"PartialD"],
Cell[CellGroupData[{
Cell[1444941, 59280, 233, 7, 27, "Input",
 CellTags->"PartialD"],
Cell[1445177, 59289, 302, 11, 32, "Output",
 CellTags->"PartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1445516, 59305, 116, 3, 27, "Input",
 CellTags->"PartialD"],
Cell[1445635, 59310, 351, 14, 29, "Output",
 CellTags->"PartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1446023, 59329, 114, 3, 27, "Input",
 CellTags->"PartialD"],
Cell[1446140, 59334, 287, 7, 39, "Output",
 CellTags->"PartialD"]
}, Open  ]]
}, Open  ]],
Cell[1446454, 59345, 71, 1, 58, "ObjectName",
 CellTags->"PartialDRelations"],
Cell[CellGroupData[{
Cell[1446550, 59350, 68, 1, 39, "Subsubsection",
 CellTags->"PartialDRelations"],
Cell[1446621, 59353, 191, 5, 32, "Text",
 CellTags->"PartialDRelations"],
Cell[1446815, 59360, 700, 29, 33, "Text",
 CellTags->"PartialDRelations"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1447552, 59394, 74, 1, 34, "Subsubsection",
 CellTags->"PartialDRelations"],
Cell[CellGroupData[{
Cell[1447651, 59399, 344, 10, 27, "Input",
 CellTags->"PartialDRelations"],
Cell[1447998, 59411, 348, 12, 32, "Output",
 CellTags->"PartialDRelations"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1448383, 59428, 256, 7, 27, "Input",
 CellTags->"PartialDRelations"],
Cell[1448642, 59437, 855, 34, 29, "Output",
 CellTags->"PartialDRelations"]
}, Open  ]]
}, Open  ]],
Cell[1449524, 59475, 71, 1, 58, "ObjectName",
 CellTags->"PartialFourVector"],
Cell[CellGroupData[{
Cell[1449620, 59480, 68, 1, 39, "Subsubsection",
 CellTags->"PartialFourVector"],
Cell[1449691, 59483, 277, 6, 54, "Text",
 CellTags->"PartialFourVector"],
Cell[1449971, 59491, 402, 19, 33, "Text",
 CellTags->"PartialFourVector"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1450410, 59515, 74, 1, 34, "Subsubsection",
 CellTags->"PartialFourVector"],
Cell[CellGroupData[{
Cell[1450509, 59520, 382, 11, 35, "Input",
 CellTags->"PartialFourVector"],
Cell[1450894, 59533, 399, 15, 28, "Output",
 CellTags->"PartialFourVector"]
}, Open  ]]
}, Open  ]],
Cell[1451320, 59552, 69, 1, 58, "ObjectName",
 CellTags->"PartialIntegrate"],
Cell[CellGroupData[{
Cell[1451414, 59557, 67, 1, 39, "Subsubsection",
 CellTags->"PartialIntegrate"],
Cell[1451484, 59560, 283, 6, 39, "Text",
 CellTags->"PartialIntegrate"],
Cell[CellGroupData[{
Cell[1451792, 59570, 132, 3, 27, "Input",
 CellTags->"PartialIntegrate"],
Cell[1451927, 59575, 185, 6, 25, "Output",
 CellTags->"PartialIntegrate"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1452161, 59587, 73, 1, 34, "Subsubsection",
 CellTags->"PartialIntegrate"],
Cell[CellGroupData[{
Cell[1452259, 59592, 326, 10, 27, "Input",
 CellTags->"PartialIntegrate"],
Cell[1452588, 59604, 1229, 40, 43, "Output",
 CellTags->"PartialIntegrate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1453854, 59649, 84, 2, 27, "Input"],
Cell[1453941, 59653, 220, 5, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1454198, 59663, 275, 9, 27, "Input",
 CellTags->"PartialIntegrate"],
Cell[1454476, 59674, 383, 14, 43, "Output",
 CellTags->"PartialIntegrate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1454896, 59693, 293, 10, 44, "Input",
 CellTags->"PartialIntegrate"],
Cell[1455192, 59705, 378, 14, 48, "Output",
 CellTags->"PartialIntegrate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1455607, 59724, 443, 14, 27, "Input",
 CellTags->"PartialIntegrate"],
Cell[1456053, 59740, 246, 8, 46, "Output",
 CellTags->"PartialIntegrate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1456336, 59753, 320, 11, 27, "Input",
 CellTags->"PartialIntegrate"],
Cell[1456659, 59766, 246, 8, 46, "Output",
 CellTags->"PartialIntegrate"]
}, Open  ]],
Cell[1456920, 59777, 138, 4, 27, "Input",
 CellTags->"PartialIntegrate"]
}, Open  ]],
Cell[1457073, 59784, 57, 1, 39, "ObjectName",
 CellTags->"PartitHead"],
Cell[CellGroupData[{
Cell[1457155, 59789, 61, 1, 33, "Subsubsection",
 CellTags->"PartitHead"],
Cell[1457219, 59792, 167, 4, 23, "Text",
 CellTags->"PartitHead"]
}, Open  ]],
Cell[1457401, 59799, 57, 1, 39, "ObjectName",
 CellTags->"PauliSigma"],
Cell[CellGroupData[{
Cell[1457483, 59804, 61, 1, 33, "Subsubsection",
 CellTags->"PauliSigma"],
Cell[1457547, 59807, 252, 5, 39, "Text",
 CellTags->"PauliSigma"],
Cell[CellGroupData[{
Cell[1457824, 59816, 142, 4, 27, "Input",
 CellTags->"PauliSigma"],
Cell[1457969, 59822, 4559, 125, 123, "Output",
 CellTags->"PauliSigma"]
}, Open  ]]
}, Open  ]],
Cell[1462555, 59951, 45, 1, 39, "ObjectName",
 CellTags->"PaVe"],
Cell[CellGroupData[{
Cell[1462625, 59956, 55, 1, 33, "Subsubsection",
 CellTags->"PaVe"],
Cell[1462683, 59959, 428, 7, 55, "Text",
 CellTags->"PaVe"],
Cell[1463114, 59968, 266, 8, 23, "Text",
 CellTags->"PaVe"],
Cell[1463383, 59978, 181, 9, 23, "Text",
 CellTags->"PaVe"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1463601, 59992, 52, 1, 33, "Subsubsection",
 CellTags->"PaVe"],
Cell[1463656, 59995, 78, 1, 23, "Text",
 CellTags->"PaVe"],
Cell[CellGroupData[{
Cell[1463759, 60000, 303, 10, 27, "Input",
 CellTags->"PaVe"],
Cell[1464065, 60012, 304, 9, 25, "Output",
 CellTags->"PaVe"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1464406, 60026, 271, 9, 27, "Input",
 CellTags->"PaVe"],
Cell[1464680, 60037, 311, 11, 29, "Output",
 CellTags->"PaVe"]
}, Open  ]]
}, Open  ]],
Cell[1465018, 60052, 63, 1, 39, "ObjectName",
 CellTags->"PaVeOrderList"],
Cell[CellGroupData[{
Cell[1465106, 60057, 64, 1, 33, "Subsubsection",
 CellTags->"PaVeOrderList"],
Cell[1465173, 60060, 176, 4, 23, "Text",
 CellTags->"PaVeOrderList"],
Cell[1465352, 60066, 487, 23, 23, "Text",
 CellTags->"PaVeOrderList"]
}, Open  ]],
Cell[1465854, 60092, 55, 1, 39, "ObjectName",
 CellTags->"PaVeOrder"],
Cell[CellGroupData[{
Cell[1465934, 60097, 60, 1, 33, "Subsubsection",
 CellTags->"PaVeOrder"],
Cell[1465997, 60100, 564, 16, 39, "Text",
 CellTags->"PaVeOrder"],
Cell[1466564, 60118, 186, 9, 23, "Text",
 CellTags->"PaVeOrder"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1466787, 60132, 57, 1, 33, "Subsubsection",
 CellTags->"PaVeOrder"],
Cell[CellGroupData[{
Cell[1466869, 60137, 413, 12, 27, "Input",
 CellTags->"PaVeOrder"],
Cell[1467285, 60151, 382, 12, 25, "Output",
 CellTags->"PaVeOrder"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1467704, 60168, 413, 12, 27, "Input",
 CellTags->"PaVeOrder"],
Cell[1468120, 60182, 382, 12, 25, "Output",
 CellTags->"PaVeOrder"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1468539, 60199, 706, 20, 48, "Input",
 CellTags->"PaVeOrder"],
Cell[1469248, 60221, 623, 18, 25, "Output",
 CellTags->"PaVeOrder"]
}, Open  ]]
}, Open  ]],
Cell[1469898, 60243, 57, 1, 39, "ObjectName",
 CellTags->"PaVeReduce"],
Cell[CellGroupData[{
Cell[1469980, 60248, 61, 1, 33, "Subsubsection",
 CellTags->"PaVeReduce"],
Cell[1470044, 60251, 167, 4, 23, "Text",
 CellTags->"PaVeReduce"],
Cell[CellGroupData[{
Cell[1470236, 60259, 120, 3, 27, "Input",
 CellTags->"PaVeReduce"],
Cell[1470359, 60264, 446, 13, 25, "Output",
 CellTags->"PaVeReduce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1470842, 60282, 106, 3, 27, "Input",
 CellTags->"PaVeReduce"],
Cell[1470951, 60287, 332, 5, 56, "Print",
 CellTags->{"Info3522790398-4590919", "PaVeReduce"}]
}, Open  ]],
Cell[1471298, 60295, 279, 14, 23, "Text",
 CellTags->"PaVeReduce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1471614, 60314, 58, 1, 33, "Subsubsection",
 CellTags->"PaVeReduce"],
Cell[CellGroupData[{
Cell[1471697, 60319, 520, 16, 27, "Input",
 CellTags->"PaVeReduce"],
Cell[1472220, 60337, 3016, 104, 107, "Output",
 CellTags->"PaVeReduce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1475273, 60446, 106, 3, 27, "Input",
 CellTags->"PaVeReduce"],
Cell[1475382, 60451, 136, 4, 25, "Output",
 CellTags->"PaVeReduce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1475555, 60460, 107, 3, 27, "Input",
 CellTags->"PaVeReduce"],
Cell[1475665, 60465, 136, 4, 25, "Output",
 CellTags->"PaVeReduce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1475838, 60474, 491, 15, 27, "Input",
 CellTags->"PaVeReduce"],
Cell[1476332, 60491, 468, 15, 43, "Output",
 CellTags->"PaVeReduce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1476837, 60511, 398, 12, 48, "Input",
 CellTags->"PaVeReduce"],
Cell[1477238, 60525, 792, 23, 72, "Output",
 CellTags->"PaVeReduce"]
}, Open  ]],
Cell[1478045, 60551, 209, 7, 27, "Input",
 CellTags->"PaVeReduce"],
Cell[1478257, 60560, 162, 5, 27, "Input",
 CellTags->"PaVeReduce"],
Cell[CellGroupData[{
Cell[1478444, 60569, 633, 17, 48, "Input",
 CellTags->"PaVeReduce"],
Cell[1479080, 60588, 8311, 259, 359, "Output",
 CellTags->"PaVeReduce"]
}, Open  ]],
Cell[1487406, 60850, 267, 8, 27, "Input",
 CellTags->"PaVeReduce"],
Cell[CellGroupData[{
Cell[1487698, 60862, 375, 11, 27, "Input",
 CellTags->"PaVeReduce"],
Cell[1488076, 60875, 2976, 57, 633, "Output",
 CellTags->"PaVeReduce"]
}, Open  ]],
Cell[1491067, 60935, 253, 7, 27, "Input",
 CellTags->"PaVeReduce"]
}, Open  ]],
Cell[1491335, 60945, 41, 1, 39, "ObjectName",
 CellTags->"PD"],
Cell[CellGroupData[{
Cell[1491401, 60950, 53, 1, 33, "Subsubsection",
 CellTags->"PD"],
Cell[1491457, 60953, 81, 1, 23, "Text",
 CellTags->"PD"],
Cell[1491541, 60956, 310, 14, 23, "Text",
 CellTags->"PD"]
}, Open  ]],
Cell[1491866, 60973, 69, 1, 39, "ObjectName",
 CellTags->"PlusDistribution"],
Cell[CellGroupData[{
Cell[1491960, 60978, 67, 1, 33, "Subsubsection",
 CellTags->"PlusDistribution"],
Cell[1492030, 60981, 147, 4, 23, "Text",
 CellTags->"PlusDistribution"],
Cell[1492180, 60987, 193, 9, 23, "Text",
 CellTags->"PlusDistribution"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1492410, 61001, 64, 1, 33, "Subsubsection",
 CellTags->"PlusDistribution"],
Cell[CellGroupData[{
Cell[1492499, 61006, 198, 6, 27, "Input",
 CellTags->"PlusDistribution"],
Cell[1492700, 61014, 208, 7, 44, "Output",
 CellTags->"PlusDistribution"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1492945, 61026, 254, 8, 27, "Input",
 CellTags->"PlusDistribution"],
Cell[1493202, 61036, 268, 9, 44, "Output",
 CellTags->"PlusDistribution"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1493507, 61050, 329, 10, 27, "Input",
 CellTags->"PlusDistribution"],
Cell[1493839, 61062, 113, 3, 25, "Output",
 CellTags->"PlusDistribution"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1493989, 61070, 389, 12, 27, "Input",
 CellTags->"PlusDistribution"],
Cell[1494381, 61084, 113, 3, 25, "Output",
 CellTags->"PlusDistribution"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1494531, 61092, 417, 13, 27, "Input",
 CellTags->"PlusDistribution"],
Cell[1494951, 61107, 113, 3, 25, "Output",
 CellTags->"PlusDistribution"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1495101, 61115, 307, 10, 27, "Input",
 CellTags->"PlusDistribution"],
Cell[1495411, 61127, 376, 13, 44, "Output",
 CellTags->"PlusDistribution"]
}, Open  ]]
}, Open  ]],
Cell[1495814, 61144, 61, 1, 39, "ObjectName",
 CellTags->"Polarization"],
Cell[CellGroupData[{
Cell[1495900, 61149, 63, 1, 33, "Subsubsection",
 CellTags->"Polarization"],
Cell[1495966, 61152, 769, 12, 87, "Text",
 CellTags->"Polarization"],
Cell[1496738, 61166, 484, 19, 23, "Text",
 CellTags->"Polarization"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1497259, 61190, 60, 1, 33, "Subsubsection",
 CellTags->"Polarization"],
Cell[CellGroupData[{
Cell[1497344, 61195, 118, 3, 27, "Input",
 CellTags->"Polarization"],
Cell[1497465, 61200, 151, 4, 25, "Output",
 CellTags->"Polarization"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1497653, 61209, 153, 4, 27, "Input",
 CellTags->"Polarization"],
Cell[1497809, 61215, 168, 4, 39, "Output",
 CellTags->"Polarization"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1498014, 61224, 160, 5, 27, "Input",
 CellTags->"Polarization"],
Cell[1498177, 61231, 237, 8, 27, "Output",
 CellTags->"Polarization"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1498451, 61244, 196, 6, 27, "Input",
 CellTags->"Polarization"],
Cell[1498650, 61252, 187, 5, 39, "Output",
 CellTags->"Polarization"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1498874, 61262, 155, 4, 27, "Input",
 CellTags->"Polarization"],
Cell[1499032, 61268, 270, 9, 25, "Output",
 CellTags->"Polarization"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1499339, 61282, 194, 6, 27, "Input",
 CellTags->"Polarization"],
Cell[1499536, 61290, 206, 5, 39, "Output",
 CellTags->"Polarization"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1499779, 61300, 302, 8, 27, "Input",
 CellTags->"Polarization"],
Cell[1500084, 61310, 109, 3, 25, "Output",
 CellTags->"Polarization"]
}, Open  ]]
}, Open  ]],
Cell[1500220, 61317, 67, 1, 39, "ObjectName",
 CellTags->"PolarizationSum"],
Cell[CellGroupData[{
Cell[1500312, 61322, 66, 1, 33, "Subsubsection",
 CellTags->"PolarizationSum"],
Cell[1500381, 61325, 277, 5, 39, "Text",
 CellTags->"PolarizationSum"],
Cell[CellGroupData[{
Cell[1500683, 61334, 130, 3, 27, "Input",
 CellTags->"PolarizationSum"],
Cell[1500816, 61339, 173, 5, 25, "Output",
 CellTags->"PolarizationSum"]
}, Open  ]],
Cell[1501004, 61347, 198, 9, 23, "Text",
 CellTags->"PolarizationSum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1501239, 61361, 63, 1, 33, "Subsubsection",
 CellTags->"PolarizationSum"],
Cell[CellGroupData[{
Cell[1501327, 61366, 155, 4, 27, "Input",
 CellTags->"PolarizationSum"],
Cell[1501485, 61372, 183, 6, 25, "Output",
 CellTags->"PolarizationSum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1501705, 61383, 165, 4, 27, "Input",
 CellTags->"PolarizationSum"],
Cell[1501873, 61389, 605, 25, 46, "Output",
 CellTags->"PolarizationSum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1502515, 61419, 175, 4, 27, "Input",
 CellTags->"PolarizationSum"],
Cell[1502693, 61425, 1686, 71, 48, "Output",
 CellTags->"PolarizationSum"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1504416, 61501, 247, 7, 27, "Input",
 CellTags->"PolarizationSum"],
Cell[1504666, 61510, 4044, 162, 50, "Output",
 CellTags->"PolarizationSum"]
}, Open  ]]
}, Open  ]],
Cell[1508737, 61676, 81, 1, 39, "ObjectName",
 CellTags->"PolarizationUncontract"],
Cell[CellGroupData[{
Cell[1508843, 61681, 73, 1, 33, "Subsubsection",
 CellTags->"PolarizationUncontract"],
Cell[1508919, 61684, 152, 4, 23, "Text",
 CellTags->"PolarizationUncontract"],
Cell[1509074, 61690, 321, 14, 23, "Text",
 CellTags->"PolarizationUncontract"]
}, Open  ]],
Cell[1509410, 61707, 73, 1, 39, "ObjectName",
 CellTags->"PolarizationVector"],
Cell[CellGroupData[{
Cell[1509508, 61712, 69, 1, 33, "Subsubsection",
 CellTags->"PolarizationVector"],
Cell[1509580, 61715, 103, 1, 23, "Text",
 CellTags->"PolarizationVector"],
Cell[1509686, 61718, 409, 18, 23, "Text",
 CellTags->"PolarizationVector"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1510132, 61741, 66, 1, 33, "Subsubsection",
 CellTags->"PolarizationVector"],
Cell[CellGroupData[{
Cell[1510223, 61746, 157, 4, 27, "Input",
 CellTags->"PolarizationVector"],
Cell[1510383, 61752, 258, 9, 28, "Output",
 CellTags->"PolarizationVector"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1510678, 61766, 194, 5, 27, "Input",
 CellTags->"PolarizationVector"],
Cell[1510875, 61773, 268, 9, 29, "Output",
 CellTags->"PolarizationVector"]
}, Open  ]],
Cell[1511158, 61785, 241, 9, 26, "Text",
 CellTags->"PolarizationVector"],
Cell[CellGroupData[{
Cell[1511424, 61798, 190, 5, 27, "Input",
 CellTags->"PolarizationVector"],
Cell[1511617, 61805, 310, 8, 39, "Output",
 CellTags->"PolarizationVector"]
}, Open  ]],
Cell[1511942, 61816, 440, 18, 26, "Text",
 CellTags->"PolarizationVector"],
Cell[CellGroupData[{
Cell[1512407, 61838, 284, 8, 27, "Input",
 CellTags->"PolarizationVector"],
Cell[1512694, 61848, 314, 11, 28, "Output",
 CellTags->"PolarizationVector"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1513045, 61864, 121, 3, 27, "Input",
 CellTags->"PolarizationVector"],
Cell[1513169, 61869, 115, 3, 25, "Output",
 CellTags->"PolarizationVector"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1513321, 61877, 310, 9, 27, "Input",
 CellTags->"PolarizationVector"],
Cell[1513634, 61888, 376, 14, 28, "Output",
 CellTags->"PolarizationVector"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1514047, 61907, 121, 3, 27, "Input",
 CellTags->"PolarizationVector"],
Cell[1514171, 61912, 336, 12, 25, "Output",
 CellTags->"PolarizationVector"]
}, Open  ]],
Cell[1514522, 61927, 1511, 51, 41, "Text",
 CellTags->"PolarizationVector"],
Cell[CellGroupData[{
Cell[1516058, 61982, 310, 9, 27, "Input",
 CellTags->"PolarizationVector"],
Cell[1516371, 61993, 376, 14, 28, "Output",
 CellTags->"PolarizationVector"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1516784, 62012, 121, 3, 27, "Input",
 CellTags->"PolarizationVector"],
Cell[1516908, 62017, 336, 12, 25, "Output",
 CellTags->"PolarizationVector"]
}, Open  ]],
Cell[1517259, 62032, 153, 4, 27, "Input",
 CellTags->"PolarizationVector"]
}, Open  ]],
Cell[1517427, 62039, 67, 1, 39, "ObjectName",
 CellTags->"PositiveInteger"],
Cell[CellGroupData[{
Cell[1517519, 62044, 66, 1, 33, "Subsubsection",
 CellTags->"PositiveInteger"],
Cell[1517588, 62047, 136, 4, 23, "Text",
 CellTags->"PositiveInteger"],
Cell[1517727, 62053, 186, 9, 23, "Text",
 CellTags->"PositiveInteger"]
}, Open  ]],
Cell[1517928, 62065, 65, 1, 39, "ObjectName",
 CellTags->"PositiveNumber"],
Cell[CellGroupData[{
Cell[1518018, 62070, 65, 1, 33, "Subsubsection",
 CellTags->"PositiveNumber"],
Cell[1518086, 62073, 146, 4, 23, "Text",
 CellTags->"PositiveNumber"],
Cell[1518235, 62079, 185, 9, 23, "Text",
 CellTags->"PositiveNumber"]
}, Open  ]],
Cell[1518435, 62091, 59, 1, 39, "ObjectName",
 CellTags->"PowerFactor"],
Cell[CellGroupData[{
Cell[1518519, 62096, 62, 1, 33, "Subsubsection",
 CellTags->"PowerFactor"],
Cell[1518584, 62099, 375, 16, 23, "Text",
 CellTags->"PowerFactor"],
Cell[1518962, 62117, 197, 9, 23, "Text",
 CellTags->"PowerFactor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1519196, 62131, 59, 1, 33, "Subsubsection",
 CellTags->"PowerFactor"],
Cell[CellGroupData[{
Cell[1519280, 62136, 144, 5, 27, "Input",
 CellTags->"PowerFactor"],
Cell[1519427, 62143, 181, 6, 25, "Output",
 CellTags->"PowerFactor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1519645, 62154, 116, 3, 27, "Input",
 CellTags->"PowerFactor"],
Cell[1519764, 62159, 181, 6, 25, "Output",
 CellTags->"PowerFactor"]
}, Open  ]]
}, Open  ]],
Cell[1519972, 62169, 63, 1, 39, "ObjectName",
 CellTags->"PowerSimplify"],
Cell[CellGroupData[{
Cell[1520060, 62174, 64, 1, 33, "Subsubsection",
 CellTags->"PowerSimplify"],
Cell[1520127, 62177, 2559, 112, 55, "Text",
 CellTags->"PowerSimplify"],
Cell[1522689, 62291, 282, 14, 23, "Text",
 CellTags->"PowerSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1523008, 62310, 61, 1, 33, "Subsubsection",
 CellTags->"PowerSimplify"],
Cell[CellGroupData[{
Cell[1523094, 62315, 234, 8, 27, "Input",
 CellTags->"PowerSimplify"],
Cell[1523331, 62325, 110, 3, 25, "Output",
 CellTags->"PowerSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1523478, 62333, 239, 8, 27, "Input",
 CellTags->"PowerSimplify"],
Cell[1523720, 62343, 178, 6, 25, "Output",
 CellTags->"PowerSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1523935, 62354, 239, 8, 27, "Input",
 CellTags->"PowerSimplify"],
Cell[1524177, 62364, 178, 6, 25, "Output",
 CellTags->"PowerSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1524392, 62375, 190, 6, 27, "Input",
 CellTags->"PowerSimplify"],
Cell[1524585, 62383, 178, 6, 25, "Output",
 CellTags->"PowerSimplify"]
}, Open  ]]
}, Open  ]],
Cell[1524790, 62393, 49, 1, 39, "ObjectName",
 CellTags->"Power2"],
Cell[CellGroupData[{
Cell[1524864, 62398, 57, 1, 33, "Subsubsection",
 CellTags->"Power2"],
Cell[1524924, 62401, 213, 5, 39, "Text",
 CellTags->"Power2"],
Cell[1525140, 62408, 186, 9, 23, "Text",
 CellTags->"Power2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1525363, 62422, 54, 1, 33, "Subsubsection",
 CellTags->"Power2"],
Cell[CellGroupData[{
Cell[1525442, 62427, 147, 5, 27, "Input",
 CellTags->"Power2"],
Cell[1525592, 62434, 171, 6, 27, "Output",
 CellTags->"Power2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1525800, 62445, 148, 5, 27, "Input",
 CellTags->"Power2"],
Cell[1525951, 62452, 257, 10, 27, "Output",
 CellTags->"Power2"]
}, Open  ]]
}, Open  ]],
Cell[1526235, 62466, 67, 1, 39, "ObjectName",
 CellTags->"PostFortranFile"],
Cell[CellGroupData[{
Cell[1526327, 62471, 66, 1, 33, "Subsubsection",
 CellTags->"PostFortranFile"],
Cell[1526396, 62474, 229, 5, 39, "Text",
 CellTags->"PostFortranFile"],
Cell[1526628, 62481, 308, 14, 23, "Text",
 CellTags->"PostFortranFile"]
}, Open  ]],
Cell[1526951, 62498, 55, 1, 39, "ObjectName",
 CellTags->"Prefactor"],
Cell[CellGroupData[{
Cell[1527031, 62503, 60, 1, 33, "Subsubsection",
 CellTags->"Prefactor"],
Cell[1527094, 62506, 290, 6, 39, "Text",
 CellTags->"Prefactor"],
Cell[1527387, 62514, 293, 14, 23, "Text",
 CellTags->"Prefactor"]
}, Open  ]],
Cell[1527695, 62531, 65, 1, 39, "ObjectName",
 CellTags->"PreFortranFile"],
Cell[CellGroupData[{
Cell[1527785, 62536, 65, 1, 33, "Subsubsection",
 CellTags->"PreFortranFile"],
Cell[1527853, 62539, 232, 5, 39, "Text",
 CellTags->"PreFortranFile"],
Cell[1528088, 62546, 310, 14, 23, "Text",
 CellTags->"PreFortranFile"]
}, Open  ]],
Cell[1528413, 62563, 79, 1, 39, "ObjectName",
 CellTags->"PropagatorDenominator"],
Cell[CellGroupData[{
Cell[1528517, 62568, 72, 1, 33, "Subsubsection",
 CellTags->"PropagatorDenominator"],
Cell[1528592, 62571, 549, 16, 55, "Text",
 CellTags->"PropagatorDenominator"],
Cell[1529144, 62589, 493, 19, 23, "Text",
 CellTags->"PropagatorDenominator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1529674, 62613, 69, 1, 33, "Subsubsection",
 CellTags->"PropagatorDenominator"],
Cell[CellGroupData[{
Cell[1529768, 62618, 178, 5, 27, "Input",
 CellTags->"PropagatorDenominator"],
Cell[1529949, 62625, 215, 7, 48, "Output",
 CellTags->"PropagatorDenominator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1530201, 62637, 136, 3, 27, "Input",
 CellTags->"PropagatorDenominator"],
Cell[1530340, 62642, 164, 5, 48, "Output",
 CellTags->"PropagatorDenominator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1530541, 62652, 189, 5, 27, "Input",
 CellTags->"PropagatorDenominator"],
Cell[1530733, 62659, 215, 7, 48, "Output",
 CellTags->"PropagatorDenominator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1530985, 62671, 158, 4, 27, "Input",
 CellTags->"PropagatorDenominator"],
Cell[1531146, 62677, 235, 6, 39, "Output",
 CellTags->"PropagatorDenominator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1531418, 62688, 194, 5, 27, "Input",
 CellTags->"PropagatorDenominator"],
Cell[1531615, 62695, 235, 6, 39, "Output",
 CellTags->"PropagatorDenominator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1531887, 62706, 145, 3, 27, "Input",
 CellTags->"PropagatorDenominator"],
Cell[1532035, 62711, 253, 9, 48, "Output",
 CellTags->"PropagatorDenominator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1532325, 62725, 127, 3, 27, "Input",
 CellTags->"PropagatorDenominator"],
Cell[1532455, 62730, 325, 10, 58, "Output",
 CellTags->"PropagatorDenominator"]
}, Open  ]],
Cell[1532795, 62743, 121, 3, 27, "Input",
 CellTags->"PropagatorDenominator"]
}, Open  ]],
Cell[1532931, 62749, 95, 1, 39, "ObjectName",
 CellTags->"PropagatorDenominatorExplicit"],
Cell[CellGroupData[{
Cell[1533051, 62754, 80, 1, 33, "Subsubsection",
 CellTags->"PropagatorDenominatorExplicit"],
Cell[1533134, 62757, 243, 5, 39, "Text",
 CellTags->"PropagatorDenominatorExplicit"],
Cell[1533380, 62764, 379, 14, 23, "Text",
 CellTags->"PropagatorDenominatorExplicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1533796, 62783, 77, 1, 33, "Subsubsection",
 CellTags->"PropagatorDenominatorExplicit"],
Cell[CellGroupData[{
Cell[1533898, 62788, 308, 11, 27, "Input",
 CellTags->"PropagatorDenominatorExplicit"],
Cell[1534209, 62801, 357, 12, 49, "Output",
 CellTags->"PropagatorDenominatorExplicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1534603, 62818, 181, 5, 27, "Input",
 CellTags->"PropagatorDenominatorExplicit"],
Cell[1534787, 62825, 766, 29, 49, "Output",
 CellTags->"PropagatorDenominatorExplicit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1535590, 62859, 131, 3, 27, "Input",
 CellTags->"PropagatorDenominatorExplicit"],
Cell[1535724, 62864, 547, 18, 61, "Output",
 CellTags->"PropagatorDenominatorExplicit"]
}, Open  ]]
}, Open  ]],
Cell[1536298, 62886, 43, 1, 39, "ObjectName",
 CellTags->"QGV"],
Cell[CellGroupData[{
Cell[1536366, 62891, 54, 1, 33, "Subsubsection",
 CellTags->"QGV"],
Cell[1536423, 62894, 72, 1, 23, "Text",
 CellTags->"QGV"],
Cell[1536498, 62897, 198, 9, 23, "Text",
 CellTags->"QGV"]
}, Open  ]],
Cell[1536711, 62909, 41, 1, 39, "ObjectName",
 CellTags->"QO"],
Cell[CellGroupData[{
Cell[1536777, 62914, 53, 1, 33, "Subsubsection",
 CellTags->"QO"],
Cell[1536833, 62917, 73, 1, 23, "Text",
 CellTags->"QO"],
Cell[1536909, 62920, 206, 9, 23, "Text",
 CellTags->"QO"]
}, Open  ]],
Cell[1537130, 62932, 41, 1, 39, "ObjectName",
 CellTags->"QP"],
Cell[CellGroupData[{
Cell[1537196, 62937, 53, 1, 33, "Subsubsection",
 CellTags->"QP"],
Cell[1537252, 62940, 169, 4, 23, "Text",
 CellTags->"QP"],
Cell[1537424, 62946, 194, 9, 23, "Text",
 CellTags->"QP"]
}, Open  ]],
Cell[1537633, 62958, 61, 1, 39, "ObjectName",
 CellTags->"QuantumField"],
Cell[CellGroupData[{
Cell[1537719, 62963, 63, 1, 33, "Subsubsection",
 CellTags->"QuantumField"],
Cell[1537785, 62966, 404, 9, 39, "Text",
 CellTags->"QuantumField"],
Cell[1538192, 62977, 421, 19, 23, "Text",
 CellTags->"QuantumField"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1538650, 63001, 60, 1, 33, "Subsubsection",
 CellTags->"QuantumField"],
Cell[1538713, 63004, 71, 1, 23, "Text",
 CellTags->"QuantumField"],
Cell[CellGroupData[{
Cell[1538809, 63009, 118, 3, 27, "Input",
 CellTags->"QuantumField"],
Cell[1538930, 63014, 109, 3, 25, "Output",
 CellTags->"QuantumField"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1539076, 63022, 131, 3, 27, "Input",
 CellTags->"QuantumField"],
Cell[1539210, 63027, 137, 4, 25, "Output",
 CellTags->"QuantumField"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1539384, 63036, 127, 3, 27, "Input",
 CellTags->"QuantumField"],
Cell[1539514, 63041, 114, 3, 25, "Output",
 CellTags->"QuantumField"]
}, Open  ]],
Cell[1539643, 63047, 80, 1, 23, "Text",
 CellTags->"QuantumField"],
Cell[CellGroupData[{
Cell[1539748, 63052, 169, 5, 27, "Input",
 CellTags->"QuantumField"],
Cell[1539920, 63059, 135, 4, 28, "Output",
 CellTags->"QuantumField"]
}, Open  ]],
Cell[1540070, 63066, 94, 1, 23, "Text",
 CellTags->"QuantumField"],
Cell[CellGroupData[{
Cell[1540189, 63071, 212, 6, 27, "Input",
 CellTags->"QuantumField"],
Cell[1540404, 63079, 319, 14, 29, "Output",
 CellTags->"QuantumField"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1540760, 63098, 114, 3, 27, "Input",
 CellTags->"QuantumField"],
Cell[1540877, 63103, 255, 6, 39, "Output",
 CellTags->"QuantumField"]
}, Open  ]],
Cell[1541147, 63112, 358, 13, 27, "Text",
 CellTags->"QuantumField"],
Cell[CellGroupData[{
Cell[1541530, 63129, 206, 6, 27, "Input",
 CellTags->"QuantumField"],
Cell[1541739, 63137, 259, 10, 27, "Output",
 CellTags->"QuantumField"]
}, Open  ]],
Cell[1542013, 63150, 185, 4, 23, "Text",
 CellTags->"QuantumField"],
Cell[CellGroupData[{
Cell[1542223, 63158, 244, 7, 27, "Input",
 CellTags->"QuantumField"],
Cell[1542470, 63167, 245, 6, 39, "Output",
 CellTags->"QuantumField"]
}, Open  ]],
Cell[1542730, 63176, 88, 1, 23, "Text",
 CellTags->"QuantumField"],
Cell[CellGroupData[{
Cell[1542843, 63181, 219, 6, 27, "Input",
 CellTags->"QuantumField"],
Cell[1543065, 63189, 355, 14, 29, "Output",
 CellTags->"QuantumField"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1543457, 63208, 184, 5, 27, "Input",
 CellTags->"QuantumField"],
Cell[1543644, 63215, 257, 9, 27, "Output",
 CellTags->"QuantumField"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1543938, 63229, 259, 7, 27, "Input",
 CellTags->"QuantumField"],
Cell[1544200, 63238, 404, 16, 27, "Output",
 CellTags->"QuantumField"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1544641, 63259, 291, 9, 27, "Input",
 CellTags->"QuantumField"],
Cell[1544935, 63270, 413, 16, 27, "Output",
 CellTags->"QuantumField"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1545385, 63291, 232, 6, 27, "Input",
 CellTags->"QuantumField"],
Cell[1545620, 63299, 112, 3, 25, "Output",
 CellTags->"QuantumField"]
}, Open  ]]
}, Open  ]],
Cell[1545759, 63306, 57, 1, 58, "ObjectName",
 CellTags->"QuarkField"],
Cell[CellGroupData[{
Cell[1545841, 63311, 61, 1, 39, "Subsubsection",
 CellTags->"QuarkField"],
Cell[1545905, 63314, 189, 4, 21, "Text",
 CellTags->"QuarkField"],
Cell[1546097, 63320, 321, 14, 22, "Text",
 CellTags->"QuarkField"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1546455, 63339, 58, 1, 33, "Subsubsection",
 CellTags->"QuarkField"],
Cell[CellGroupData[{
Cell[1546538, 63344, 87, 2, 27, "Input",
 CellTags->"QuarkField"],
Cell[1546628, 63348, 112, 3, 25, "Output",
 CellTags->"QuarkField"]
}, Open  ]]
}, Open  ]],
Cell[1546767, 63355, 69, 1, 39, "ObjectName",
 CellTags->"QuarkGluonVertex"],
Cell[CellGroupData[{
Cell[1546861, 63360, 67, 1, 33, "Subsubsection",
 CellTags->"QuarkGluonVertex"],
Cell[1546931, 63363, 260, 9, 23, "Text",
 CellTags->"QuarkGluonVertex"],
Cell[CellGroupData[{
Cell[1547216, 63376, 132, 3, 27, "Input",
 CellTags->"QuarkGluonVertex"],
Cell[1547351, 63381, 491, 13, 25, "Output",
 CellTags->"QuarkGluonVertex"]
}, Open  ]],
Cell[1547857, 63397, 196, 9, 23, "Text",
 CellTags->"QuarkGluonVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1548090, 63411, 64, 1, 33, "Subsubsection",
 CellTags->"QuarkGluonVertex"],
Cell[CellGroupData[{
Cell[1548179, 63416, 153, 4, 27, "Input",
 CellTags->"QuarkGluonVertex"],
Cell[1548335, 63422, 149, 4, 27, "Output",
 CellTags->"QuarkGluonVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1548521, 63431, 208, 5, 27, "Input",
 CellTags->"QuarkGluonVertex"],
Cell[1548732, 63438, 149, 4, 27, "Output",
 CellTags->"QuarkGluonVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1548918, 63447, 208, 5, 27, "Input",
 CellTags->"QuarkGluonVertex"],
Cell[1549129, 63454, 149, 4, 27, "Output",
 CellTags->"QuarkGluonVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1549315, 63463, 208, 5, 27, "Input",
 CellTags->"QuarkGluonVertex"],
Cell[1549526, 63470, 149, 4, 27, "Output",
 CellTags->"QuarkGluonVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1549712, 63479, 315, 9, 27, "Input",
 CellTags->"QuarkGluonVertex"],
Cell[1550030, 63490, 366, 11, 25, "Output",
 CellTags->"QuarkGluonVertex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1550433, 63506, 316, 9, 27, "Input",
 CellTags->"QuarkGluonVertex"],
Cell[1550752, 63517, 367, 11, 25, "Output",
 CellTags->"QuarkGluonVertex"]
}, Open  ]]
}, Open  ]],
Cell[1551146, 63532, 55, 1, 39, "ObjectName",
 CellTags->"QuarkMass"],
Cell[CellGroupData[{
Cell[1551226, 63537, 60, 1, 33, "Subsubsection",
 CellTags->"QuarkMass"],
Cell[1551289, 63540, 76, 1, 23, "Text",
 CellTags->"QuarkMass"],
Cell[1551368, 63543, 183, 9, 23, "Text",
 CellTags->"QuarkMass"]
}, Open  ]],
Cell[1551566, 63555, 67, 1, 39, "ObjectName",
 CellTags->"QuarkPropagator"],
Cell[CellGroupData[{
Cell[1551658, 63560, 66, 1, 33, "Subsubsection",
 CellTags->"QuarkPropagator"],
Cell[1551727, 63563, 174, 4, 23, "Text",
 CellTags->"QuarkPropagator"],
Cell[CellGroupData[{
Cell[1551926, 63571, 130, 3, 27, "Input",
 CellTags->"QuarkPropagator"],
Cell[1552059, 63576, 534, 14, 25, "Output",
 CellTags->"QuarkPropagator"]
}, Open  ]],
Cell[1552608, 63593, 341, 14, 33, "Text",
 CellTags->"QuarkPropagator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1552986, 63612, 63, 1, 33, "Subsubsection",
 CellTags->"QuarkPropagator"],
Cell[CellGroupData[{
Cell[1553074, 63617, 124, 3, 27, "Input",
 CellTags->"QuarkPropagator"],
Cell[1553201, 63622, 177, 6, 28, "Output",
 CellTags->"QuarkPropagator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1553415, 63633, 171, 5, 27, "Input",
 CellTags->"QuarkPropagator"],
Cell[1553589, 63640, 177, 6, 28, "Output",
 CellTags->"QuarkPropagator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1553803, 63651, 157, 4, 27, "Input",
 CellTags->"QuarkPropagator"],
Cell[1553963, 63657, 177, 6, 28, "Output",
 CellTags->"QuarkPropagator"]
}, Open  ]]
}, Open  ]],
Cell[1554167, 63667, 59, 1, 58, "ObjectName",
 CellTags->"ReduceGamma"],
Cell[CellGroupData[{
Cell[1554251, 63672, 62, 1, 39, "Subsubsection",
 CellTags->"ReduceGamma"],
Cell[1554316, 63675, 194, 4, 32, "Text",
 CellTags->"ReduceGamma"],
Cell[1554513, 63681, 179, 9, 33, "Text",
 CellTags->"ReduceGamma"]
}, Open  ]],
Cell[1554707, 63693, 67, 1, 58, "ObjectName",
 CellTags->"ReduceToScalars"],
Cell[CellGroupData[{
Cell[1554799, 63698, 66, 1, 39, "Subsubsection",
 CellTags->"ReduceToScalars"],
Cell[1554868, 63701, 210, 5, 36, "Text",
 CellTags->"ReduceToScalars"],
Cell[1555081, 63708, 299, 14, 22, "Text",
 CellTags->"ReduceToScalars"]
}, Open  ]],
Cell[1555395, 63725, 49, 1, 39, "ObjectName",
 CellTags->"Rename"],
Cell[CellGroupData[{
Cell[1555469, 63730, 57, 1, 26, "Subsubsection",
 CellTags->"Rename"],
Cell[1555529, 63733, 144, 4, 21, "Text",
 CellTags->"Rename"],
Cell[1555676, 63739, 177, 9, 22, "Text",
 CellTags->"Rename"]
}, Open  ]],
Cell[1555868, 63751, 61, 1, 39, "ObjectName",
 CellTags->"RHI"],
Cell[CellGroupData[{
Cell[1555954, 63756, 54, 1, 26, "Subsubsection",
 CellTags->"RHI"],
Cell[1556011, 63759, 611, 12, 114, "Text",
 CellTags->"RHI"],
Cell[1556625, 63773, 168, 9, 23, "Text",
 CellTags->"RHI"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1556830, 63787, 51, 1, 33, "Subsubsection",
 CellTags->"RHI"],
Cell[1556884, 63790, 70, 2, 27, "Input",
 CellTags->"RHI"]
}, Open  ]],
Cell[1556969, 63795, 67, 1, 39, "ObjectName",
 CellTags->"RHI2FC"],
Cell[CellGroupData[{
Cell[1557061, 63800, 57, 1, 33, "Subsubsection",
 CellTags->"RHI2FC"],
Cell[1557121, 63803, 614, 12, 135, "Text",
 CellTags->"RHI2FC"],
Cell[1557738, 63817, 171, 9, 23, "Text",
 CellTags->"RHI2FC"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1557946, 63831, 54, 1, 33, "Subsubsection",
 CellTags->"RHI2FC"],
Cell[1558003, 63834, 73, 2, 27, "Input",
 CellTags->"RHI2FC"]
}, Open  ]],
Cell[1558091, 63839, 61, 1, 39, "ObjectName",
 CellTags->"RHM"],
Cell[CellGroupData[{
Cell[1558177, 63844, 54, 1, 33, "Subsubsection",
 CellTags->"RHM"],
Cell[1558234, 63847, 77, 1, 23, "Text",
 CellTags->"RHM"],
Cell[1558314, 63850, 159, 9, 23, "Text",
 CellTags->"RHM"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1558510, 63864, 51, 1, 33, "Subsubsection",
 CellTags->"RHM"],
Cell[1558564, 63867, 70, 2, 27, "Input",
 CellTags->"RHM"]
}, Open  ]],
Cell[1558649, 63872, 61, 1, 39, "ObjectName",
 CellTags->"RHO"],
Cell[CellGroupData[{
Cell[1558735, 63877, 54, 1, 33, "Subsubsection",
 CellTags->"RHO"],
Cell[1558792, 63880, 267, 5, 39, "Text",
 CellTags->"RHO"],
Cell[1559062, 63887, 159, 9, 23, "Text",
 CellTags->"RHO"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1559258, 63901, 51, 1, 33, "Subsubsection",
 CellTags->"RHO"],
Cell[1559312, 63904, 70, 2, 27, "Input",
 CellTags->"RHO"]
}, Open  ]],
Cell[1559397, 63909, 45, 1, 39, "ObjectName",
 CellTags->"RHP"],
Cell[CellGroupData[{
Cell[1559467, 63914, 54, 1, 33, "Subsubsection",
 CellTags->"RHP"],
Cell[1559524, 63917, 272, 5, 36, "Text",
 CellTags->"RHP"],
Cell[1559799, 63924, 159, 9, 22, "Text",
 CellTags->"RHP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1559995, 63938, 51, 1, 33, "Subsubsection",
 CellTags->"RHP"],
Cell[CellGroupData[{
Cell[1560071, 63943, 133, 3, 27, "Input"],
Cell[1560207, 63948, 1937, 77, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1562181, 64030, 133, 3, 27, "Input"],
Cell[1562317, 64035, 713, 29, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1563067, 64069, 133, 3, 27, "Input"],
Cell[1563203, 64074, 1415, 59, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1564655, 64138, 133, 3, 27, "Input"],
Cell[1564791, 64143, 507, 22, 49, "Output"]
}, Open  ]],
Cell[1565313, 64168, 70, 2, 27, "Input",
 CellTags->"RHP"]
}, Open  ]],
Cell[1565398, 64173, 61, 1, 58, "ObjectName",
 CellTags->"RTL"],
Cell[CellGroupData[{
Cell[1565484, 64178, 54, 1, 39, "Subsubsection",
 CellTags->"RTL"],
Cell[1565541, 64181, 188, 4, 32, "Text",
 CellTags->"RTL"],
Cell[1565732, 64187, 266, 14, 33, "Text",
 CellTags->"RTL"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1566035, 64206, 51, 1, 33, "Subsubsection",
 CellTags->"RTL"],
Cell[1566089, 64209, 70, 2, 27, "Input",
 CellTags->"RTL"]
}, Open  ]],
Cell[1566174, 64214, 63, 1, 39, "ObjectName",
 CellTags->"RightPartialD"],
Cell[CellGroupData[{
Cell[1566262, 64219, 64, 1, 33, "Subsubsection",
 CellTags->"RightPartialD"],
Cell[1566329, 64222, 256, 10, 26, "Text",
 CellTags->"RightPartialD"],
Cell[1566588, 64234, 434, 19, 23, "Text",
 CellTags->"RightPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1567059, 64258, 61, 1, 33, "Subsubsection",
 CellTags->"RightPartialD"],
Cell[CellGroupData[{
Cell[1567145, 64263, 124, 3, 27, "Input",
 CellTags->"RightPartialD"],
Cell[1567272, 64268, 252, 9, 32, "Output",
 CellTags->"RightPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1567561, 64282, 255, 7, 27, "Input",
 CellTags->"RightPartialD"],
Cell[1567819, 64291, 308, 11, 32, "Output",
 CellTags->"RightPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1568164, 64307, 121, 3, 27, "Input",
 CellTags->"RightPartialD"],
Cell[1568288, 64312, 356, 14, 29, "Output",
 CellTags->"RightPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1568681, 64331, 115, 3, 27, "Input",
 CellTags->"RightPartialD"],
Cell[1568799, 64336, 292, 7, 39, "Output",
 CellTags->"RightPartialD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1569128, 64348, 162, 5, 27, "Input",
 CellTags->"RightPartialD"],
Cell[1569293, 64355, 178, 4, 39, "Output",
 CellTags->"RightPartialD"]
}, Open  ]]
}, Open  ]],
Cell[1569498, 64363, 61, 1, 39, "ObjectName",
 CellTags->"RussianTrick"],
Cell[CellGroupData[{
Cell[1569584, 64368, 63, 1, 33, "Subsubsection",
 CellTags->"RussianTrick"],
Cell[1569650, 64371, 318, 6, 39, "Text",
 CellTags->"RussianTrick"],
Cell[1569971, 64379, 90, 1, 23, "Text",
 CellTags->"RussianTrick"],
Cell[1570064, 64382, 326, 14, 23, "Text",
 CellTags->"RussianTrick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1570427, 64401, 60, 1, 33, "Subsubsection",
 CellTags->"RussianTrick"],
Cell[CellGroupData[{
Cell[1570512, 64406, 374, 12, 27, "Input",
 CellTags->"RussianTrick"],
Cell[1570889, 64420, 501, 21, 29, "Output",
 CellTags->"RussianTrick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1571427, 64446, 108, 3, 27, "Input",
 CellTags->"RussianTrick"],
Cell[1571538, 64451, 661, 23, 49, "Output",
 CellTags->"RussianTrick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1572236, 64479, 172, 5, 27, "Input",
 CellTags->"RussianTrick"],
Cell[1572411, 64486, 3469, 121, 141, "Output",
 CellTags->"RussianTrick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1575917, 64612, 112, 3, 27, "Input",
 CellTags->"RussianTrick"],
Cell[1576032, 64617, 2675, 111, 29, "Output",
 CellTags->"RussianTrick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1578744, 64733, 135, 4, 27, "Input",
 CellTags->"RussianTrick"],
Cell[1578882, 64739, 2947, 112, 48, "Output",
 CellTags->"RussianTrick"]
}, Open  ]],
Cell[1581844, 64854, 111, 3, 27, "Input",
 CellTags->"RussianTrick"]
}, Open  ]],
Cell[1581970, 64860, 71, 1, 39, "ObjectName",
 CellTags->"ScalarGluonVertex"],
Cell[CellGroupData[{
Cell[1582066, 64865, 68, 1, 39, "Subsubsection",
 CellTags->"ScalarGluonVertex"],
Cell[1582137, 64868, 430, 8, 71, "Text",
 CellTags->"ScalarGluonVertex"],
Cell[CellGroupData[{
Cell[1582592, 64880, 134, 3, 27, "Input",
 CellTags->"ScalarGluonVertex"],
Cell[1582729, 64885, 271, 8, 25, "Output",
 CellTags->"ScalarGluonVertex"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1583049, 64899, 65, 1, 33, "Subsubsection",
 CellTags->"ScalarGluonVertex"],
Cell[CellGroupData[{
Cell[1583139, 64904, 274, 8, 27, "Input",
 CellTags->"ScalarGluonVertex"],
Cell[1583416, 64914, 479, 19, 25, "Output",
 CellTags->"ScalarGluonVertex"]
}, Open  ]]
}, Open  ]],
Cell[1583922, 64937, 63, 1, 58, "ObjectName",
 CellTags->"ScalarProduct"],
Cell[CellGroupData[{
Cell[1584010, 64942, 64, 1, 33, "Subsubsection",
 CellTags->"ScalarProduct"],
Cell[1584077, 64945, 836, 21, 71, "Text",
 CellTags->"ScalarProduct"],
Cell[1584916, 64968, 880, 38, 23, "Text",
 CellTags->"ScalarProduct"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1585833, 65011, 61, 1, 33, "Subsubsection",
 CellTags->"ScalarProduct"],
Cell[CellGroupData[{
Cell[1585919, 65016, 143, 4, 27, "Input",
 CellTags->"ScalarProduct"],
Cell[1586065, 65022, 212, 8, 25, "Output",
 CellTags->"ScalarProduct"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1586314, 65035, 186, 6, 27, "Input",
 CellTags->"ScalarProduct"],
Cell[1586503, 65043, 301, 11, 25, "Output",
 CellTags->"ScalarProduct"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1586841, 65059, 143, 4, 27, "Input",
 CellTags->"ScalarProduct"],
Cell[1586987, 65065, 168, 6, 27, "Output",
 CellTags->"ScalarProduct"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1587192, 65076, 120, 3, 27, "Input",
 CellTags->"ScalarProduct"],
Cell[1587315, 65081, 168, 6, 27, "Output",
 CellTags->"ScalarProduct"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1587520, 65092, 179, 5, 27, "Input",
 CellTags->"ScalarProduct"],
Cell[1587702, 65099, 221, 6, 39, "Output",
 CellTags->"ScalarProduct"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1587960, 65110, 231, 7, 27, "Input",
 CellTags->"ScalarProduct"],
Cell[1588194, 65119, 271, 8, 39, "Output",
 CellTags->"ScalarProduct"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1588502, 65132, 248, 8, 27, "Input",
 CellTags->"ScalarProduct"],
Cell[1588753, 65142, 131, 4, 40, "Output",
 CellTags->"ScalarProduct"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1588921, 65151, 295, 9, 27, "Input",
 CellTags->"ScalarProduct"],
Cell[1589219, 65162, 571, 23, 40, "Output",
 CellTags->"ScalarProduct"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1589827, 65190, 280, 9, 27, "Input",
 CellTags->"ScalarProduct"],
Cell[1590110, 65201, 571, 23, 40, "Output",
 CellTags->"ScalarProduct"]
}, Open  ]],
Cell[1590696, 65227, 99, 2, 27, "Input",
 CellTags->"ScalarProduct"]
}, Open  ]],
Cell[1590810, 65232, 75, 1, 39, "ObjectName",
 CellTags->"ScalarProductCancel"],
Cell[CellGroupData[{
Cell[1590910, 65237, 70, 1, 33, "Subsubsection",
 CellTags->"ScalarProductCancel"],
Cell[1590983, 65240, 186, 4, 23, "Text",
 CellTags->"ScalarProductCancel"],
Cell[CellGroupData[{
Cell[1591194, 65248, 89, 2, 27, "Input",
 CellTags->"ScalarProductCancel"],
Cell[1591286, 65252, 134, 3, 25, "Output",
 CellTags->"ScalarProductCancel"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1591457, 65260, 134, 3, 27, "Input",
 CellTags->"ScalarProductCancel"],
Cell[1591594, 65265, 392, 10, 25, "Output",
 CellTags->"ScalarProductCancel"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1592023, 65280, 106, 3, 27, "Input",
 CellTags->"ScalarProductCancel"],
Cell[1592132, 65285, 179, 3, 38, "Print",
 CellTags->{"Info3522766000-2743550", "ScalarProductCancel"}]
}, Open  ]],
Cell[1592326, 65291, 743, 33, 23, "Text",
 CellTags->"ScalarProductCancel"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1593106, 65329, 67, 1, 33, "Subsubsection",
 CellTags->"ScalarProductCancel"],
Cell[1593176, 65332, 244, 9, 23, "Text",
 CellTags->"ScalarProductCancel"],
Cell[CellGroupData[{
Cell[1593445, 65345, 429, 15, 27, "Input",
 CellTags->"ScalarProductCancel"],
Cell[1593877, 65362, 454, 17, 46, "Output",
 CellTags->"ScalarProductCancel"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1594368, 65384, 156, 4, 27, "Input",
 CellTags->"ScalarProductCancel"],
Cell[1594527, 65390, 849, 32, 56, "Output",
 CellTags->"ScalarProductCancel"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1595413, 65427, 162, 4, 27, "Input",
 CellTags->"ScalarProductCancel"],
Cell[1595578, 65433, 708, 26, 56, "Output",
 CellTags->"ScalarProductCancel"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1596323, 65464, 185, 5, 27, "Input",
 CellTags->"ScalarProductCancel"],
Cell[1596511, 65471, 708, 26, 56, "Output",
 CellTags->"ScalarProductCancel"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1597256, 65502, 578, 18, 27, "Input",
 CellTags->"ScalarProductCancel"],
Cell[1597837, 65522, 898, 33, 49, "Output",
 CellTags->"ScalarProductCancel"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1598772, 65560, 197, 5, 27, "Input",
 CellTags->"ScalarProductCancel"],
Cell[1598972, 65567, 3108, 111, 113, "Output",
 CellTags->"ScalarProductCancel"]
}, Open  ]],
Cell[1602095, 65681, 162, 5, 27, "Input",
 CellTags->"ScalarProductCancel"]
}, Open  ]],
Cell[1602272, 65689, 51, 1, 39, "ObjectName",
 CellTags->"ScaleMu"],
Cell[CellGroupData[{
Cell[1602348, 65694, 58, 1, 33, "Subsubsection",
 CellTags->"ScaleMu"],
Cell[1602409, 65697, 128, 4, 23, "Text",
 CellTags->"ScaleMu"],
Cell[CellGroupData[{
Cell[1602562, 65705, 81, 2, 27, "Input",
 CellTags->"ScaleMu"],
Cell[1602646, 65709, 108, 3, 25, "Output",
 CellTags->"ScaleMu"]
}, Open  ]]
}, Open  ]],
Cell[1602781, 65716, 53, 1, 39, "ObjectName",
 CellTags->"Schouten"],
Cell[CellGroupData[{
Cell[1602859, 65721, 59, 1, 33, "Subsubsection",
 CellTags->"Schouten"],
Cell[1602921, 65724, 460, 8, 79, "Text",
 CellTags->"Schouten"],
Cell[1603384, 65734, 289, 13, 23, "Text",
 CellTags->"Schouten"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1603710, 65752, 56, 1, 33, "Subsubsection",
 CellTags->"Schouten"],
Cell[CellGroupData[{
Cell[1603791, 65757, 1938, 54, 156, "Input",
 CellTags->"Schouten"],
Cell[1605732, 65813, 15696, 628, 199, "Output",
 CellTags->"Schouten"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1621465, 66446, 106, 3, 27, "Input",
 CellTags->"Schouten"],
Cell[1621574, 66451, 105, 3, 25, "Output",
 CellTags->"Schouten"]
}, Open  ]],
Cell[1621694, 66457, 84, 2, 27, "Input"]
}, Open  ]],
Cell[1621793, 66462, 41, 1, 39, "ObjectName",
 CellTags->"SD"],
Cell[CellGroupData[{
Cell[1621859, 66467, 53, 1, 33, "Subsubsection",
 CellTags->"SD"],
Cell[1621915, 66470, 265, 7, 39, "Text",
 CellTags->"SD"],
Cell[1622183, 66479, 173, 9, 23, "Text",
 CellTags->"SD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1622393, 66493, 50, 1, 33, "Subsubsection",
 CellTags->"SD"],
Cell[CellGroupData[{
Cell[1622468, 66498, 121, 4, 27, "Input",
 CellTags->"SD"],
Cell[1622592, 66504, 147, 5, 27, "Output",
 CellTags->"SD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1622776, 66514, 130, 4, 27, "Input",
 CellTags->"SD"],
Cell[1622909, 66520, 214, 6, 39, "Output",
 CellTags->"SD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1623160, 66531, 130, 4, 27, "Input",
 CellTags->"SD"],
Cell[1623293, 66537, 136, 4, 39, "Output",
 CellTags->"SD"]
}, Open  ]]
}, Open  ]],
Cell[1623456, 66545, 57, 1, 39, "ObjectName",
 CellTags->"SelectFree"],
Cell[CellGroupData[{
Cell[1623538, 66550, 61, 1, 33, "Subsubsection",
 CellTags->"SelectFree"],
Cell[1623602, 66553, 255, 5, 39, "Text",
 CellTags->"SelectFree"],
Cell[1623860, 66560, 77, 1, 23, "Text",
 CellTags->"SelectFree"],
Cell[1623940, 66563, 300, 14, 23, "Text",
 CellTags->"SelectFree"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1624277, 66582, 58, 1, 33, "Subsubsection",
 CellTags->"SelectFree"],
Cell[CellGroupData[{
Cell[1624360, 66587, 211, 6, 27, "Input",
 CellTags->"SelectFree"],
Cell[1624574, 66595, 130, 4, 25, "Output",
 CellTags->"SelectFree"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1624741, 66604, 166, 5, 27, "Input",
 CellTags->"SelectFree"],
Cell[1624910, 66611, 107, 3, 25, "Output",
 CellTags->"SelectFree"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1625054, 66619, 275, 8, 27, "Input",
 CellTags->"SelectFree"],
Cell[1625332, 66629, 130, 4, 25, "Output",
 CellTags->"SelectFree"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1625499, 66638, 137, 4, 27, "Input",
 CellTags->"SelectFree"],
Cell[1625639, 66644, 107, 3, 25, "Output",
 CellTags->"SelectFree"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1625783, 66652, 137, 4, 27, "Input",
 CellTags->"SelectFree"],
Cell[1625923, 66658, 107, 3, 25, "Output",
 CellTags->"SelectFree"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1626067, 66666, 137, 4, 27, "Input",
 CellTags->"SelectFree"],
Cell[1626207, 66672, 107, 3, 25, "Output",
 CellTags->"SelectFree"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1626351, 66680, 166, 5, 27, "Input",
 CellTags->"SelectFree"],
Cell[1626520, 66687, 107, 3, 25, "Output",
 CellTags->"SelectFree"]
}, Open  ]]
}, Open  ]],
Cell[1626654, 66694, 61, 1, 58, "ObjectName",
 CellTags->"SelectGraphs"],
Cell[CellGroupData[{
Cell[1626740, 66699, 63, 1, 39, "Subsubsection",
 CellTags->"SelectGraphs"],
Cell[1626806, 66702, 486, 8, 75, "Text",
 CellTags->"SelectGraphs"],
Cell[1627295, 66712, 189, 9, 33, "Text",
 CellTags->"SelectGraphs"]
}, Open  ]],
Cell[1627499, 66724, 63, 1, 58, "ObjectName",
 CellTags->"SelectNotFree"],
Cell[CellGroupData[{
Cell[1627587, 66729, 64, 1, 39, "Subsubsection",
 CellTags->"SelectNotFree"],
Cell[1627654, 66732, 143, 4, 32, "Text",
 CellTags->"SelectNotFree"],
Cell[1627800, 66738, 270, 5, 54, "Text",
 CellTags->"SelectNotFree"],
Cell[1628073, 66745, 83, 1, 32, "Text",
 CellTags->"SelectNotFree"],
Cell[1628159, 66748, 294, 14, 33, "Text",
 CellTags->"SelectNotFree"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1628490, 66767, 61, 1, 33, "Subsubsection",
 CellTags->"SelectNotFree"],
Cell[CellGroupData[{
Cell[1628576, 66772, 207, 6, 27, "Input",
 CellTags->"SelectNotFree"],
Cell[1628786, 66780, 162, 5, 25, "Output",
 CellTags->"SelectNotFree"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1628985, 66790, 276, 8, 27, "Input",
 CellTags->"SelectNotFree"],
Cell[1629264, 66800, 172, 5, 25, "Output",
 CellTags->"SelectNotFree"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1629473, 66810, 143, 4, 27, "Input",
 CellTags->"SelectNotFree"],
Cell[1629619, 66816, 110, 3, 25, "Output",
 CellTags->"SelectNotFree"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1629766, 66824, 167, 5, 27, "Input",
 CellTags->"SelectNotFree"],
Cell[1629936, 66831, 110, 3, 25, "Output",
 CellTags->"SelectNotFree"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1630083, 66839, 143, 4, 27, "Input",
 CellTags->"SelectNotFree"],
Cell[1630229, 66845, 110, 3, 25, "Output",
 CellTags->"SelectNotFree"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1630376, 66853, 143, 4, 27, "Input",
 CellTags->"SelectNotFree"],
Cell[1630522, 66859, 110, 3, 25, "Output",
 CellTags->"SelectNotFree"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1630669, 66867, 172, 5, 27, "Input",
 CellTags->"SelectNotFree"],
Cell[1630844, 66874, 138, 4, 25, "Output",
 CellTags->"SelectNotFree"]
}, Open  ]]
}, Open  ]],
Cell[1631009, 66882, 59, 1, 39, "ObjectName",
 CellTags->"SelectSplit"],
Cell[CellGroupData[{
Cell[1631093, 66887, 62, 1, 33, "Subsubsection",
 CellTags->"SelectSplit"],
Cell[1631158, 66890, 249, 5, 39, "Text",
 CellTags->"SelectSplit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1631444, 66900, 59, 1, 33, "Subsubsection",
 CellTags->"SelectSplit"],
Cell[CellGroupData[{
Cell[1631528, 66905, 804, 26, 29, "Input",
 CellTags->"SelectSplit"],
Cell[1632335, 66933, 532, 19, 29, "Output",
 CellTags->"SelectSplit"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1632904, 66957, 652, 21, 29, "Input",
 CellTags->"SelectSplit"],
Cell[1633559, 66980, 495, 16, 29, "Output",
 CellTags->"SelectSplit"]
}, Open  ]]
}, Open  ]],
Cell[1634081, 67000, 51, 1, 39, "ObjectName",
 CellTags->"Select1"],
Cell[CellGroupData[{
Cell[1634157, 67005, 58, 1, 33, "Subsubsection",
 CellTags->"Select1"],
Cell[1634218, 67008, 243, 5, 39, "Text",
 CellTags->"Select1"],
Cell[1634464, 67015, 175, 9, 23, "Text",
 CellTags->"Select1"]
}, Open  ]],
Cell[1634654, 67027, 51, 1, 39, "ObjectName",
 CellTags->"Select2"],
Cell[CellGroupData[{
Cell[1634730, 67032, 58, 1, 39, "Subsubsection",
 CellTags->"Select2"],
Cell[1634791, 67035, 245, 5, 54, "Text",
 CellTags->"Select2"],
Cell[1635039, 67042, 175, 9, 33, "Text",
 CellTags->"Select2"]
}, Open  ]],
Cell[1635229, 67054, 51, 1, 58, "ObjectName",
 CellTags->"Series2"],
Cell[CellGroupData[{
Cell[1635305, 67059, 58, 1, 39, "Subsubsection",
 CellTags->"Series2"],
Cell[1635366, 67062, 383, 9, 39, "Text",
 CellTags->"Series2"],
Cell[CellGroupData[{
Cell[1635774, 67075, 114, 3, 27, "Input",
 CellTags->"Series2"],
Cell[1635891, 67080, 528, 15, 25, "Output",
 CellTags->"Series2"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1636468, 67101, 55, 1, 33, "Subsubsection",
 CellTags->"Series2"],
Cell[CellGroupData[{
Cell[1636548, 67106, 339, 12, 27, "Input",
 CellTags->"Series2"],
Cell[1636890, 67120, 357, 12, 43, "Output",
 CellTags->"Series2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1637284, 67137, 174, 5, 27, "Input",
 CellTags->"Series2"],
Cell[1637461, 67144, 242, 8, 43, "Output",
 CellTags->"Series2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1637740, 67157, 222, 7, 27, "Input",
 CellTags->"Series2"],
Cell[1637965, 67166, 806, 25, 43, "Output",
 CellTags->"Series2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1638808, 67196, 174, 5, 27, "Input",
 CellTags->"Series2"],
Cell[1638985, 67203, 385, 14, 46, "Output",
 CellTags->"Series2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1639407, 67222, 290, 8, 27, "Input",
 CellTags->"Series2"],
Cell[1639700, 67232, 994, 32, 43, "Output",
 CellTags->"Series2"]
}, Open  ]],
Cell[1640709, 67267, 187, 6, 23, "Text"],
Cell[CellGroupData[{
Cell[1640921, 67277, 460, 15, 27, "Input",
 CellTags->"Series2"],
Cell[1641384, 67294, 1000, 33, 43, "Output",
 CellTags->"Series2"]
}, Open  ]],
Cell[1642399, 67330, 113, 3, 23, "Text",
 CellTags->"Series2"],
Cell[CellGroupData[{
Cell[1642537, 67337, 484, 15, 27, "Input",
 CellTags->"Series2"],
Cell[1643024, 67354, 648, 24, 46, "Output",
 CellTags->"Series2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1643709, 67383, 578, 17, 27, "Input",
 CellTags->"Series2"],
Cell[1644290, 67402, 988, 35, 43, "Output",
 CellTags->"Series2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1645315, 67442, 242, 6, 27, "Input",
 CellTags->"Series2"],
Cell[1645560, 67450, 292, 7, 25, "Output",
 CellTags->"Series2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1645889, 67462, 147, 4, 27, "Input",
 CellTags->"Series2"],
Cell[1646039, 67468, 3114, 106, 67, "Output",
 CellTags->"Series2"]
}, Open  ]],
Cell[1649168, 67577, 351, 11, 23, "Text",
 CellTags->"Series2"]
}, Open  ]],
Cell[1649534, 67591, 51, 1, 39, "ObjectName",
 CellTags->"Series3"],
Cell[CellGroupData[{
Cell[1649610, 67596, 58, 1, 33, "Subsubsection",
 CellTags->"Series3"],
Cell[1649671, 67599, 267, 5, 39, "Text",
 CellTags->"Series3"],
Cell[CellGroupData[{
Cell[1649963, 67608, 114, 3, 27, "Input",
 CellTags->"Series3"],
Cell[1650080, 67613, 262, 8, 25, "Output",
 CellTags->"Series3"]
}, Open  ]],
Cell[1650357, 67624, 175, 9, 23, "Text",
 CellTags->"Series3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1650569, 67638, 55, 1, 33, "Subsubsection",
 CellTags->"Series3"],
Cell[CellGroupData[{
Cell[1650649, 67643, 339, 12, 27, "Input",
 CellTags->"Series3"],
Cell[1650991, 67657, 307, 11, 43, "Output",
 CellTags->"Series3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1651335, 67673, 214, 7, 27, "Input",
 CellTags->"Series3"],
Cell[1651552, 67682, 215, 7, 43, "Output",
 CellTags->"Series3"]
}, Open  ]]
}, Open  ]],
Cell[1651794, 67693, 63, 1, 39, "ObjectName",
 CellTags->"SetMandelstam"],
Cell[CellGroupData[{
Cell[1651882, 67698, 64, 1, 33, "Subsubsection",
 CellTags->"SetMandelstam"],
Cell[1651949, 67701, 462, 9, 79, "Text",
 CellTags->"SetMandelstam"],
Cell[CellGroupData[{
Cell[1652436, 67714, 126, 3, 27, "Input",
 CellTags->"SetMandelstam"],
Cell[1652565, 67719, 237, 8, 25, "Output",
 CellTags->"SetMandelstam"]
}, Open  ]],
Cell[1652817, 67730, 190, 9, 23, "Text",
 CellTags->"SetMandelstam"]
}, Open  ]],
Cell[1653022, 67742, 79, 1, 39, "ObjectName",
 CellTags->"SimplifyDeltaFunction"],
Cell[CellGroupData[{
Cell[1653126, 67747, 72, 1, 33, "Subsubsection",
 CellTags->"SimplifyDeltaFunction"],
Cell[1653201, 67750, 299, 6, 39, "Text",
 CellTags->"SimplifyDeltaFunction"],
Cell[1653503, 67758, 347, 14, 23, "Text",
 CellTags->"SimplifyDeltaFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1653887, 67777, 69, 1, 33, "Subsubsection",
 CellTags->"SimplifyDeltaFunction"],
Cell[CellGroupData[{
Cell[1653981, 67782, 203, 6, 27, "Input",
 CellTags->"SimplifyDeltaFunction"],
Cell[1654187, 67790, 268, 9, 25, "Output",
 CellTags->"SimplifyDeltaFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1654492, 67804, 164, 4, 27, "Input",
 CellTags->"SimplifyDeltaFunction"],
Cell[1654659, 67810, 392, 13, 41, "Output",
 CellTags->"SimplifyDeltaFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1655088, 67828, 203, 6, 27, "Input",
 CellTags->"SimplifyDeltaFunction"],
Cell[1655294, 67836, 301, 10, 25, "Output",
 CellTags->"SimplifyDeltaFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1655632, 67851, 164, 4, 27, "Input",
 CellTags->"SimplifyDeltaFunction"],
Cell[1655799, 67857, 812, 27, 41, "Output",
 CellTags->"SimplifyDeltaFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1656648, 67889, 220, 6, 27, "Input",
 CellTags->"SimplifyDeltaFunction"],
Cell[1656871, 67897, 313, 10, 25, "Output",
 CellTags->"SimplifyDeltaFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1657221, 67912, 164, 4, 27, "Input",
 CellTags->"SimplifyDeltaFunction"],
Cell[1657388, 67918, 212, 7, 25, "Output",
 CellTags->"SimplifyDeltaFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1657637, 67930, 263, 8, 27, "Input",
 CellTags->"SimplifyDeltaFunction"],
Cell[1657903, 67940, 330, 11, 25, "Output",
 CellTags->"SimplifyDeltaFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1658270, 67956, 164, 4, 27, "Input",
 CellTags->"SimplifyDeltaFunction"],
Cell[1658437, 67962, 234, 8, 25, "Output",
 CellTags->"SimplifyDeltaFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1658708, 67975, 298, 9, 27, "Input",
 CellTags->"SimplifyDeltaFunction"],
Cell[1659009, 67986, 371, 12, 25, "Output",
 CellTags->"SimplifyDeltaFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1659417, 68003, 164, 4, 27, "Input",
 CellTags->"SimplifyDeltaFunction"],
Cell[1659584, 68009, 118, 3, 25, "Output",
 CellTags->"SimplifyDeltaFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1659739, 68017, 263, 8, 27, "Input",
 CellTags->"SimplifyDeltaFunction"],
Cell[1660005, 68027, 330, 11, 25, "Output",
 CellTags->"SimplifyDeltaFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1660372, 68043, 164, 4, 27, "Input",
 CellTags->"SimplifyDeltaFunction"],
Cell[1660539, 68049, 234, 8, 25, "Output",
 CellTags->"SimplifyDeltaFunction"]
}, Open  ]]
}, Open  ]],
Cell[1660800, 68061, 77, 1, 39, "ObjectName",
 CellTags->"SimplifyGTI"],
Cell[CellGroupData[{
Cell[1660902, 68066, 62, 1, 33, "Subsubsection",
 CellTags->"SimplifyGTI"],
Cell[1660967, 68069, 71, 1, 23, "Text",
 CellTags->"SimplifyGTI"],
Cell[1661041, 68072, 167, 9, 23, "Text",
 CellTags->"SimplifyGTI"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1661245, 68086, 59, 1, 33, "Subsubsection",
 CellTags->"SimplifyGTI"],
Cell[1661307, 68089, 78, 2, 27, "Input",
 CellTags->"SimplifyGTI"]
}, Open  ]],
Cell[1661400, 68094, 67, 1, 39, "ObjectName",
 CellTags->"SimplifyPolyLog"],
Cell[CellGroupData[{
Cell[1661492, 68099, 66, 1, 33, "Subsubsection",
 CellTags->"SimplifyPolyLog"],
Cell[1661561, 68102, 199, 4, 23, "Text",
 CellTags->"SimplifyPolyLog"],
Cell[1661763, 68108, 183, 9, 23, "Text",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1661983, 68122, 63, 1, 33, "Subsubsection",
 CellTags->"SimplifyPolyLog"],
Cell[1662049, 68125, 224, 6, 27, "Input",
 CellTags->"SimplifyPolyLog"],
Cell[CellGroupData[{
Cell[1662298, 68135, 195, 6, 27, "Input",
 CellTags->"SimplifyPolyLog"],
Cell[1662496, 68143, 664, 20, 43, "Output",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1663197, 68168, 170, 5, 27, "Input",
 CellTags->"SimplifyPolyLog"],
Cell[1663370, 68175, 432, 14, 25, "Output",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1663839, 68194, 221, 7, 27, "Input",
 CellTags->"SimplifyPolyLog"],
Cell[1664063, 68203, 631, 20, 29, "Output",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1664731, 68228, 195, 6, 27, "Input",
 CellTags->"SimplifyPolyLog"],
Cell[1664929, 68236, 608, 19, 29, "Output",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1665574, 68260, 271, 9, 27, "Input",
 CellTags->"SimplifyPolyLog"],
Cell[1665848, 68271, 670, 22, 43, "Output",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1666555, 68298, 248, 8, 27, "Input",
 CellTags->"SimplifyPolyLog"],
Cell[1666806, 68308, 645, 21, 43, "Output",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1667488, 68334, 281, 9, 27, "Input",
 CellTags->"SimplifyPolyLog"],
Cell[1667772, 68345, 732, 29, 43, "Output",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1668541, 68379, 216, 7, 27, "Input",
 CellTags->"SimplifyPolyLog"],
Cell[1668760, 68388, 496, 17, 46, "Output",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1669293, 68410, 195, 6, 27, "Input",
 CellTags->"SimplifyPolyLog"],
Cell[1669491, 68418, 115, 3, 25, "Output",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1669643, 68426, 195, 6, 27, "Input",
 CellTags->"SimplifyPolyLog"],
Cell[1669841, 68434, 1063, 36, 29, "Output",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1670941, 68475, 271, 9, 27, "Input",
 CellTags->"SimplifyPolyLog"],
Cell[1671215, 68486, 1480, 50, 79, "Output",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1672732, 68541, 221, 7, 27, "Input",
 CellTags->"SimplifyPolyLog"],
Cell[1672956, 68550, 1255, 45, 46, "Output",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1674248, 68600, 271, 9, 27, "Input",
 CellTags->"SimplifyPolyLog"],
Cell[1674522, 68611, 2740, 96, 118, "Output",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1677299, 68712, 191, 6, 27, "Input",
 CellTags->"SimplifyPolyLog"],
Cell[1677493, 68720, 336, 12, 43, "Output",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1677866, 68737, 166, 5, 27, "Input",
 CellTags->"SimplifyPolyLog"],
Cell[1678035, 68744, 251, 8, 43, "Output",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1678323, 68757, 146, 4, 27, "Input",
 CellTags->"SimplifyPolyLog"],
Cell[1678472, 68763, 406, 14, 43, "Output",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1678915, 68782, 146, 4, 27, "Input",
 CellTags->"SimplifyPolyLog"],
Cell[1679064, 68788, 355, 13, 41, "Output",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1679456, 68806, 146, 4, 27, "Input",
 CellTags->"SimplifyPolyLog"],
Cell[1679605, 68812, 355, 13, 41, "Output",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[1679975, 68828, 116, 3, 27, "Input",
 CellTags->"SimplifyPolyLog"]
}, Open  ]],
Cell[1680106, 68834, 73, 1, 39, "ObjectName",
 CellTags->"Simplify2"],
Cell[CellGroupData[{
Cell[1680204, 68839, 60, 1, 33, "Subsubsection",
 CellTags->"Simplify2"],
Cell[1680267, 68842, 81, 1, 23, "Text",
 CellTags->"Simplify2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1680385, 68848, 57, 1, 33, "Subsubsection",
 CellTags->"Simplify2"],
Cell[1680445, 68851, 76, 2, 27, "Input",
 CellTags->"Simplify2"]
}, Open  ]],
Cell[1680536, 68856, 57, 1, 39, "ObjectName",
 CellTags->"SmallDelta"],
Cell[CellGroupData[{
Cell[1680618, 68861, 61, 1, 33, "Subsubsection",
 CellTags->"SmallDelta"],
Cell[1680682, 68864, 87, 1, 23, "Text",
 CellTags->"SmallDelta"]
}, Open  ]],
Cell[1680784, 68868, 61, 1, 39, "ObjectName",
 CellTags->"SmallEpsilon"],
Cell[CellGroupData[{
Cell[1680870, 68873, 63, 1, 33, "Subsubsection",
 CellTags->"SmallEpsilon"],
Cell[1680936, 68876, 91, 1, 23, "Text",
 CellTags->"SmallEpsilon"]
}, Open  ]],
Cell[1681042, 68880, 63, 1, 39, "ObjectName",
 CellTags->"SmallVariable"],
Cell[CellGroupData[{
Cell[1681130, 68885, 64, 1, 33, "Subsubsection",
 CellTags->"SmallVariable"],
Cell[1681197, 68888, 281, 5, 39, "Text",
 CellTags->"SmallVariable"],
Cell[1681481, 68895, 437, 19, 23, "Text",
 CellTags->"SmallVariable"]
}, Open  ]],
Cell[1681933, 68917, 65, 1, 39, "ObjectName",
 CellTags->"SmallVariables"],
Cell[CellGroupData[{
Cell[1682023, 68922, 65, 1, 33, "Subsubsection",
 CellTags->"SmallVariables"],
Cell[1682091, 68925, 225, 5, 39, "Text",
 CellTags->"SmallVariables"],
Cell[1682319, 68932, 182, 9, 23, "Text",
 CellTags->"SmallVariables"]
}, Open  ]],
Cell[1682516, 68944, 43, 1, 39, "ObjectName",
 CellTags->"SMP"],
Cell[CellGroupData[{
Cell[1682584, 68949, 54, 1, 33, "Subsubsection",
 CellTags->"SMP"],
Cell[1682641, 68952, 232, 5, 39, "Text",
 CellTags->"SMP"],
Cell[CellGroupData[{
Cell[1682898, 68961, 127, 4, 27, "Input",
 CellTags->"SMP"],
Cell[1683028, 68967, 166, 5, 39, "Output",
 CellTags->"SMP"]
}, Open  ]],
Cell[1683209, 68975, 168, 8, 23, "Text",
 CellTags->"SMP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1683414, 68988, 51, 1, 33, "Subsubsection",
 CellTags->"SMP"],
Cell[CellGroupData[{
Cell[1683490, 68993, 109, 3, 27, "Input",
 CellTags->"SMP"],
Cell[1683602, 68998, 101, 3, 25, "Output",
 CellTags->"SMP"]
}, Open  ]]
}, Open  ]],
Cell[1683730, 69005, 53, 1, 39, "ObjectName",
 CellTags->"SMVertex"],
Cell[CellGroupData[{
Cell[1683808, 69010, 59, 1, 33, "Subsubsection",
 CellTags->"SMVertex"],
Cell[1683870, 69013, 304, 6, 39, "Text",
 CellTags->"SMVertex"],
Cell[CellGroupData[{
Cell[1684199, 69023, 112, 3, 27, "Input",
 CellTags->"SMVertex"],
Cell[1684314, 69028, 235, 8, 25, "Output",
 CellTags->"SMVertex"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1684598, 69042, 56, 1, 33, "Subsubsection",
 CellTags->"SMVertex"],
Cell[CellGroupData[{
Cell[1684679, 69047, 223, 6, 27, "Input",
 CellTags->"SMVertex"],
Cell[1684905, 69055, 1179, 44, 27, "Output",
 CellTags->"SMVertex"]
}, Open  ]]
}, Open  ]],
Cell[1686111, 69103, 61, 1, 39, "ObjectName",
 CellTags->"Smu"],
Cell[CellGroupData[{
Cell[1686197, 69108, 54, 1, 33, "Subsubsection",
 CellTags->"Smu"],
Cell[1686254, 69111, 45, 1, 23, "Text",
 CellTags->"Smu"]
}, Open  ]],
Cell[1686314, 69115, 41, 1, 39, "ObjectName",
 CellTags->"Sn"],
Cell[CellGroupData[{
Cell[1686380, 69120, 53, 1, 33, "Subsubsection",
 CellTags->"Sn"],
Cell[1686436, 69123, 300, 14, 23, "Text",
 CellTags->"Sn"]
}, Open  ]],
Cell[1686751, 69140, 41, 1, 58, "ObjectName",
 CellTags->"SO"],
Cell[CellGroupData[{
Cell[1686817, 69145, 53, 1, 39, "Subsubsection",
 CellTags->"SO"],
Cell[1686873, 69148, 173, 4, 32, "Text",
 CellTags->"SO"],
Cell[1687049, 69154, 580, 28, 33, "Text",
 CellTags->"SO"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1687666, 69187, 50, 1, 33, "Subsubsection",
 CellTags->"SO"],
Cell[CellGroupData[{
Cell[1687741, 69192, 98, 3, 27, "Input",
 CellTags->"SO"],
Cell[1687842, 69197, 265, 10, 25, "Output",
 CellTags->"SO"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1688144, 69212, 121, 4, 27, "Input",
 CellTags->"SO"],
Cell[1688268, 69218, 384, 15, 25, "Output",
 CellTags->"SO"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1688689, 69238, 163, 6, 27, "Input",
 CellTags->"SO"],
Cell[1688855, 69246, 217, 6, 39, "Output",
 CellTags->"SO"]
}, Open  ]]
}, Open  ]],
Cell[1689099, 69256, 43, 1, 39, "ObjectName",
 CellTags->"SOD"],
Cell[CellGroupData[{
Cell[1689167, 69261, 54, 1, 26, "Subsubsection",
 CellTags->"SOD"],
Cell[1689224, 69264, 189, 4, 36, "Text",
 CellTags->"SOD"],
Cell[1689416, 69270, 492, 24, 22, "Text",
 CellTags->"SOD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1689945, 69299, 51, 1, 33, "Subsubsection",
 CellTags->"SOD"],
Cell[CellGroupData[{
Cell[1690021, 69304, 100, 3, 27, "Input",
 CellTags->"SOD"],
Cell[1690124, 69309, 266, 10, 25, "Output",
 CellTags->"SOD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1690427, 69324, 123, 4, 27, "Input",
 CellTags->"SOD"],
Cell[1690553, 69330, 385, 15, 25, "Output",
 CellTags->"SOD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1690975, 69350, 165, 6, 27, "Input",
 CellTags->"SOD"],
Cell[1691143, 69358, 268, 8, 39, "Output",
 CellTags->"SOD"]
}, Open  ]]
}, Open  ]],
Cell[1691438, 69370, 49, 1, 39, "ObjectName",
 CellTags->"Solve2"],
Cell[CellGroupData[{
Cell[1691512, 69375, 57, 1, 26, "Subsubsection",
 CellTags->"Solve2"],
Cell[1691572, 69378, 346, 7, 39, "Text",
 CellTags->"Solve2"],
Cell[CellGroupData[{
Cell[1691943, 69389, 112, 3, 27, "Input",
 CellTags->"Solve2"],
Cell[1692058, 69394, 264, 8, 25, "Output",
 CellTags->"Solve2"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1692371, 69408, 54, 1, 33, "Subsubsection",
 CellTags->"Solve2"],
Cell[CellGroupData[{
Cell[1692450, 69413, 390, 14, 27, "Input",
 CellTags->"Solve2"],
Cell[1692843, 69429, 373, 13, 43, "Output",
 CellTags->"Solve2"]
}, Open  ]],
Cell[1693231, 69445, 111, 3, 23, "Text",
 CellTags->"Solve2"],
Cell[CellGroupData[{
Cell[1693367, 69452, 153, 5, 27, "Input",
 CellTags->"Solve2"],
Cell[1693523, 69459, 176, 6, 25, "Output",
 CellTags->"Solve2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1693736, 69470, 267, 8, 27, "Input",
 CellTags->"Solve2"],
Cell[1694006, 69480, 176, 6, 25, "Output",
 CellTags->"Solve2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1694219, 69491, 443, 15, 27, "Input",
 CellTags->"Solve2"],
Cell[1694665, 69508, 314, 11, 43, "Output",
 CellTags->"Solve2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1695016, 69524, 389, 14, 27, "Input",
 CellTags->"Solve2"],
Cell[1695408, 69540, 406, 14, 43, "Output",
 CellTags->"Solve2"]
}, Open  ]]
}, Open  ]],
Cell[1695841, 69558, 49, 1, 39, "ObjectName",
 CellTags->"Solve3"],
Cell[CellGroupData[{
Cell[1695915, 69563, 57, 1, 26, "Subsubsection",
 CellTags->"Solve3"],
Cell[1695975, 69566, 271, 5, 39, "Text",
 CellTags->"Solve3"],
Cell[CellGroupData[{
Cell[1696271, 69575, 112, 3, 27, "Input",
 CellTags->"Solve3"],
Cell[1696386, 69580, 320, 10, 25, "Output",
 CellTags->"Solve3"]
}, Open  ]],
Cell[1696721, 69593, 162, 8, 23, "Text",
 CellTags->"SMP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1696920, 69606, 54, 1, 33, "Subsubsection",
 CellTags->"Solve3"],
Cell[CellGroupData[{
Cell[1696999, 69611, 390, 14, 27, "Input",
 CellTags->"Solve3"],
Cell[1697392, 69627, 373, 13, 43, "Output",
 CellTags->"Solve3"]
}, Open  ]]
}, Open  ]],
Cell[1697792, 69644, 41, 1, 39, "ObjectName",
 CellTags->"SP"],
Cell[CellGroupData[{
Cell[1697858, 69649, 53, 1, 33, "Subsubsection",
 CellTags->"SP"],
Cell[1697914, 69652, 327, 11, 41, "Text",
 CellTags->"SP"],
Cell[1698244, 69665, 429, 19, 23, "Text",
 CellTags->"SP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1698710, 69689, 50, 1, 33, "Subsubsection",
 CellTags->"SP"],
Cell[CellGroupData[{
Cell[1698785, 69694, 184, 6, 27, "Input",
 CellTags->"SP"],
Cell[1698972, 69702, 366, 16, 27, "Output",
 CellTags->"SP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1699375, 69723, 189, 7, 27, "Input",
 CellTags->"SP"],
Cell[1699567, 69732, 297, 11, 25, "Output",
 CellTags->"SP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1699901, 69748, 234, 8, 27, "Input",
 CellTags->"SP"],
Cell[1700138, 69758, 412, 17, 27, "Output",
 CellTags->"SP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1700587, 69780, 168, 5, 27, "Input",
 CellTags->"SP"],
Cell[1700758, 69787, 415, 17, 27, "Output",
 CellTags->"SP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1701210, 69809, 157, 5, 27, "Input",
 CellTags->"SP"],
Cell[1701370, 69816, 136, 4, 39, "Output",
 CellTags->"SP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1701543, 69825, 188, 7, 27, "Input",
 CellTags->"SP"],
Cell[1701734, 69834, 210, 6, 39, "Output",
 CellTags->"SP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1701981, 69845, 217, 8, 27, "Input",
 CellTags->"SP"],
Cell[1702201, 69855, 136, 4, 39, "Output",
 CellTags->"SP"]
}, Open  ]]
}, Open  ]],
Cell[1702364, 69863, 43, 1, 39, "ObjectName",
 CellTags->"SPC"],
Cell[CellGroupData[{
Cell[1702432, 69868, 54, 1, 33, "Subsubsection",
 CellTags->"SPC"],
Cell[1702489, 69871, 81, 1, 23, "Text",
 CellTags->"SPC"],
Cell[1702573, 69874, 207, 9, 23, "Text",
 CellTags->"SPC"]
}, Open  ]],
Cell[1702795, 69886, 43, 1, 39, "ObjectName",
 CellTags->"SPD"],
Cell[CellGroupData[{
Cell[1702863, 69891, 54, 1, 33, "Subsubsection",
 CellTags->"SPD"],
Cell[1702920, 69894, 346, 11, 41, "Text",
 CellTags->"SPD"],
Cell[1703269, 69907, 522, 24, 23, "Text",
 CellTags->"SPD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1703828, 69936, 51, 1, 33, "Subsubsection",
 CellTags->"SPD"],
Cell[CellGroupData[{
Cell[1703904, 69941, 187, 6, 27, "Input",
 CellTags->"SPD"],
Cell[1704094, 69949, 367, 16, 27, "Output",
 CellTags->"SPD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1704498, 69970, 191, 7, 27, "Input",
 CellTags->"SPD"],
Cell[1704692, 69979, 298, 11, 25, "Output",
 CellTags->"SPD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1705027, 69995, 236, 8, 27, "Input",
 CellTags->"SPD"],
Cell[1705266, 70005, 413, 17, 27, "Output",
 CellTags->"SPD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1705716, 70027, 170, 5, 27, "Input",
 CellTags->"SPD"],
Cell[1705889, 70034, 416, 17, 27, "Output",
 CellTags->"SPD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1706342, 70056, 159, 5, 27, "Input",
 CellTags->"SPD"],
Cell[1706504, 70063, 138, 4, 39, "Output",
 CellTags->"SPD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1706679, 70072, 190, 7, 27, "Input",
 CellTags->"SPD"],
Cell[1706872, 70081, 261, 8, 39, "Output",
 CellTags->"SPD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1707170, 70094, 219, 8, 27, "Input",
 CellTags->"SPD"],
Cell[1707392, 70104, 138, 4, 39, "Output",
 CellTags->"SPD"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1707567, 70113, 270, 9, 27, "Input",
 CellTags->"SPD"],
Cell[1707840, 70124, 138, 4, 39, "Output",
 CellTags->"SPD"]
}, Open  ]]
}, Open  ]],
Cell[1708005, 70132, 49, 1, 39, "ObjectName",
 CellTags->"Spinor"],
Cell[CellGroupData[{
Cell[1708079, 70137, 57, 1, 33, "Subsubsection",
 CellTags->"Spinor"],
Cell[1708139, 70140, 1326, 49, 103, "Text",
 CellTags->"Spinor"],
Cell[1709468, 70191, 766, 34, 23, "Text",
 CellTags->"Spinor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1710271, 70230, 54, 1, 33, "Subsubsection",
 CellTags->"Spinor"],
Cell[CellGroupData[{
Cell[1710350, 70235, 106, 3, 27, "Input",
 CellTags->"Spinor"],
Cell[1710459, 70240, 175, 6, 25, "Output",
 CellTags->"Spinor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1710671, 70251, 129, 4, 27, "Input",
 CellTags->"Spinor"],
Cell[1710803, 70257, 185, 6, 25, "Output",
 CellTags->"Spinor"]
}, Open  ]],
Cell[1711003, 70266, 146, 4, 23, "Text",
 CellTags->"Spinor"],
Cell[CellGroupData[{
Cell[1711174, 70274, 250, 8, 27, "Input",
 CellTags->"Spinor"],
Cell[1711427, 70284, 126, 4, 25, "Output",
 CellTags->"Spinor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1711590, 70293, 254, 8, 27, "Input",
 CellTags->"Spinor"],
Cell[1711847, 70303, 251, 9, 25, "Output",
 CellTags->"Spinor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1712135, 70317, 141, 4, 27, "Input",
 CellTags->"Spinor"],
Cell[1712279, 70323, 192, 6, 39, "Output",
 CellTags->"Spinor"]
}, Open  ]],
Cell[1712486, 70332, 158, 4, 23, "Text",
 CellTags->"Spinor"],
Cell[CellGroupData[{
Cell[1712669, 70340, 212, 7, 27, "Input",
 CellTags->"Spinor"],
Cell[1712884, 70349, 192, 6, 39, "Output",
 CellTags->"Spinor"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1713113, 70360, 165, 5, 27, "Input",
 CellTags->"Spinor"],
Cell[1713281, 70367, 192, 6, 39, "Output",
 CellTags->"Spinor"]
}, Open  ]],
Cell[1713488, 70376, 77, 1, 23, "Text",
 CellTags->"Spinor"],
Cell[CellGroupData[{
Cell[1713590, 70381, 210, 7, 27, "Input",
 CellTags->"Spinor"],
Cell[1713803, 70390, 192, 6, 39, "Output",
 CellTags->"Spinor"]
}, Open  ]]
}, Open  ]],
Cell[1714022, 70400, 63, 1, 39, "ObjectName",
 CellTags->"SpinorCollect"],
Cell[CellGroupData[{
Cell[1714110, 70405, 64, 1, 33, "Subsubsection",
 CellTags->"SpinorCollect"],
Cell[1714177, 70408, 191, 4, 23, "Text",
 CellTags->"SpinorCollect"],
Cell[1714371, 70414, 301, 13, 23, "Text",
 CellTags->"SpinorCollect"]
}, Open  ]],
Cell[1714687, 70430, 57, 1, 39, "ObjectName",
 CellTags->"SpinorUBar"],
Cell[CellGroupData[{
Cell[1714769, 70435, 61, 1, 33, "Subsubsection",
 CellTags->"SpinorUBar"],
Cell[1714833, 70438, 170, 7, 23, "Text",
 CellTags->"SpinorUBar"],
Cell[1715006, 70447, 505, 24, 23, "Text",
 CellTags->"SpinorUBar"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1715548, 70476, 58, 1, 33, "Subsubsection",
 CellTags->"SpinorUBar"],
Cell[1715609, 70479, 85, 1, 23, "Text",
 CellTags->"SpinorUBar"],
Cell[CellGroupData[{
Cell[1715719, 70484, 114, 3, 27, "Input",
 CellTags->"SpinorUBar"],
Cell[1715836, 70489, 202, 7, 25, "Output",
 CellTags->"SpinorUBar"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1716075, 70501, 137, 4, 27, "Input",
 CellTags->"SpinorUBar"],
Cell[1716215, 70507, 212, 7, 25, "Output",
 CellTags->"SpinorUBar"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1716464, 70519, 173, 5, 27, "Input",
 CellTags->"SpinorUBar"],
Cell[1716640, 70526, 152, 4, 39, "Output",
 CellTags->"SpinorUBar"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1716829, 70535, 204, 7, 27, "Input",
 CellTags->"SpinorUBar"],
Cell[1717036, 70544, 196, 6, 39, "Output",
 CellTags->"SpinorUBar"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1717269, 70555, 233, 8, 27, "Input",
 CellTags->"SpinorUBar"],
Cell[1717505, 70565, 196, 6, 39, "Output",
 CellTags->"SpinorUBar"]
}, Open  ]]
}, Open  ]],
Cell[1717728, 70575, 51, 1, 39, "ObjectName",
 CellTags->"SpinorU"],
Cell[CellGroupData[{
Cell[1717804, 70580, 58, 1, 33, "Subsubsection",
 CellTags->"SpinorU"],
Cell[1717865, 70583, 79, 1, 23, "Text",
 CellTags->"SpinorU"],
Cell[1717947, 70586, 511, 24, 23, "Text",
 CellTags->"SpinorU"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1718495, 70615, 55, 1, 33, "Subsubsection",
 CellTags->"SpinorU"],
Cell[CellGroupData[{
Cell[1718575, 70620, 108, 3, 27, "Input",
 CellTags->"SpinorU"],
Cell[1718686, 70625, 132, 4, 25, "Output",
 CellTags->"SpinorU"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1718855, 70634, 131, 4, 27, "Input",
 CellTags->"SpinorU"],
Cell[1718989, 70640, 142, 4, 25, "Output",
 CellTags->"SpinorU"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1719168, 70649, 167, 5, 27, "Input",
 CellTags->"SpinorU"],
Cell[1719338, 70656, 146, 4, 39, "Output",
 CellTags->"SpinorU"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1719521, 70665, 198, 7, 27, "Input",
 CellTags->"SpinorU"],
Cell[1719722, 70674, 193, 6, 39, "Output",
 CellTags->"SpinorU"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1719952, 70685, 227, 8, 27, "Input",
 CellTags->"SpinorU"],
Cell[1720182, 70695, 193, 6, 39, "Output",
 CellTags->"SpinorU"]
}, Open  ]]
}, Open  ]],
Cell[1720402, 70705, 57, 1, 39, "ObjectName",
 CellTags->"SpinorVBar"],
Cell[CellGroupData[{
Cell[1720484, 70710, 61, 1, 33, "Subsubsection",
 CellTags->"SpinorVBar"],
Cell[1720548, 70713, 175, 7, 23, "Text",
 CellTags->"SpinorVBar"],
Cell[1720726, 70722, 505, 24, 23, "Text",
 CellTags->"SpinorVBar"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1721268, 70751, 58, 1, 33, "Subsubsection",
 CellTags->"SpinorVBar"],
Cell[CellGroupData[{
Cell[1721351, 70756, 114, 3, 27, "Input",
 CellTags->"SpinorVBar"],
Cell[1721468, 70761, 202, 7, 25, "Output",
 CellTags->"SpinorVBar"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1721707, 70773, 137, 4, 27, "Input",
 CellTags->"SpinorVBar"],
Cell[1721847, 70779, 212, 7, 25, "Output",
 CellTags->"SpinorVBar"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1722096, 70791, 173, 5, 27, "Input",
 CellTags->"SpinorVBar"],
Cell[1722272, 70798, 152, 4, 39, "Output",
 CellTags->"SpinorVBar"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1722461, 70807, 204, 7, 27, "Input",
 CellTags->"SpinorVBar"],
Cell[1722668, 70816, 217, 7, 39, "Output",
 CellTags->"SpinorVBar"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1722922, 70828, 233, 8, 27, "Input",
 CellTags->"SpinorVBar"],
Cell[1723158, 70838, 217, 7, 39, "Output",
 CellTags->"SpinorVBar"]
}, Open  ]]
}, Open  ]],
Cell[1723402, 70849, 51, 1, 39, "ObjectName",
 CellTags->"SpinorV"],
Cell[CellGroupData[{
Cell[1723478, 70854, 58, 1, 33, "Subsubsection",
 CellTags->"SpinorV"],
Cell[1723539, 70857, 79, 1, 23, "Text",
 CellTags->"SpinorV"],
Cell[1723621, 70860, 511, 24, 23, "Text",
 CellTags->"SpinorV"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1724169, 70889, 55, 1, 33, "Subsubsection",
 CellTags->"SpinorV"],
Cell[CellGroupData[{
Cell[1724249, 70894, 108, 3, 27, "Input",
 CellTags->"SpinorV"],
Cell[1724360, 70899, 132, 4, 25, "Output",
 CellTags->"SpinorV"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1724529, 70908, 131, 4, 27, "Input",
 CellTags->"SpinorV"],
Cell[1724663, 70914, 142, 4, 25, "Output",
 CellTags->"SpinorV"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1724842, 70923, 167, 5, 27, "Input",
 CellTags->"SpinorV"],
Cell[1725012, 70930, 146, 4, 39, "Output",
 CellTags->"SpinorV"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1725195, 70939, 198, 7, 27, "Input",
 CellTags->"SpinorV"],
Cell[1725396, 70948, 214, 7, 39, "Output",
 CellTags->"SpinorV"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1725647, 70960, 227, 8, 27, "Input",
 CellTags->"SpinorV"],
Cell[1725877, 70970, 214, 7, 39, "Output",
 CellTags->"SpinorV"]
}, Open  ]]
}, Open  ]],
Cell[1726118, 70981, 75, 1, 39, "ObjectName",
 CellTags->"SpinPolarizationSum"],
Cell[CellGroupData[{
Cell[1726218, 70986, 70, 1, 33, "Subsubsection",
 CellTags->"SpinPolarizationSum"],
Cell[1726291, 70989, 164, 4, 23, "Text",
 CellTags->"SpinPolarizationSum"],
Cell[1726458, 70995, 203, 8, 23, "Text",
 CellTags->"SpinPolarizationSum"]
}, Open  ]],
Cell[1726676, 71006, 43, 1, 39, "ObjectName",
 CellTags->"SPL"],
Cell[CellGroupData[{
Cell[1726744, 71011, 54, 1, 33, "Subsubsection",
 CellTags->"SPL"],
Cell[1726801, 71014, 77, 1, 23, "Text",
 CellTags->"SPL"],
Cell[1726881, 71017, 195, 9, 23, "Text",
 CellTags->"SPL"]
}, Open  ]],
Cell[1727091, 71029, 71, 1, 39, "ObjectName",
 CellTags->"SplittingFunction"],
Cell[CellGroupData[{
Cell[1727187, 71034, 68, 1, 33, "Subsubsection",
 CellTags->"SplittingFunction"],
Cell[1727258, 71037, 218, 7, 23, "Text",
 CellTags->"SplittingFunction"],
Cell[CellGroupData[{
Cell[1727501, 71048, 134, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1727638, 71053, 181, 6, 25, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[1727834, 71062, 218, 9, 23, "Text",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1728089, 71076, 65, 1, 33, "Subsubsection",
 CellTags->"SplittingFunction"],
Cell[1728157, 71079, 65, 1, 23, "Text",
 CellTags->"SplittingFunction"],
Cell[1728225, 71082, 221, 6, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1728449, 71090, 170, 4, 23, "Text",
 CellTags->"SplittingFunction"],
Cell[CellGroupData[{
Cell[1728644, 71098, 130, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1728777, 71103, 531, 19, 44, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1729345, 71127, 130, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1729478, 71132, 301, 10, 30, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1729816, 71147, 130, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1729949, 71152, 269, 9, 43, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1730255, 71166, 130, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1730388, 71171, 859, 29, 44, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1731284, 71205, 130, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1731417, 71210, 1128, 38, 44, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1732582, 71253, 130, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1732715, 71258, 599, 21, 43, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1733351, 71284, 130, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1733484, 71289, 541, 19, 30, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[1734040, 71311, 130, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1734173, 71316, 63, 1, 23, "Text",
 CellTags->"SplittingFunction"],
Cell[1734239, 71319, 221, 6, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[CellGroupData[{
Cell[1734485, 71329, 130, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1734618, 71334, 531, 19, 44, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1735186, 71358, 130, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1735319, 71363, 236, 8, 28, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1735592, 71376, 130, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1735725, 71381, 235, 8, 25, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1735997, 71394, 130, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1736130, 71399, 811, 28, 44, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1736978, 71432, 130, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1737111, 71437, 1247, 42, 44, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1738395, 71484, 130, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1738528, 71489, 503, 18, 25, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1739068, 71512, 131, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1739202, 71517, 445, 16, 25, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1739684, 71538, 130, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1739817, 71543, 445, 16, 28, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1740299, 71564, 131, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1740433, 71569, 445, 16, 28, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1740915, 71590, 130, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1741048, 71595, 1362, 46, 44, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1742447, 71646, 131, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1742581, 71651, 1362, 46, 44, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1743980, 71702, 131, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1744114, 71707, 637, 22, 30, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1744788, 71734, 132, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1744923, 71739, 5385, 174, 246, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1750345, 71918, 130, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1750478, 71923, 2906, 92, 75, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1753421, 72020, 130, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1753554, 72025, 3584, 117, 146, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1757175, 72147, 130, 3, 27, "Input",
 CellTags->"SplittingFunction"],
Cell[1757308, 72152, 4258, 139, 188, "Output",
 CellTags->"SplittingFunction"]
}, Open  ]]
}, Open  ]],
Cell[1761593, 72295, 79, 1, 39, "ObjectName",
 CellTags->"StandardMatrixElement"],
Cell[CellGroupData[{
Cell[1761697, 72300, 72, 1, 33, "Subsubsection",
 CellTags->"StandardMatrixElement"],
Cell[1761772, 72303, 134, 3, 23, "Text",
 CellTags->"StandardMatrixElement"],
Cell[1761909, 72308, 189, 9, 23, "Text",
 CellTags->"StandardMatrixElement"]
}, Open  ]],
Cell[1762113, 72320, 57, 1, 39, "ObjectName",
 CellTags->"SubContext"],
Cell[CellGroupData[{
Cell[1762195, 72325, 61, 1, 33, "Subsubsection",
 CellTags->"SubContext"],
Cell[1762259, 72328, 120, 3, 23, "Text",
 CellTags->"SubContext"],
Cell[1762382, 72333, 279, 14, 23, "Text",
 CellTags->"SubContext"]
}, Open  ]],
Cell[1762676, 72350, 51, 1, 39, "ObjectName",
 CellTags->"SubLoop"],
Cell[CellGroupData[{
Cell[1762752, 72355, 58, 1, 33, "Subsubsection",
 CellTags->"SubLoop"],
Cell[1762813, 72358, 152, 4, 23, "Text",
 CellTags->"SubLoop"],
Cell[1762968, 72364, 178, 9, 23, "Text",
 CellTags->"SubLoop"]
}, Open  ]],
Cell[1763161, 72376, 45, 1, 39, "ObjectName",
 CellTags->"SumP"],
Cell[CellGroupData[{
Cell[1763231, 72381, 55, 1, 33, "Subsubsection",
 CellTags->"SumP"],
Cell[1763289, 72384, 767, 31, 27, "Text",
 CellTags->"SumP"],
Cell[1764059, 72417, 261, 14, 23, "Text",
 CellTags->"SumP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1764357, 72436, 52, 1, 33, "Subsubsection",
 CellTags->"SumP"],
Cell[CellGroupData[{
Cell[1764434, 72441, 149, 5, 27, "Input",
 CellTags->"SumP"],
Cell[1764586, 72448, 263, 8, 29, "Output",
 CellTags->"SumP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1764886, 72461, 149, 5, 27, "Input",
 CellTags->"SumP"],
Cell[1765038, 72468, 263, 8, 29, "Output",
 CellTags->"SumP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1765338, 72481, 125, 4, 27, "Input",
 CellTags->"SumP"],
Cell[1765466, 72487, 238, 7, 29, "Output",
 CellTags->"SumP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1765741, 72499, 125, 4, 27, "Input",
 CellTags->"SumP"],
Cell[1765869, 72505, 124, 4, 43, "Output",
 CellTags->"SumP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1766030, 72514, 301, 12, 51, "Input",
 CellTags->"SumP"],
Cell[1766334, 72528, 124, 4, 43, "Output",
 CellTags->"SumP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1766495, 72537, 186, 6, 27, "Input",
 CellTags->"SumP"],
Cell[1766684, 72545, 764, 29, 43, "Output",
 CellTags->"SumP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1767485, 72579, 124, 4, 27, "Input",
 CellTags->"SumP"],
Cell[1767612, 72585, 124, 4, 43, "Output",
 CellTags->"SumP"]
}, Open  ]]
}, Open  ]],
Cell[1767763, 72593, 45, 1, 39, "ObjectName",
 CellTags->"SumS"],
Cell[CellGroupData[{
Cell[1767833, 72598, 55, 1, 33, "Subsubsection",
 CellTags->"SumS"],
Cell[1767891, 72601, 1438, 57, 41, "Text",
 CellTags->"SumS"],
Cell[CellGroupData[{
Cell[1769354, 72662, 108, 3, 27, "Input",
 CellTags->"SumS"],
Cell[1769465, 72667, 165, 6, 25, "Output",
 CellTags->"SumS"]
}, Open  ]],
Cell[1769645, 72676, 261, 14, 23, "Text",
 CellTags->"SumS"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1769943, 72695, 52, 1, 33, "Subsubsection",
 CellTags->"SumS"],
Cell[CellGroupData[{
Cell[1770020, 72700, 149, 5, 27, "Input",
 CellTags->"SumS"],
Cell[1770172, 72707, 211, 8, 25, "Output",
 CellTags->"SumS"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1770420, 72720, 149, 5, 27, "Input",
 CellTags->"SumS"],
Cell[1770572, 72727, 211, 8, 25, "Output",
 CellTags->"SumS"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1770820, 72740, 144, 5, 27, "Input",
 CellTags->"SumS"],
Cell[1770967, 72747, 172, 6, 25, "Output",
 CellTags->"SumS"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1771176, 72758, 173, 5, 27, "Input",
 CellTags->"SumS"],
Cell[1771352, 72765, 261, 10, 43, "Output",
 CellTags->"SumS"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1771650, 72780, 197, 6, 27, "Input",
 CellTags->"SumS"],
Cell[1771850, 72788, 340, 13, 47, "Output",
 CellTags->"SumS"]
}, Open  ]],
Cell[1772205, 72804, 192, 6, 27, "Input",
 CellTags->"SumS"],
Cell[CellGroupData[{
Cell[1772422, 72814, 149, 5, 27, "Input",
 CellTags->"SumS"],
Cell[1772574, 72821, 509, 19, 47, "Output",
 CellTags->"SumS"]
}, Open  ]],
Cell[1773098, 72843, 193, 6, 27, "Input",
 CellTags->"SumS"],
Cell[CellGroupData[{
Cell[1773316, 72853, 125, 4, 27, "Input",
 CellTags->"SumS"],
Cell[1773444, 72859, 124, 4, 43, "Output",
 CellTags->"SumS"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1773605, 72868, 174, 6, 51, "Input",
 CellTags->"SumS"],
Cell[1773782, 72876, 124, 4, 43, "Output",
 CellTags->"SumS"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1773943, 72885, 159, 5, 27, "Input",
 CellTags->"SumS"],
Cell[1774105, 72892, 212, 8, 25, "Output",
 CellTags->"SumS"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1774354, 72905, 146, 4, 27, "Input",
 CellTags->"SumS"],
Cell[1774503, 72911, 149, 5, 43, "Output",
 CellTags->"SumS"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1774689, 72921, 144, 5, 27, "Input",
 CellTags->"SumS"],
Cell[1774836, 72928, 142, 5, 43, "Output",
 CellTags->"SumS"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1775015, 72938, 125, 4, 27, "Input",
 CellTags->"SumS"],
Cell[1775143, 72944, 142, 5, 43, "Output",
 CellTags->"SumS"]
}, Open  ]]
}, Open  ]],
Cell[1775312, 72953, 45, 1, 39, "ObjectName",
 CellTags->"SumT"],
Cell[CellGroupData[{
Cell[1775382, 72958, 55, 1, 33, "Subsubsection",
 CellTags->"SumT"],
Cell[1775440, 72961, 461, 15, 41, "Text",
 CellTags->"SumT"],
Cell[1775904, 72978, 261, 14, 23, "Text",
 CellTags->"SumT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1776202, 72997, 52, 1, 33, "Subsubsection",
 CellTags->"SumT"],
Cell[CellGroupData[{
Cell[1776279, 73002, 149, 5, 27, "Input",
 CellTags->"SumT"],
Cell[1776431, 73009, 236, 9, 27, "Output",
 CellTags->"SumT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1776704, 73023, 149, 5, 27, "Input",
 CellTags->"SumT"],
Cell[1776856, 73030, 236, 9, 27, "Output",
 CellTags->"SumT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1777129, 73044, 125, 4, 27, "Input",
 CellTags->"SumT"],
Cell[1777257, 73050, 180, 7, 27, "Output",
 CellTags->"SumT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1777474, 73062, 173, 5, 27, "Input",
 CellTags->"SumT"],
Cell[1777650, 73069, 361, 14, 44, "Output",
 CellTags->"SumT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1778048, 73088, 125, 4, 27, "Input",
 CellTags->"SumT"],
Cell[1778176, 73094, 142, 5, 43, "Output",
 CellTags->"SumT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1778355, 73104, 244, 9, 51, "Input",
 CellTags->"SumT"],
Cell[1778602, 73115, 142, 5, 43, "Output",
 CellTags->"SumT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1778781, 73125, 159, 5, 27, "Input",
 CellTags->"SumT"],
Cell[1778943, 73132, 237, 9, 27, "Output",
 CellTags->"SumT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1779217, 73146, 136, 4, 27, "Input",
 CellTags->"SumT"],
Cell[1779356, 73152, 253, 7, 43, "Output",
 CellTags->"SumT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1779646, 73164, 125, 4, 27, "Input",
 CellTags->"SumT"],
Cell[1779774, 73170, 142, 5, 43, "Output",
 CellTags->"SumT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1779953, 73180, 144, 5, 27, "Input",
 CellTags->"SumT"],
Cell[1780100, 73187, 142, 5, 43, "Output",
 CellTags->"SumT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1780279, 73197, 268, 10, 51, "Input",
 CellTags->"SumT"],
Cell[1780550, 73209, 336, 12, 25, "Output",
 CellTags->"SumT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1780923, 73226, 136, 4, 27, "Input",
 CellTags->"SumT"],
Cell[1781062, 73232, 170, 6, 43, "Output",
 CellTags->"SumT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1781269, 73243, 155, 5, 27, "Input",
 CellTags->"SumT"],
Cell[1781427, 73250, 253, 7, 43, "Output",
 CellTags->"SumT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1781717, 73262, 129, 4, 27, "Input",
 CellTags->"SumT"],
Cell[1781849, 73268, 458, 16, 43, "Output",
 CellTags->"SumT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1782344, 73289, 240, 9, 27, "Input",
 CellTags->"SumT"],
Cell[1782587, 73300, 458, 16, 43, "Output",
 CellTags->"SumT"]
}, Open  ]]
}, Open  ]],
Cell[1783072, 73320, 45, 1, 39, "ObjectName",
 CellTags->"SUND"],
Cell[CellGroupData[{
Cell[1783142, 73325, 55, 1, 33, "Subsubsection",
 CellTags->"SUND"],
Cell[1783200, 73328, 224, 10, 23, "Text",
 CellTags->"SUND"],
Cell[1783427, 73340, 392, 19, 22, "Text",
 CellTags->"SUND"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1783856, 73364, 52, 1, 33, "Subsubsection",
 CellTags->"SUND"],
Cell[CellGroupData[{
Cell[1783933, 73369, 135, 4, 27, "Input",
 CellTags->"SUND"],
Cell[1784071, 73375, 147, 5, 27, "Output",
 CellTags->"SUND"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1784255, 73385, 211, 6, 27, "Input",
 CellTags->"SUND"],
Cell[1784469, 73393, 1086, 44, 25, "Output",
 CellTags->"SUND"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1785592, 73442, 135, 4, 27, "Input",
 CellTags->"SUND"],
Cell[1785730, 73448, 147, 5, 27, "Output",
 CellTags->"SUND"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1785914, 73458, 135, 4, 27, "Input",
 CellTags->"SUND"],
Cell[1786052, 73464, 147, 5, 27, "Output",
 CellTags->"SUND"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1786236, 73474, 266, 8, 27, "Input",
 CellTags->"SUND"],
Cell[1786505, 73484, 260, 9, 29, "Output",
 CellTags->"SUND"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1786802, 73498, 377, 12, 27, "Input",
 CellTags->"SUND"],
Cell[1787182, 73512, 304, 11, 47, "Output",
 CellTags->"SUND"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1787523, 73528, 377, 12, 27, "Input",
 CellTags->"SUND"],
Cell[1787903, 73542, 474, 19, 47, "Output",
 CellTags->"SUND"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1788414, 73566, 173, 6, 27, "Input",
 CellTags->"SUND"],
Cell[1788590, 73574, 150, 4, 39, "Output",
 CellTags->"SUND"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1788777, 73583, 202, 7, 27, "Input",
 CellTags->"SUND"],
Cell[1788982, 73592, 258, 7, 39, "Output",
 CellTags->"SUND"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1789277, 73604, 231, 8, 27, "Input",
 CellTags->"SUND"],
Cell[1789511, 73614, 150, 4, 39, "Output",
 CellTags->"SUND"]
}, Open  ]],
Cell[1789676, 73621, 104, 3, 27, "Input",
 CellTags->"SUND"]
}, Open  ]],
Cell[1789795, 73627, 53, 1, 39, "ObjectName",
 CellTags->"SUNDelta"],
Cell[CellGroupData[{
Cell[1789873, 73632, 59, 1, 33, "Subsubsection",
 CellTags->"SUNDelta"],
Cell[1789935, 73635, 172, 6, 23, "Text",
 CellTags->"SUNDelta"],
Cell[1790110, 73643, 717, 33, 23, "Text",
 CellTags->"SUNDelta"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1790864, 73681, 56, 1, 33, "Subsubsection",
 CellTags->"SUNDelta"],
Cell[CellGroupData[{
Cell[1790945, 73686, 133, 4, 27, "Input",
 CellTags->"SUNDelta"],
Cell[1791081, 73692, 153, 5, 27, "Output",
 CellTags->"SUNDelta"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1791271, 73702, 262, 8, 27, "Input",
 CellTags->"SUNDelta"],
Cell[1791536, 73712, 301, 13, 27, "Output",
 CellTags->"SUNDelta"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1791874, 73730, 205, 6, 27, "Input",
 CellTags->"SUNDelta"],
Cell[1792082, 73738, 301, 13, 27, "Output",
 CellTags->"SUNDelta"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1792420, 73756, 169, 5, 27, "Input",
 CellTags->"SUNDelta"],
Cell[1792592, 73763, 148, 4, 39, "Output",
 CellTags->"SUNDelta"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1792777, 73772, 200, 7, 27, "Input",
 CellTags->"SUNDelta"],
Cell[1792980, 73781, 220, 6, 39, "Output",
 CellTags->"SUNDelta"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1793237, 73792, 229, 8, 27, "Input",
 CellTags->"SUNDelta"],
Cell[1793469, 73802, 142, 4, 39, "Output",
 CellTags->"SUNDelta"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1793648, 73811, 194, 7, 27, "Input",
 CellTags->"SUNDelta"],
Cell[1793845, 73820, 220, 6, 39, "Output",
 CellTags->"SUNDelta"]
}, Open  ]],
Cell[1794080, 73829, 256, 5, 39, "Text",
 CellTags->"SUNDelta"],
Cell[CellGroupData[{
Cell[1794361, 73838, 315, 10, 27, "Input",
 CellTags->"SUNDelta"],
Cell[1794679, 73850, 460, 20, 27, "Output",
 CellTags->"SUNDelta"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1795176, 73875, 110, 3, 27, "Input",
 CellTags->"SUNDelta"],
Cell[1795289, 73880, 395, 11, 39, "Output",
 CellTags->"SUNDelta"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1795721, 73896, 200, 7, 27, "Input",
 CellTags->"SUNDelta"],
Cell[1795924, 73905, 236, 6, 39, "Output",
 CellTags->"SUNDelta"]
}, Open  ]]
}, Open  ]],
Cell[1796187, 73915, 69, 1, 39, "ObjectName",
 CellTags->"SUNDeltaContract"],
Cell[CellGroupData[{
Cell[1796281, 73920, 67, 1, 33, "Subsubsection",
 CellTags->"SUNDeltaContract"],
Cell[1796351, 73923, 397, 9, 55, "Text",
 CellTags->"SUNDeltaContract"],
Cell[1796751, 73934, 297, 14, 23, "Text",
 CellTags->"SUNDeltaContract"]
}, Open  ]],
Cell[1797063, 73951, 45, 1, 39, "ObjectName",
 CellTags->"SUNF"],
Cell[CellGroupData[{
Cell[1797133, 73956, 55, 1, 33, "Subsubsection",
 CellTags->"SUNF"],
Cell[1797191, 73959, 190, 6, 23, "Text",
 CellTags->"SUNF"],
Cell[CellGroupData[{
Cell[1797406, 73969, 108, 3, 27, "Input",
 CellTags->"SUNF"],
Cell[1797517, 73974, 168, 6, 25, "Output",
 CellTags->"SUNF"]
}, Open  ]],
Cell[1797700, 73983, 701, 34, 23, "Text",
 CellTags->"SUNF"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1798438, 74022, 52, 1, 33, "Subsubsection",
 CellTags->"SUNF"],
Cell[CellGroupData[{
Cell[1798515, 74027, 294, 10, 27, "Input",
 CellTags->"SUNF"],
Cell[1798812, 74039, 272, 10, 27, "Output",
 CellTags->"SUNF"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1799121, 74054, 103, 3, 27, "Input",
 CellTags->"SUNF"],
Cell[1799227, 74059, 764, 34, 27, "Output",
 CellTags->"SUNF"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1800028, 74098, 110, 3, 27, "Input",
 CellTags->"SUNF"],
Cell[1800141, 74103, 455, 20, 27, "Output",
 CellTags->"SUNF"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1800633, 74128, 135, 4, 27, "Input",
 CellTags->"SUNF"],
Cell[1800771, 74134, 147, 5, 27, "Output",
 CellTags->"SUNF"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1800955, 74144, 163, 5, 27, "Input",
 CellTags->"SUNF"],
Cell[1801121, 74151, 101, 3, 25, "Output",
 CellTags->"SUNF"]
}, Open  ]],
Cell[1801237, 74157, 319, 10, 23, "Text",
 CellTags->"SUNF"],
Cell[CellGroupData[{
Cell[1801581, 74171, 185, 5, 27, "Input",
 CellTags->"SUNF"],
Cell[1801769, 74178, 1147, 44, 25, "Output",
 CellTags->"SUNF"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1802953, 74227, 266, 8, 27, "Input",
 CellTags->"SUNF"],
Cell[1803222, 74237, 353, 15, 27, "Output",
 CellTags->"SUNF"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1803612, 74257, 239, 7, 27, "Input",
 CellTags->"SUNF"],
Cell[1803854, 74266, 1166, 45, 25, "Output",
 CellTags->"SUNF"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1805057, 74316, 173, 6, 27, "Input",
 CellTags->"SUNF"],
Cell[1805233, 74324, 150, 4, 39, "Output",
 CellTags->"SUNF"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1805420, 74333, 202, 7, 27, "Input",
 CellTags->"SUNF"],
Cell[1805625, 74342, 258, 7, 39, "Output",
 CellTags->"SUNF"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1805920, 74354, 231, 8, 27, "Input",
 CellTags->"SUNF"],
Cell[1806154, 74364, 150, 4, 39, "Output",
 CellTags->"SUNF"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1806341, 74373, 135, 4, 27, "Input",
 CellTags->"SUNF"],
Cell[1806479, 74379, 147, 5, 27, "Output",
 CellTags->"SUNF"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1806663, 74389, 162, 5, 27, "Input",
 CellTags->"SUNF"],
Cell[1806828, 74396, 401, 18, 27, "Output",
 CellTags->"SUNF"]
}, Open  ]]
}, Open  ]],
Cell[1807256, 74418, 57, 1, 39, "ObjectName",
 CellTags->"SUNFJacobi"],
Cell[CellGroupData[{
Cell[1807338, 74423, 61, 1, 33, "Subsubsection",
 CellTags->"SUNFJacobi"],
Cell[1807402, 74426, 146, 4, 23, "Text",
 CellTags->"SUNFJacobi"],
Cell[1807551, 74432, 283, 13, 23, "Text",
 CellTags->"SUNFJacobi"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1807871, 74450, 58, 1, 33, "Subsubsection",
 CellTags->"SUNFJacobi"],
Cell[CellGroupData[{
Cell[1807954, 74455, 380, 12, 27, "Input",
 CellTags->"SUNFJacobi"],
Cell[1808337, 74469, 694, 32, 28, "Output",
 CellTags->"SUNFJacobi"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1809068, 74506, 379, 12, 27, "Input",
 CellTags->"SUNFJacobi"],
Cell[1809450, 74520, 1362, 62, 28, "Output",
 CellTags->"SUNFJacobi"]
}, Open  ]]
}, Open  ]],
Cell[1810839, 74586, 53, 1, 39, "ObjectName",
 CellTags->"SUNIndex"],
Cell[CellGroupData[{
Cell[1810917, 74591, 59, 1, 33, "Subsubsection",
 CellTags->"SUNIndex"],
Cell[1810979, 74594, 135, 6, 23, "Text",
 CellTags->"SUNIndex"],
Cell[1811117, 74602, 405, 18, 23, "Text",
 CellTags->"SUNIndex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1811559, 74625, 56, 1, 33, "Subsubsection",
 CellTags->"SUNIndex"],
Cell[CellGroupData[{
Cell[1811640, 74630, 110, 3, 27, "Input",
 CellTags->"SUNIndex"],
Cell[1811753, 74635, 105, 3, 25, "Output",
 CellTags->"SUNIndex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1811895, 74643, 110, 3, 27, "Input",
 CellTags->"SUNIndex"],
Cell[1812008, 74648, 125, 3, 39, "Output",
 CellTags->"SUNIndex"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1812170, 74656, 200, 7, 27, "Input",
 CellTags->"SUNIndex"],
Cell[1812373, 74665, 220, 6, 39, "Output",
 CellTags->"SUNIndex"]
}, Open  ]]
}, Open  ]],
Cell[1812620, 74675, 65, 1, 39, "ObjectName",
 CellTags->"SUNIndexRename"],
Cell[CellGroupData[{
Cell[1812710, 74680, 65, 1, 33, "Subsubsection",
 CellTags->"SUNIndexRename"],
Cell[1812778, 74683, 163, 4, 23, "Text",
 CellTags->"SUNIndexRename"],
Cell[1812944, 74689, 304, 14, 23, "Text",
 CellTags->"SUNIndexRename"]
}, Open  ]],
Cell[1813263, 74706, 45, 1, 39, "ObjectName",
 CellTags->"SUNN"],
Cell[CellGroupData[{
Cell[1813333, 74711, 55, 1, 33, "Subsubsection",
 CellTags->"SUNN"],
Cell[1813391, 74714, 203, 7, 23, "Text",
 CellTags->"SUNN"],
Cell[1813597, 74723, 579, 29, 23, "Text",
 CellTags->"SUNN"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1814213, 74757, 52, 1, 33, "Subsubsection",
 CellTags->"SUNN"],
Cell[CellGroupData[{
Cell[1814290, 74762, 317, 9, 27, "Input",
 CellTags->"SUNN"],
Cell[1814610, 74773, 149, 5, 27, "Output",
 CellTags->"SUNN"]
}, Open  ]]
}, Open  ]],
Cell[1814786, 74782, 57, 1, 39, "ObjectName",
 CellTags->"SUNNToCACF"],
Cell[CellGroupData[{
Cell[1814868, 74787, 61, 1, 33, "Subsubsection",
 CellTags->"SUNNToCACF"],
Cell[1814932, 74790, 187, 4, 23, "Text",
 CellTags->"SUNNToCACF"],
Cell[1815122, 74796, 573, 29, 23, "Text",
 CellTags->"SUNNToCACF"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1815732, 74830, 58, 1, 33, "Subsubsection",
 CellTags->"SUNNToCACF"],
Cell[CellGroupData[{
Cell[1815815, 74835, 322, 9, 27, "Input",
 CellTags->"SUNNToCACF"],
Cell[1816140, 74846, 186, 6, 25, "Output",
 CellTags->"SUNNToCACF"]
}, Open  ]]
}, Open  ]],
Cell[1816353, 74856, 59, 1, 39, "ObjectName",
 CellTags->"SUNSimplify"],
Cell[CellGroupData[{
Cell[1816437, 74861, 62, 1, 33, "Subsubsection",
 CellTags->"SUNSimplify"],
Cell[1816502, 74864, 376, 7, 55, "Text",
 CellTags->"SUNSimplify"],
Cell[CellGroupData[{
Cell[1816903, 74875, 122, 3, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1817028, 74880, 512, 13, 45, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[1817555, 74896, 299, 13, 23, "Text",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1817891, 74914, 59, 1, 33, "Subsubsection",
 CellTags->"SUNSimplify"],
Cell[CellGroupData[{
Cell[1817975, 74919, 247, 8, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1818225, 74929, 231, 8, 27, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1818493, 74942, 117, 3, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1818613, 74947, 304, 13, 27, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1818954, 74965, 189, 6, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1819146, 74973, 249, 10, 25, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1819432, 74988, 117, 3, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1819552, 74993, 130, 4, 25, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1819719, 75002, 183, 5, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1819905, 75009, 203, 7, 47, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1820145, 75021, 254, 8, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1820402, 75031, 227, 8, 27, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1820666, 75044, 117, 3, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1820786, 75049, 360, 15, 27, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1821183, 75069, 269, 8, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1821455, 75079, 227, 8, 27, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1821719, 75092, 117, 3, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1821839, 75097, 197, 6, 29, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1822073, 75108, 259, 8, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1822335, 75118, 227, 8, 27, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1822599, 75131, 117, 3, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1822719, 75136, 360, 15, 27, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1823116, 75156, 259, 8, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1823378, 75166, 227, 8, 27, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1823642, 75179, 180, 5, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1823825, 75186, 108, 3, 25, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1823970, 75194, 384, 12, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1824357, 75208, 311, 11, 47, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1824705, 75224, 389, 12, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1825097, 75238, 448, 18, 47, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1825582, 75261, 246, 7, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1825831, 75270, 1173, 45, 25, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1827041, 75320, 246, 7, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1827290, 75329, 1132, 44, 25, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1828459, 75378, 273, 8, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1828735, 75388, 251, 8, 43, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1829023, 75401, 439, 14, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1829465, 75417, 379, 14, 27, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1829881, 75436, 181, 5, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1830065, 75443, 705, 32, 27, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1830807, 75480, 238, 6, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1831048, 75488, 1363, 62, 27, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1832448, 75555, 200, 6, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1832651, 75563, 164, 5, 29, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1832852, 75573, 341, 10, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1833196, 75585, 543, 21, 27, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1833776, 75611, 181, 5, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1833960, 75618, 543, 21, 27, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1834540, 75644, 180, 5, 27, "Input",
 CellTags->"SUNSimplify"],
Cell[1834723, 75651, 571, 22, 27, "Output",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[1835309, 75676, 208, 6, 27, "Input",
 CellTags->"SUNSimplify"]
}, Open  ]],
Cell[1835532, 75685, 45, 1, 39, "ObjectName",
 CellTags->"SUNT"],
Cell[CellGroupData[{
Cell[1835602, 75690, 55, 1, 33, "Subsubsection",
 CellTags->"SUNT"],
Cell[1835660, 75693, 237, 10, 23, "Text",
 CellTags->"SUNT"],
Cell[1835900, 75705, 674, 34, 23, "Text",
 CellTags->"SUNT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1836611, 75744, 52, 1, 33, "Subsubsection",
 CellTags->"SUNT"],
Cell[CellGroupData[{
Cell[1836688, 75749, 102, 3, 27, "Input",
 CellTags->"SUNT"],
Cell[1836793, 75754, 157, 6, 25, "Output",
 CellTags->"SUNT"]
}, Open  ]],
Cell[1836965, 75763, 203, 7, 23, "Text",
 CellTags->"SUNT"],
Cell[CellGroupData[{
Cell[1837193, 75774, 207, 6, 27, "Input",
 CellTags->"SUNT"],
Cell[1837403, 75782, 311, 13, 25, "Output",
 CellTags->"SUNT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1837751, 75800, 145, 4, 27, "Input",
 CellTags->"SUNT"],
Cell[1837899, 75806, 365, 16, 25, "Output",
 CellTags->"SUNT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1838301, 75827, 242, 7, 27, "Input",
 CellTags->"SUNT"],
Cell[1838546, 75836, 268, 11, 44, "Output",
 CellTags->"SUNT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1838851, 75852, 184, 5, 27, "Input",
 CellTags->"SUNT"],
Cell[1839038, 75859, 133, 4, 29, "Output",
 CellTags->"SUNT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1839208, 75868, 174, 5, 27, "Input",
 CellTags->"SUNT"],
Cell[1839385, 75875, 399, 16, 43, "Output",
 CellTags->"SUNT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1839821, 75896, 242, 7, 27, "Input",
 CellTags->"SUNT"],
Cell[1840066, 75905, 268, 11, 44, "Output",
 CellTags->"SUNT"]
}, Open  ]],
Cell[1840349, 75919, 422, 15, 23, "Text",
 CellTags->"SUNT"],
Cell[CellGroupData[{
Cell[1840796, 75938, 161, 5, 27, "Input",
 CellTags->"SUNT"],
Cell[1840960, 75945, 328, 14, 43, "Output",
 CellTags->"SUNT"]
}, Open  ]],
Cell[1841303, 75962, 197, 7, 26, "Text",
 CellTags->"SUNT"],
Cell[CellGroupData[{
Cell[1841525, 75973, 197, 6, 27, "Input",
 CellTags->"SUNT"],
Cell[1841725, 75981, 353, 15, 28, "Output",
 CellTags->"SUNT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1842115, 76001, 198, 6, 27, "Input",
 CellTags->"SUNT"],
Cell[1842316, 76009, 263, 8, 55, "Output",
 CellTags->"SUNT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1842616, 76022, 167, 6, 27, "Input",
 CellTags->"SUNT"],
Cell[1842786, 76030, 152, 4, 39, "Output",
 CellTags->"SUNT"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1842975, 76039, 195, 7, 27, "Input",
 CellTags->"SUNT"],
Cell[1843173, 76048, 117, 3, 39, "Output",
 CellTags->"SUNT"]
}, Open  ]]
}, Open  ]],
Cell[1843317, 76055, 53, 1, 39, "ObjectName",
 CellTags->"SUNTrace"],
Cell[CellGroupData[{
Cell[1843395, 76060, 59, 1, 33, "Subsubsection",
 CellTags->"SUNTrace"],
Cell[1843457, 76063, 81, 1, 23, "Text",
 CellTags->"SUNTrace"],
Cell[CellGroupData[{
Cell[1843563, 76068, 116, 3, 27, "Input",
 CellTags->"SUNTrace"],
Cell[1843682, 76073, 172, 6, 25, "Output",
 CellTags->"SUNTrace"]
}, Open  ]],
Cell[1843869, 76082, 280, 14, 23, "Text",
 CellTags->"SUNTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1844186, 76101, 56, 1, 33, "Subsubsection",
 CellTags->"SUNTrace"],
Cell[CellGroupData[{
Cell[1844267, 76106, 165, 5, 27, "Input",
 CellTags->"SUNTrace"],
Cell[1844435, 76113, 332, 14, 43, "Output",
 CellTags->"SUNTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1844804, 76132, 175, 5, 27, "Input",
 CellTags->"SUNTrace"],
Cell[1844982, 76139, 524, 22, 25, "Output",
 CellTags->"SUNTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1845543, 76166, 240, 7, 27, "Input",
 CellTags->"SUNTrace"],
Cell[1845786, 76175, 811, 35, 44, "Output",
 CellTags->"SUNTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1846634, 76215, 185, 5, 27, "Input",
 CellTags->"SUNTrace"],
Cell[1846822, 76222, 641, 27, 25, "Output",
 CellTags->"SUNTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1847500, 76254, 278, 8, 27, "Input",
 CellTags->"SUNTrace"],
Cell[1847781, 76264, 4270, 184, 44, "Output",
 CellTags->"SUNTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1852088, 76453, 177, 5, 27, "Input",
 CellTags->"SUNTrace"],
Cell[1852268, 76460, 641, 27, 25, "Output",
 CellTags->"SUNTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1852946, 76492, 288, 8, 27, "Input",
 CellTags->"SUNTrace"],
Cell[1853237, 76502, 11352, 436, 173, "Output",
 CellTags->"SUNTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1864626, 76943, 177, 5, 27, "Input",
 CellTags->"SUNTrace"],
Cell[1864806, 76950, 758, 32, 25, "Output",
 CellTags->"SUNTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1865601, 76987, 270, 8, 27, "Input",
 CellTags->"SUNTrace"],
Cell[1865874, 76997, 105, 3, 25, "Output",
 CellTags->"SUNTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1866016, 77005, 270, 8, 27, "Input",
 CellTags->"SUNTrace"],
Cell[1866289, 77015, 105, 3, 25, "Output",
 CellTags->"SUNTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1866431, 77023, 270, 8, 27, "Input",
 CellTags->"SUNTrace"],
Cell[1866704, 77033, 105, 3, 25, "Output",
 CellTags->"SUNTrace"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1866846, 77041, 270, 8, 27, "Input",
 CellTags->"SUNTrace"],
Cell[1867119, 77051, 576, 23, 29, "Output",
 CellTags->"SUNTrace"]
}, Open  ]]
}, Open  ]],
Cell[1867722, 77078, 61, 1, 39, "ObjectName",
 CellTags->"SymbolicSum2"],
Cell[CellGroupData[{
Cell[1867808, 77083, 63, 1, 33, "Subsubsection",
 CellTags->"SymbolicSum2"],
Cell[1867874, 77086, 284, 6, 39, "Text",
 CellTags->"SymbolicSum2"]
}, Open  ]],
Cell[1868173, 77095, 61, 1, 39, "ObjectName",
 CellTags->"SymbolicSum3"],
Cell[CellGroupData[{
Cell[1868259, 77100, 63, 1, 33, "Subsubsection",
 CellTags->"SymbolicSum3"],
Cell[1868325, 77103, 292, 6, 39, "Text",
 CellTags->"SymbolicSum3"]
}, Open  ]],
Cell[1868632, 77112, 57, 1, 39, "ObjectName",
 CellTags->"Symmetrize"],
Cell[CellGroupData[{
Cell[1868714, 77117, 61, 1, 33, "Subsubsection",
 CellTags->"Symmetrize"],
Cell[1868778, 77120, 145, 4, 23, "Text",
 CellTags->"Symmetrize"],
Cell[1868926, 77126, 193, 8, 23, "Text",
 CellTags->"Symmetrize"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1869156, 77139, 58, 1, 33, "Subsubsection",
 CellTags->"Symmetrize"],
Cell[CellGroupData[{
Cell[1869239, 77144, 240, 8, 27, "Input",
 CellTags->"Symmetrize"],
Cell[1869482, 77154, 317, 11, 43, "Output",
 CellTags->"Symmetrize"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1869836, 77170, 260, 8, 27, "Input",
 CellTags->"Symmetrize"],
Cell[1870099, 77180, 652, 20, 43, "Output",
 CellTags->"Symmetrize"]
}, Open  ]]
}, Open  ]],
Cell[1870778, 77204, 61, 1, 39, "ObjectName",
 CellTags->{"TBox", "Tbox"}],
Cell[CellGroupData[{
Cell[1870864, 77209, 65, 1, 33, "Subsubsection",
 CellTags->{"TBox", "Tbox"}],
Cell[1870932, 77212, 262, 5, 39, "Text",
 CellTags->{"TBox", "Tbox"}]
}, Open  ]],
Cell[1871209, 77220, 45, 1, 39, "ObjectName",
 CellTags->"Tdec"],
Cell[CellGroupData[{
Cell[1871279, 77225, 55, 1, 33, "Subsubsection",
 CellTags->"Tdec"],
Cell[1871337, 77228, 256, 5, 39, "Text",
 CellTags->"Tdec"],
Cell[CellGroupData[{
Cell[1871618, 77237, 108, 3, 27, "Input",
 CellTags->"Tdec"],
Cell[1871729, 77242, 412, 11, 25, "Output",
 CellTags->"Tdec"]
}, Open  ]],
Cell[1872156, 77256, 389, 19, 23, "Text",
 CellTags->"Tdec"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1872582, 77280, 52, 1, 33, "Subsubsection",
 CellTags->"Tdec"],
Cell[1872637, 77283, 608, 22, 32, "Text",
 CellTags->"Tdec"],
Cell[CellGroupData[{
Cell[1873270, 77309, 202, 7, 27, "Input",
 CellTags->"Tdec"],
Cell[1873475, 77318, 556, 21, 44, "Output",
 CellTags->"Tdec"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1874068, 77344, 199, 7, 27, "Input",
 CellTags->"Tdec"],
Cell[1874270, 77353, 354, 14, 46, "Output",
 CellTags->"Tdec"]
}, Open  ]],
Cell[1874639, 77370, 776, 28, 25, "Text",
 CellTags->"Tdec"],
Cell[1875418, 77400, 529, 18, 27, "Input",
 CellTags->"Tdec"],
Cell[CellGroupData[{
Cell[1875972, 77422, 199, 7, 27, "Input",
 CellTags->"Tdec"],
Cell[1876174, 77431, 7304, 266, 96, "Output",
 CellTags->"Tdec"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1883515, 77702, 380, 13, 27, "Input",
 CellTags->"Tdec"],
Cell[1883898, 77717, 4966, 181, 71, "Output",
 CellTags->"Tdec"]
}, Open  ]],
Cell[1888879, 77901, 121, 4, 27, "Input",
 CellTags->"Tdec"]
}, Open  ]],
Cell[1889015, 77908, 65, 1, 39, "ObjectName",
 CellTags->"TensorFunction"],
Cell[CellGroupData[{
Cell[1889105, 77913, 65, 1, 33, "Subsubsection",
 CellTags->"TensorFunction"],
Cell[1889173, 77916, 360, 7, 39, "Text",
 CellTags->"TensorFunction"],
Cell[1889536, 77925, 191, 9, 23, "Text",
 CellTags->"TensorFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1889764, 77939, 62, 1, 33, "Subsubsection",
 CellTags->"TensorFunction"],
Cell[CellGroupData[{
Cell[1889851, 77944, 178, 4, 27, "Input",
 CellTags->"TensorFunction"],
Cell[1890032, 77950, 212, 6, 25, "Output",
 CellTags->"TensorFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1890281, 77961, 116, 3, 27, "Input",
 CellTags->"TensorFunction"],
Cell[1890400, 77966, 193, 4, 39, "Output",
 CellTags->"TensorFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1890630, 77975, 198, 6, 27, "Input",
 CellTags->"TensorFunction"],
Cell[1890831, 77983, 376, 14, 25, "Output",
 CellTags->"TensorFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1891244, 78002, 116, 3, 27, "Input",
 CellTags->"TensorFunction"],
Cell[1891363, 78007, 358, 10, 39, "Output",
 CellTags->"TensorFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1891758, 78022, 228, 7, 27, "Input",
 CellTags->"TensorFunction"],
Cell[1891989, 78031, 263, 8, 25, "Output",
 CellTags->"TensorFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1892289, 78044, 228, 7, 27, "Input",
 CellTags->"TensorFunction"],
Cell[1892520, 78053, 263, 8, 25, "Output",
 CellTags->"TensorFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1892820, 78066, 116, 3, 27, "Input",
 CellTags->"TensorFunction"],
Cell[1892939, 78071, 243, 7, 39, "Output",
 CellTags->"TensorFunction"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1893219, 78083, 118, 3, 27, "Input",
 CellTags->"TensorFunction"],
Cell[1893340, 78088, 129, 4, 25, "Output",
 CellTags->"TensorFunction"]
}, Open  ]],
Cell[1893484, 78095, 154, 4, 27, "Input",
 CellTags->"TensorFunction"]
}, Open  ]],
Cell[1893653, 78102, 41, 1, 39, "ObjectName",
 CellTags->"Tf"],
Cell[CellGroupData[{
Cell[1893719, 78107, 53, 1, 33, "Subsubsection",
 CellTags->"Tf"],
Cell[1893775, 78110, 214, 10, 26, "Text",
 CellTags->"Tf"],
Cell[1893992, 78122, 414, 18, 23, "Text",
 CellTags->"Tf"]
}, Open  ]],
Cell[1894421, 78143, 43, 1, 39, "ObjectName",
 CellTags->"TFi"],
Cell[CellGroupData[{
Cell[1894489, 78148, 54, 1, 33, "Subsubsection",
 CellTags->"TFi"],
Cell[CellGroupData[{
Cell[1894568, 78153, 72, 2, 27, "Input"],
Cell[1894643, 78157, 456, 10, 19, "Message"]
}, Open  ]],
Cell[1895114, 78170, 576, 10, 87, "Text",
 CellTags->"TFi"],
Cell[1895693, 78182, 237, 8, 23, "Text",
 CellTags->"TFi"],
Cell[1895933, 78192, 185, 4, 23, "Text",
 CellTags->"TFi"],
Cell[1896121, 78198, 266, 13, 23, "Text",
 CellTags->"TFi"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1896424, 78216, 51, 1, 33, "Subsubsection",
 CellTags->"TFi"],
Cell[CellGroupData[{
Cell[1896500, 78221, 506, 17, 27, "Input",
 CellTags->"TFi"],
Cell[1897009, 78240, 778, 24, 92, "Output",
 CellTags->"TFi"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1897824, 78269, 295, 10, 27, "Input",
 CellTags->"TFi"],
Cell[1898122, 78281, 333, 11, 29, "Output",
 CellTags->"TFi"]
}, Open  ]]
}, Open  ]],
Cell[1898482, 78296, 59, 1, 39, "ObjectName",
 CellTags->"ThreeVector"],
Cell[CellGroupData[{
Cell[1898566, 78301, 62, 1, 33, "Subsubsection",
 CellTags->"ThreeVector"],
Cell[1898631, 78304, 91, 1, 23, "Text",
 CellTags->"ThreeVector"],
Cell[1898725, 78307, 304, 13, 23, "Text",
 CellTags->"ThreeVector"]
}, Open  ]],
Cell[1899044, 78323, 43, 1, 39, "ObjectName",
 CellTags->"TID"],
Cell[CellGroupData[{
Cell[1899112, 78328, 54, 1, 33, "Subsubsection",
 CellTags->"TID"],
Cell[1899169, 78331, 80, 1, 23, "Text",
 CellTags->"TID"],
Cell[CellGroupData[{
Cell[1899274, 78336, 106, 3, 27, "Input",
 CellTags->"TID"],
Cell[1899383, 78341, 655, 15, 45, "Output",
 CellTags->"TID"]
}, Open  ]],
Cell[1900053, 78359, 293, 14, 23, "Text",
 CellTags->"TID"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1900383, 78378, 51, 1, 33, "Subsubsection",
 CellTags->"TID"],
Cell[CellGroupData[{
Cell[1900459, 78383, 374, 12, 27, "Input",
 CellTags->"TID"],
Cell[1900836, 78397, 532, 21, 49, "Output",
 CellTags->"TID"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1901405, 78423, 181, 6, 27, "Input",
 CellTags->"TID"],
Cell[1901589, 78431, 4307, 136, 65, "Output",
 CellTags->"TID"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1905933, 78572, 271, 9, 27, "Input",
 CellTags->"TID"],
Cell[1906207, 78583, 389, 16, 49, "Output",
 CellTags->"TID"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1906633, 78604, 123, 4, 27, "Input",
 CellTags->"TID"],
Cell[1906759, 78610, 627, 27, 49, "Output",
 CellTags->"TID"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1907423, 78642, 195, 6, 27, "Input",
 CellTags->"TID"],
Cell[1907621, 78650, 627, 27, 49, "Output",
 CellTags->"TID"]
}, Open  ]]
}, Open  ]],
Cell[1908275, 78681, 45, 1, 39, "ObjectName",
 CellTags->"TIDL"],
Cell[CellGroupData[{
Cell[1908345, 78686, 55, 1, 33, "Subsubsection",
 CellTags->"TIDL"],
Cell[1908403, 78689, 87, 1, 23, "Text",
 CellTags->"TIDL"],
Cell[1908493, 78692, 154, 8, 23, "Text",
 CellTags->"TIDL"]
}, Open  ]],
Cell[1908662, 78703, 52, 1, 33, "Subsubsection",
 CellTags->"TIDL"],
Cell[CellGroupData[{
Cell[1908739, 78708, 154, 5, 36, "Subsubsection",
 CellTags->"TIDL"],
Cell[1908896, 78715, 414, 13, 25, "Text",
 CellTags->"TIDL"],
Cell[CellGroupData[{
Cell[1909335, 78732, 202, 7, 27, "Input",
 CellTags->"TIDL"],
Cell[1909540, 78741, 465, 20, 49, "Output",
 CellTags->"TIDL"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1910054, 78767, 159, 5, 36, "Subsubsection",
 CellTags->"TIDL"],
Cell[CellGroupData[{
Cell[1910238, 78776, 312, 11, 27, "Input",
 CellTags->"TIDL"],
Cell[1910553, 78789, 1876, 74, 53, "Output",
 CellTags->"TIDL"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1912478, 78869, 154, 5, 36, "Subsubsection",
 CellTags->"TIDL"],
Cell[CellGroupData[{
Cell[1912657, 78878, 277, 10, 27, "Input",
 CellTags->"TIDL"],
Cell[1912937, 78890, 2812, 108, 51, "Output",
 CellTags->"TIDL"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1915798, 79004, 159, 5, 36, "Subsubsection",
 CellTags->"TIDL"],
Cell[CellGroupData[{
Cell[1915982, 79013, 387, 14, 27, "Input",
 CellTags->"TIDL"],
Cell[1916372, 79029, 24393, 841, 353, "Output",
 CellTags->"TIDL"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1940814, 79876, 165, 5, 36, "Subsubsection",
 CellTags->"TIDL"],
Cell[1940982, 79883, 434, 15, 27, "Input",
 CellTags->"TIDL"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1941453, 79903, 173, 5, 36, "Subsubsection",
 CellTags->"TIDL"],
Cell[1941629, 79910, 506, 17, 27, "Input",
 CellTags->"TIDL"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1942172, 79932, 154, 5, 36, "Subsubsection",
 CellTags->"TIDL"],
Cell[CellGroupData[{
Cell[1942351, 79941, 312, 11, 27, "Input",
 CellTags->"TIDL"],
Cell[1942666, 79954, 14684, 522, 149, "Output",
 CellTags->"TIDL"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1957399, 80482, 159, 5, 36, "Subsubsection",
 CellTags->"TIDL"],
Cell[1957561, 80489, 374, 13, 27, "Input",
 CellTags->"TIDL"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1957972, 80507, 165, 5, 36, "Subsubsection",
 CellTags->"TIDL"],
Cell[1958140, 80514, 444, 15, 27, "Input",
 CellTags->"TIDL"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1958621, 80534, 173, 5, 36, "Subsubsection",
 CellTags->"TIDL"],
Cell[1958797, 80541, 529, 18, 27, "Input",
 CellTags->"TIDL"],
Cell[CellGroupData[{
Cell[1959351, 80563, 240, 7, 27, "Input",
 CellTags->"TIDL"],
Cell[1959594, 80572, 161, 5, 25, "Output",
 CellTags->"TIDL"]
}, Open  ]]
}, Open  ]],
Cell[1959782, 80581, 65, 1, 39, "ObjectName",
 CellTags->"TimedIntegrate"],
Cell[CellGroupData[{
Cell[1959872, 80586, 65, 1, 33, "Subsubsection",
 CellTags->"TimedIntegrate"],
Cell[1959940, 80589, 225, 5, 39, "Text",
 CellTags->"TimedIntegrate"],
Cell[CellGroupData[{
Cell[1960190, 80598, 128, 3, 27, "Input",
 CellTags->"TimedIntegrate"],
Cell[1960321, 80603, 424, 13, 25, "Output",
 CellTags->"TimedIntegrate"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1960794, 80622, 62, 1, 33, "Subsubsection",
 CellTags->"TimedIntegrate"],
Cell[1960859, 80625, 73, 1, 23, "Text",
 CellTags->"TimedIntegrate"],
Cell[CellGroupData[{
Cell[1960957, 80630, 305, 9, 27, "Input",
 CellTags->"TimedIntegrate"],
Cell[1961265, 80641, 129, 4, 25, "Output",
 CellTags->"TimedIntegrate"]
}, Open  ]],
Cell[1961409, 80648, 59, 1, 23, "Text",
 CellTags->"TimedIntegrate"],
Cell[CellGroupData[{
Cell[1961493, 80653, 389, 11, 27, "Input",
 CellTags->"TimedIntegrate"],
Cell[1961885, 80666, 449, 14, 29, "Output",
 CellTags->"TimedIntegrate"]
}, Open  ]]
}, Open  ]],
Cell[1962361, 80684, 61, 1, 39, "ObjectName",
 CellTags->"TLI"],
Cell[CellGroupData[{
Cell[1962447, 80689, 54, 1, 33, "Subsubsection",
 CellTags->"TLI"],
Cell[1962504, 80692, 616, 12, 111, "Text",
 CellTags->"TLI"],
Cell[CellGroupData[{
Cell[1963145, 80708, 106, 3, 27, "Input",
 CellTags->"TLI"],
Cell[1963254, 80713, 229, 8, 25, "Output",
 CellTags->"TLI"]
}, Open  ]],
Cell[1963498, 80724, 168, 9, 23, "Text",
 CellTags->"TLI"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1963703, 80738, 51, 1, 33, "Subsubsection",
 CellTags->"TLI"],
Cell[1963757, 80741, 70, 2, 27, "Input",
 CellTags->"TLI"]
}, Open  ]],
Cell[1963842, 80746, 65, 1, 39, "ObjectName",
 CellTags->"TLIFP"],
Cell[CellGroupData[{
Cell[1963932, 80751, 56, 1, 33, "Subsubsection",
 CellTags->"TLIFP"],
Cell[1963991, 80754, 93, 1, 23, "Text",
 CellTags->"TLIFP"],
Cell[CellGroupData[{
Cell[1964109, 80759, 110, 3, 27, "Input",
 CellTags->"TLIFP"],
Cell[1964222, 80764, 425, 12, 25, "Output",
 CellTags->"TLIFP"]
}, Open  ]],
Cell[1964662, 80779, 161, 9, 23, "Text",
 CellTags->"TLIFP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1964860, 80793, 53, 1, 33, "Subsubsection",
 CellTags->"TLIFP"],
Cell[1964916, 80796, 72, 2, 27, "Input",
 CellTags->"TLIFP"]
}, Open  ]],
Cell[1965003, 80801, 67, 1, 39, "ObjectName",
 CellTags->"TLIHYP"],
Cell[CellGroupData[{
Cell[1965095, 80806, 57, 1, 33, "Subsubsection",
 CellTags->"TLIHYP"],
Cell[1965155, 80809, 136, 4, 23, "Text",
 CellTags->"TLIHYP"],
Cell[CellGroupData[{
Cell[1965316, 80817, 112, 3, 27, "Input",
 CellTags->"TLIHYP"],
Cell[1965431, 80822, 241, 8, 25, "Output",
 CellTags->"TLIHYP"]
}, Open  ]],
Cell[1965687, 80833, 162, 9, 23, "Text",
 CellTags->"TLIHYP"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1965886, 80847, 54, 1, 33, "Subsubsection",
 CellTags->"TLIHYP"],
Cell[1965943, 80850, 73, 2, 27, "Input",
 CellTags->"TLIHYP"]
}, Open  ]],
Cell[1966031, 80855, 45, 1, 39, "ObjectName",
 CellTags->"TLI2"],
Cell[CellGroupData[{
Cell[1966101, 80860, 55, 1, 33, "Subsubsection",
 CellTags->"TLI2"],
Cell[1966159, 80863, 83, 1, 23, "Text",
 CellTags->"TLI2"],
Cell[1966245, 80866, 160, 9, 23, "Text",
 CellTags->"TLI2"]
}, Open  ]],
Cell[1966420, 80878, 67, 1, 39, "ObjectName",
 CellTags->"TLI2FC"],
Cell[CellGroupData[{
Cell[1966512, 80883, 57, 1, 33, "Subsubsection",
 CellTags->"TLI2FC"],
Cell[1966572, 80886, 109, 3, 23, "Text",
 CellTags->"TLI2FC"],
Cell[CellGroupData[{
Cell[1966706, 80893, 112, 3, 27, "Input",
 CellTags->"TLI2FC"],
Cell[1966821, 80898, 355, 11, 25, "Output",
 CellTags->"TLI2FC"]
}, Open  ]],
Cell[1967191, 80912, 262, 13, 23, "Text",
 CellTags->"TLI2FC"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1967490, 80930, 54, 1, 33, "Subsubsection",
 CellTags->"TLI2FC"],
Cell[1967547, 80933, 73, 2, 27, "Input",
 CellTags->"TLI2FC"]
}, Open  ]],
Cell[1967635, 80938, 65, 1, 39, "ObjectName",
 CellTags->"ToDistribution"],
Cell[CellGroupData[{
Cell[1967725, 80943, 65, 1, 33, "Subsubsection",
 CellTags->"ToDistribution"],
Cell[1967793, 80946, 424, 7, 55, "Text",
 CellTags->"ToDistribution"],
Cell[CellGroupData[{
Cell[1968242, 80957, 128, 3, 27, "Input",
 CellTags->"ToDistribution"],
Cell[1968373, 80962, 189, 6, 25, "Output",
 CellTags->"ToDistribution"]
}, Open  ]],
Cell[1968577, 80971, 209, 9, 23, "Text",
 CellTags->"ToDistribution"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1968823, 80985, 62, 1, 33, "Subsubsection",
 CellTags->"ToDistribution"],
Cell[CellGroupData[{
Cell[1968910, 80990, 217, 6, 27, "Input",
 CellTags->"ToDistribution"],
Cell[1969130, 80998, 197, 6, 25, "Output",
 CellTags->"ToDistribution"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1969364, 81009, 277, 9, 27, "Input",
 CellTags->"ToDistribution"],
Cell[1969644, 81020, 1338, 48, 52, "Output",
 CellTags->"ToDistribution"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1971019, 81073, 206, 5, 27, "Input",
 CellTags->"ToDistribution"],
Cell[1971228, 81080, 189, 6, 25, "Output",
 CellTags->"ToDistribution"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1971454, 81091, 277, 9, 27, "Input",
 CellTags->"ToDistribution"],
Cell[1971734, 81102, 1380, 50, 50, "Output",
 CellTags->"ToDistribution"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1973151, 81157, 461, 14, 29, "Input",
 CellTags->"ToDistribution"],
Cell[1973615, 81173, 371, 13, 27, "Output",
 CellTags->"ToDistribution"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1974023, 81191, 118, 3, 27, "Input",
 CellTags->"ToDistribution"],
Cell[1974144, 81196, 334, 9, 25, "Output",
 CellTags->"ToDistribution"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1974515, 81210, 409, 13, 27, "Input",
 CellTags->"ToDistribution"],
Cell[1974927, 81225, 371, 13, 27, "Output",
 CellTags->"ToDistribution"]
}, Open  ]]
}, Open  ]],
Cell[1975325, 81242, 69, 1, 39, "ObjectName",
 CellTags->"ToHypergeometric"],
Cell[CellGroupData[{
Cell[1975419, 81247, 67, 1, 33, "Subsubsection",
 CellTags->"ToHypergeometric"],
Cell[1975489, 81250, 1686, 67, 39, "Text",
 CellTags->"ToHypergeometric"],
Cell[1977178, 81319, 479, 19, 23, "Text",
 CellTags->"ToHypergeometric"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1977694, 81343, 64, 1, 33, "Subsubsection",
 CellTags->"ToHypergeometric"],
Cell[CellGroupData[{
Cell[1977783, 81348, 395, 13, 29, "Input",
 CellTags->"ToHypergeometric"],
Cell[1978181, 81363, 489, 15, 45, "Output",
 CellTags->"ToHypergeometric"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1978707, 81383, 488, 16, 29, "Input",
 CellTags->"ToHypergeometric"],
Cell[1979198, 81401, 356, 13, 45, "Output",
 CellTags->"ToHypergeometric"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1979591, 81419, 395, 13, 29, "Input",
 CellTags->"ToHypergeometric"],
Cell[1979989, 81434, 552, 17, 51, "Output",
 CellTags->"ToHypergeometric"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1980578, 81456, 488, 16, 29, "Input",
 CellTags->"ToHypergeometric"],
Cell[1981069, 81474, 431, 15, 51, "Output",
 CellTags->"ToHypergeometric"]
}, Open  ]]
}, Open  ]],
Cell[1981527, 81493, 51, 1, 39, "ObjectName",
 CellTags->"ToLarin"],
Cell[CellGroupData[{
Cell[1981603, 81498, 58, 1, 33, "Subsubsection",
 CellTags->"ToLarin"],
Cell[1981664, 81501, 605, 19, 23, "Text",
 CellTags->"ToLarin"],
Cell[1982272, 81522, 163, 9, 23, "Text",
 CellTags->"ToLarin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1982472, 81536, 55, 1, 33, "Subsubsection",
 CellTags->"ToLarin"],
Cell[CellGroupData[{
Cell[1982552, 81541, 229, 6, 27, "Input",
 CellTags->"ToLarin"],
Cell[1982784, 81549, 389, 15, 27, "Output",
 CellTags->"ToLarin"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1983210, 81569, 108, 3, 27, "Input",
 CellTags->"ToLarin"],
Cell[1983321, 81574, 1097, 45, 43, "Output",
 CellTags->"ToLarin"]
}, Open  ]]
}, Open  ]],
Cell[1984445, 81623, 47, 1, 39, "ObjectName",
 CellTags->"ToTFi"],
Cell[CellGroupData[{
Cell[1984517, 81628, 56, 1, 33, "Subsubsection",
 CellTags->"ToTFi"],
Cell[1984576, 81631, 272, 5, 39, "Text",
 CellTags->"ToTFi"],
Cell[1984851, 81638, 262, 13, 23, "Text",
 CellTags->"ToTFi"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1985150, 81656, 53, 1, 33, "Subsubsection",
 CellTags->"ToTFi"],
Cell[CellGroupData[{
Cell[1985228, 81661, 333, 11, 27, "Input",
 CellTags->"ToTFi"],
Cell[1985564, 81674, 1870, 49, 49, "Output",
 CellTags->"ToTFi"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1987471, 81728, 149, 4, 27, "Input",
 CellTags->"ToTFi"],
Cell[1987623, 81734, 2126, 54, 50, "Output",
 CellTags->"ToTFi"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1989786, 81793, 107, 3, 27, "Input",
 CellTags->"ToTFi"],
Cell[1989896, 81798, 491, 16, 39, "Output",
 CellTags->"ToTFi"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1990424, 81819, 468, 15, 27, "Input",
 CellTags->"ToTFi"],
Cell[1990895, 81836, 916, 33, 49, "Output",
 CellTags->"ToTFi"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1991860, 81875, 41, 1, 39, "ObjectName",
 CellTags->"TR"],
Cell[1991904, 81878, 100, 3, 25, "Output",
 CellTags->"TR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1992041, 81886, 53, 1, 33, "Subsubsection",
 CellTags->"TR"],
Cell[1992097, 81889, 420, 12, 39, "Text",
 CellTags->"TR"],
Cell[CellGroupData[{
Cell[1992542, 81905, 104, 3, 27, "Input",
 CellTags->"TR"],
Cell[1992649, 81910, 761, 18, 45, "Output",
 CellTags->"TR"]
}, Open  ]],
Cell[1993425, 81931, 536, 23, 23, "Text",
 CellTags->"TR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1993998, 81959, 50, 1, 33, "Subsubsection",
 CellTags->"TR"],
Cell[CellGroupData[{
Cell[1994073, 81964, 129, 4, 27, "Input",
 CellTags->"TR"],
Cell[1994205, 81970, 194, 6, 25, "Output",
 CellTags->"TR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1994436, 81981, 98, 3, 27, "Input",
 CellTags->"TR"],
Cell[1994537, 81986, 175, 6, 25, "Output",
 CellTags->"TR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1994749, 81997, 375, 12, 27, "Input",
 CellTags->"TR"],
Cell[1995127, 82011, 1257, 50, 29, "Output",
 CellTags->"TR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1996421, 82066, 205, 6, 27, "Input",
 CellTags->"TR"],
Cell[1996629, 82074, 559, 23, 25, "Output",
 CellTags->"TR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1997225, 82102, 240, 7, 27, "Input",
 CellTags->"TR"],
Cell[1997468, 82111, 8363, 321, 47, "Output",
 CellTags->"TR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2005868, 82437, 421, 13, 27, "Input",
 CellTags->"TR"],
Cell[2006292, 82452, 10947, 412, 66, "Output",
 CellTags->"TR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2017276, 82869, 171, 5, 27, "Input",
 CellTags->"TR"],
Cell[2017450, 82876, 991, 39, 25, "Output",
 CellTags->"TR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2018478, 82920, 444, 14, 27, "Input",
 CellTags->"TR"],
Cell[2018925, 82936, 342, 13, 29, "Output",
 CellTags->"TR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2019304, 82954, 224, 7, 27, "Input",
 CellTags->"TR"],
Cell[2019531, 82963, 180, 6, 25, "Output",
 CellTags->"TR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2019748, 82974, 104, 3, 27, "Input",
 CellTags->"TR"],
Cell[2019855, 82979, 173, 5, 39, "Output",
 CellTags->"TR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2020065, 82989, 347, 10, 27, "Input",
 CellTags->"TR"],
Cell[2020415, 83001, 190, 6, 25, "Output",
 CellTags->"TR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2020642, 83012, 104, 3, 27, "Input",
 CellTags->"TR"],
Cell[2020749, 83017, 183, 5, 39, "Output",
 CellTags->"TR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2020969, 83027, 339, 11, 27, "Input",
 CellTags->"TR"],
Cell[2021311, 83040, 428, 16, 27, "Output",
 CellTags->"TR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2021776, 83061, 214, 6, 27, "Input",
 CellTags->"TR"],
Cell[2021993, 83069, 208, 7, 25, "Output",
 CellTags->"TR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2022238, 83081, 213, 6, 27, "Input",
 CellTags->"TR"],
Cell[2022454, 83089, 208, 7, 25, "Output",
 CellTags->"TR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2022699, 83101, 214, 6, 27, "Input",
 CellTags->"TR"],
Cell[2022916, 83109, 99, 3, 25, "Output",
 CellTags->"TR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2023052, 83117, 213, 6, 27, "Input",
 CellTags->"TR"],
Cell[2023268, 83125, 99, 3, 25, "Output",
 CellTags->"TR"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2023404, 83133, 139, 4, 27, "Input"],
Cell[2023546, 83139, 150, 5, 25, "Output"]
}, Open  ]],
Cell[2023711, 83147, 57, 2, 23, "Text"],
Cell[CellGroupData[{
Cell[2023793, 83153, 71, 2, 27, "Input"],
Cell[2023867, 83157, 644, 13, 155, "Print",
 CellTags->"Info3522766033-2743550"]
}, Open  ]],
Cell[2024526, 83173, 1240, 36, 88, "Input"],
Cell[CellGroupData[{
Cell[2025791, 83213, 80, 2, 27, "Input"],
Cell[2025874, 83217, 218, 5, 21, "Print"],
Cell[2026095, 83224, 300, 11, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2026432, 83240, 80, 2, 27, "Input"],
Cell[2026515, 83244, 215, 5, 21, "Print"],
Cell[2026733, 83251, 618, 20, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2027388, 83276, 81, 2, 27, "Input"],
Cell[2027472, 83280, 216, 5, 21, "Print"],
Cell[2027691, 83287, 787, 25, 29, "Output"]
}, Open  ]],
Cell[2028493, 83315, 143, 5, 27, "Input",
 CellTags->"TR"]
}, Open  ]],
Cell[2028651, 83323, 65, 1, 39, "ObjectName",
 CellTags->"TraceDimension"],
Cell[CellGroupData[{
Cell[2028741, 83328, 65, 1, 33, "Subsubsection",
 CellTags->"TraceDimension"],
Cell[2028809, 83331, 142, 4, 23, "Text",
 CellTags->"TraceDimension"],
Cell[2028954, 83337, 200, 9, 23, "Text",
 CellTags->"TraceDimension"]
}, Open  ]],
Cell[2029169, 83349, 57, 1, 39, "ObjectName",
 CellTags->"TraceOfOne"],
Cell[CellGroupData[{
Cell[2029251, 83354, 61, 1, 33, "Subsubsection",
 CellTags->"TraceOfOne"],
Cell[2029315, 83357, 149, 4, 23, "Text",
 CellTags->"TraceOfOne"],
Cell[2029467, 83363, 273, 13, 23, "Text",
 CellTags->"TraceOfOne"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2029777, 83381, 58, 1, 33, "Subsubsection",
 CellTags->"TraceOfOne"],
Cell[CellGroupData[{
Cell[2029860, 83386, 273, 7, 27, "Input",
 CellTags->"TraceOfOne"],
Cell[2030136, 83395, 109, 3, 25, "Output",
 CellTags->"TraceOfOne"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2030282, 83403, 272, 7, 27, "Input",
 CellTags->"TraceOfOne"],
Cell[2030557, 83412, 109, 3, 25, "Output",
 CellTags->"TraceOfOne"]
}, Open  ]]
}, Open  ]],
Cell[2030693, 83419, 47, 1, 39, "ObjectName",
 CellTags->"Trick"],
Cell[CellGroupData[{
Cell[2030765, 83424, 56, 1, 33, "Subsubsection",
 CellTags->"Trick"],
Cell[2030824, 83427, 174, 4, 23, "Text",
 CellTags->"Trick"],
Cell[2031001, 83433, 625, 29, 23, "Text",
 CellTags->"Trick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2031663, 83467, 62, 1, 34, "Subsubsection",
 CellTags->"Trick"],
Cell[2031728, 83470, 376, 15, 26, "Text",
 CellTags->"Trick"],
Cell[CellGroupData[{
Cell[2032129, 83489, 350, 11, 27, "Input",
 CellTags->"Trick"],
Cell[2032482, 83502, 264, 10, 27, "Output",
 CellTags->"Trick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2032783, 83517, 330, 11, 27, "Input",
 CellTags->"Trick"],
Cell[2033116, 83530, 426, 16, 27, "Output",
 CellTags->"Trick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2033579, 83551, 104, 3, 27, "Input",
 CellTags->"Trick"],
Cell[2033686, 83556, 527, 22, 27, "Output",
 CellTags->"Trick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2034250, 83583, 227, 6, 27, "Input",
 CellTags->"Trick"],
Cell[2034480, 83591, 391, 15, 27, "Output",
 CellTags->"Trick"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2034908, 83611, 133, 4, 27, "Input",
 CellTags->"Trick"],
Cell[2035044, 83617, 213, 6, 39, "Output",
 CellTags->"Trick"]
}, Open  ]]
}, Open  ]],
Cell[2035284, 83627, 65, 1, 39, "ObjectName",
 CellTags->"TrickIntegrate"],
Cell[CellGroupData[{
Cell[2035374, 83632, 65, 1, 33, "Subsubsection",
 CellTags->"TrickIntegrate"],
Cell[2035442, 83635, 483, 8, 55, "Text",
 CellTags->"TrickIntegrate"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2035962, 83648, 62, 1, 33, "Subsubsection",
 CellTags->"TrickIntegrate"],
Cell[CellGroupData[{
Cell[2036049, 83653, 364, 12, 27, "Input",
 CellTags->"TrickIntegrate"],
Cell[2036416, 83667, 517, 18, 29, "Output",
 CellTags->"TrickIntegrate"]
}, Open  ]]
}, Open  ]],
Cell[2036960, 83689, 67, 1, 39, "ObjectName",
 CellTags->"TrickMandelstam"],
Cell[CellGroupData[{
Cell[2037052, 83694, 66, 1, 33, "Subsubsection",
 CellTags->"TrickMandelstam"],
Cell[2037121, 83697, 1340, 55, 43, "Text",
 CellTags->"TrickMandelstam"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2038498, 83757, 63, 1, 33, "Subsubsection",
 CellTags->"TrickMandelstam"],
Cell[CellGroupData[{
Cell[2038586, 83762, 528, 18, 29, "Input",
 CellTags->"TrickMandelstam"],
Cell[2039117, 83782, 250, 9, 29, "Output",
 CellTags->"TrickMandelstam"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2039404, 83796, 568, 17, 27, "Input",
 CellTags->"TrickMandelstam"],
Cell[2039975, 83815, 235, 8, 27, "Output",
 CellTags->"TrickMandelstam"]
}, Open  ]]
}, Open  ]],
Cell[2040237, 83827, 43, 1, 39, "ObjectName",
 CellTags->"Tr2"],
Cell[CellGroupData[{
Cell[2040305, 83832, 54, 1, 33, "Subsubsection",
 CellTags->"Tr2"],
Cell[2040362, 83835, 347, 6, 55, "Text",
 CellTags->"Tr2"],
Cell[CellGroupData[{
Cell[2040734, 83845, 106, 3, 27, "Input",
 CellTags->"Tr2"],
Cell[2040843, 83850, 168, 6, 25, "Output",
 CellTags->"Tr2"]
}, Open  ]],
Cell[2041026, 83859, 593, 28, 23, "Text",
 CellTags->"Tr2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2041656, 83892, 51, 1, 33, "Subsubsection",
 CellTags->"Tr2"],
Cell[CellGroupData[{
Cell[2041732, 83897, 164, 4, 27, "Input"],
Cell[2041899, 83903, 548, 20, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2042484, 83928, 187, 6, 27, "Input",
 CellTags->"Tr2"],
Cell[2042674, 83936, 156, 5, 28, "Output",
 CellTags->"Tr2"]
}, Open  ]]
}, Open  ]],
Cell[2042857, 83945, 116, 2, 39, "ObjectName",
 CellTags->"Twist2AlienOperator"],
Cell[CellGroupData[{
Cell[2042998, 83951, 70, 1, 33, "Subsubsection",
 CellTags->"Twist2AlienOperator"],
Cell[2043071, 83954, 194, 4, 23, "Text",
 CellTags->"Twist2AlienOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2043302, 83963, 67, 1, 33, "Subsubsection",
 CellTags->"Twist2AlienOperator"],
Cell[CellGroupData[{
Cell[2043394, 83968, 160, 4, 27, "Input",
 CellTags->"Twist2AlienOperator"],
Cell[2043557, 83974, 887, 30, 51, "Output",
 CellTags->"Twist2AlienOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2044481, 84009, 246, 7, 27, "Input",
 CellTags->"Twist2AlienOperator"],
Cell[2044730, 84018, 3113, 103, 56, "Output",
 CellTags->"Twist2AlienOperator"]
}, Open  ]]
}, Open  ]],
Cell[2047870, 84125, 120, 2, 39, "ObjectName",
 CellTags->"Twist2CounterOperator"],
Cell[CellGroupData[{
Cell[2048015, 84131, 72, 1, 33, "Subsubsection",
 CellTags->"Twist2CounterOperator"],
Cell[2048090, 84134, 239, 5, 39, "Text",
 CellTags->"Twist2CounterOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2048366, 84144, 69, 1, 33, "Subsubsection",
 CellTags->"Twist2CounterOperator"],
Cell[CellGroupData[{
Cell[2048460, 84149, 204, 5, 27, "Input",
 CellTags->"Twist2CounterOperator"],
Cell[2048667, 84156, 4002, 136, 83, "Output",
 CellTags->"Twist2CounterOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2052706, 84297, 159, 4, 27, "Input",
 CellTags->"Twist2CounterOperator"],
Cell[2052868, 84303, 1020, 35, 51, "Output",
 CellTags->"Twist2CounterOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2053925, 84343, 242, 6, 27, "Input",
 CellTags->"Twist2CounterOperator"],
Cell[2054170, 84351, 2610, 89, 57, "Output",
 CellTags->"Twist2CounterOperator"]
}, Open  ]]
}, Open  ]],
Cell[2056807, 84444, 75, 1, 39, "ObjectName",
 CellTags->"Twist2GluonOperator"],
Cell[CellGroupData[{
Cell[2056907, 84449, 70, 1, 33, "Subsubsection",
 CellTags->"Twist2GluonOperator"],
Cell[2056980, 84452, 964, 15, 119, "Text",
 CellTags->"Twist2GluonOperator"],
Cell[2057947, 84469, 223, 9, 23, "Text",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2058207, 84483, 99, 1, 33, "Subsubsection",
 CellTags->"Twist2GluonOperator"],
Cell[CellGroupData[{
Cell[2058331, 84488, 352, 8, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2058686, 84498, 444, 12, 25, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[2059145, 84513, 62, 1, 23, "Text",
 CellTags->"Twist2GluonOperator"],
Cell[CellGroupData[{
Cell[2059232, 84518, 271, 8, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2059506, 84528, 894, 35, 31, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2060437, 84568, 321, 9, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2060761, 84579, 1120, 45, 29, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2061918, 84629, 221, 6, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2062142, 84637, 336, 12, 31, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2062515, 84654, 271, 7, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2062789, 84663, 705, 28, 27, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[2063509, 84694, 62, 1, 23, "Text",
 CellTags->"Twist2GluonOperator"],
Cell[CellGroupData[{
Cell[2063596, 84699, 355, 10, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2063954, 84711, 1193, 48, 31, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2065184, 84764, 325, 10, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2065512, 84776, 492, 18, 31, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2066041, 84799, 375, 11, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2066419, 84812, 11308, 411, 130, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[2077742, 85226, 62, 1, 23, "Text",
 CellTags->"Twist2GluonOperator"],
Cell[CellGroupData[{
Cell[2077829, 85231, 431, 12, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2078263, 85245, 4976, 185, 31, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2083276, 85435, 391, 12, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2083670, 85449, 606, 22, 31, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2084313, 85476, 441, 13, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2084757, 85491, 24305, 869, 373, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2109111, 86366, 100, 1, 33, "Subsubsection",
 CellTags->"Twist2GluonOperator"],
Cell[CellGroupData[{
Cell[2109236, 86371, 268, 6, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2109507, 86379, 444, 12, 25, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[2109966, 86394, 62, 1, 23, "Text",
 CellTags->"Twist2GluonOperator"],
Cell[CellGroupData[{
Cell[2110053, 86399, 271, 8, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2110327, 86409, 904, 36, 43, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2111268, 86450, 321, 9, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2111592, 86461, 2656, 102, 43, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2114285, 86568, 221, 6, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2114509, 86576, 336, 12, 31, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2114882, 86593, 271, 7, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2115156, 86602, 2231, 84, 29, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[2117402, 86689, 62, 1, 23, "Text",
 CellTags->"Twist2GluonOperator"],
Cell[CellGroupData[{
Cell[2117489, 86694, 355, 10, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2117847, 86706, 1267, 50, 43, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2119151, 86761, 325, 10, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2119479, 86773, 492, 18, 31, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2120008, 86796, 375, 11, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2120386, 86809, 16342, 587, 204, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[2136743, 87399, 62, 1, 23, "Text",
 CellTags->"Twist2GluonOperator"],
Cell[CellGroupData[{
Cell[2136830, 87404, 431, 12, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2137264, 87418, 4986, 186, 43, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2142287, 87609, 391, 12, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2142681, 87623, 606, 22, 31, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2143324, 87650, 441, 13, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2143768, 87665, 31861, 1141, 450, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2175678, 88812, 76, 1, 33, "Subsubsection",
 CellTags->"Twist2GluonOperator"],
Cell[2175757, 88815, 97, 1, 23, "Text",
 CellTags->"Twist2GluonOperator"],
Cell[2175857, 88818, 295, 7, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2176155, 88827, 380, 11, 27, "Input",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2176572, 88843, 102, 1, 33, "Subsubsection",
 CellTags->"Twist2GluonOperator"],
Cell[CellGroupData[{
Cell[2176699, 88848, 284, 6, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2176986, 88856, 443, 12, 25, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[2177444, 88871, 62, 1, 23, "Text",
 CellTags->"Twist2GluonOperator"],
Cell[CellGroupData[{
Cell[2177531, 88876, 320, 10, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2177854, 88888, 3609, 129, 43, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[2181478, 89020, 62, 1, 23, "Text",
 CellTags->"Twist2GluonOperator"],
Cell[CellGroupData[{
Cell[2181565, 89025, 355, 10, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2181923, 89037, 54187, 1690, 830, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[2236125, 90730, 62, 1, 23, "Text",
 CellTags->"Twist2GluonOperator"],
Cell[CellGroupData[{
Cell[2236212, 90735, 482, 13, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2236697, 90750, 4976, 185, 31, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2241722, 90941, 104, 1, 33, "Subsubsection",
 CellTags->"Twist2GluonOperator"],
Cell[CellGroupData[{
Cell[2241851, 90946, 284, 6, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2242138, 90954, 443, 12, 25, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[2242596, 90969, 62, 1, 23, "Text",
 CellTags->"Twist2GluonOperator"],
Cell[CellGroupData[{
Cell[2242683, 90974, 320, 10, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2243006, 90986, 3074, 116, 43, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[2246095, 91105, 62, 1, 23, "Text",
 CellTags->"Twist2GluonOperator"],
Cell[2246160, 91108, 380, 11, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[CellGroupData[{
Cell[2246565, 91123, 325, 10, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2246893, 91135, 3075, 116, 43, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2250005, 91256, 375, 11, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2250383, 91269, 3075, 116, 43, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[2253473, 91388, 62, 1, 23, "Text",
 CellTags->"Twist2GluonOperator"],
Cell[CellGroupData[{
Cell[2253560, 91393, 482, 13, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2254045, 91408, 4986, 186, 43, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[2259046, 91597, 78, 1, 23, "Text",
 CellTags->"Twist2GluonOperator"],
Cell[CellGroupData[{
Cell[2259149, 91602, 520, 16, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2259672, 91620, 10907, 376, 148, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]],
Cell[2270594, 91999, 109, 3, 23, "Text",
 CellTags->"Twist2GluonOperator"],
Cell[2270706, 92004, 295, 7, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[CellGroupData[{
Cell[2271026, 92015, 428, 13, 27, "Input",
 CellTags->"Twist2GluonOperator"],
Cell[2271457, 92030, 9245, 285, 168, "Output",
 CellTags->"Twist2GluonOperator"]
}, Open  ]]
}, Open  ]],
Cell[2280729, 92319, 75, 1, 39, "ObjectName",
 CellTags->"Twist2QuarkOperator"],
Cell[CellGroupData[{
Cell[2280829, 92324, 70, 1, 33, "Subsubsection",
 CellTags->"Twist2QuarkOperator"],
Cell[2280902, 92327, 980, 15, 119, "Text",
 CellTags->"Twist2QuarkOperator"],
Cell[2281885, 92344, 223, 9, 23, "Text",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]],
Cell[2282123, 92356, 67, 1, 33, "Subsubsection",
 CellTags->"Twist2QuarkOperator"],
Cell[CellGroupData[{
Cell[2282215, 92361, 98, 1, 33, "Subsubsection",
 CellTags->"Twist2QuarkOperator"],
Cell[CellGroupData[{
Cell[2282338, 92366, 268, 6, 27, "Input",
 CellTags->"Twist2QuarkOperator"],
Cell[2282609, 92374, 443, 12, 25, "Output",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]],
Cell[2283067, 92389, 75, 1, 23, "Text",
 CellTags->"Twist2QuarkOperator"],
Cell[CellGroupData[{
Cell[2283167, 92394, 156, 4, 27, "Input",
 CellTags->"Twist2QuarkOperator"],
Cell[2283326, 92400, 600, 21, 27, "Output",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]],
Cell[2283941, 92424, 81, 1, 23, "Text",
 CellTags->"Twist2QuarkOperator"],
Cell[CellGroupData[{
Cell[2284047, 92429, 305, 9, 27, "Input",
 CellTags->"Twist2QuarkOperator"],
Cell[2284355, 92440, 1581, 57, 53, "Output",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]],
Cell[2285951, 92500, 87, 1, 23, "Text",
 CellTags->"Twist2QuarkOperator"],
Cell[CellGroupData[{
Cell[2286063, 92505, 380, 11, 27, "Input",
 CellTags->"Twist2QuarkOperator"],
Cell[2286446, 92518, 4917, 163, 109, "Output",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2291412, 92687, 100, 1, 33, "Subsubsection",
 CellTags->"Twist2QuarkOperator"],
Cell[CellGroupData[{
Cell[2291537, 92692, 273, 6, 27, "Input",
 CellTags->"Twist2QuarkOperator"],
Cell[2291813, 92700, 443, 12, 25, "Output",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]],
Cell[2292271, 92715, 75, 1, 23, "Text",
 CellTags->"Twist2QuarkOperator"],
Cell[CellGroupData[{
Cell[2292371, 92720, 156, 4, 27, "Input",
 CellTags->"Twist2QuarkOperator"],
Cell[2292530, 92726, 481, 17, 27, "Output",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]],
Cell[2293026, 92746, 81, 1, 23, "Text",
 CellTags->"Twist2QuarkOperator"],
Cell[CellGroupData[{
Cell[2293132, 92751, 305, 9, 27, "Input",
 CellTags->"Twist2QuarkOperator"],
Cell[2293440, 92762, 1492, 54, 53, "Output",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]],
Cell[2294947, 92819, 87, 1, 23, "Text",
 CellTags->"Twist2QuarkOperator"],
Cell[CellGroupData[{
Cell[2295059, 92824, 380, 11, 27, "Input",
 CellTags->"Twist2QuarkOperator"],
Cell[2295442, 92837, 4776, 159, 78, "Output",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]],
Cell[2300233, 92999, 93, 1, 23, "Text",
 CellTags->"Twist2QuarkOperator"],
Cell[CellGroupData[{
Cell[2300351, 93004, 197, 6, 27, "Input",
 CellTags->"Twist2QuarkOperator"],
Cell[2300551, 93012, 263, 8, 39, "Output",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2300851, 93025, 376, 10, 27, "Input",
 CellTags->"Twist2QuarkOperator"],
Cell[2301230, 93037, 1971, 72, 52, "Output",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2303238, 93114, 449, 12, 27, "Input",
 CellTags->"Twist2QuarkOperator"],
Cell[2303690, 93128, 9405, 298, 101, "Output",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2313144, 93432, 102, 1, 33, "Subsubsection",
 CellTags->"Twist2QuarkOperator"],
Cell[CellGroupData[{
Cell[2313271, 93437, 269, 6, 27, "Input",
 CellTags->"Twist2QuarkOperator"],
Cell[2313543, 93445, 444, 12, 25, "Output",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]],
Cell[2314002, 93460, 178, 4, 23, "Text",
 CellTags->"Twist2QuarkOperator"],
Cell[2314183, 93466, 275, 5, 39, "Text",
 CellTags->"Twist2QuarkOperator"],
Cell[CellGroupData[{
Cell[2314483, 93475, 205, 6, 27, "Input",
 CellTags->"Twist2QuarkOperator"],
Cell[2314691, 93483, 800, 28, 27, "Output",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]],
Cell[2315506, 93514, 100, 1, 23, "Text",
 CellTags->"Twist2QuarkOperator"],
Cell[CellGroupData[{
Cell[2315631, 93519, 305, 9, 27, "Input",
 CellTags->"Twist2QuarkOperator"],
Cell[2315939, 93530, 2305, 78, 53, "Output",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]],
Cell[2318259, 93611, 87, 1, 23, "Text",
 CellTags->"Twist2QuarkOperator"],
Cell[CellGroupData[{
Cell[2318371, 93616, 156, 4, 27, "Input",
 CellTags->"Twist2QuarkOperator"],
Cell[2318530, 93622, 1102, 33, 61, "Output",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2319681, 93661, 104, 1, 33, "Subsubsection",
 CellTags->"Twist2QuarkOperator"],
Cell[CellGroupData[{
Cell[2319810, 93666, 269, 6, 27, "Input",
 CellTags->"Twist2QuarkOperator"],
Cell[2320082, 93674, 444, 12, 25, "Output",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]],
Cell[2320541, 93689, 75, 1, 23, "Text",
 CellTags->"Twist2QuarkOperator"],
Cell[CellGroupData[{
Cell[2320641, 93694, 205, 6, 27, "Input",
 CellTags->"Twist2QuarkOperator"],
Cell[2320849, 93702, 800, 28, 27, "Output",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]],
Cell[2321664, 93733, 81, 1, 23, "Text",
 CellTags->"Twist2QuarkOperator"],
Cell[CellGroupData[{
Cell[2321770, 93738, 305, 9, 27, "Input",
 CellTags->"Twist2QuarkOperator"],
Cell[2322078, 93749, 2305, 78, 53, "Output",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]],
Cell[2324398, 93830, 210, 6, 27, "Input",
 CellTags->"Twist2QuarkOperator"]
}, Open  ]],
Cell[2324623, 93839, 75, 1, 39, "ObjectName",
 CellTags->"Twist3QuarkOperator"],
Cell[CellGroupData[{
Cell[2324723, 93844, 70, 1, 33, "Subsubsection",
 CellTags->"Twist3QuarkOperator"],
Cell[2324796, 93847, 768, 12, 87, "Text",
 CellTags->"Twist3QuarkOperator"],
Cell[CellGroupData[{
Cell[2325589, 93863, 134, 3, 27, "Input",
 CellTags->"Twist3QuarkOperator"],
Cell[2325726, 93868, 328, 10, 25, "Output",
 CellTags->"Twist3QuarkOperator"]
}, Open  ]],
Cell[2326069, 93881, 366, 14, 23, "Text",
 CellTags->"Twist3QuarkOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2326472, 93900, 67, 1, 33, "Subsubsection",
 CellTags->"Twist3QuarkOperator"],
Cell[CellGroupData[{
Cell[2326564, 93905, 132, 3, 27, "Input",
 CellTags->"Twist3QuarkOperator"],
Cell[2326699, 93910, 654, 23, 27, "Output",
 CellTags->"Twist3QuarkOperator"]
}, Open  ]]
}, Open  ]],
Cell[2327380, 93937, 75, 1, 39, "ObjectName",
 CellTags->"Twist4GluonOperator"],
Cell[CellGroupData[{
Cell[2327480, 93942, 70, 1, 33, "Subsubsection",
 CellTags->"Twist4GluonOperator"],
Cell[2327553, 93945, 150, 4, 23, "Text",
 CellTags->"Twist4GluonOperator"],
Cell[2327706, 93951, 509, 19, 23, "Text",
 CellTags->"Twist4GluonOperator"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2328252, 93975, 67, 1, 33, "Subsubsection",
 CellTags->"Twist4GluonOperator"],
Cell[CellGroupData[{
Cell[2328344, 93980, 529, 15, 27, "Input",
 CellTags->"Twist4GluonOperator"],
Cell[2328876, 93997, 119831, 4588, 1063, "Output",
 CellTags->"Twist4GluonOperator"]
}, Open  ]]
}, Open  ]],
Cell[2448734, 98589, 104, 1, 39, "ObjectName",
 CellTags->"TwoLoopSimplify"],
Cell[CellGroupData[{
Cell[2448863, 98594, 66, 1, 33, "Subsubsection",
 CellTags->"TwoLoopSimplify"],
Cell[2448932, 98597, 335, 6, 55, "Text",
 CellTags->"TwoLoopSimplify"],
Cell[2449270, 98605, 207, 9, 23, "Text",
 CellTags->"TwoLoopSimplify"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2449514, 98619, 63, 1, 33, "Subsubsection",
 CellTags->"TwoLoopSimplify"],
Cell[2449580, 98622, 82, 2, 27, "Input",
 CellTags->"TwoLoopSimplify"]
}, Open  ]],
Cell[2449677, 98627, 57, 1, 39, "ObjectName",
 CellTags->"Uncontract"],
Cell[CellGroupData[{
Cell[2449759, 98632, 61, 1, 33, "Subsubsection",
 CellTags->"Uncontract"],
Cell[2449823, 98635, 256, 5, 39, "Text",
 CellTags->"Uncontract"],
Cell[CellGroupData[{
Cell[2450104, 98644, 120, 3, 27, "Input",
 CellTags->"Uncontract"],
Cell[2450227, 98649, 372, 11, 25, "Output",
 CellTags->"Uncontract"]
}, Open  ]],
Cell[2450614, 98663, 181, 9, 23, "Text",
 CellTags->"Uncontract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2450832, 98677, 58, 1, 33, "Subsubsection",
 CellTags->"Uncontract"],
Cell[CellGroupData[{
Cell[2450915, 98682, 234, 7, 27, "Input",
 CellTags->"Uncontract"],
Cell[2451152, 98691, 397, 17, 25, "Output",
 CellTags->"Uncontract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2451586, 98713, 143, 4, 27, "Input",
 CellTags->"Uncontract"],
Cell[2451732, 98719, 781, 31, 27, "Output",
 CellTags->"Uncontract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2452550, 98755, 138, 4, 27, "Input",
 CellTags->"Uncontract"],
Cell[2452691, 98761, 224, 8, 25, "Output",
 CellTags->"Uncontract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2452952, 98774, 143, 4, 27, "Input",
 CellTags->"Uncontract"],
Cell[2453098, 98780, 224, 8, 25, "Output",
 CellTags->"Uncontract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2453359, 98793, 153, 4, 27, "Input",
 CellTags->"Uncontract"],
Cell[2453515, 98799, 1138, 44, 27, "Output",
 CellTags->"Uncontract"]
}, Open  ]],
Cell[2454668, 98846, 89, 1, 23, "Text",
 CellTags->"Uncontract"],
Cell[CellGroupData[{
Cell[2454782, 98851, 208, 6, 27, "Input",
 CellTags->"Uncontract"],
Cell[2454993, 98859, 209, 8, 25, "Output",
 CellTags->"Uncontract"]
}, Open  ]],
Cell[2455217, 98870, 152, 4, 23, "Text",
 CellTags->"Uncontract"],
Cell[CellGroupData[{
Cell[2455394, 98878, 248, 7, 27, "Input",
 CellTags->"Uncontract"],
Cell[2455645, 98887, 570, 22, 27, "Output",
 CellTags->"Uncontract"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2456252, 98914, 274, 8, 27, "Input",
 CellTags->"Uncontract"],
Cell[2456529, 98924, 1030, 40, 27, "Output",
 CellTags->"Uncontract"]
}, Open  ]],
Cell[2457574, 98967, 134, 4, 27, "Input",
 CellTags->"Uncontract"]
}, Open  ]],
Cell[2457723, 98974, 83, 1, 39, "ObjectName",
 CellTags->"UnDeclareNonCommutative"],
Cell[CellGroupData[{
Cell[2457831, 98979, 74, 1, 33, "Subsubsection",
 CellTags->"UnDeclareNonCommutative"],
Cell[2457908, 98982, 198, 4, 23, "Text",
 CellTags->"UnDeclareNonCommutative"],
Cell[2458109, 98988, 343, 14, 23, "Text",
 CellTags->"UnDeclareNonCommutative"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2458489, 99007, 71, 1, 33, "Subsubsection",
 CellTags->"UnDeclareNonCommutative"],
Cell[2458563, 99010, 138, 3, 27, "Input",
 CellTags->"UnDeclareNonCommutative"],
Cell[2458704, 99015, 153, 4, 23, "Text",
 CellTags->"UnDeclareNonCommutative"],
Cell[CellGroupData[{
Cell[2458882, 99023, 107, 2, 27, "Input",
 CellTags->"UnDeclareNonCommutative"],
Cell[2458992, 99027, 123, 3, 25, "Output",
 CellTags->"UnDeclareNonCommutative"]
}, Open  ]],
Cell[2459130, 99033, 103, 1, 23, "Text",
 CellTags->"UnDeclareNonCommutative"],
Cell[2459236, 99036, 140, 3, 27, "Input",
 CellTags->"UnDeclareNonCommutative"],
Cell[CellGroupData[{
Cell[2459401, 99043, 161, 4, 27, "Input",
 CellTags->"UnDeclareNonCommutative"],
Cell[2459565, 99049, 123, 3, 25, "Output",
 CellTags->"UnDeclareNonCommutative"]
}, Open  ]],
Cell[2459703, 99055, 161, 4, 27, "Input",
 CellTags->"UnDeclareNonCommutative"],
Cell[CellGroupData[{
Cell[2459889, 99063, 171, 4, 27, "Input",
 CellTags->"UnDeclareNonCommutative"],
Cell[2460063, 99069, 173, 5, 25, "Output",
 CellTags->"UnDeclareNonCommutative"]
}, Open  ]],
Cell[2460251, 99077, 163, 4, 27, "Input",
 CellTags->"UnDeclareNonCommutative"],
Cell[CellGroupData[{
Cell[2460439, 99085, 171, 4, 27, "Input",
 CellTags->"UnDeclareNonCommutative"],
Cell[2460613, 99091, 173, 5, 25, "Output",
 CellTags->"UnDeclareNonCommutative"]
}, Open  ]]
}, Open  ]],
Cell[2460813, 99100, 47, 1, 39, "ObjectName",
 CellTags->"Upper"],
Cell[CellGroupData[{
Cell[2460885, 99105, 56, 1, 33, "Subsubsection",
 CellTags->"Upper"],
Cell[2460944, 99108, 126, 4, 23, "Text",
 CellTags->"Upper"],
Cell[2461073, 99114, 397, 18, 23, "Text",
 CellTags->"Upper"]
}, Open  ]],
Cell[2461485, 99135, 86, 1, 39, "ObjectName",
 CellTags->"UVPart"],
Cell[CellGroupData[{
Cell[2461596, 99140, 57, 1, 33, "Subsubsection",
 CellTags->"UVPart"],
Cell[2461656, 99143, 128, 4, 23, "Text",
 CellTags->"UVPart"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2461821, 99152, 54, 1, 33, "Subsubsection",
 CellTags->"UVPart"],
Cell[2461878, 99155, 73, 2, 27, "Input",
 CellTags->"UVPart"]
}, Open  ]],
Cell[2461966, 99160, 51, 1, 39, "ObjectName",
 CellTags->"Vectors"],
Cell[CellGroupData[{
Cell[2462042, 99165, 58, 1, 33, "Subsubsection",
 CellTags->"Vectors"],
Cell[2462103, 99168, 203, 4, 39, "Text",
 CellTags->"Vectors"],
Cell[2462309, 99174, 188, 8, 23, "Text",
 CellTags->"Vectors"]
}, Open  ]],
Cell[2462512, 99185, 53, 1, 39, "ObjectName",
 CellTags->"WriteOut"],
Cell[CellGroupData[{
Cell[2462590, 99190, 59, 1, 33, "Subsubsection",
 CellTags->"WriteOut"],
Cell[2462652, 99193, 216, 5, 39, "Text",
 CellTags->"WriteOut"],
Cell[2462871, 99200, 171, 8, 23, "Text",
 CellTags->"WriteOut"]
}, Open  ]],
Cell[2463057, 99211, 61, 1, 39, "ObjectName",
 CellTags->"WriteOutPaVe"],
Cell[CellGroupData[{
Cell[2463143, 99216, 63, 1, 33, "Subsubsection",
 CellTags->"WriteOutPaVe"],
Cell[2463209, 99219, 260, 5, 39, "Text",
 CellTags->"WriteOutPaVe"],
Cell[2463472, 99226, 398, 18, 23, "Text",
 CellTags->"WriteOutPaVe"]
}, Open  ]],
Cell[2463885, 99247, 49, 1, 39, "ObjectName",
 CellTags->"Write2"],
Cell[CellGroupData[{
Cell[2463959, 99252, 57, 1, 33, "Subsubsection",
 CellTags->"Write2"],
Cell[2464019, 99255, 297, 6, 39, "Text",
 CellTags->"Write2"],
Cell[2464319, 99263, 153, 4, 23, "Text",
 CellTags->"Write2"],
Cell[CellGroupData[{
Cell[2464497, 99271, 136, 3, 27, "Input",
 CellTags->"Write2"],
Cell[2464636, 99276, 248, 9, 39, "Output",
 CellTags->"Write2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2464921, 99290, 112, 3, 27, "Input",
 CellTags->"Write2"],
Cell[2465036, 99295, 637, 15, 45, "Output",
 CellTags->"Write2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2465710, 99315, 115, 3, 27, "Input",
 CellTags->"Write2"],
Cell[2465828, 99320, 133, 4, 25, "Output",
 CellTags->"Write2"]
}, Open  ]],
Cell[2465976, 99327, 290, 14, 23, "Text",
 CellTags->"Write2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2466303, 99346, 54, 1, 33, "Subsubsection",
 CellTags->"Write2"],
Cell[CellGroupData[{
Cell[2466382, 99351, 429, 15, 35, "Input",
 CellTags->"Write2"],
Cell[2466814, 99368, 855, 29, 31, "Output",
 CellTags->"Write2"]
}, Open  ]],
Cell[2467684, 99400, 208, 7, 27, "Input",
 CellTags->"Write2"],
Cell[2467895, 99409, 78, 1, 23, "Text",
 CellTags->"Write2"],
Cell[2467976, 99412, 184, 6, 27, "Input",
 CellTags->"Write2"],
Cell[2468163, 99420, 73, 1, 23, "Text",
 CellTags->"Write2"],
Cell[CellGroupData[{
Cell[2468261, 99425, 363, 11, 27, "Input",
 CellTags->"Write2"],
Cell[2468627, 99438, 801, 22, 72, "Output",
 CellTags->"Write2"]
}, Open  ]],
Cell[2469443, 99463, 286, 8, 27, "Input",
 CellTags->"Write2"],
Cell[CellGroupData[{
Cell[2469754, 99475, 233, 7, 27, "Input",
 CellTags->"Write2"],
Cell[2469990, 99484, 710, 27, 27, "Output",
 CellTags->"Write2"]
}, Open  ]],
Cell[2470715, 99514, 185, 6, 27, "Input",
 CellTags->"Write2"],
Cell[CellGroupData[{
Cell[2470925, 99524, 363, 11, 27, "Input",
 CellTags->"Write2"],
Cell[2471291, 99537, 1061, 30, 191, "Output",
 CellTags->"Write2"]
}, Open  ]],
Cell[2472367, 99570, 286, 8, 27, "Input",
 CellTags->"Write2"],
Cell[2472656, 99580, 106, 3, 23, "Text",
 CellTags->"Write2"],
Cell[2472765, 99585, 247, 8, 27, "Input",
 CellTags->"Write2"],
Cell[CellGroupData[{
Cell[2473037, 99597, 363, 11, 27, "Input",
 CellTags->"Write2"],
Cell[2473403, 99610, 954, 25, 123, "Output",
 CellTags->"Write2"]
}, Open  ]],
Cell[2474372, 99638, 397, 11, 27, "Input",
 CellTags->"Write2"]
}, Open  ]],
Cell[2474784, 99652, 43, 1, 39, "ObjectName",
 CellTags->"XYT"],
Cell[CellGroupData[{
Cell[2474852, 99657, 54, 1, 33, "Subsubsection",
 CellTags->"XYT"],
Cell[2474909, 99660, 215, 9, 23, "Text",
 CellTags->"XYT"]
}, Open  ]],
Cell[2475139, 99672, 79, 1, 39, "ObjectName",
 CellTags->"ZeroMomentumInsertion"],
Cell[CellGroupData[{
Cell[2475243, 99677, 72, 1, 33, "Subsubsection",
 CellTags->"ZeroMomentumInsertion"],
Cell[2475318, 99680, 154, 4, 23, "Text",
 CellTags->"ZeroMomentumInsertion"],
Cell[2475475, 99686, 473, 18, 23, "Text",
 CellTags->"ZeroMomentumInsertion"]
}, Open  ]],
Cell[2475963, 99707, 47, 1, 39, "ObjectName",
 CellTags->"Zeta2"],
Cell[CellGroupData[{
Cell[2476035, 99712, 56, 1, 33, "Subsubsection",
 CellTags->"Zeta2"],
Cell[2476094, 99715, 94, 1, 23, "Text",
 CellTags->"Zeta2"],
Cell[2476191, 99718, 191, 8, 23, "Text",
 CellTags->"Zeta2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2476419, 99731, 53, 1, 33, "Subsubsection",
 CellTags->"Zeta2"],
Cell[CellGroupData[{
Cell[2476497, 99736, 77, 2, 27, "Input",
 CellTags->"Zeta2"],
Cell[2476577, 99740, 136, 4, 25, "Output",
 CellTags->"Zeta2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2476750, 99749, 104, 3, 27, "Input",
 CellTags->"Zeta2"],
Cell[2476857, 99754, 120, 3, 25, "Output",
 CellTags->"Zeta2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2477014, 99762, 138, 4, 27, "Input",
 CellTags->"Zeta2"],
Cell[2477155, 99768, 160, 5, 25, "Output",
 CellTags->"Zeta2"]
}, Open  ]]
}, Open  ]],
Cell[2477342, 99777, 65, 1, 39, "ObjectName",
 CellTags->"$Abbreviations"],
Cell[CellGroupData[{
Cell[2477432, 99782, 65, 1, 33, "Subsubsection",
 CellTags->"$Abbreviations"],
Cell[2477500, 99785, 293, 6, 39, "Text",
 CellTags->"$Abbreviations"],
Cell[CellGroupData[{
Cell[2477818, 99795, 129, 3, 27, "Input",
 CellTags->"$Abbreviations"],
Cell[2477950, 99800, 867, 17, 78, "Output",
 CellTags->"$Abbreviations"]
}, Open  ]],
Cell[2478832, 99820, 652, 29, 23, "Text",
 CellTags->"$Abbreviations"]
}, Open  ]],
Cell[2479499, 99852, 43, 1, 39, "ObjectName",
 CellTags->"$AL"],
Cell[CellGroupData[{
Cell[2479567, 99857, 54, 1, 33, "Subsubsection",
 CellTags->"$AL"],
Cell[2479624, 99860, 114, 3, 23, "Text",
 CellTags->"$AL"],
Cell[CellGroupData[{
Cell[2479763, 99867, 73, 2, 27, "Input",
 CellTags->"$AL"],
Cell[2479839, 99871, 102, 3, 25, "Output",
 CellTags->"$AL"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2479978, 99879, 241, 7, 27, "Input",
 CellTags->"$AL"],
Cell[2480222, 99888, 563, 22, 27, "Output",
 CellTags->"$AL"]
}, Open  ]],
Cell[2480800, 99913, 117, 4, 27, "Input",
 CellTags->"$AL"],
Cell[CellGroupData[{
Cell[2480942, 99921, 241, 7, 27, "Input",
 CellTags->"$AL"],
Cell[2481186, 99930, 477, 20, 27, "Output",
 CellTags->"$AL"]
}, Open  ]],
Cell[2481678, 99953, 109, 4, 27, "Input",
 CellTags->"$AL"]
}, Open  ]],
Cell[2481802, 99960, 61, 1, 39, "ObjectName",
 CellTags->"$BreitMaison"],
Cell[CellGroupData[{
Cell[2481888, 99965, 63, 1, 33, "Subsubsection",
 CellTags->"$BreitMaison"],
Cell[2481954, 99968, 319, 9, 39, "Text",
 CellTags->"$BreitMaison"],
Cell[2482276, 99979, 370, 19, 23, "Text",
 CellTags->"$BreitMaison"]
}, Open  ]],
Cell[2482661, 100001, 49, 1, 39, "ObjectName",
 CellTags->"$Color"],
Cell[CellGroupData[{
Cell[2482735, 100006, 57, 1, 33, "Subsubsection",
 CellTags->"$Color"],
Cell[2482795, 100009, 130, 4, 23, "Text",
 CellTags->"$Color"]
}, Open  ]],
Cell[2482940, 100016, 57, 1, 39, "ObjectName",
 CellTags->"$Covariant"],
Cell[CellGroupData[{
Cell[2483022, 100021, 61, 1, 33, "Subsubsection",
 CellTags->"$Covariant"],
Cell[2483086, 100024, 183, 4, 23, "Text",
 CellTags->"$Covariant"],
Cell[CellGroupData[{
Cell[2483294, 100032, 87, 2, 27, "Input",
 CellTags->"$Covariant"],
Cell[2483384, 100036, 111, 3, 25, "Output",
 CellTags->"$Covariant"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2483532, 100044, 110, 3, 27, "Input",
 CellTags->"$Covariant"],
Cell[2483645, 100049, 142, 4, 25, "Output",
 CellTags->"$Covariant"]
}, Open  ]],
Cell[2483802, 100056, 130, 4, 27, "Input",
 CellTags->"$Covariant"],
Cell[CellGroupData[{
Cell[2483957, 100064, 110, 3, 27, "Input",
 CellTags->"$Covariant"],
Cell[2484070, 100069, 140, 4, 28, "Output",
 CellTags->"$Covariant"]
}, Open  ]],
Cell[2484225, 100076, 131, 4, 27, "Input",
 CellTags->"$Covariant"]
}, Open  ]],
Cell[2484371, 100083, 45, 1, 39, "ObjectName",
 CellTags->"$FCS"],
Cell[CellGroupData[{
Cell[2484441, 100088, 55, 1, 33, "Subsubsection",
 CellTags->"$FCS"],
Cell[2484499, 100091, 142, 4, 23, "Text",
 CellTags->"$FCS"],
Cell[CellGroupData[{
Cell[2484666, 100099, 75, 2, 27, "Input",
 CellTags->"$FCS"],
Cell[2484744, 100103, 700, 14, 45, "Output",
 CellTags->"$FCS"]
}, Open  ]]
}, Open  ]],
Cell[2485471, 100121, 45, 1, 39, "ObjectName",
 CellTags->"$FCT"],
Cell[CellGroupData[{
Cell[2485541, 100126, 55, 1, 33, "Subsubsection",
 CellTags->"$FCT"],
Cell[2485599, 100129, 177, 4, 23, "Text",
 CellTags->"$FCT"],
Cell[2485779, 100135, 128, 4, 27, "Input",
 CellTags->"$FCT"],
Cell[CellGroupData[{
Cell[2485932, 100143, 170, 5, 27, "Input",
 CellTags->"$FCT"],
Cell[2486105, 100150, 196, 6, 25, "Output",
 CellTags->"$FCT"]
}, Open  ]],
Cell[2486316, 100159, 129, 4, 27, "Input",
 CellTags->"$FCT"],
Cell[CellGroupData[{
Cell[2486470, 100167, 170, 5, 27, "Input",
 CellTags->"$FCT"],
Cell[2486643, 100174, 196, 6, 25, "Output",
 CellTags->"$FCT"]
}, Open  ]]
}, Open  ]],
Cell[2486866, 100184, 65, 1, 39, "ObjectName",
 CellTags->"$FeynCalcStuff"],
Cell[CellGroupData[{
Cell[2486956, 100189, 65, 1, 33, "Subsubsection",
 CellTags->"$FeynCalcStuff"],
Cell[2487024, 100192, 102, 1, 23, "Text",
 CellTags->"$FeynCalcStuff"]
}, Open  ]],
Cell[2487141, 100196, 69, 1, 39, "ObjectName",
 CellTags->"$FeynCalcVersion"],
Cell[CellGroupData[{
Cell[2487235, 100201, 67, 1, 33, "Subsubsection",
 CellTags->"$FeynCalcVersion"],
Cell[2487305, 100204, 124, 3, 23, "Text",
 CellTags->"$FeynCalcVersion"],
Cell[CellGroupData[{
Cell[2487454, 100211, 99, 2, 27, "Input",
 CellTags->"$FeynCalcVersion"],
Cell[2487556, 100215, 125, 3, 25, "Output",
 CellTags->"$FeynCalcVersion"]
}, Open  ]]
}, Open  ]],
Cell[2487708, 100222, 95, 1, 39, "ObjectName",
 CellTags->"$FortranContinuationCharacter"],
Cell[CellGroupData[{
Cell[2487828, 100227, 80, 1, 33, "Subsubsection",
 CellTags->"$FortranContinuationCharacter"],
Cell[2487911, 100230, 143, 3, 23, "Text",
 CellTags->"$FortranContinuationCharacter"],
Cell[CellGroupData[{
Cell[2488079, 100237, 125, 2, 27, "Input",
 CellTags->"$FortranContinuationCharacter"],
Cell[2488207, 100241, 134, 3, 25, "Output",
 CellTags->"$FortranContinuationCharacter"]
}, Open  ]],
Cell[2488356, 100247, 194, 9, 23, "Text",
 CellTags->"$FortranContinuationCharacter"]
}, Open  ]],
Cell[2488565, 100259, 49, 1, 39, "ObjectName",
 CellTags->"$Gauge"],
Cell[CellGroupData[{
Cell[2488639, 100264, 57, 1, 33, "Subsubsection",
 CellTags->"$Gauge"],
Cell[2488699, 100267, 260, 5, 39, "Text",
 CellTags->"$Gauge"],
Cell[2488962, 100274, 168, 9, 23, "Text",
 CellTags->"$Gauge"]
}, Open  ]],
Cell[2489145, 100286, 49, 1, 39, "ObjectName",
 CellTags->"$Larin"],
Cell[CellGroupData[{
Cell[2489219, 100291, 57, 1, 33, "Subsubsection",
 CellTags->"$Larin"],
Cell[2489279, 100294, 1133, 30, 87, "Text",
 CellTags->"$Larin"],
Cell[CellGroupData[{
Cell[2490437, 100328, 79, 2, 27, "Input",
 CellTags->"$Larin"],
Cell[2490519, 100332, 107, 3, 25, "Output",
 CellTags->"$Larin"]
}, Open  ]],
Cell[2490641, 100338, 377, 18, 23, "Text",
 CellTags->"$Larin"]
}, Open  ]],
Cell[2491033, 100359, 55, 1, 39, "ObjectName",
 CellTags->"$LimitTo4"],
Cell[CellGroupData[{
Cell[2491113, 100364, 60, 1, 33, "Subsubsection",
 CellTags->"$LimitTo4"],
Cell[2491176, 100367, 203, 4, 23, "Text",
 CellTags->"$LimitTo4"],
Cell[CellGroupData[{
Cell[2491404, 100375, 85, 2, 27, "Input",
 CellTags->"$LimitTo4"],
Cell[2491492, 100379, 109, 3, 25, "Output",
 CellTags->"$LimitTo4"]
}, Open  ]],
Cell[2491616, 100385, 391, 19, 23, "Text",
 CellTags->"$LimitTo4"]
}, Open  ]],
Cell[2492022, 100407, 67, 1, 39, "ObjectName",
 CellTags->"$LorentzIndices"],
Cell[CellGroupData[{
Cell[2492114, 100412, 66, 1, 33, "Subsubsection",
 CellTags->"$LorentzIndices"],
Cell[2492183, 100415, 164, 4, 23, "Text",
 CellTags->"$LorentzIndices"],
Cell[2492350, 100421, 140, 4, 27, "Input",
 CellTags->"$LorentzIndices"],
Cell[CellGroupData[{
Cell[2492515, 100429, 333, 9, 27, "Input",
 CellTags->"$LorentzIndices"],
Cell[2492851, 100440, 669, 28, 25, "Output",
 CellTags->"$LorentzIndices"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2493557, 100473, 117, 3, 27, "Input",
 CellTags->"$LorentzIndices"],
Cell[2493677, 100478, 380, 10, 39, "Output",
 CellTags->"$LorentzIndices"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2494094, 100493, 302, 9, 27, "Input",
 CellTags->"$LorentzIndices"],
Cell[2494399, 100504, 884, 38, 25, "Output",
 CellTags->"$LorentzIndices"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2495320, 100547, 117, 3, 27, "Input",
 CellTags->"$LorentzIndices"],
Cell[2495440, 100552, 655, 19, 59, "Output",
 CellTags->"$LorentzIndices"]
}, Open  ]],
Cell[2496110, 100574, 141, 4, 27, "Input",
 CellTags->"$LorentzIndices"]
}, Open  ]],
Cell[2496266, 100581, 59, 1, 39, "ObjectName",
 CellTags->"$MIntegrate"],
Cell[CellGroupData[{
Cell[2496350, 100586, 62, 1, 33, "Subsubsection",
 CellTags->"$MIntegrate"],
Cell[2496415, 100589, 136, 4, 23, "Text",
 CellTags->"$MIntegrate"],
Cell[CellGroupData[{
Cell[2496576, 100597, 89, 2, 27, "Input",
 CellTags->"$MIntegrate"],
Cell[2496668, 100601, 126, 4, 25, "Output",
 CellTags->"$MIntegrate"]
}, Open  ]],
Cell[2496809, 100608, 191, 9, 23, "Text",
 CellTags->"$MIntegrate"]
}, Open  ]],
Cell[2497015, 100620, 43, 1, 39, "ObjectName",
 CellTags->"$MU"],
Cell[CellGroupData[{
Cell[2497083, 100625, 54, 1, 33, "Subsubsection",
 CellTags->"$MU"],
Cell[2497140, 100628, 151, 4, 23, "Text",
 CellTags->"$MU"],
Cell[CellGroupData[{
Cell[2497316, 100636, 73, 2, 27, "Input",
 CellTags->"$MU"],
Cell[2497392, 100640, 102, 3, 25, "Output",
 CellTags->"$MU"]
}, Open  ]],
Cell[2497509, 100646, 174, 9, 23, "Text",
 CellTags->"$MU"]
}, Open  ]],
Cell[2497698, 100658, 69, 1, 39, "ObjectName",
 CellTags->"$MemoryAvailable"],
Cell[CellGroupData[{
Cell[2497792, 100663, 67, 1, 33, "Subsubsection",
 CellTags->"$MemoryAvailable"],
Cell[2497862, 100666, 434, 11, 39, "Text",
 CellTags->"$MemoryAvailable"],
Cell[CellGroupData[{
Cell[2498321, 100681, 99, 2, 27, "Input",
 CellTags->"$MemoryAvailable"],
Cell[2498423, 100685, 115, 3, 25, "Output",
 CellTags->"$MemoryAvailable"]
}, Open  ]]
}, Open  ]],
Cell[2498565, 100692, 53, 1, 39, "ObjectName",
 CellTags->"$NonComm"],
Cell[CellGroupData[{
Cell[2498643, 100697, 59, 1, 33, "Subsubsection",
 CellTags->"$NonComm"],
Cell[2498705, 100700, 109, 3, 23, "Text",
 CellTags->"$NonComm"],
Cell[CellGroupData[{
Cell[2498839, 100707, 83, 2, 27, "Input",
 CellTags->"$NonComm"],
Cell[2498925, 100711, 803, 15, 83, "Output",
 CellTags->"$NonComm"]
}, Open  ]],
Cell[2499743, 100729, 307, 14, 23, "Text",
 CellTags->"$NonComm"]
}, Open  ]],
Cell[2500065, 100746, 63, 1, 39, "ObjectName",
 CellTags->"$PairBrackets"],
Cell[CellGroupData[{
Cell[2500153, 100751, 64, 1, 33, "Subsubsection",
 CellTags->"$PairBrackets"],
Cell[2500220, 100754, 155, 4, 23, "Text",
 CellTags->"$PairBrackets"],
Cell[CellGroupData[{
Cell[2500400, 100762, 93, 2, 27, "Input",
 CellTags->"$PairBrackets"],
Cell[2500496, 100766, 114, 3, 25, "Output",
 CellTags->"$PairBrackets"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2500647, 100774, 204, 7, 27, "Input",
 CellTags->"$PairBrackets"],
Cell[2500854, 100783, 425, 18, 25, "Output",
 CellTags->"$PairBrackets"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2501316, 100806, 118, 3, 27, "Input",
 CellTags->"$PairBrackets"],
Cell[2501437, 100811, 113, 3, 25, "Output",
 CellTags->"$PairBrackets"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2501587, 100819, 204, 7, 27, "Input",
 CellTags->"$PairBrackets"],
Cell[2501794, 100828, 445, 18, 25, "Output",
 CellTags->"$PairBrackets"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2502276, 100851, 119, 3, 27, "Input",
 CellTags->"$PairBrackets"],
Cell[2502398, 100856, 114, 3, 25, "Output",
 CellTags->"$PairBrackets"]
}, Open  ]]
}, Open  ]],
Cell[2502539, 100863, 65, 1, 39, "ObjectName",
 CellTags->"$SpinorMinimal"],
Cell[CellGroupData[{
Cell[2502629, 100868, 65, 1, 33, "Subsubsection",
 CellTags->"$SpinorMinimal"],
Cell[2502697, 100871, 241, 5, 39, "Text",
 CellTags->"$SpinorMinimal"],
Cell[CellGroupData[{
Cell[2502963, 100880, 95, 2, 27, "Input",
 CellTags->"$SpinorMinimal"],
Cell[2503061, 100884, 115, 3, 25, "Output",
 CellTags->"$SpinorMinimal"]
}, Open  ]],
Cell[2503191, 100890, 200, 9, 23, "Text",
 CellTags->"$SpinorMinimal"]
}, Open  ]],
Cell[2503406, 100902, 61, 1, 39, "ObjectName",
 CellTags->"$VeryVerbose"],
Cell[CellGroupData[{
Cell[2503492, 100907, 63, 1, 33, "Subsubsection",
 CellTags->"$VeryVerbose"],
Cell[2503558, 100910, 221, 5, 39, "Text",
 CellTags->"$VeryVerbose"],
Cell[CellGroupData[{
Cell[2503804, 100919, 91, 2, 27, "Input",
 CellTags->"$VeryVerbose"],
Cell[2503898, 100923, 109, 3, 25, "Output",
 CellTags->"$VeryVerbose"]
}, Open  ]],
Cell[2504022, 100929, 141, 4, 27, "Input",
 CellTags->"$VeryVerbose"],
Cell[CellGroupData[{
Cell[2504188, 100937, 287, 10, 27, "Input",
 CellTags->"$VeryVerbose"],
Cell[2504478, 100949, 121, 3, 21, "Print",
 CellTags->"$VeryVerbose"],
Cell[2504602, 100954, 255, 7, 21, "Print",
 CellTags->"$VeryVerbose"],
Cell[2504860, 100963, 273, 7, 21, "Print",
 CellTags->"$VeryVerbose"]
}, Open  ]],
Cell[2505148, 100973, 131, 4, 27, "Input",
 CellTags->"$VeryVerbose"],
Cell[2505282, 100979, 159, 9, 23, "Text",
 CellTags->"$V0"]
}, Open  ]],
Cell[2505456, 100991, 47, 1, 39, "ObjectName",
 CellTags->"$West"],
Cell[CellGroupData[{
Cell[2505528, 100996, 56, 1, 33, "Subsubsection",
 CellTags->"$West"],
Cell[2505587, 100999, 577, 14, 63, "Text",
 CellTags->"$West"],
Cell[2506167, 101015, 158, 8, 23, "Text",
 CellTags->"$West"],
Cell[2506328, 101025, 54, 0, 29, "Commentary"],
Cell[CellGroupData[{
Cell[2506407, 101029, 125, 3, 27, "Input"],
Cell[2506535, 101034, 107, 2, 25, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2506679, 101041, 85, 2, 27, "Input"],
Cell[2506767, 101045, 90, 2, 25, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2506894, 101052, 87, 2, 27, "Input"],
Cell[2506984, 101056, 90, 2, 25, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2507111, 101063, 82, 2, 27, "Input"],
Cell[2507196, 101067, 99, 2, 25, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2507356, 101076, 70, 1, 63, "Section",
 CellTags->"Experimental"],
Cell[2507429, 101079, 73, 1, 39, "ObjectName",
 CellTags->"DoPolarizationSums"],
Cell[CellGroupData[{
Cell[2507527, 101084, 69, 1, 33, "Subsubsection",
 CellTags->"DoPolarizationSums"],
Cell[2507599, 101087, 291, 7, 95, "Text",
 CellTags->"DoPolarizationSums"],
Cell[2507893, 101096, 317, 14, 23, "Text",
 CellTags->"DoPolarizationSums"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2508247, 101115, 66, 1, 33, "Subsubsection",
 CellTags->"DoPolarizationSums"],
Cell[2508316, 101118, 310, 6, 39, "Text",
 CellTags->"DoPolarizationSums"],
Cell[2508629, 101126, 123, 3, 23, "Text",
 CellTags->"DoPolarizationSums"],
Cell[CellGroupData[{
Cell[2508777, 101133, 571, 17, 48, "Input",
 CellTags->"DoPolarizationSums"],
Cell[2509351, 101152, 448, 16, 29, "Output",
 CellTags->"DoPolarizationSums"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2509836, 101173, 116, 3, 27, "Input",
 CellTags->"DoPolarizationSums"],
Cell[2509955, 101178, 133, 4, 25, "Output",
 CellTags->"DoPolarizationSums"]
}, Open  ]],
Cell[2510103, 101185, 1270, 48, 26, "Text",
 CellTags->"DoPolarizationSums"],
Cell[2511376, 101235, 562, 21, 23, "Text",
 CellTags->"DoPolarizationSums"],
Cell[2511941, 101258, 142, 4, 27, "Input",
 CellTags->"DoPolarizationSums"],
Cell[2512086, 101264, 311, 10, 27, "Input",
 CellTags->"DoPolarizationSums"],
Cell[CellGroupData[{
Cell[2512422, 101278, 271, 8, 27, "Input",
 CellTags->"DoPolarizationSums"],
Cell[2512696, 101288, 735, 20, 75, "Output",
 CellTags->"DoPolarizationSums"]
}, Open  ]],
Cell[2513446, 101311, 213, 9, 24, "Text",
 CellTags->"DoPolarizationSums"],
Cell[2513662, 101322, 276, 9, 27, "Input",
 CellTags->"DoPolarizationSums"],
Cell[2513941, 101333, 328, 10, 27, "Input",
 CellTags->"DoPolarizationSums"],
Cell[2514272, 101345, 323, 13, 26, "Text",
 CellTags->"DoPolarizationSums"],
Cell[2514598, 101360, 697, 30, 26, "Text",
 CellTags->"DoPolarizationSums"],
Cell[CellGroupData[{
Cell[2515320, 101394, 434, 13, 51, "Input",
 CellTags->"DoPolarizationSums"],
Cell[2515757, 101409, 775, 24, 75, "Output",
 CellTags->"DoPolarizationSums"]
}, Open  ]],
Cell[2516547, 101436, 624, 27, 26, "Text",
 CellTags->"DoPolarizationSums"],
Cell[CellGroupData[{
Cell[2517196, 101467, 433, 13, 51, "Input",
 CellTags->"DoPolarizationSums"],
Cell[2517632, 101482, 775, 24, 75, "Output",
 CellTags->"DoPolarizationSums"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2518444, 101511, 859, 24, 68, "Input",
 CellTags->"DoPolarizationSums"],
Cell[2519306, 101537, 606, 22, 31, "Output",
 CellTags->"DoPolarizationSums"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2519949, 101564, 130, 3, 27, "Input",
 CellTags->"DoPolarizationSums"],
Cell[2520082, 101569, 323, 12, 30, "Output",
 CellTags->"DoPolarizationSums"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2520442, 101586, 116, 3, 27, "Input",
 CellTags->"DoPolarizationSums"],
Cell[2520561, 101591, 133, 4, 25, "Output",
 CellTags->"DoPolarizationSums"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2520731, 101600, 120, 3, 27, "Input",
 CellTags->"DoPolarizationSums"],
Cell[2520854, 101605, 133, 4, 25, "Output",
 CellTags->"DoPolarizationSums"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2521024, 101614, 126, 3, 27, "Input",
 CellTags->"DoPolarizationSums"],
Cell[2521153, 101619, 133, 4, 25, "Output",
 CellTags->"DoPolarizationSums"]
}, Open  ]],
Cell[2521301, 101626, 167, 4, 27, "Input",
 CellTags->"DoPolarizationSums"]
}, Open  ]],
Cell[2521483, 101633, 90, 1, 39, "ObjectName",
 CellTags->"FeynmanDoIntegrals"],
Cell[CellGroupData[{
Cell[2521598, 101638, 69, 1, 33, "Subsubsection",
 CellTags->"FeynmanDoIntegrals"],
Cell[2521670, 101641, 1518, 23, 191, "Text",
 CellTags->"FeynmanDoIntegrals"],
Cell[2523191, 101666, 347, 14, 23, "Text",
 CellTags->"FeynmanDoIntegrals"],
Cell[CellGroupData[{
Cell[2523563, 101684, 136, 3, 27, "Input",
 CellTags->"FeynmanDoIntegrals"],
Cell[2523702, 101689, 1037, 29, 64, "Output",
 CellTags->"FeynmanDoIntegrals"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2524788, 101724, 66, 1, 33, "Subsubsection",
 CellTags->"FeynmanDoIntegrals"],
Cell[2524857, 101727, 85, 2, 27, "Input",
 CellTags->"FeynmanDoIntegrals"]
}, Open  ]],
Cell[2524957, 101732, 92, 1, 39, "ObjectName",
 CellTags->"FeynmanParametrize1"],
Cell[CellGroupData[{
Cell[2525074, 101737, 70, 1, 33, "Subsubsection",
 CellTags->"FeynmanParametrize1"],
Cell[2525147, 101740, 717, 12, 111, "Text",
 CellTags->"FeynmanParametrize1"],
Cell[CellGroupData[{
Cell[2525889, 101756, 138, 3, 27, "Input",
 CellTags->"FeynmanParametrize1"],
Cell[2526030, 101761, 505, 13, 25, "Output",
 CellTags->"FeynmanParametrize1"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2526584, 101780, 67, 1, 33, "Subsubsection",
 CellTags->"FeynmanParametrize1"],
Cell[2526654, 101783, 86, 2, 27, "Input",
 CellTags->"FeynmanParametrize1"]
}, Open  ]],
Cell[2526755, 101788, 80, 1, 39, "ObjectName",
 CellTags->"FeynmanReduce"],
Cell[CellGroupData[{
Cell[2526860, 101793, 64, 1, 33, "Subsubsection",
 CellTags->"FeynmanReduce"],
Cell[2526927, 101796, 723, 12, 111, "Text",
 CellTags->"FeynmanReduce"],
Cell[CellGroupData[{
Cell[2527675, 101812, 126, 3, 27, "Input",
 CellTags->"FeynmanReduce"],
Cell[2527804, 101817, 288, 9, 25, "Output",
 CellTags->"FeynmanReduce"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2528141, 101832, 61, 1, 33, "Subsubsection",
 CellTags->"FeynmanReduce"],
Cell[2528205, 101835, 80, 2, 27, "Input",
 CellTags->"FeynmanReduce"],
Cell[2528288, 101839, 122, 3, 23, "Text",
 CellTags->"Experimental"],
Cell[CellGroupData[{
Cell[2528435, 101846, 198, 6, 27, "Input",
 CellTags->"Experimental"],
Cell[2528636, 101854, 193, 6, 25, "Output",
 CellTags->"Experimental"]
}, Open  ]],
Cell[2528844, 101863, 100, 1, 23, "Text",
 CellTags->"Experimental"],
Cell[CellGroupData[{
Cell[2528969, 101868, 222, 6, 27, "Input",
 CellTags->"Experimental"],
Cell[2529194, 101876, 246, 7, 25, "Output",
 CellTags->"Experimental"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2529477, 101888, 75, 1, 27, "Input"],
Cell[2529555, 101891, 105, 2, 25, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
