(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    132505,       3287]
NotebookOptionsPosition[    128070,       3139]
NotebookOutlinePosition[    128789,       3167]
CellTagsIndexPosition[    128659,       3161]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["The 2-loop ghost selfenergy ", "Subsection"],

Cell[BoxData[
 RowBox[{"<<", "HighEnergyPhysics`FeynCalc`"}]], "Input"],

Cell["Loading FeynCalc from /home/rolfm/HighEnergyPhysics", "Text",
 CellMargins->{{Inherited, Inherited}, {1, 0}},
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.522783939902508*^9}],

Cell[TextData[{
 StyleBox["FeynCalc",
  FontWeight->"Bold"],
 " ",
 "8.0.2",
 " For help, type ?FeynCalc, open ",
 ButtonBox["FeynCalcRef8.nb",
  BaseStyle->"AddOnsLink",
  ButtonFunction:>NotebookOpen[
   "/home/rolfm/HighEnergyPhysics/Documentation/English/FeynCalcRef8.nb"],
  ButtonData:>{"Short Overview", "intro"},
  ButtonNote->"Open FeynCalcRef8.nb"],
 " or visit ",
 ButtonBox["www.feyncalc.org",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.feyncalc.org/"], None},
  ButtonNote->"http://www.feyncalc.org/"]
}], "Text",
 CellMargins->{{Inherited, Inherited}, {1, 0}},
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.522783941040847*^9}],

Cell[TextData[{
 "Loading FeynArts, see ",
 ButtonBox["www.feynarts.de",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.feynarts.de/"], None},
  ButtonNote->"http://www.feynarts.de/"],
 " for documentation"
}], "Text",
 CellMargins->{{Inherited, Inherited}, {1, 0}},
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.522783941205732*^9}],

Cell["FeynArts 3.4 patched for use with FeynCalc", "Text",
 CellMargins->{{Inherited, Inherited}, {1, 0}},
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{3.522783941307523*^9}],

Cell[CellGroupData[{

Cell["The graphs", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Paint", "[", 
   RowBox[{
    RowBox[{"inserts", "=", 
     RowBox[{"InsertFields", "[", 
      RowBox[{
       RowBox[{"Rest", "@", 
        RowBox[{"CreateTopologies", "[", 
         RowBox[{"2", ",", 
          RowBox[{"1", "\[Rule]", "1"}], ",", 
          RowBox[{"ExcludeTopologies", "\[Rule]", 
           RowBox[{"{", "Tadpoles", "}"}]}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"U", "[", "5", "]"}], "}"}], "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"U", "[", "5", "]"}], "}"}]}], ",", 
       RowBox[{"InsertionLevel", "\[Rule]", "Classes"}], ",", 
       RowBox[{"GenericModel", "\[Rule]", "\"\<FCQCDLorentz\>\""}], ",", 
       RowBox[{"Model", "\[Rule]", "\"\<FCQCD\>\""}]}], "]"}]}], ",", 
    RowBox[{"ColumnsXRows", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"4", ",", "2"}], "}"}]}], ",", 
    RowBox[{"SheetHeader", "\[Rule]", "False"}], ",", 
    RowBox[{"PaintLevel", "\[Rule]", 
     RowBox[{"{", "Generic", "}"}]}], ",", 
    RowBox[{"Numbering", "\[Rule]", "None"}]}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 FormBox[
  GraphicsBox[{InsetBox[
     GraphicsBox[
      {Thickness[0.005], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{-1.0009326700810561`*^-11, 10.}, {5.999999999982448, 
         10.}}]}, PolygonBox[{{3.6, 10.}, {2.4, 9.6}, {2.4, 10.4}}], 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {3., 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{20.00000000000066, 10.}, {13.999999999999321`, 10.}}]}, 
       PolygonBox[{{17.599999999999994`, 10.}, {16.39999999999999, 10.4}, {
        16.39999999999999, 9.6}}], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {16.999999999999993`, 10.9452}, {0, -1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.864573208290214, 9.864573207387709}, 
         3.8669453704948786`, {3.1065638443429586`, 4.747417796295682}]}, 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {6.81579111096687, 6.815791085716318}, \
{1, 1}], LineBox[CompressedData["
1:eJwdVXlUzAsbHsmHGJdIM83SzGSW3+83UkI1hUfW0qK6lpAW5GpfFNFyJblI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        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {13.316594227670251`, 6.68340579846254}, \
{-1, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{9.99999997334453, 14.000000000000902`}, {10.00000002665547, 
         6.000000000000003}}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {10.6952, 10.0000000086634}, {-1, 0}], 
       LineBox[CompressedData["
1:eJwlkAs0lYkexSWiEKWcw3fenHO+7zsKUZJoJzXKTZRHIUUJKc9SN6I0RCTX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        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {6.657315156232203, 13.342684817461137`}, \
{1, -1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.989559209705002, 9.989559209635424}, 4.010454381060245, {
         0.002603396315374207, 1.5681929371436802`}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {13.13981750122236, 13.139817526177083`}, \
{-1, -1}], 
       {PointSize[0.04], PointBox[{9.99999997334337, 13.99999999999999}], 
        PointBox[{10.00000002665663, 6.}], PointBox[{6., 10.}], 
        PointBox[{13.99999999999999, 10.}]}},
      AspectRatio->1,
      PlotRange->{{-1, 21}, {-1, 21}}], {0, 22}, {0, 0}, {22, 22}], InsetBox[
     GraphicsBox[
      {Thickness[0.005], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{-1.0009326700810561`*^-11, 10.}, {5.999999999982448, 
         10.}}]}, PolygonBox[{{3.6, 10.}, {2.4, 9.6}, {2.4, 10.4}}], 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {3., 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{20.00000000000066, 10.}, {13.999999999999321`, 10.}}]}, 
       PolygonBox[{{17.599999999999994`, 10.}, {16.39999999999999, 10.4}, {
        16.39999999999999, 9.6}}], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {16.999999999999993`, 10.9452}, {0, -1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.864573208290214, 9.864573207387709}, 
         3.8669453704948786`, {3.1065638443429586`, 4.747417796295682}]}, 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {6.81579111096687, 6.815791085716318}, \
{1, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.989559228732924, 10.010440771197487`}, 
         4.0104543619824895`, {4.714992378597311, 6.280581915631125}]}, 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {13.13981753178458, 6.860182493170143}, \
{-1, 1}], LineBox[CompressedData["
1:eJwd1nk8VekbAPBTyC0qStPFEM45EibtqEavRhKSst3iF8JYGiGlq2bK0ghJ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        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {11.645199999999999`, 10.00000001499435}, \
{-1, 0}], LineBox[CompressedData["
1:eJwlkAs0lYkexSWiEKWcw3fenHO+7zsKUZJoJzXKTZRHIUUJKc9SN6I0RCTX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        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {6.657315156232203, 13.342684817461137`}, \
{1, -1}], LineBox[CompressedData["
1:eJwtlQlQk9cahiNFCxWpSFkUpFCSf42CUi0icj8qXkS4rMUqglqVRZagtFqJ
hquGi6VFscQBxREIihGwWFKQIgqhuCCIAa0FW0SWVMEEqEtrZdFyvrn/TCaT
TPL/53znfZ/HaUtyaLSRQCBIm3qR97E35OJBgJcQBB5ZTqGuYmj5M2ThG08h
BAi6VWfCxHDuuptiX7oQ3Kue9ctixZB/oDA86q4QqKga9afxYvB2nz+gFokg
oHGkQLtBDEvi7xyZ96UIyvY+6q72FEOEl1X7oiYRvLZ2bfzLXAzWF8aizWZQ
ELxkY86Wezz43VcyJzwpCJp4Ltqk4KFV07z60TYKHN/3vpETwENMfkG/ZxoF
lx9LDuUZ81CjtzZYZlLwm63mcmM9B7quOFlfBgWRNja/T8o4uHX50v17qRRo
Ci/nNPlwIBy/yRyeul9bhSTB2ooDF8Oo6VU/Cu6+HMnN+oOFMIdJna2Ygh1x
WcvCuliQ/0vb2juLArM6i7viNhYexo26Wz4VwSd+Dfx2LQuuO3xFAZ0iCFnn
cPB+Dwsvz/ha9jaKIEJ2ZM61MRZOdXQFj1VO7dcnUdPnxIGUDsmuOyeCkrzB
f4eFctAr91cHqkSgHnh/sDKTA6XA+rS+QgSmQ/4G22sczH492dakEcHu/w2X
rJjGQ0TG1vGuByLYpGKPH/Xg4W2Vp/zq1Px2GHyvxyfxYCTxiEldTkGqj3r+
6lweooZ/qjbfS0FO5nmDmZoH+RVmblETBdscIl4F1fMweNfxXNAcGgwVbukF
tTx85Vh7XbJ16vPF2MXfnebhtz0LjG6pabjTYDwrXsbDrZOJWrsJGm6Lbe4M
rubhwJtD5QnLGdCv5c5ypjw4yH+WZCUxsLTeZVdLIwfa475ZW44ycGalKurU
bg7Wa5mHs08z8Ktxp2Qdz0FHnc/5sRIG2hO3R60ZYEE6XuuizGcgUrusbJGS
BY2X8L8xcgYK2+fMd41loao28773VgZytiSU3FvKgnCfzmznCgbysk02u1uw
ENtQmupqxYBHS5LE/CUDh4veytk/TINxfZmfZpCBgyMn6clmGla0G4Iljxh4
0v/LgeZSGoTzjKmhUQYSdqY2Z35LwyVwURQZs7BKVX9i7wEa+OcubtnOLLQs
03WnS2kY9wo6wvpPrbe2Qh0moyG3Vfrh2lQWVBa0cufXNDiG/rU9pZyFR7xq
vV8xDVbLUqjoqXz8/VmTdu41GsorbwxqzDlY9KDUrfMZDf37zlu9cOfgnerJ
i284Bnj12vyM9Rz4FKVmSRIZeDqsv/BZEgeme0/YeVQz8LJ4RqVdCgdxvl8Y
lRmxkFVpkucVw0HYeMKD/4SwELFQ97HMjwNvSUnYR6dYiF6o/7HVnoO3Vlbp
Q/pZ0AVOx/dbxxW15PvH0qeh5HddPekryf9G26u6yX0+/r0I75tys24aeU7H
zFx8bmR63zyyjsiKlO/Juob6mr4h65wedA/XPZ7vj/vQNTtbk329lk4sJvv0
v+g+RPb9ONYO55Dh2INzsdYZ45zswzfGk7nN3/Z1EZnjB8JenGv2Ehucs43j
Dzj3GOcQPIdBuQLPZfkMFzynluMKPLdwJ8MNco71K+LxXLniNXjOraXhIeTc
1yW8izloeM9mDcnFH/Jd35KcmC/twdwYqm0xRxsSZJgrM68gzNnn9TrMXZHl
aBfJ4cOYo5jLWHt5GuZ08hLmds0uC8zxC7dhzDXQx8pJzjtnRyaT3Me0J/eQ
HsAEv5H0glqc8Q3picNmNfYm3Wkm9qjOshR7lSyrKSM9+yXwKPbuiUfubdLD
H9t2Yy872kOnkZ5+mdOBvU0x7r5Getxbdgx7nbZopYr0fLeJGnv/rjTAlnBg
j2ocuVBzdaiKcCJo1SvkhqAzOppwZFPHIeTKoYakg4QzNaqtyJ0Tb58cIxw6
9uyDs4RLP7l7IqeuWKUht7IfRhQTjp21CEauFShyK5Fzehtfwr1mpfII4WBn
40nkYkz5AuRkh1EDcnPgVOEcwtHbZ4KRqwJnpZBw9u+x58jdig1+yOH9gX7I
ZZfnNHI64MMbyO0S+zDkuFK4II9wvfJnb+R8i/h75L5ptjV6IM5+moJ44Ycn
AvTE0j+j0BsWN1X7iEfmJppcIV4xmxWoJ57pTq1B7+y60NZHPDQh/Qq9lKwf
9SWeGjnoThFv7SlupInH4j0K0GvLTd5Dz2mM4tF7jlJWSzw4OGz7gHhRyw8c
Jp4sqbQtJN4cWS/uJx7d79aFXu19UfEJ8eyr8HcGiHdnpqzKIR7e3P4Evexy
LHYB8XTvTAV6+/PpdlM+d4bx/3v9HxP1aBI=
        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {13.316594195929966`, 13.316594222062754`}, \
{-1, -1}], 
       {PointSize[0.04], PointBox[{9.99999997334337, 13.99999999999999}], 
        PointBox[{10.00000002665663, 6.}], PointBox[{6., 10.}], 
        PointBox[{13.99999999999999, 10.}]}},
      AspectRatio->1,
      PlotRange->{{-1, 21}, {-1, 21}}], {22, 22}, {0, 0}, {22, 22}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.005], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{-1.0009326700810561`*^-11, 10.}, {5.999999999982448, 
         10.}}]}, PolygonBox[{{3.6, 10.}, {2.4, 9.6}, {2.4, 10.4}}], 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {3., 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{20.00000000000066, 10.}, {13.999999999999321`, 10.}}]}, 
       PolygonBox[{{17.599999999999994`, 10.}, {16.39999999999999, 10.4}, {
        16.39999999999999, 9.6}}], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {16.999999999999993`, 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.999999999999995, 10.}, 3.9999999999999947`, {
         3.141592653589793, 6.283185307179586}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 5.3048000000000055`}, \
{0, 1}], LineBox[CompressedData["
1:eJwtVHk01QkYtVWkhkhv+b33LL33W+hgFDPJ6IoslUTZKqY0kozTorQvHoNC
NVnqCJFKVDK2LFOTcHAeRczTPIeQLBPSvnhpfjPNd8537rl/fN/57r3nfMZB
O7yC1VRUVHzY/he/Fheq/6EYWQOrRCXxHIwWRtoY2IlRN849PGLJgT8+dfXG
inG34/ETDxUOTCtLLYe7xMhulAbvnJwHoSCs0c5agjR1t5GXJhx4bIk+vyxR
gkN9r8v2RnBQ1mtgnqmQoDXAqdNokJ3va+/RJUhcMwx0K9jFRVXR7Uh6BYmJ
kQdnL2nzcMsuKi9qK4mUyNGgS/k8pCx0e1G1k8Txmdlx4mV8pMdsvKsfRsJE
EU29b+ajrXiWdbcfiaMqO275OBLwf1ST1f0DiRtLp2q7LhK4oxNjVy8kEXhQ
oBPSQ6D54sQi2aQEljmlDRIlAbu/DNKOsfdpyJNLi98TWOj/5FV7tQQf/HMV
Tm0ErLeV6a/JkaDSKThTfpLAaFvg4QBWX9qelRo2NIHFyXm2p45K4Pzy4/pP
hXyszQjTqjsggWd2+JItJB/T/nCtER+XYG5ByIb553h4Y/FhqzxZgiq1jpM6
rN7T3kRWYrkElJeFY3YiF/R3Xfu/DEvwc6kLuYjk4gHTmRBuSmJbBdrm9HFg
Vf1OsHo/icGAM8lOdRxUb1X0eD4gUeqY3pLUzgEnSu56j6SgTFdcLfmGCzIk
SIs+RKEcRvGhrN8j3DaJQz0Fp97oU0OvuWhptOp7+IWC/mSbgV4iD6p+zyd9
KBq3M+8bDZnzIZYm5EXa0lC6X1fI2/iwjBncPLaYhtmBGKvfwwjc71ju7ELT
OP728rDnWwIJifknfbVoLPXzI8xDBdD4kfTI6KNwREp77aoVwPujlMkvoxA5
smpgi6oQf8drJ948QcFiKE+0yFiINy69V8WbKUxG8P1fsHxSttGzzJ6C7ZD3
6hJ1IdpbJxogpkBp1d6bahDgxrSKNwb6FOpqwlu+7BJggbPmB+tZFLK9ffxq
pwugr/d8/IwuhZjwqWDrJAI5v+0rMjGmoBmiXDs2m0C/Tlr8E3a/3x7Gtv4s
H/GW7xbs2E6BE5EVYcvmd82pOq4ul8LM3AGr1Ec8NDuHvi8cocDj/Jnbnc1D
nK459wTrRysRVVHB5ju4ceIZeZqG1k7P0cAqHtaYHO7mPKORstdRPj6Dj+1k
z6Ml1gzu6cY6+B7i43iH06kzBxi8M9NY/kabgFa1Ybr2TQax9nLfpkLWzzOV
xaubGSSkRj7V8xOgyXzTLl05g7NzxtxblQJcsXeQMjIGac6zbcaThRjfORbh
UciAO5p4vmueCBVN+zPORTOQfvCoj4kSwbx5nNfvwSAkQ3lB0SaCziv3Za5c
BrvVmPXkDEP472j6JbuPRnIvb324sSHcFIc3GxfR8B+1VuOw3PWa9zsqjkbR
T3dTR6YbQjNt4P38UBoBZNGwV4cI98de6uX50mh4XiBSJIgw3TGp//RaGp/X
bn+R9K0I0hypiUMAjcLA63dcZELUXLZJaN1DYzhUfiN/kxAZE6WhvHQa54sP
zm35JEBB54XFec00ymSqupdyBdDtqb56UJtB3KcgmWawAJYyNV71Ola/6Iik
3EWAxodenbuvMNg0lblB3Yv1x/2S3r6PDB65r/heESvAsWPGRqkrTbHOIgjK
AQFSQisva6eZorzf2aB3qxATxTZS+3aWfzapXa4ugmpmqu+xKVMkV8u+2Vso
wukSH2XVXDNE//o4c2iDIawGdcmnLP/6T43+RzP8A4COQGc=
        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {5.706292966747745, 12.23006116185843}, \
{1, -1}], 
       CircleBox[{9.999999999999995, 13.05}, 2.0499999999999945`, {
        0.2213144423477913, 2.9202782112420023`}], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 15.795199999999994`}, \
{0, -1}], 
       CircleBox[{9.999999999999995, 13.95}, 2.0499999999999945`, {
        3.3629070959375844`, 6.061870864831795}], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 11.204800000000002`}, \
{0, 1}], LineBox[CompressedData["
1:eJwtVAtQzXkUTu9RSXoQPaj7f/z+/9u23V7c6vZlVFqU7HoUYtGmGGF70YuK
q0mm28bdbct65JXqovIoTAo9WHUTFTaUXqIhKutRe5k9M2fOnDPf+b45M2e+
Wesil4Sqq6mpLVPl1/px/GvwUPsWAoi2rVmj6ybEi8y0BfnuAiwNtjd0/kUI
g1l5TZelArT6aZZWJQoR2F+v/uCJAPuiHubFJguRqz1UpetCQfNeWYnJJiHI
9lslNfspuCyWSBbPFeJu9Jvllx9RqMuw6czVFUJrsvDplek0Jtr7bJVX8whN
cr8V4kdjysGToh3RPC6sMalbEEpjQsb7/C00D70H92/MiqSxZ+REsfMjDu2d
YZrW4TQkUXnnunI4RLbs+ShbRmPYti2lNYhDd/HOPIkbjUEmaewGz6HS7KCy
RaVH3/xSoNDn8LbXyevABwpndRZ5a48RZGsdWKLWSsFvvm1xlBoHakzxzPYy
hW6rzqzHxhyUXSO++/IpBJfRRmJXDq97Hr7O20eh8a/W5BMbOVz0e+A4spNC
alh3ov8JDldF0pW/xlCon7L5kqyfQ5as46wokULMq/UwduDhMSfzB38ZheaZ
tzz6Ynhs7v+SsKmMQj/tK24t5xFY06Hu1EsB71xXXerjUeQW+e8jloae0YLG
wYlCxOkbxitjaLyQkgx1cyEqVodcrbtL47nVHaMZRkIwnwZEhhSDgHTt0uB3
PN7mDdp57mDQti9Qv+8Gj+wU+aBlDQP2D7Hi2C4ekikLveO/MDi813eOzIkH
yenyfi5gket3SGzXxWHRwZHpQ64sPntpBVyRcTBc5egbruo7TS9Z3J7H4eWZ
1oS7FAtRfH7l6DhB06cay15tFf4n7Qrt2wQb9xSO2j9lcC1a7WHP7wTKc9MC
nEsZxNFFRSM7CDrSa10FUgbubfkXrCMIFvZcV8aFMEgtfZnVHk5QsmLF0D9u
DAo7Vk2fosJzmU0T3GYxWBt2Y1RLTnDnbFVbtyGDnUmjsdOrCdoUGjndugwO
lc2X3R4laJkbXGtnoNp3nSz4zYlD+WxzSYUlA5PznjbOURzSLNnCeBW/R/Fj
verzHCYeXZ5rHMYg1yO4aLxX9T/HO2y3HGHwpFjwstGIR3votbClPQwSunS4
co5HwdvstTYuLExcBC7r7Hkc83Q0L8pgEbIyq8vdiged3R+d/pzFYesUz9JR
Dj1LzWYXOBCIn5gRn+scGiKZBo0YAq/3uzXdYzhMO6LBFpwheP5OvFSb4pDq
eXYxW09wYN5Hp4QmgvV2M5Lm3ieIt7K2mJZEYNxcEFtdRxBw0cd9g4jgvu2f
yUuKCE4uO6dQvGGxOblW+nk3QeYabXfDShbijCYNuT8B1v6tL89msd1z289O
Uwkk4eZ6JbEsnIkNTj1jMVCb2R4UweJcmk0ApWAxmJPSEKHqvUytjhvsZaHD
pMgTVfigD+k+LWEsUn+MsG3LYtFW9cjAaBkL//MWXqJyFU/dmOJMIIubrwo8
dnWymCcx6tJZycLVaiC/2ZRgKNbczne7at45u2b5AoJO4/ftPnIWq+9FXE9T
3WcRbngqp56FxNlwfEMhwUy+Wy7SJRg7cTNXv4HApPqp0i+QoMr74lZB+9e7
4zT7jhKwlX2Ju1oIZnjIJvUNE1zjW/VPVxAcGd5QYjWfw9EOqZXDfoKppiYD
ymwO4o0JBs0qfdu8xviIJg6+CUFB5mMsJinLns75zCHU5/s7ytMshlNzpbQx
D95M+p3DEhaOduPPTE14fPrmp8z/fsrjPwQ/Oso=
        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {14.283684782537893`, 12.224334161450233`}, \
{-1, -1}], 
       {PointSize[0.04], PointBox[{11.99999999999999, 13.5}], 
        PointBox[{8., 13.5}], PointBox[{6., 10.}], 
        PointBox[{13.99999999999999, 10.}]}},
      AspectRatio->1,
      PlotRange->{{-1, 21}, {-1, 21}}], {44, 22}, {0, 0}, {22, 22}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.005], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{-1.0009326700810561`*^-11, 10.}, {5.999999999982448, 
         10.}}]}, PolygonBox[{{3.6, 10.}, {2.4, 9.6}, {2.4, 10.4}}], 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {3., 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{20.00000000000066, 10.}, {13.999999999999321`, 10.}}]}, 
       PolygonBox[{{17.599999999999994`, 10.}, {16.39999999999999, 10.4}, {
        16.39999999999999, 9.6}}], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {16.999999999999993`, 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.999999999999995, 10.}, 3.9999999999999947`, {
         3.141592653589793, 6.283185307179586}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 5.3048000000000055`}, \
{0, 1}], LineBox[CompressedData["
1:eJwtVHk01QkYtVWkhkhv+b33LL33W+hgFDPJ6IoslUTZKqY0kozTorQvHoNC
NVnqCJFKVDK2LFOTcHAeRczTPIeQLBPSvnhpfjPNd8537rl/fN/57r3nfMZB
O7yC1VRUVHzY/he/Fheq/6EYWQOrRCXxHIwWRtoY2IlRN849PGLJgT8+dfXG
inG34/ETDxUOTCtLLYe7xMhulAbvnJwHoSCs0c5agjR1t5GXJhx4bIk+vyxR
gkN9r8v2RnBQ1mtgnqmQoDXAqdNokJ3va+/RJUhcMwx0K9jFRVXR7Uh6BYmJ
kQdnL2nzcMsuKi9qK4mUyNGgS/k8pCx0e1G1k8Txmdlx4mV8pMdsvKsfRsJE
EU29b+ajrXiWdbcfiaMqO275OBLwf1ST1f0DiRtLp2q7LhK4oxNjVy8kEXhQ
oBPSQ6D54sQi2aQEljmlDRIlAbu/DNKOsfdpyJNLi98TWOj/5FV7tQQf/HMV
Tm0ErLeV6a/JkaDSKThTfpLAaFvg4QBWX9qelRo2NIHFyXm2p45K4Pzy4/pP
hXyszQjTqjsggWd2+JItJB/T/nCtER+XYG5ByIb553h4Y/FhqzxZgiq1jpM6
rN7T3kRWYrkElJeFY3YiF/R3Xfu/DEvwc6kLuYjk4gHTmRBuSmJbBdrm9HFg
Vf1OsHo/icGAM8lOdRxUb1X0eD4gUeqY3pLUzgEnSu56j6SgTFdcLfmGCzIk
SIs+RKEcRvGhrN8j3DaJQz0Fp97oU0OvuWhptOp7+IWC/mSbgV4iD6p+zyd9
KBq3M+8bDZnzIZYm5EXa0lC6X1fI2/iwjBncPLaYhtmBGKvfwwjc71ju7ELT
OP728rDnWwIJifknfbVoLPXzI8xDBdD4kfTI6KNwREp77aoVwPujlMkvoxA5
smpgi6oQf8drJ948QcFiKE+0yFiINy69V8WbKUxG8P1fsHxSttGzzJ6C7ZD3
6hJ1IdpbJxogpkBp1d6bahDgxrSKNwb6FOpqwlu+7BJggbPmB+tZFLK9ffxq
pwugr/d8/IwuhZjwqWDrJAI5v+0rMjGmoBmiXDs2m0C/Tlr8E3a/3x7Gtv4s
H/GW7xbs2E6BE5EVYcvmd82pOq4ul8LM3AGr1Ec8NDuHvi8cocDj/Jnbnc1D
nK459wTrRysRVVHB5ju4ceIZeZqG1k7P0cAqHtaYHO7mPKORstdRPj6Dj+1k
z6Ml1gzu6cY6+B7i43iH06kzBxi8M9NY/kabgFa1Ybr2TQax9nLfpkLWzzOV
xaubGSSkRj7V8xOgyXzTLl05g7NzxtxblQJcsXeQMjIGac6zbcaThRjfORbh
UciAO5p4vmueCBVN+zPORTOQfvCoj4kSwbx5nNfvwSAkQ3lB0SaCziv3Za5c
BrvVmPXkDEP472j6JbuPRnIvb324sSHcFIc3GxfR8B+1VuOw3PWa9zsqjkbR
T3dTR6YbQjNt4P38UBoBZNGwV4cI98de6uX50mh4XiBSJIgw3TGp//RaGp/X
bn+R9K0I0hypiUMAjcLA63dcZELUXLZJaN1DYzhUfiN/kxAZE6WhvHQa54sP
zm35JEBB54XFec00ymSqupdyBdDtqb56UJtB3KcgmWawAJYyNV71Ola/6Iik
3EWAxodenbuvMNg0lblB3Yv1x/2S3r6PDB65r/heESvAsWPGRqkrTbHOIgjK
AQFSQisva6eZorzf2aB3qxATxTZS+3aWfzapXa4ugmpmqu+xKVMkV8u+2Vso
wukSH2XVXDNE//o4c2iDIawGdcmnLP/6T43+RzP8A4COQGc=
        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {5.706292966747745, 12.23006116185843}, \
{1, -1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.999999999999995, 13.05}, 2.0499999999999945`, {
         0.2213144423477913, 2.9202782112420023`}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 15.795199999999994`}, \
{0, -1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.999999999999995, 13.95}, 2.0499999999999945`, {
         3.3629070959375844`, 6.061870864831795}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 11.204800000000002`}, \
{0, 1}], LineBox[CompressedData["
1:eJwtVAtQzXkUTu9RSXoQPaj7f/z+/9u23V7c6vZlVFqU7HoUYtGmGGF70YuK
q0mm28bdbct65JXqovIoTAo9WHUTFTaUXqIhKutRe5k9M2fOnDPf+b45M2e+
Wesil4Sqq6mpLVPl1/px/GvwUPsWAoi2rVmj6ybEi8y0BfnuAiwNtjd0/kUI
g1l5TZelArT6aZZWJQoR2F+v/uCJAPuiHubFJguRqz1UpetCQfNeWYnJJiHI
9lslNfspuCyWSBbPFeJu9Jvllx9RqMuw6czVFUJrsvDplek0Jtr7bJVX8whN
cr8V4kdjysGToh3RPC6sMalbEEpjQsb7/C00D70H92/MiqSxZ+REsfMjDu2d
YZrW4TQkUXnnunI4RLbs+ShbRmPYti2lNYhDd/HOPIkbjUEmaewGz6HS7KCy
RaVH3/xSoNDn8LbXyevABwpndRZ5a48RZGsdWKLWSsFvvm1xlBoHakzxzPYy
hW6rzqzHxhyUXSO++/IpBJfRRmJXDq97Hr7O20eh8a/W5BMbOVz0e+A4spNC
alh3ov8JDldF0pW/xlCon7L5kqyfQ5as46wokULMq/UwduDhMSfzB38ZheaZ
tzz6Ynhs7v+SsKmMQj/tK24t5xFY06Hu1EsB71xXXerjUeQW+e8jloae0YLG
wYlCxOkbxitjaLyQkgx1cyEqVodcrbtL47nVHaMZRkIwnwZEhhSDgHTt0uB3
PN7mDdp57mDQti9Qv+8Gj+wU+aBlDQP2D7Hi2C4ekikLveO/MDi813eOzIkH
yenyfi5gket3SGzXxWHRwZHpQ64sPntpBVyRcTBc5egbruo7TS9Z3J7H4eWZ
1oS7FAtRfH7l6DhB06cay15tFf4n7Qrt2wQb9xSO2j9lcC1a7WHP7wTKc9MC
nEsZxNFFRSM7CDrSa10FUgbubfkXrCMIFvZcV8aFMEgtfZnVHk5QsmLF0D9u
DAo7Vk2fosJzmU0T3GYxWBt2Y1RLTnDnbFVbtyGDnUmjsdOrCdoUGjndugwO
lc2X3R4laJkbXGtnoNp3nSz4zYlD+WxzSYUlA5PznjbOURzSLNnCeBW/R/Fj
verzHCYeXZ5rHMYg1yO4aLxX9T/HO2y3HGHwpFjwstGIR3votbClPQwSunS4
co5HwdvstTYuLExcBC7r7Hkc83Q0L8pgEbIyq8vdiged3R+d/pzFYesUz9JR
Dj1LzWYXOBCIn5gRn+scGiKZBo0YAq/3uzXdYzhMO6LBFpwheP5OvFSb4pDq
eXYxW09wYN5Hp4QmgvV2M5Lm3ieIt7K2mJZEYNxcEFtdRxBw0cd9g4jgvu2f
yUuKCE4uO6dQvGGxOblW+nk3QeYabXfDShbijCYNuT8B1v6tL89msd1z289O
Uwkk4eZ6JbEsnIkNTj1jMVCb2R4UweJcmk0ApWAxmJPSEKHqvUytjhvsZaHD
pMgTVfigD+k+LWEsUn+MsG3LYtFW9cjAaBkL//MWXqJyFU/dmOJMIIubrwo8
dnWymCcx6tJZycLVaiC/2ZRgKNbczne7at45u2b5AoJO4/ftPnIWq+9FXE9T
3WcRbngqp56FxNlwfEMhwUy+Wy7SJRg7cTNXv4HApPqp0i+QoMr74lZB+9e7
4zT7jhKwlX2Ju1oIZnjIJvUNE1zjW/VPVxAcGd5QYjWfw9EOqZXDfoKppiYD
ymwO4o0JBs0qfdu8xviIJg6+CUFB5mMsJinLns75zCHU5/s7ytMshlNzpbQx
D95M+p3DEhaOduPPTE14fPrmp8z/fsrjPwQ/Oso=
        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {14.283684782537893`, 12.224334161450233`}, \
{-1, -1}], 
       {PointSize[0.04], PointBox[{11.99999999999999, 13.5}], 
        PointBox[{8., 13.5}], PointBox[{6., 10.}], 
        PointBox[{13.99999999999999, 10.}]}},
      AspectRatio->1,
      PlotRange->{{-1, 21}, {-1, 21}}], {66, 22}, {0, 0}, {22, 22}], 
    InsetBox[
     GraphicsBox[
      {Thickness[0.005], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{-1.0009326700810561`*^-11, 10.}, {5.999999999982448, 
         10.}}]}, PolygonBox[{{3.6, 10.}, {2.4, 9.6}, {2.4, 10.4}}], 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {3., 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{20.00000000000066, 10.}, {13.999999999999321`, 10.}}]}, 
       PolygonBox[{{17.599999999999994`, 10.}, {16.39999999999999, 10.4}, {
        16.39999999999999, 9.6}}], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {16.999999999999993`, 9.0548}, {0, 1}], 
       LineBox[CompressedData["
1:eJw9lwk4VfkfxiW5yJIWdzv3uqu7UVEppXpNKZG/0kaJSDKUrSJJiESLrFMh
qWnRpmbaKVGRFjIlQk0NZVJKosgV/zvz/Obe57nPec5zzzn3/L6/7/d9Py/f
J9h1jaaGhka/6vvPsW/wn48C/x4GhXCN8JKWjDWH1bwHFePuCJF/TdMvaKE5
bHbdGBW+VQg3vb1N99eYY132tCWZY4Wotpl82D3AHPxYl3c6LwWI7p+9/Yin
OVYUaf6vbLcAyf2N5eNnmcM5Zf+cohkCbM5avzqTaY4TMa36ud/5sEwOeGX+
RoHsuvBq71t8RPkGJnUcV8D7YIoJM52PbQsmPuL6KODb9La9NIyP+ZOHfhxG
KbB5O32xozcf0zeHfCirk6OiPMH6igcfVK1GO5UlhzRxbZ3Daj5md9BnbHWX
Y2maTXel6v6bO3kfX4jlcB789Ko0iY/Fn54FPlfKULlau//aUT4K5pjePf1C
huEPG+etKeEjv/gv/0n3ZUj8O452u4GPVU9rY/rLZAi58MiY28VH2gPNqab3
ZDDPnZU0WlcA131dd5yfy3Arh9UayRJg3ZWjBqXdMiQHcpQ/mQmQbuk4Yzxb
jglleQHrFQI8thLlNc6TI/NPC4tOqQDdPX734rfJsfzCby2lHAFGXWTs3nFF
jr2WLx836QjQ7KG0bfkkByshPzakjY81OFXgJ1LV6+yz5cNV9cvUj2bcW6TA
l4z6mspkPt6OeNPeGKnAQH7UQKwjH2/s27SeZChgVRWk26zJR9DOCVobDyvw
wCIqPOQyD8pwxcLlOQqkG5fl+q/hwaFosIy9U4FL+fzvcSY87Fl4ZMOq1QoU
RXLjrA+awveURXa9per6RRzPKyam2NXcUWD4VQ7N7kMJp85wYdRwNm7cBTmy
B8/2RHpwkbttZtYFPzl6dKdLIhVcpE5jbtKi5EiVHdt/l8GFRfHkrCVPZbB8
wh76s4CLsLCoucv2yRA7QhF6dTYXfR4t28e5ynBmvd6yoi1ciP7u943gyDDk
5t1PV0u4qNLW+uL0RQpvp1rP3/RMYf30sZPfH1Jc70iZ88TNFAXpY09YFUtx
f3L2sspfTTF+46YFr85LwQtMNh9oNcXI8dujV6nOlfVH6lcYqdbvstP45+tS
LO5IqtER8bCubvDWiiopBtbWlGwcz0OlvHKXzXspMvbSljdN4OGMuefwDEMZ
PgV0p1+w4IHbXM6KmyJD2rzRn1M5PHy7Fa08uUaGaYvt82yH8hBdOebinAxV
f11+/BY3TXF7Xj93UYkMjyaun9/gZYpsrzPhR1tkmLB83bKADi4STDcPUhpy
6GW5zZUGcVETu2pu3wg5PKPpmcmvOLA4GyEaMlqOxpM9/ssdOCgw2ut8lyZH
UdiPD3mFFO52fY168kH1/Jc5i2cwKZw7Rv1WUyqD/5Iyr6372Mih/7CNSJKh
wqN1uiuDDQ2fUylB9jJIlct3lV5nof9xQ62hUoqx4ftyrTez0HUmPnT4OSn0
79P2SZaysPRudxzdS4pep1c3mhax0Njd15s2Woo9HlUj44JZCLFqP29fI8GI
RzGDIcdZSAmi0+0zJTgq4Y/O+cxCxIXMcS3eEqQGp7/RcGKjqyXqdrmNBCML
Gj5YFrJxyWHvfh1Kgj8ymm2LR1Gg2IEBa3UkaP5m75CwicKHxaIjvgNm+N3N
zcakmgIzyuqb7w8zuB3mX69icPDHwaBbxVoSrM24VNyzkIN7DlahJ0dJEGZQ
FNYYzoH7wPd8O5kEiVHsnLM7OPg99lag/2wJZvlvCI+JVp1POrakYLUEkxql
SwSeHIivBQVZ7JDA6kroZh0pB8dKphqXnZCo9q9iyNQXFJzW6G6pL1etrye4
ZclWCp0jR5sVvpLgxrG18cf1KOzYmnovslMCE+P3QttdbJjRmhLyeyUY1qKp
HDPIwtPob3LlFwnSaaeFkiAWXj7s/TJGdf/Oz+drHF8ywdj49cnaGxLInnvr
6SxiIuXHvmvhuyXw768Ty+sYKCmVTnvtrKpn3xiO9XoGXjDvX7bTliBjuYt+
DYeBDzb6WhrXzCBbkGQnb6fDizpt+9XPDHjFdtnfSEehMJ47gm6Gt+xQQ9c2
OiZeGtve9VCM+dvTp8SbMHA2u2z6ySQxag9o74zxZCBWnPvNw0WMCzT2+7E3
GGh1TTRayRejsiyRliRjYsOJ4Lv6gyKEZa4vHp7PxCOzWu8R70SYMW/ML5ZM
FpyijnhFN4kQsNDo8c0Uluq9pHojn4sQy4ZEQ8nC9Z+37fJ/IcLwEzZXB93Y
0BFU23P+FuG98bCBA8fYsD7Udqflm+p3zjLn9EY2aIWjDJP1xHgrvL+6oJeN
SmWIopUnRsInV9uMH2wc6EwMqZwixuq8/AbNNjb2OwXb1i8Q48GAjiSrmI3+
DfulMWvFOLPju25lOBtb+l/ntW0RI7/TVr+dYsPJzX73sGQxGmvdQ9m/sXC+
T/Th6D7V+vMuFlhPZmGigqo6vEeMqbW0Xc0XmdD3sPtJsE2M3uP0sbHmTHSZ
2xg89xFDmscJHnWSgalf7B9YTRXjmL/RQwM5A6d8Vtn/oiXGDf7rsb3FdMxO
s5wefEeEiaHjAgZ86Dh/o3eZIlKE0qHyHH8RHUF/b8oykolgV+b/3ESLjt2M
XQGf64Tqc8dZtILaRCFukesvB1XfTrUVYgJ53oJDh4t+VgrU/3fLoGhSVblA
/T7aTyu+SA4JYEbe9+OvJTdfxgnwlaynvLbFatUGAaaQ9ToOaxq9MkSAs6Qe
hSeLNvaFC1BH6hU91NTbZIcAeaSeP3b718ceEOAUqfeqS6l3pOcFeEj2w9sw
ct/kewL4kP0ar7WvlvlKgB1kPzsXtneGfxWglez3XR8TW0pXCAPSD59fWhY1
M4RoJ/0y85e4TfuFQhiSfqo5X//1o0So7rfCBM/87SIh1pF+tGhQ5HXQhZhJ
+jXRPXVal4YQG0g/jz4X+fnonwI8IP0e1bha99cLAvU8OK+ZcdstQrV+Mi/l
Tn+M0p8ogDOZp/kvtv7V8Y6vnrfcliV39A7y1fNoWNGlHJzLV88rp9XaseQ7
D5lknqfPrL9r+jsPKWTe12mGzE3eyIMf0YPm3XoWB2bxICd6QU2kGbznqXyd
6InZdt1nWgY8td7U9oqivGg80IgehccHT0k05IFF9Ir28UPDQtX9RUTPCrO/
7ZBO5an1bold+acZ7jxUEz18Mjct7ckWnlovHR6sOL0sl6fWU4cYZO4v5qn1
9sgQba+SOh52Ej2ecLUqxa2dp9ZrmV8aZitV6yN6/jqhSjdHxTX/6b3BmSbP
nCF8XCF+8PJNZtaBHh7eEL+YfTXMv6eFhyriJ9pUwvSpFTwYE7/Z7hJYQ+Wp
6kn8KDDt3buiQB6OEL9Krhq1oGgcT+1nM030DF/Umar9DhEm/TV2pvhO/FCn
oJdqO86FAfFLpdf8pc26XIwjfvpl2rlmwSaO2m9v1AxLNO6g1H6ce6XikOc2
Cn7Er/0Zo3VWSCnUED/Pf/3WN+IzG6XE77NPjrj6o56t5gHXgRmhw/9UzRHh
hfZSoyEVg2zoE564jVMji6dQsCa8EbKOdts9nsJDwiN9QbUHwxooNa/oxWrp
XpjIUfPMlWkbH/xI4SCd8E7eiVltDc0cNQ+tPh38fo+K+zIJL3EXacQ6rOHi
B+EpX+/OFxZ7uWreqjms1Jp5hKvmsUz6GC+7fC64hNeONR69mJ3MxSPCc4nu
q/wnrOSimPCe25cetj+bCx/Cg+csta2NyznQJLyoMcemL38FB2cJT+qxdUMX
/kVhG+HN3OTUZ4vdKYwjPFqdVDWm5x4b6YRXL2vGPcuzUvkE4dla5xP9+YdZ
OER4t2kqr7B5DAs0wsOyc8ceLshlIovwcoPHTcZMGyZK/+Pp3RpbKzsZuEx4
u9/41Eqn+wxkER5ndB7ooZcxUE14Xb7R4tuK5ww1zyv+nGzmqM/EIOH96tZh
j0PdmOgmeUAec67Q6ioTPiQvWM3RTbQRsNR5ouZgdVt3OkudN0aMsArt1WTD
g+SRpdlX7ziuYyOL5JWa3MD4w/fZ6jxjmlH0JsaEQhLJOwv+Ymz2daFQSvLQ
k4C+3WWhFCxIXprkvlSDptKJYJKnfk+yHZu1nlLnrV/DyiJOz6GgT/KYo3Cx
1EWHUue1zZ9LxHMusdV5LoRfE09zZmMZyXslywYkFc9Y6jy4xchUttWVhXKS
F93Svou77zGxheTJLs/9a29PY8KP5M1ea1kH7xIDviSPpn6U252YzEAuyaua
z0Q29Y/oKCB59rW248a8SDpcSN7t0w5X3viJrs7DbnvSyuYr6BCQvDznw1uH
dRPpCCZ5+kpK3wThSjqmk7y90NjufPxROiaQPP5PZtfQYGDIv0cR/g98L44G

        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 5.0548000000000055`}, \
{0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.493974050732, 10.324871971010285`}, 
         3.5090449505152663`, {2.0105863474436756`, 3.2343067312428637`}]}, 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {5.923353752278861, 12.10602642726922}, \
{1, -1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.999999999999995, 13.05}, 2.0499999999999945`, {
         0.2213144423477913, 2.9202782112420023`}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 15.795199999999994`}, \
{0, -1}], LineBox[CompressedData["
1:eJw9lXlUjXkYx+tKUrJURIN777u/lzJjiZR8MWWpK1lv65m5KqWmZWQZSYvC
CO2ihJAlWyqNZcgyGhGubCUdZTuWq4WajLa5xnve3znv+f3xO7/3+T3P8/1+
Hrk6bL6/RE9PL0z3fd2/LRm+7aPwT2vGbItSKY7eVlY/Pa3ABOe3qYbZUsQo
vYLrVAqsUh7VhJ6WosUxzFrZyeN+F/uosUOKaRGj7WsP8qhv821R28mwccag
pv5ePDYvv/7gU4IMXqp9EaU0jwYrGI+ukeFWhuGtK0Y8tnSlZm6ykWOLBxtY
ZcBD1VVmUrZejsDqS/viLXls1J46F39dDoW/pZmNA4/FnvaKFD0Ca2822GlD
eGjrlAGOYwjsnnNh5roDPP4t7GdwzZ3AYe9hvfWf8LBIismNCiSgyTvYuNFE
gQ8nP/qvWUFg392hUarxCpib3ev0/5WANulQk3S+Avu1QeUaPwKT5toO1CxV
wHlw+c49cwjcnn6r2D1IgcacQ7nbKV28Q9tMDXXne1W3lu1olcOsLsJ4hrsC
PgNk+/tckmNm88YNX8YpYF+oVxKdKEdiYPyUM8YKlKUjP3ueHI+5SZrmB7r8
bJsjM2k5kswHxVam8eC+cwvJMJZjSHSdhcaJh5Nt7OAqAzlCLhiM3dDC4Ykq
J2C/pRyO2e4Xt+ZwuG/b5Z08Q46srKpNNi4c2o9WLKzVxbOI/6xljDh0D/PP
PlEth92Q8EVTa1gs0P5+rXMcAftZztbtV1lMs/BtNkgmUPLb5rTSchbdL4eY
NTQQ2FqDFZefs1jTci23iiHRONyr/p4Zh6SMjzGvPUkYjK0olLtzIAIe9nkR
TWJpSspddRYHm+K8Q/tTSaxoN41LfMahwJh0ku4iEX3HliIpHi0Tlamrs0gE
Z/Lvj/zEYxnrcmxUMomqiXRBQCqPc4sWFJ2LIyEdOledW8wjeKJ+7ZEwEo86
PY6nXueR8W6Oc5tK957qAr+0ch65u3+YcGYKidvHens1lPLQ0494cWUkiUku
Vy5HZfEwSy1s/75bl1/f59GPg3jMfGyeuO4Zgcf3L3aeHcNjbb3JcuXfBGzS
CwynvudwUPlq3IfzBB5VW/hwezk89fZsDSsj4JQpsRrvxmEI9JNPVxMY+07W
pNbjcL00vXi+EYn0yBEtT86ySKxVlrS6klhCX/adHcNi++auqC95JDzldI/G
g0VXz9dFQlOpW64sQlZLEnr7UuJ5JFXkYlJMiffHzw5xPdFOIU34/6uy7vC5
LC3GH3Eg3yQFNH4U3re4yKrSzInGQ+H9sdLWzKJJNKyF/Eo47doNMlrM/22o
m9FdfVqsT0f39uGODZRYP5+ld27OuUqJ9Q0YfOac8WFKrH/KjW5qSQol9md6
wXGl83oKMqF/adUlCx+EU2J/+94oCt0cSIn9n9f29Hx9ACXqo9LV18MnlMJK
QT81uxSfh8dT8BP09UuwaeywfAq9Bf3F9XdQW9dQoj6/WL39MHIkLer3/Pu8
AR3htKjvfPNVDr0qaVH/Ha+y/eezjOgPyWLbY9RaBmaCf5gKyYHwPxlkCv6S
Hfbb5fOGEf1XWhHzzrqDQbDgz6qXhenBbQwsBP+urBiQtPwJgy2Cvx1Cyjz9
TzF4JPj/sluPS7wuXoLAhz3Nz3w+T2NEfngfHr8zyIQR+WLq56GOqKVF/pS8
s1v28xla5JPKfIfdmBxa5NebDza9srfRIt9M3U2zN22lRf69joxVJ2TRqBL4
qO/2qcPhJI2jAj9NiaJdVzQ0cgW+Hsj/62FYD40ogb+R5vOcoyczIp/zJGhF
HIMggd+hktDla+4xSBL4bvmqrO0+w4r8j8icPKpfFCvOh2HGef1zdX1KEObH
QH1thpGEE+eLo8exrFkshyZh/tR7m/zROZbDemE+xSZOqG2jOBwR5lfH/35j
xfn2HxDt6BI=
        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 10.954800000000002`}, \
{0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{10.449854645994966`, 10.292774083425702`}, 
         3.562197172882098, {-0.08228199986392748, 1.120574228356973}]}, 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {14.06662399700678, 12.100299426861024`}, \
{-1, -1}], 
       {PointSize[0.04], PointBox[{11.99999999999999, 13.5}], 
        PointBox[{8., 13.5}], PointBox[{6., 10.}], 
        PointBox[{13.99999999999999, 10.}]}},
      AspectRatio->1,
      PlotRange->{{-1, 21}, {-1, 21}}], {0, 0}, {0, 0}, {22, 22}], InsetBox[
     GraphicsBox[
      {Thickness[0.005], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{-1.0009326700810561`*^-11, 10.}, {5.999999999982448, 
         10.}}]}, PolygonBox[{{3.6, 10.}, {2.4, 9.6}, {2.4, 10.4}}], 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {3., 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{20.00000000000066, 10.}, {13.999999999999321`, 10.}}]}, 
       PolygonBox[{{17.599999999999994`, 10.}, {16.39999999999999, 10.4}, {
        16.39999999999999, 9.6}}], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {16.999999999999993`, 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{9.999999999999995, 10.}, 3.9999999999999947`, {
         3.141592653589793, 6.283185307179586}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 5.3048000000000055`}, \
{0, 1}], LineBox[CompressedData["
1:eJwtVHk01QkYtVWkhkhv+b33LL33W+hgFDPJ6IoslUTZKqY0kozTorQvHoNC
NVnqCJFKVDK2LFOTcHAeRczTPIeQLBPSvnhpfjPNd8537rl/fN/57r3nfMZB
O7yC1VRUVHzY/he/Fheq/6EYWQOrRCXxHIwWRtoY2IlRN849PGLJgT8+dfXG
inG34/ETDxUOTCtLLYe7xMhulAbvnJwHoSCs0c5agjR1t5GXJhx4bIk+vyxR
gkN9r8v2RnBQ1mtgnqmQoDXAqdNokJ3va+/RJUhcMwx0K9jFRVXR7Uh6BYmJ
kQdnL2nzcMsuKi9qK4mUyNGgS/k8pCx0e1G1k8Txmdlx4mV8pMdsvKsfRsJE
EU29b+ajrXiWdbcfiaMqO275OBLwf1ST1f0DiRtLp2q7LhK4oxNjVy8kEXhQ
oBPSQ6D54sQi2aQEljmlDRIlAbu/DNKOsfdpyJNLi98TWOj/5FV7tQQf/HMV
Tm0ErLeV6a/JkaDSKThTfpLAaFvg4QBWX9qelRo2NIHFyXm2p45K4Pzy4/pP
hXyszQjTqjsggWd2+JItJB/T/nCtER+XYG5ByIb553h4Y/FhqzxZgiq1jpM6
rN7T3kRWYrkElJeFY3YiF/R3Xfu/DEvwc6kLuYjk4gHTmRBuSmJbBdrm9HFg
Vf1OsHo/icGAM8lOdRxUb1X0eD4gUeqY3pLUzgEnSu56j6SgTFdcLfmGCzIk
SIs+RKEcRvGhrN8j3DaJQz0Fp97oU0OvuWhptOp7+IWC/mSbgV4iD6p+zyd9
KBq3M+8bDZnzIZYm5EXa0lC6X1fI2/iwjBncPLaYhtmBGKvfwwjc71ju7ELT
OP728rDnWwIJifknfbVoLPXzI8xDBdD4kfTI6KNwREp77aoVwPujlMkvoxA5
smpgi6oQf8drJ948QcFiKE+0yFiINy69V8WbKUxG8P1fsHxSttGzzJ6C7ZD3
6hJ1IdpbJxogpkBp1d6bahDgxrSKNwb6FOpqwlu+7BJggbPmB+tZFLK9ffxq
pwugr/d8/IwuhZjwqWDrJAI5v+0rMjGmoBmiXDs2m0C/Tlr8E3a/3x7Gtv4s
H/GW7xbs2E6BE5EVYcvmd82pOq4ul8LM3AGr1Ec8NDuHvi8cocDj/Jnbnc1D
nK459wTrRysRVVHB5ju4ceIZeZqG1k7P0cAqHtaYHO7mPKORstdRPj6Dj+1k
z6Ml1gzu6cY6+B7i43iH06kzBxi8M9NY/kabgFa1Ybr2TQax9nLfpkLWzzOV
xaubGSSkRj7V8xOgyXzTLl05g7NzxtxblQJcsXeQMjIGac6zbcaThRjfORbh
UciAO5p4vmueCBVN+zPORTOQfvCoj4kSwbx5nNfvwSAkQ3lB0SaCziv3Za5c
BrvVmPXkDEP472j6JbuPRnIvb324sSHcFIc3GxfR8B+1VuOw3PWa9zsqjkbR
T3dTR6YbQjNt4P38UBoBZNGwV4cI98de6uX50mh4XiBSJIgw3TGp//RaGp/X
bn+R9K0I0hypiUMAjcLA63dcZELUXLZJaN1DYzhUfiN/kxAZE6WhvHQa54sP
zm35JEBB54XFec00ymSqupdyBdDtqb56UJtB3KcgmWawAJYyNV71Ola/6Iik
3EWAxodenbuvMNg0lblB3Yv1x/2S3r6PDB65r/heESvAsWPGRqkrTbHOIgjK
AQFSQisva6eZorzf2aB3qxATxTZS+3aWfzapXa4ugmpmqu+xKVMkV8u+2Vso
wukSH2XVXDNE//o4c2iDIawGdcmnLP/6T43+RzP8A4COQGc=
        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {5.706292966747745, 12.23006116185843}, \
{1, -1}], LineBox[CompressedData["
1:eJw9lXlYTXkcxlsYTWmZinkYqnu2m+65t0iZMPUyZKJkV1RMuqTlFkJSWi0z
aHkqKS5TWgYjdSsm0ygiNfaytBjVEOHWkBLdytzhPOf3POc5f/yec77b+36+
At+QJVItDQ2NEPXz//vzscDHT8cK73rTXEzPmWPlFIWQXCiCnfOLlC+yzBGr
yE0jCkTY5nbyjqzYHIaXkusV2izqh4QPulXmuJjYcIVazaK1z+eNr4MFIiq6
jd7kstgXcPXe2wQL5BWsSXRpZtE+HrpskwXsAj9Mdexn8fNQSvpeiQBb8xsz
xCoWHkOVepW7BDgsnLUmqpPFHuXZ8rirAjzI6uy6W81ixaoZVskaBPbYmdWY
pLJQ/u223tGagF/ZnN/jvVh8KBo9onoxAc8TzwaGaRam+6PlO/0J2Pis/mpH
rwhdhT3S8C0E1to8Tyi4LoKJ8d1B6WYCpmGeRm1nRMhRbqy540egtrjuX+uj
IjiPqTl8bD4B2z+nuhYeEqH7SL48kVLH89zc80F9f9zj+oZDvQJ0EYl9FYUi
eBta5Iy6KEC54Y7IkTdEmFGkURq1W4CdGVGX5/eJUJmKvKxFAkx6eM3aUKSu
z/51WDqtrl/ZHW0bzMLyG/egNF0BXsYRr6wvsJhjHzOmfoQAaXNUNyMNxGjy
OLI+52sBLkkLZ2/xE6PBfsgr6XsBNvqLw++WitF/sm5ZizqeMmqUSVO/GMPj
pFlnGgW49iLpVBUjwVLlT9WDtgSuni+v1/lOApj6vB6RRMB1z/ZgFwcJhp+O
NW5vJxDGVB5wmihB+JtqeT1DwvhJrrmkS4wDaT3Rz1aRGLxp7/64UAzB+vuj
nkSRkIeE2Mj9xZCUZOfnpJA4qNOzK8JCjFO65FzzTBIJk+taHrWweDPNLWV7
Bon0gAemK4+z2CBccFqUREJS27w8U8aifPlSRXksifbnxXJfVxYB0zRbfg0h
YaWdv1Q2nUX6y/nOfR4kTITLjwQ7sJAfnWxX9h0J22UDuWYuLDQ0Nz25ZEai
ttTRKcGfhXFKUb/NsLq+dxPjLA+xmPfQZHdkK4FJ7GzteXdYRLTpBbhdI1Af
tPxDlakYuW4dtl0XCFgJX+U8XCvGI69VvSGVBP4IGOq4XiTGWGgmFTcSuDWm
1Uj+UYwr51JLluiQCN7/jwE9T4I9LW6lva4kTjY7ZZ+LkeDgvqGdA9kk8h83
a1jnSzD0yWckbGzVp0SCoO1aCSN9KP4+jFIs0Cuh+O/tXIJcz/RTkHH/f1o5
HLpQSOM2F9/sRJ5eMmhUcPmtUIy/YTyXhojLP8a8N13xLY0Grr4SS2VEvAUN
K67+Tpm7zm1Nmu+PajhxgmM7xffPe92tv+Zfpvj+SseUlesWUDDm+p9cO0yt
TKb4+cw69Zub8y4Kbdz8UhtLl90Lpfj5flmrkO3zp/j5L+p7dKFtPYV4Th83
XH08vWUU9nP6acy0ej8hjsJRTl/Bgfox4/IoqDj9xRrM9BU3Ubw+B8a/6DIz
o3n9lr/KNlSF0ry+80y2zdS+QfP6V3VkSZcIGdRy/tBcYX+aimDQzfmHqdM6
EVrBIJDzl0WBX6Z3J4PLnP/K6qJfilUM0jl/1j8tSg3sY6Dk/Lu1znB/QDOD
bZy/ZwRVrpKeZWDF+b/K/eOCOHW8SI4Px163er+fxfD88CqYenijnjofji/6
fp6+m1ponj+lLx02/FhG83zyMDnkYH2E5vnV2SXRzjpI83zTX6yftfcAzfPv
WViMb0IGDWuOjxrub1UzC2l4cPzUJxSZl+7QWMfx9UTelfshH2ns5vi7xWSR
c9R0hufzL1roRSzD81umJQsIv8vwfB/bUdnXwAhhz/E/NH26aPROIb8fxulm
G8hrhIjk9oeRpjJNR8sSVdx+cfI8nfGD0BJG3P5p89I7PzjFEvHcforZbdfS
R1nCg9tfA5/8JsTnPSfCf3ygAUo=
        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 16.045199999999994`}, \
{0, -1}], LineBox[CompressedData["
1:eJw9lXlUjXkYx+tKUrJURIN777u/lzJjiZR8MWWpK1lv65m5KqWmZWQZSYvC
CO2ihJAlWyqNZcgyGhGubCUdZTuWq4WajLa5xnve3znv+f3xO7/3+T3P8/1+
Hrk6bL6/RE9PL0z3fd2/LRm+7aPwT2vGbItSKY7eVlY/Pa3ABOe3qYbZUsQo
vYLrVAqsUh7VhJ6WosUxzFrZyeN+F/uosUOKaRGj7WsP8qhv821R28mwccag
pv5ePDYvv/7gU4IMXqp9EaU0jwYrGI+ukeFWhuGtK0Y8tnSlZm6ykWOLBxtY
ZcBD1VVmUrZejsDqS/viLXls1J46F39dDoW/pZmNA4/FnvaKFD0Ca2822GlD
eGjrlAGOYwjsnnNh5roDPP4t7GdwzZ3AYe9hvfWf8LBIismNCiSgyTvYuNFE
gQ8nP/qvWUFg392hUarxCpib3ev0/5WANulQk3S+Avu1QeUaPwKT5toO1CxV
wHlw+c49cwjcnn6r2D1IgcacQ7nbKV28Q9tMDXXne1W3lu1olcOsLsJ4hrsC
PgNk+/tckmNm88YNX8YpYF+oVxKdKEdiYPyUM8YKlKUjP3ueHI+5SZrmB7r8
bJsjM2k5kswHxVam8eC+cwvJMJZjSHSdhcaJh5Nt7OAqAzlCLhiM3dDC4Ykq
J2C/pRyO2e4Xt+ZwuG/b5Z08Q46srKpNNi4c2o9WLKzVxbOI/6xljDh0D/PP
PlEth92Q8EVTa1gs0P5+rXMcAftZztbtV1lMs/BtNkgmUPLb5rTSchbdL4eY
NTQQ2FqDFZefs1jTci23iiHRONyr/p4Zh6SMjzGvPUkYjK0olLtzIAIe9nkR
TWJpSspddRYHm+K8Q/tTSaxoN41LfMahwJh0ku4iEX3HliIpHi0Tlamrs0gE
Z/Lvj/zEYxnrcmxUMomqiXRBQCqPc4sWFJ2LIyEdOledW8wjeKJ+7ZEwEo86
PY6nXueR8W6Oc5tK957qAr+0ch65u3+YcGYKidvHens1lPLQ0494cWUkiUku
Vy5HZfEwSy1s/75bl1/f59GPg3jMfGyeuO4Zgcf3L3aeHcNjbb3JcuXfBGzS
CwynvudwUPlq3IfzBB5VW/hwezk89fZsDSsj4JQpsRrvxmEI9JNPVxMY+07W
pNbjcL00vXi+EYn0yBEtT86ySKxVlrS6klhCX/adHcNi++auqC95JDzldI/G
g0VXz9dFQlOpW64sQlZLEnr7UuJ5JFXkYlJMiffHzw5xPdFOIU34/6uy7vC5
LC3GH3Eg3yQFNH4U3re4yKrSzInGQ+H9sdLWzKJJNKyF/Eo47doNMlrM/22o
m9FdfVqsT0f39uGODZRYP5+ld27OuUqJ9Q0YfOac8WFKrH/KjW5qSQol9md6
wXGl83oKMqF/adUlCx+EU2J/+94oCt0cSIn9n9f29Hx9ACXqo9LV18MnlMJK
QT81uxSfh8dT8BP09UuwaeywfAq9Bf3F9XdQW9dQoj6/WL39MHIkLer3/Pu8
AR3htKjvfPNVDr0qaVH/Ha+y/eezjOgPyWLbY9RaBmaCf5gKyYHwPxlkCv6S
Hfbb5fOGEf1XWhHzzrqDQbDgz6qXhenBbQwsBP+urBiQtPwJgy2Cvx1Cyjz9
TzF4JPj/sluPS7wuXoLAhz3Nz3w+T2NEfngfHr8zyIQR+WLq56GOqKVF/pS8
s1v28xla5JPKfIfdmBxa5NebDza9srfRIt9M3U2zN22lRf69joxVJ2TRqBL4
qO/2qcPhJI2jAj9NiaJdVzQ0cgW+Hsj/62FYD40ogb+R5vOcoyczIp/zJGhF
HIMggd+hktDla+4xSBL4bvmqrO0+w4r8j8icPKpfFCvOh2HGef1zdX1KEObH
QH1thpGEE+eLo8exrFkshyZh/tR7m/zROZbDemE+xSZOqG2jOBwR5lfH/35j
xfn2HxDt6BI=
        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999995, 10.954800000000002`}, \
{0, 1}], LineBox[CompressedData["
1:eJwtVAtQzXkUTu9RSXoQPaj7f/z+/9u23V7c6vZlVFqU7HoUYtGmGGF70YuK
q0mm28bdbct65JXqovIoTAo9WHUTFTaUXqIhKutRe5k9M2fOnDPf+b45M2e+
Wesil4Sqq6mpLVPl1/px/GvwUPsWAoi2rVmj6ybEi8y0BfnuAiwNtjd0/kUI
g1l5TZelArT6aZZWJQoR2F+v/uCJAPuiHubFJguRqz1UpetCQfNeWYnJJiHI
9lslNfspuCyWSBbPFeJu9Jvllx9RqMuw6czVFUJrsvDplek0Jtr7bJVX8whN
cr8V4kdjysGToh3RPC6sMalbEEpjQsb7/C00D70H92/MiqSxZ+REsfMjDu2d
YZrW4TQkUXnnunI4RLbs+ShbRmPYti2lNYhDd/HOPIkbjUEmaewGz6HS7KCy
RaVH3/xSoNDn8LbXyevABwpndRZ5a48RZGsdWKLWSsFvvm1xlBoHakzxzPYy
hW6rzqzHxhyUXSO++/IpBJfRRmJXDq97Hr7O20eh8a/W5BMbOVz0e+A4spNC
alh3ov8JDldF0pW/xlCon7L5kqyfQ5as46wokULMq/UwduDhMSfzB38ZheaZ
tzz6Ynhs7v+SsKmMQj/tK24t5xFY06Hu1EsB71xXXerjUeQW+e8jloae0YLG
wYlCxOkbxitjaLyQkgx1cyEqVodcrbtL47nVHaMZRkIwnwZEhhSDgHTt0uB3
PN7mDdp57mDQti9Qv+8Gj+wU+aBlDQP2D7Hi2C4ekikLveO/MDi813eOzIkH
yenyfi5gket3SGzXxWHRwZHpQ64sPntpBVyRcTBc5egbruo7TS9Z3J7H4eWZ
1oS7FAtRfH7l6DhB06cay15tFf4n7Qrt2wQb9xSO2j9lcC1a7WHP7wTKc9MC
nEsZxNFFRSM7CDrSa10FUgbubfkXrCMIFvZcV8aFMEgtfZnVHk5QsmLF0D9u
DAo7Vk2fosJzmU0T3GYxWBt2Y1RLTnDnbFVbtyGDnUmjsdOrCdoUGjndugwO
lc2X3R4laJkbXGtnoNp3nSz4zYlD+WxzSYUlA5PznjbOURzSLNnCeBW/R/Fj
verzHCYeXZ5rHMYg1yO4aLxX9T/HO2y3HGHwpFjwstGIR3votbClPQwSunS4
co5HwdvstTYuLExcBC7r7Hkc83Q0L8pgEbIyq8vdiged3R+d/pzFYesUz9JR
Dj1LzWYXOBCIn5gRn+scGiKZBo0YAq/3uzXdYzhMO6LBFpwheP5OvFSb4pDq
eXYxW09wYN5Hp4QmgvV2M5Lm3ieIt7K2mJZEYNxcEFtdRxBw0cd9g4jgvu2f
yUuKCE4uO6dQvGGxOblW+nk3QeYabXfDShbijCYNuT8B1v6tL89msd1z289O
Uwkk4eZ6JbEsnIkNTj1jMVCb2R4UweJcmk0ApWAxmJPSEKHqvUytjhvsZaHD
pMgTVfigD+k+LWEsUn+MsG3LYtFW9cjAaBkL//MWXqJyFU/dmOJMIIubrwo8
dnWymCcx6tJZycLVaiC/2ZRgKNbczne7at45u2b5AoJO4/ftPnIWq+9FXE9T
3WcRbngqp56FxNlwfEMhwUy+Wy7SJRg7cTNXv4HApPqp0i+QoMr74lZB+9e7
4zT7jhKwlX2Ju1oIZnjIJvUNE1zjW/VPVxAcGd5QYjWfw9EOqZXDfoKppiYD
ymwO4o0JBs0qfdu8xviIJg6+CUFB5mMsJinLns75zCHU5/s7ytMshlNzpbQx
D95M+p3DEhaOduPPTE14fPrmp8z/fsrjPwQ/Oso=
        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {14.283684782537893`, 12.224334161450233`}, \
{-1, -1}], 
       {PointSize[0.04], PointBox[{11.99999999999999, 13.5}], 
        PointBox[{8., 13.5}], PointBox[{6., 10.}], 
        PointBox[{13.99999999999999, 10.}]}},
      AspectRatio->1,
      PlotRange->{{-1, 21}, {-1, 21}}], {22, 0}, {0, 0}, {22, 22}], InsetBox[
     GraphicsBox[
      {Thickness[0.005], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{1.5256684804398901`*^-12, 10.}, {3.000000000006441, 10.}}]},
        PolygonBox[{{2.1, 10.}, {0.9, 9.6}, {0.9, 10.4}}], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {1.5, 10.9452}, {0, -1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{19.999999999998018`, 10.}, {16.99999999999754, 10.}}]}, 
       PolygonBox[{{19.1, 10.}, {17.9, 10.4}, {17.9, 9.6}}], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {18.5, 9.0548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        LineBox[{{12.000000000001542`, 10.}, {8.00000000000287, 10.}}]}, 
       InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {9.999999999999986, 9.3048}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{14.499999999999986`, 10.}, 2.500000000000015, {
         5.773159728050814*^-15, 3.141592653589787}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {14.499999999999986`, 13.1952}, {0, -1}], 
       LineBox[CompressedData["
1:eJw9Vgs0Veke76XS0FDT43qdfY7inH0eezPVlVc/RaVEQomERKkJiYRBRKEb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        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {14.499999999999986`, 6.5548}, {0, 1}], 
       {Dashing[{0.005, 0.030000000000000002`}], 
        CircleBox[{5.5, 10.}, 2.5, {-3.141592653589793, 0.}]}, InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {5.499999999999999, 6.8048}, {0, 1}], 
       LineBox[CompressedData["
1:eJw9Vgs0lGkfFxFjaGaYYa6Ny1yU6stiJfKLUka5lJD4iBRdttqicg1T6Ev3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        "]], InsetBox[
        TagBox[
         StyleBox[
          TagBox["\<\"\"\>",
           DisplayForm],
          FontFamily->"Times",
          FontSize->8.247272727272728],
         StyleForm[#, FontFamily -> "Times", FontSize -> 
          8.247272727272728]& ], {5.5, 13.4452}, {0, -1}], 
       {PointSize[0.04], PointBox[{11.99999999999997, 10.}], 
        PointBox[{8., 10.}], PointBox[{3., 10.}], PointBox[{17., 10.}]}},
      AspectRatio->1,
      PlotRange->{{-1, 21}, {-1, 21}}], {44, 0}, {0, 0}, {22, 22}]},
   AspectRatio->NCache[
     Rational[1, 2], 0.5],
   PlotRange->{{0, 88}, {0, 44}}], TraditionalForm]], "Print",
 CellChangeTimes->{3.472902146249308*^9, 3.522783942314725*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Calculating the bare 2-loop off-shell ghost selfenergy diagrams\
\>", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"QuarkMass", "=", "0"}], ";"}]], "Input"],

Cell["We need to put the AmplitudeLevel setting to Classes here.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"amps", "=", 
    RowBox[{"CalcColorFactor", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"CreateFeynAmp", "[", 
          RowBox[{"inserts", ",", 
           RowBox[{"Truncated", "\[Rule]", "True"}], ",", 
           RowBox[{"PreFactor", "\[Rule]", "I"}], ",", 
           RowBox[{"AmplitudeLevel", "\[Rule]", 
            RowBox[{"{", "Classes", "}"}]}]}], "]"}], "/.", 
         RowBox[{"p1", "\[RuleDelayed]", "p"}]}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"li1", "\[RuleDelayed]", "\[Mu]"}], ",", 
          RowBox[{"li2", "\[RuleDelayed]", "\[Nu]"}]}], "}"}]}], "/.", 
       RowBox[{
        RowBox[{"FeynAmpList", "[", "__", "]"}], "\[RuleDelayed]", "List"}]}],
       " ", "/.", " ", 
      RowBox[{
       RowBox[{"FeynAmp", "[", 
        RowBox[{"_", ",", "_", ",", "x_"}], "]"}], "\[RuleDelayed]", "x"}]}], 
     "]"}]}], ";"}], "//", "Timing"}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0.668042`", ",", "Null"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.472902148174882*^9, 3.522783948019529*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amps", "//", "TableForm"}]], "Input"],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["C", "A", "2"], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["ci1",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["ci2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li4"], "(", 
         FormBox[
          RowBox[{"-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Nu]"], "(", 
         FormBox[
          RowBox[{"-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"q2", "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"q2", "-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li3"], "(", 
         FormBox[
          RowBox[{"q2", "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Mu]"], "(", 
         FormBox[
          RowBox[{"q2", "-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], "(", "q2", ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li3", "li4"}]], "(", 
         FormBox[
          RowBox[{"q1", "-", "p"}],
          TraditionalForm], ")"}]}]},
      {
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["C", "A", "2"], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["ci1",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["ci2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"-", "q2"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li4"], "(", 
         FormBox[
          RowBox[{"-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li6"], "(", 
         FormBox[
          RowBox[{"-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Nu]"], "(", 
         FormBox[
          RowBox[{"-", "q2"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li3", "li4"}]], "(", 
         FormBox[
          RowBox[{"q1", "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li5", "li6"}]], "(", 
         FormBox[
          RowBox[{"p", "-", "q2"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], "(", 
         FormBox[
          RowBox[{"q2", "-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox["V", 
          RowBox[{"\[Mu]", "li3", "li5"}]], "(", 
         RowBox[{
          FormBox[
           RowBox[{"q1", "-", "q2"}],
           TraditionalForm], 
          RowBox[{",", " "}], 
          FormBox[
           RowBox[{"p", "-", "q1"}],
           TraditionalForm], 
          RowBox[{",", " "}], 
          FormBox[
           RowBox[{"q2", "-", "p"}],
           TraditionalForm]}], ")"}]}]},
      {
       RowBox[{"\[ImaginaryI]", " ", "Tf", " ", 
        SubscriptBox["C", "A"], " ", 
        SubscriptBox["N", "f"], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["ci1",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["ci2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li4"], "(", 
         FormBox[
          RowBox[{"-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Nu]"], "(", 
         FormBox[
          RowBox[{"-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li3", "li4"}]], "(", 
         FormBox[
          RowBox[{"p", "-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], "(", 
         FormBox[
          RowBox[{"q1", "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{"tr", "(", 
         FormBox[
          RowBox[{
           RowBox[{
            SubscriptBox["\[CapitalPi]", "q"], "(", 
            FormBox[
             RowBox[{"q2", "-", "p"}],
             TraditionalForm], ")"}], ".", 
           SuperscriptBox["Q", "\[Mu]"], ".", 
           RowBox[{
            SubscriptBox["\[CapitalPi]", "q"], "(", 
            FormBox[
             RowBox[{"q2", "-", "q1"}],
             TraditionalForm], ")"}], ".", 
           SuperscriptBox["Q", "li3"]}],
          TraditionalForm], ")"}]}]},
      {
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SubsuperscriptBox["C", "A", "2"], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["ci1",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["ci2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li4"], "(", 
         FormBox[
          RowBox[{"-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Nu]"], "(", 
         FormBox[
          RowBox[{"-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"q2", "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"q2", "-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li3"], "(", 
         FormBox[
          RowBox[{"q2", "-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Mu]"], "(", 
         FormBox[
          RowBox[{"q2", "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li3", "li4"}]], "(", 
         FormBox[
          RowBox[{"p", "-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], "(", 
         FormBox[
          RowBox[{"q1", "-", "p"}],
          TraditionalForm], ")"}]}]},
      {
       RowBox[{"\[ImaginaryI]", " ", 
        SubsuperscriptBox["C", "A", "2"], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["ci1",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["ci2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Nu]"], "(", 
         FormBox[
          RowBox[{"-", "p"}],
          TraditionalForm], ")"}], " ", 
        SuperscriptBox[
         RowBox[{
          SubscriptBox["\[CapitalPi]", "u"], "(", 
          FormBox[
           RowBox[{"q1", "-", "p"}],
           TraditionalForm], ")"}], "2"], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"q2", "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li3"], "(", 
         FormBox[
          RowBox[{"q1", "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li4"], "(", 
         FormBox[
          RowBox[{"q2", "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Mu]"], "(", 
         FormBox[
          RowBox[{"q1", "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], "(", "q1", ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li3", "li4"}]], "(", 
         FormBox[
          RowBox[{"q1", "-", "q2"}],
          TraditionalForm], ")"}]}]},
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["C", "A", "2"], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["ci1",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["ci2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li8"], "(", 
         FormBox[
          RowBox[{"-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Nu]"], "(", 
         FormBox[
          RowBox[{"-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li3", "li4"}]], "(", 
         FormBox[
          RowBox[{"q1", "-", "q2"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li5", "li6"}]], "(", 
         FormBox[
          RowBox[{"q2", "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li7", "li8"}]], "(", 
         FormBox[
          RowBox[{"p", "-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], "(", 
         FormBox[
          RowBox[{"q1", "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox["V", 
          RowBox[{"li3", "li5", "li7"}]], "(", 
         RowBox[{
          FormBox[
           RowBox[{"q2", "-", "q1"}],
           TraditionalForm], 
          RowBox[{",", " "}], 
          FormBox[
           RowBox[{"p", "-", "q2"}],
           TraditionalForm], 
          RowBox[{",", " "}], 
          FormBox[
           RowBox[{"q1", "-", "p"}],
           TraditionalForm]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["V", 
          RowBox[{"\[Mu]", "li4", "li6"}]], "(", 
         RowBox[{
          FormBox[
           RowBox[{"p", "-", "q1"}],
           TraditionalForm], 
          RowBox[{",", " "}], 
          FormBox[
           RowBox[{"q1", "-", "q2"}],
           TraditionalForm], 
          RowBox[{",", " "}], 
          FormBox[
           RowBox[{"q2", "-", "p"}],
           TraditionalForm]}], ")"}]}]},
      {
       RowBox[{"\[ImaginaryI]", " ", 
        SubsuperscriptBox["C", "A", "2"], " ", 
        SubscriptBox["\[Delta]", 
         RowBox[{
          FormBox[
           FormBox["ci1",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["ci2",
            TraditionalForm],
           TraditionalForm]}]], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubscriptBox["\[CapitalPi]", "u"], "(", 
         FormBox[
          RowBox[{"-", "q2"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li3"], "(", 
         FormBox[
          RowBox[{"-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "li4"], "(", 
         FormBox[
          RowBox[{"-", "q2"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Nu]"], "(", 
         FormBox[
          RowBox[{"-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SuperscriptBox[
          OverscriptBox["\[CapitalLambda]", "~"], "\[Mu]"], "(", 
         FormBox[
          RowBox[{"-", "q1"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"li3", "li4"}]], "(", 
         FormBox[
          RowBox[{"q2", "-", "p"}],
          TraditionalForm], ")"}], " ", 
        RowBox[{
         SubsuperscriptBox["\[CapitalPi]", "g", 
          RowBox[{"\[Mu]", "\[Nu]"}]], "(", 
         FormBox[
          RowBox[{"p", "-", "q1"}],
          TraditionalForm], ")"}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{3.472902148239208*^9, 3.522783948233343*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A function to do self energy diagrams", "Subsection"],

Cell["This is a substitution rule for a tensor integral of rank 1.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tsub1", "=", 
  RowBox[{
   RowBox[{"FCI", "[", 
    RowBox[{
     RowBox[{"FVD", "[", 
      RowBox[{
       RowBox[{"qu1", ":", 
        RowBox[{"(", 
         RowBox[{"q1", "|", "q2"}], ")"}]}], ",", "mu"}], "]"}], 
     RowBox[{"FVD", "[", 
      RowBox[{
       RowBox[{"qu2", ":", 
        RowBox[{"(", 
         RowBox[{"q1", "|", "q2"}], ")"}]}], ",", "nu"}], "]"}]}], "]"}], ":>", 
   RowBox[{"TIDL", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"qu1", ",", "mu"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"qu2", ",", "nu"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", "p", "}"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     SuperscriptBox[
      FormBox[
       RowBox[{"qu1", ":", 
        RowBox[{"q1", "|", "q2"}]}],
       TraditionalForm], 
      FormBox[
       FormBox["mu",
        TraditionalForm],
       TraditionalForm]], ")"}], " ", 
    RowBox[{"(", 
     SuperscriptBox[
      FormBox[
       RowBox[{"qu2", ":", 
        RowBox[{"q1", "|", "q2"}]}],
       TraditionalForm], 
      FormBox[
       FormBox["nu",
        TraditionalForm],
       TraditionalForm]], ")"}]}], "\[RuleDelayed]", 
   RowBox[{"TIDL", "(", 
    RowBox[{
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"qu1", "mu"},
        {"qu2", "nu"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], ",", 
     RowBox[{"{", "p", "}"}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.472902148481415*^9, 3.522783951122336*^9}]
}, Open  ]],

Cell["This is a substitution rule for a tensor integral of rank 2.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tsub2", "=", 
  RowBox[{
   RowBox[{"FCI", "[", 
    RowBox[{"FVD", "[", 
     RowBox[{
      RowBox[{"qu", ":", 
       RowBox[{"(", 
        RowBox[{"q1", "|", "q2"}], ")"}]}], ",", "al_"}], "]"}], "]"}], ":>", 
   
   RowBox[{"TIDL", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"qu", ",", "al"}], "}"}], "}"}], ",", 
     RowBox[{"{", "p", "}"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox[
     RowBox[{"qu", ":", 
      RowBox[{"q1", "|", "q2"}]}],
     TraditionalForm], 
    FormBox[
     FormBox["al_",
      TraditionalForm],
     TraditionalForm]], "\[RuleDelayed]", 
   RowBox[{"TIDL", "(", 
    RowBox[{
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"qu", "al"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], ",", 
     RowBox[{"{", "p", "}"}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.472902148822219*^9, 3.522783953468962*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ScalarProduct", "[", 
    RowBox[{"p", ",", "p"}], "]"}], "=", "pp"}], ";", 
  RowBox[{
   RowBox[{"FAD", "[", "p", "]"}], "=", 
   RowBox[{"1", "/", "pp"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"do2self1", "[", "z_", "]"}], ":=", 
  RowBox[{"FCE", "[", 
   RowBox[{"ToFI", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"ch1", "[", "z", "]"}], "=", 
         RowBox[{"Expand", "[", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"SUNSimplify", "[", 
              RowBox[{
               RowBox[{"Explicit", "[", 
                RowBox[{"z", ",", 
                 RowBox[{"Dimension", "\[Rule]", "D"}], ",", 
                 RowBox[{"Gauge", "\[Rule]", 
                  RowBox[{"1", "-", "\[Xi]"}]}]}], "]"}], ",", 
               RowBox[{"Explicit", "\[Rule]", "True"}]}], "]"}], "/.", 
             "\[InvisibleSpace]", 
             RowBox[{"DiracTrace", "\[Rule]", "TR"}]}], "]"}], ",", 
           RowBox[{"q1", "|", "q2"}]}], "]"}]}], ")"}], "/.", 
       "\[InvisibleSpace]", "tsub1"}], "/.", "\[InvisibleSpace]", "tsub2"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"q1", ",", "q2"}], "}"}], ",", 
     RowBox[{"{", "p", "}"}]}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"do2self2", "[", "z_", "]"}], ":=", 
  RowBox[{
   RowBox[{"TarcerRecurse", "[", 
    RowBox[{
     RowBox[{"Collect3", "[", 
      RowBox[{
       RowBox[{"z", "/.", "inttable"}], ",", 
       RowBox[{"{", 
        RowBox[{"TAI", ",", "TBI", ",", "TVI", ",", "TFI"}], "}"}], ",", 
       RowBox[{"Factoring", "\[Rule]", "Factor2"}]}], "]"}], ";", 
     RowBox[{"If", "[", 
      RowBox[{"comment", ",", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<starting recursion on \>\"", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"ch2", "[", "z", "]"}], "]"}], ",", "\"\< integrals\>\""}], 
        "]"}]}], "]"}], ";", 
     RowBox[{"ch2", "[", "z", "]"}]}], "]"}], "/.", "\[InvisibleSpace]", 
   RowBox[{"x_Plus", "\[RuleDelayed]", 
    RowBox[{
     RowBox[{"Collect2", "[", 
      RowBox[{"x", ",", "\[Xi]"}], "]"}], "/;", 
     RowBox[{
      RowBox[{"Variables", "[", "x", "]"}], "\[Equal]", 
      RowBox[{"{", 
       RowBox[{"D", ",", "\[Xi]"}], "}"}]}]}]}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculate the graphs one by one", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"comment", "=", "True"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SPD", "[", 
    RowBox[{"p", ",", "p"}], "]"}], "=", "pp"}], ";"}]], "Input"],

Cell["Do all the algebra but no integrals yet.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"res1", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<calculating \>\"", ",", "i", ",", " ", "\"\<  time = \>\"", ",", 
         
         RowBox[{
          RowBox[{"Timing", "[", 
           RowBox[{
            RowBox[{"re", "[", "i", "]"}], "=", 
            RowBox[{"do2self1", "[", 
             RowBox[{"(", 
              RowBox[{"amps", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ")"}], "]"}]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         "\"\<, number of integrals to calculate = \>\"", ",", 
         RowBox[{"Length", "[", 
          RowBox[{"re", "[", "i", "]"}], "]"}]}], "]"}], ";", 
       RowBox[{"re", "[", "i", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", " ", 
        RowBox[{"Length", "[", "amps", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"calculating \"\>", "\[InvisibleSpace]", "1", 
    "\[InvisibleSpace]", "\<\"  time = \"\>", "\[InvisibleSpace]", 
    "0.7160449999999996`", 
    "\[InvisibleSpace]", "\<\", number of integrals to calculate = \"\>", 
    "\[InvisibleSpace]", "36"}],
   SequenceForm[
   "calculating ", 1, "  time = ", 0.7160449999999996, 
    ", number of integrals to calculate = ", 36],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.472902149359593*^9, 3.522783973645802*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"calculating \"\>", "\[InvisibleSpace]", "2", 
    "\[InvisibleSpace]", "\<\"  time = \"\>", "\[InvisibleSpace]", 
    "2.1121320000000003`", 
    "\[InvisibleSpace]", "\<\", number of integrals to calculate = \"\>", 
    "\[InvisibleSpace]", "108"}],
   SequenceForm[
   "calculating ", 2, "  time = ", 2.1121320000000003`, 
    ", number of integrals to calculate = ", 108],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.472902149359593*^9, 3.522783975704288*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"calculating \"\>", "\[InvisibleSpace]", "3", 
    "\[InvisibleSpace]", "\<\"  time = \"\>", "\[InvisibleSpace]", 
    "1.8481149999999997`", 
    "\[InvisibleSpace]", "\<\", number of integrals to calculate = \"\>", 
    "\[InvisibleSpace]", "75"}],
   SequenceForm[
   "calculating ", 3, "  time = ", 1.8481149999999997`, 
    ", number of integrals to calculate = ", 75],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.472902149359593*^9, 3.522783977571489*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"calculating \"\>", "\[InvisibleSpace]", "4", 
    "\[InvisibleSpace]", "\<\"  time = \"\>", "\[InvisibleSpace]", 
    "0.5920370000000003`", 
    "\[InvisibleSpace]", "\<\", number of integrals to calculate = \"\>", 
    "\[InvisibleSpace]", "54"}],
   SequenceForm[
   "calculating ", 4, "  time = ", 0.5920370000000003, 
    ", number of integrals to calculate = ", 54],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.472902149359593*^9, 3.522783978215982*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"calculating \"\>", "\[InvisibleSpace]", "5", 
    "\[InvisibleSpace]", "\<\"  time = \"\>", "\[InvisibleSpace]", 
    "1.0960690000000008`", 
    "\[InvisibleSpace]", "\<\", number of integrals to calculate = \"\>", 
    "\[InvisibleSpace]", "56"}],
   SequenceForm[
   "calculating ", 5, "  time = ", 1.0960690000000008`, 
    ", number of integrals to calculate = ", 56],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.472902149359593*^9, 3.522783979555629*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"calculating \"\>", "\[InvisibleSpace]", "6", 
    "\[InvisibleSpace]", "\<\"  time = \"\>", "\[InvisibleSpace]", 
    "11.644727999999999`", 
    "\[InvisibleSpace]", "\<\", number of integrals to calculate = \"\>", 
    "\[InvisibleSpace]", "514"}],
   SequenceForm[
   "calculating ", 6, "  time = ", 11.644727999999999`, 
    ", number of integrals to calculate = ", 514],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.472902149359593*^9, 3.522783991250315*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"\<\"calculating \"\>", "\[InvisibleSpace]", "7", 
    "\[InvisibleSpace]", "\<\"  time = \"\>", "\[InvisibleSpace]", 
    "0.46002800000000066`", 
    "\[InvisibleSpace]", "\<\", number of integrals to calculate = \"\>", 
    "\[InvisibleSpace]", "25"}],
   SequenceForm[
   "calculating ", 7, "  time = ", 0.46002800000000066`, 
    ", number of integrals to calculate = ", 25],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.472902149359593*^9, 3.522783991770257*^9}]
}, Open  ]],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"18.485155`", ",", "Null"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.47290216095982*^9, 3.522783991840049*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"allints", " ", "=", " ", 
   RowBox[{"Cases2", "[", 
    RowBox[{"res1", ",", "TFI"}], "]"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"allints", "//", "Length"}]], "Input"],

Cell[BoxData[
 FormBox["651", TraditionalForm]], "Output",
 CellChangeTimes->{3.472902161324441*^9}]
}, Open  ]],

Cell["\<\
There are 651 integrals to be done for the ghost self energy. There are \
several possibilities how to proceed. One possibility is to calculate the \
integrals one by one and save them to a file. This can be conveniently done \
using the CheckDB function. If the file \"tfioffshellmassless.s\" does not \
exist the first argument of CheckDB is evaluated, otherwise the list is \
loaded and assigned to inttable:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"inttable", "=", 
    RowBox[{"CheckDB", "[", 
     RowBox[{
      RowBox[{"Dispatch", "[", 
       RowBox[{"Thread", "[", 
        RowBox[{"allints", "\[Rule]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"WriteString", "[", 
             RowBox[{"\"\<stdout\>\"", ",", "\"\<.\>\""}], "]"}], ";", 
            RowBox[{"TarcerRecurse", "[", 
             RowBox[{
             "allints", "\[LeftDoubleBracket]", "i", 
              "\[RightDoubleBracket]"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "[", "allints", "]"}]}], "}"}]}], "]"}]}], 
        "]"}], "]"}], ",", "\"\<tfioffshellmassless.s\>\""}], "]"}]}], ";"}], 
  "]"}]], "Input"],

Cell["\<\
..............................................................................\
..............................................................................\
..............................................................................\
..............................................................................\
..............................................................................\
..............................................................................\
..............................................................................\
..............................................................................\
...........................\
\>", "Print",
 CellChangeTimes->{3.4729021613834677`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"100.27999999999999`", ",", "Null"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.4729022641856117`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"result", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Collect2", "[", 
       RowBox[{"#", ",", 
        RowBox[{"{", 
         RowBox[{"TAI", ",", "TBI", ",", "TJI"}], "}"}], ",", 
        RowBox[{"Factoring", "\[Rule]", "Factor2"}]}], "]"}], "&"}], "/@", 
     RowBox[{"(", 
      RowBox[{"res1", "/.", "inttable"}], ")"}]}]}], ";"}], "]"}]], "Input",
 CellChangeTimes->{3.472902291302947*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0.6299999999999955`", ",", "Null"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.472902265353889*^9, 3.4729022932360287`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"result", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"pp", " ", "\[Xi]", " ", 
     SubsuperscriptBox["C", "A", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["D", "3"], " ", 
        RowBox[{"(", 
         RowBox[{"-", "\[Xi]"}], ")"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["D", "2"], " ", "\[Xi]"}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["D", "2"]}], "-", 
       RowBox[{"17", " ", "D", " ", "\[Xi]"}], "+", 
       RowBox[{"6", " ", "D"}], "+", 
       RowBox[{"8", " ", "\[Xi]"}]}], ")"}], " ", 
     SubsuperscriptBox["g", "s", "4"], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"ci1", "ci2"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       InterpretationBox[
        SubsuperscriptBox[
         StyleBox["B",
          SingleLetterItalics->False,
          FontWeight->"Bold"], 
         RowBox[{
          FormBox[
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}],
           TraditionalForm], 
          FormBox[
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}],
           TraditionalForm]}], 
         RowBox[{"(", 
          FormBox["D",
           TraditionalForm], ")"}]],
        HighEnergyPhysics`Tarcer`TBI[D, $CellContext`pp, {{1, 0}, {1, 0}}],
        Editable->True], ")"}], "2"]}], 
    RowBox[{"64", " ", 
     RowBox[{"(", 
      RowBox[{"4", "-", "D"}], ")"}]}]], "-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"16", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"4", "-", "D"}], ")"}], "2"]}]], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"3", "-", "D"}], ")"}], " ", 
     SubsuperscriptBox["C", "A", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"2", " ", 
         SuperscriptBox["D", "3"], " ", 
         SuperscriptBox["\[Xi]", "2"]}]}], "+", 
       RowBox[{"21", " ", 
        SuperscriptBox["D", "2"], " ", 
        SuperscriptBox["\[Xi]", "2"]}], "-", 
       RowBox[{"10", " ", 
        SuperscriptBox["D", "2"], " ", "\[Xi]"}], "-", 
       RowBox[{"68", " ", "D", " ", 
        SuperscriptBox["\[Xi]", "2"]}], "+", 
       RowBox[{"60", " ", "D", " ", "\[Xi]"}], "-", 
       RowBox[{"8", " ", "D"}], "+", 
       RowBox[{"72", " ", 
        SuperscriptBox["\[Xi]", "2"]}], "-", 
       RowBox[{"96", " ", "\[Xi]"}], "+", "32"}], ")"}], " ", 
     SubsuperscriptBox["g", "s", "4"], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"ci1", "ci2"}]], " ", 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["D",
         TraditionalForm], ")"}]],
      HighEnergyPhysics`Tarcer`TJI[
      D, $CellContext`pp, {{1, 0}, {1, 0}, {1, 0}}],
      Editable->True]}]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.47290226571873*^9, 3.472902297794883*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Variables", "[", "result", "]"}], "//", "InputForm"}]], "Input"],

Cell["\<\
{CA, D, Gstrong, Nf, pp, Tf, \[Xi], SD[ci1, ci2], 
 TBI[D, pp, {{1, 0}, {1, 0}}], 
 TJI[D, pp, {{1, 0}, {1, 0}, {1, 0}}]}\
\>", "Output",
 CellChangeTimes->{3.472902266029595*^9, 3.472902301242632*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Context", "[", "TBI", "]"}]], "Input"],

Cell[BoxData[
 FormBox["\<\"HighEnergyPhysics`Tarcer`\"\>", TraditionalForm]], "Output",
 CellChangeTimes->{3.472902266139612*^9, 3.472902303599511*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Do the expansion of the master integrals in \[CurlyEpsilon] and compare with \
the literature\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"??", "Tf"}]], "Input",
 CellChangeTimes->{{3.472902385691998*^9, 3.472902386092847*^9}, 
   3.47290247120977*^9}],

Cell["HighEnergyPhysics`qcd`Tf`Tf", "Print", "PrintUsage",
 CellChangeTimes->{3.472902471654913*^9},
 CellTags->"Info3472906071-3368256"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Nf"}]], "Input",
 CellChangeTimes->{{3.472902394185211*^9, 3.472902394672224*^9}}],

Cell[BoxData[
 StyleBox["\<\"Nf denotes the number of flavors.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.4729023951089*^9},
 CellTags->"Info3472905995-6725410"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ghselftf", " ", "=", 
  RowBox[{"result", "[", 
   RowBox[{"[", "3", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"2", "-", "D"}], ")"}], "2"], " ", "Tf", " ", 
     SubscriptBox["C", "A"], " ", 
     SubscriptBox["N", "f"], " ", 
     SubsuperscriptBox["g", "s", "4"], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"ci1", "ci2"}]], " ", 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["D",
         TraditionalForm], ")"}]],
      HighEnergyPhysics`Tarcer`TJI[
      D, $CellContext`pp, {{1, 0}, {1, 0}, {1, 0}}],
      Editable->True]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"4", "-", "D"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"6", "-", "D"}], ")"}]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.472902266274378*^9, 3.472902309827043*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"eta", "=", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"Gamma", "[", 
       RowBox[{
        FractionBox["D", "2"], "-", "1"}], "]"}], "2"], " ", 
     RowBox[{"Gamma", "[", 
      RowBox[{"3", "-", 
       FractionBox["D", "2"]}], "]"}]}], 
    RowBox[{"Gamma", "[", 
     RowBox[{"D", "-", "3"}], "]"}]]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TarcerExpand", "[", 
  RowBox[{
   FractionBox["ghselftf", 
    SuperscriptBox["eta", "2"]], ",", 
   RowBox[{"D", "\[Rule]", 
    RowBox[{"4", "-", 
     RowBox[{"2", " ", "Epsilon"}]}]}], ",", "0"}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pp", " ", "Tf", " ", 
     SubscriptBox["C", "A"], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["S", "HighEnergyPhysics`FeynCalc`Epsilon`Epsilon"],
        FontWeight->"Bold"],
       HighEnergyPhysics`Tarcer`SEpsilon[
       4 - 2 HighEnergyPhysics`FeynCalc`Epsilon`Epsilon],
       Editable->False], "2"], " ", 
     SubscriptBox["N", "f"], " ", 
     SubsuperscriptBox["g", "s", "4"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "pp"}], ")"}], 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       TagBox["\[CurlyEpsilon]",
        TraditionalForm]}]], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"ci1", "ci2"}]]}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["7", 
       RowBox[{"4", " ", 
        TagBox["\[CurlyEpsilon]",
         TraditionalForm]}]]}], "-", 
     FractionBox["1", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        TagBox["\[CurlyEpsilon]",
         TraditionalForm], "2"]}]], "-", 
     FractionBox["53", "8"]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.4729022694319267`*^9, 3.472902312744775*^9}]
}, Open  ]],

Cell[TextData[{
 "The above is exactly what is given in eq. (6.13) of \"A.I. Davydychev, \
P.Osland, O.V. Tarasov, Phy. Rev. D ",
 StyleBox["58",
  FontWeight->"Bold"],
 ", 036007 (1998)\"."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ghselfca", " ", "=", 
  RowBox[{"Collect2", "[", 
   RowBox[{
    RowBox[{"Plus", "@@", 
     RowBox[{"Drop", "[", 
      RowBox[{"result", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"TBI", ",", "TJI"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"pp", " ", 
     SubsuperscriptBox["C", "A", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["D", "2"], " ", 
        SuperscriptBox["\[Xi]", "2"]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["D", "2"], " ", "\[Xi]"}], "-", 
       RowBox[{"15", " ", "D", " ", 
        SuperscriptBox["\[Xi]", "2"]}], "+", 
       RowBox[{"58", " ", "D", " ", "\[Xi]"}], "-", 
       RowBox[{"16", " ", "D"}], "+", 
       RowBox[{"26", " ", 
        SuperscriptBox["\[Xi]", "2"]}], "-", 
       RowBox[{"104", " ", "\[Xi]"}], "+", "56"}], ")"}], " ", 
     SubsuperscriptBox["g", "s", "4"], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"ci1", "ci2"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       InterpretationBox[
        SubsuperscriptBox[
         StyleBox["B",
          SingleLetterItalics->False,
          FontWeight->"Bold"], 
         RowBox[{
          FormBox[
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}],
           TraditionalForm], 
          FormBox[
           RowBox[{"{", 
            RowBox[{"1", ",", "0"}], "}"}],
           TraditionalForm]}], 
         RowBox[{"(", 
          FormBox["D",
           TraditionalForm], ")"}]],
        HighEnergyPhysics`Tarcer`TBI[D, $CellContext`pp, {{1, 0}, {1, 0}}],
        Editable->True], ")"}], "2"]}], 
    RowBox[{"32", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "4"}], ")"}]}]], "-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"16", " ", 
      RowBox[{"(", 
       RowBox[{"D", "-", "6"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"D", "-", "4"}], ")"}], "2"]}]], 
    RowBox[{
     SubsuperscriptBox["C", "A", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", 
        SuperscriptBox["D", "5"], " ", 
        SuperscriptBox["\[Xi]", "2"]}], "-", 
       RowBox[{"115", " ", 
        SuperscriptBox["D", "4"], " ", 
        SuperscriptBox["\[Xi]", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["D", "4"], " ", "\[Xi]"}], "+", 
       RowBox[{"867", " ", 
        SuperscriptBox["D", "3"], " ", 
        SuperscriptBox["\[Xi]", "2"]}], "-", 
       RowBox[{"130", " ", 
        SuperscriptBox["D", "3"], " ", "\[Xi]"}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["D", "3"]}], "-", 
       RowBox[{"3216", " ", 
        SuperscriptBox["D", "2"], " ", 
        SuperscriptBox["\[Xi]", "2"]}], "+", 
       RowBox[{"1188", " ", 
        SuperscriptBox["D", "2"], " ", "\[Xi]"}], "+", 
       RowBox[{"24", " ", 
        SuperscriptBox["D", "2"]}], "+", 
       RowBox[{"5884", " ", "D", " ", 
        SuperscriptBox["\[Xi]", "2"]}], "-", 
       RowBox[{"3840", " ", "D", " ", "\[Xi]"}], "+", 
       RowBox[{"432", " ", "D"}], "-", 
       RowBox[{"4256", " ", 
        SuperscriptBox["\[Xi]", "2"]}], "+", 
       RowBox[{"4160", " ", "\[Xi]"}], "-", "1024"}], ")"}], " ", 
     SubsuperscriptBox["g", "s", "4"], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"ci1", "ci2"}]], " ", 
     InterpretationBox[
      SubsuperscriptBox[
       StyleBox["J",
        SingleLetterItalics->False,
        FontWeight->"Bold"], 
       RowBox[{
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm], 
        FormBox[
         RowBox[{"{", 
          RowBox[{"1", ",", "0"}], "}"}],
         TraditionalForm]}], 
       RowBox[{"(", 
        FormBox["D",
         TraditionalForm], ")"}]],
      HighEnergyPhysics`Tarcer`TJI[
      D, $CellContext`pp, {{1, 0}, {1, 0}, {1, 0}}],
      Editable->True]}]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.472902269837351*^9, 3.4729023225678062`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TarcerExpand", "[", 
  RowBox[{
   FractionBox["ghselfca", 
    SuperscriptBox["eta", "2"]], ",", 
   RowBox[{"D", "\[Rule]", 
    RowBox[{"4", "-", 
     RowBox[{"2", " ", "Epsilon"}]}]}], ",", "1"}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"pp", " ", 
     SubsuperscriptBox["C", "A", "2"], " ", 
     SuperscriptBox[
      InterpretationBox[
       StyleBox[
        SubscriptBox["S", "HighEnergyPhysics`FeynCalc`Epsilon`Epsilon"],
        FontWeight->"Bold"],
       HighEnergyPhysics`Tarcer`SEpsilon[
       4 - 2 HighEnergyPhysics`FeynCalc`Epsilon`Epsilon],
       Editable->False], "2"], " ", 
     SubsuperscriptBox["g", "s", "4"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "pp"}], ")"}], 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       TagBox["\[CurlyEpsilon]",
        TraditionalForm]}]], " ", 
     SubscriptBox["\[Delta]", 
      RowBox[{"ci1", "ci2"}]]}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      TagBox["\[CurlyEpsilon]",
       TraditionalForm], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"3", " ", 
              TemplateBox[{"3"},
               "Zeta"]}], "4"]}], "+", 
           FractionBox["17", "8"], "-", 
           FractionBox[
            SuperscriptBox["\[Pi]", "4"], "320"]}], ")"}], " ", 
         SuperscriptBox["\[Xi]", "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"3", " ", 
              TemplateBox[{"3"},
               "Zeta"]}], "2"]}], "-", 
           FractionBox["383", "128"]}], ")"}], " ", "\[Xi]"}], "-", 
        FractionBox[
         RowBox[{"15", " ", 
          TemplateBox[{"3"},
           "Zeta"]}], "2"], "-", 
        FractionBox[
         SuperscriptBox["\[Pi]", "4"], "80"], "+", 
        FractionBox["3881", "64"]}], ")"}]}], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       TemplateBox[{"3"},
        "Zeta"], " ", 
       SuperscriptBox["\[Xi]", "2"]}], "16"], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       TemplateBox[{"3"},
        "Zeta"]}], "4"], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         SuperscriptBox["\[Xi]", "2"], "32"]}], "+", 
       FractionBox[
        RowBox[{"7", " ", "\[Xi]"}], "16"], "+", 
       FractionBox["5", "4"]}], 
      SuperscriptBox[
       TagBox["\[CurlyEpsilon]",
        TraditionalForm], "2"]], "+", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{"7", " ", "\[Xi]"}], "32"], "+", 
       FractionBox["83", "16"]}], 
      TagBox["\[CurlyEpsilon]",
       TraditionalForm]], "+", 
     FractionBox[
      RowBox[{"3", " ", 
       SuperscriptBox["\[Xi]", "2"]}], "8"], "-", 
     FractionBox[
      RowBox[{"9", " ", "\[Xi]"}], "64"], "+", 
     FractionBox["599", "32"]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.472902269911478*^9, 3.4729023374245157`*^9}]
}, Open  ]],

Cell[TextData[{
 "This verifies eq. (6.12) of \"A.I. Davydychev, P.Osland, O.V. Tarasov, Phy. \
Rev. D ",
 StyleBox["58",
  FontWeight->"Bold"],
 ", 036007 (1998)\"."
}], "Text"]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{1036, 602},
WindowMargins->{{107, Automatic}, {Automatic, 21}},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"8.0 for Linux x86 (32-bit) (February 23, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3472905995-6725410"->{
  Cell[116778, 2758, 179, 4, 61, "Print",
   CellTags->"Info3472905995-6725410"]},
 "Info3472906071-3368256"->{
  Cell[116490, 2747, 137, 2, 62, "Print",
   CellTags->"Info3472906071-3368256"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3472905995-6725410", 128441, 3152},
 {"Info3472906071-3368256", 128553, 3155}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 50, 0, 57, "Subsection"],
Cell[620, 24, 71, 1, 44, "Input"],
Cell[694, 27, 205, 4, 23, "Text"],
Cell[902, 33, 683, 22, 24, "Text"],
Cell[1588, 57, 371, 12, 23, "Text"],
Cell[1962, 71, 196, 4, 23, "Text"],
Cell[CellGroupData[{
Cell[2183, 79, 35, 0, 40, "Subsubsection"],
Cell[CellGroupData[{
Cell[2243, 83, 1092, 27, 213, "Input"],
Cell[3338, 112, 76945, 1485, 282, 64171, 1274, "CachedBoxData", "BoxData", \
"Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[80332, 1603, 96, 2, 40, "Subsubsection"],
Cell[80431, 1607, 75, 2, 44, "Input"],
Cell[80509, 1611, 74, 0, 43, "Text"],
Cell[CellGroupData[{
Cell[80608, 1615, 981, 26, 129, "Input"],
Cell[81592, 1643, 178, 4, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81807, 1652, 61, 1, 44, "Input"],
Cell[81871, 1655, 15556, 486, 296, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[97488, 2148, 59, 0, 57, "Subsection"],
Cell[97550, 2150, 76, 0, 43, "Text"],
Cell[CellGroupData[{
Cell[97651, 2154, 688, 23, 73, "Input"],
Cell[98342, 2179, 1278, 41, 69, "Output"]
}, Open  ]],
Cell[99635, 2223, 76, 0, 43, "Text"],
Cell[CellGroupData[{
Cell[99736, 2227, 425, 15, 44, "Input"],
Cell[100164, 2244, 951, 28, 49, "Output"]
}, Open  ]],
Cell[101130, 2275, 223, 7, 44, "Input"],
Cell[101356, 2284, 1119, 30, 241, "Input"],
Cell[102478, 2316, 1027, 27, 185, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103542, 2348, 53, 0, 57, "Subsection"],
Cell[103598, 2350, 76, 2, 44, "Input"],
Cell[103677, 2354, 124, 4, 44, "Input"],
Cell[103804, 2360, 56, 0, 43, "Text"],
Cell[CellGroupData[{
Cell[103885, 2364, 962, 27, 157, "Input"],
Cell[CellGroupData[{
Cell[104872, 2395, 546, 12, 34, "Print"],
Cell[105421, 2409, 549, 12, 34, "Print"],
Cell[105973, 2423, 547, 12, 34, "Print"],
Cell[106523, 2437, 546, 12, 34, "Print"],
Cell[107072, 2451, 547, 12, 34, "Print"],
Cell[107622, 2465, 549, 12, 34, "Print"],
Cell[108174, 2479, 549, 12, 34, "Print"]
}, Open  ]],
Cell[108738, 2494, 178, 4, 44, "Output"]
}, Open  ]],
Cell[108931, 2501, 147, 4, 44, "Input"],
Cell[CellGroupData[{
Cell[109103, 2509, 61, 1, 44, "Input"],
Cell[109167, 2512, 100, 2, 44, "Output"]
}, Open  ]],
Cell[109282, 2517, 435, 7, 123, "Text"],
Cell[CellGroupData[{
Cell[109742, 2528, 811, 22, 213, "Input"],
Cell[110556, 2552, 736, 11, 34, "Print"],
Cell[111295, 2565, 171, 5, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[111503, 2575, 460, 13, 101, "Input"],
Cell[111966, 2590, 195, 5, 44, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112198, 2600, 82, 2, 44, "Input"],
Cell[112283, 2604, 3266, 101, 180, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115586, 2710, 99, 2, 44, "Input"],
Cell[115688, 2714, 211, 5, 91, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115936, 2724, 62, 1, 44, "Input"],
Cell[116001, 2727, 152, 2, 44, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[116202, 2735, 123, 3, 57, "Subsection"],
Cell[CellGroupData[{
Cell[116350, 2742, 137, 3, 44, "Input"],
Cell[116490, 2747, 137, 2, 62, "Print",
 CellTags->"Info3472906071-3368256"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116664, 2754, 111, 2, 44, "Input"],
Cell[116778, 2758, 179, 4, 61, "Print",
 CellTags->"Info3472905995-6725410"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116994, 2767, 118, 3, 44, "Input"],
Cell[117115, 2772, 1271, 42, 81, "Output"]
}, Open  ]],
Cell[118401, 2817, 382, 13, 89, "Input"],
Cell[CellGroupData[{
Cell[118808, 2834, 242, 7, 72, "Input"],
Cell[119053, 2843, 1226, 38, 68, "Output"]
}, Open  ]],
Cell[120294, 2884, 202, 6, 70, "Text"],
Cell[CellGroupData[{
Cell[120521, 2894, 327, 10, 44, "Input"],
Cell[120851, 2906, 3867, 115, 213, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[124755, 3026, 242, 7, 72, "Input"],
Cell[125000, 3035, 2861, 92, 236, "Output"]
}, Open  ]],
Cell[127876, 3130, 178, 6, 43, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
